// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qrhitexturerendertarget_wrapper.h"

// Argument includes
#include <qsize.h>
#include <rhi/qrhi.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QRhiTextureRenderTargetWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

bool QRhiTextureRenderTargetWrapper::create()
{
    if (m_PyMethodCache[0]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QRhiTextureRenderTarget.create");
        return false;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "create";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        Shiboken::Errors::setPureVirtualMethodError("QRhiTextureRenderTarget.create");
        return false;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRhiTextureRenderTarget", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QRhiTextureRenderTarget", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QRhiTextureRenderTargetWrapper::destroy()
{
    if (m_PyMethodCache[1]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QRhiTextureRenderTarget.destroy");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "destroy";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        Shiboken::Errors::setPureVirtualMethodError("QRhiTextureRenderTarget.destroy");
        return;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRhiTextureRenderTarget", funcName);
        return;
    }
}

float QRhiTextureRenderTargetWrapper::devicePixelRatio() const
{
    if (m_PyMethodCache[2]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QRhiTextureRenderTarget.devicePixelRatio");
        return 0;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return 0;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "devicePixelRatio";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        Shiboken::Errors::setPureVirtualMethodError("QRhiTextureRenderTarget.devicePixelRatio");
        return 0;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRhiTextureRenderTarget", funcName);
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QRhiTextureRenderTarget", funcName, "float", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    float cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QRhiRenderPassDescriptor * QRhiTextureRenderTargetWrapper::newCompatibleRenderPassDescriptor()
{
    if (m_PyMethodCache[3]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QRhiTextureRenderTarget.newCompatibleRenderPassDescriptor");
        return nullptr;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "newCompatibleRenderPassDescriptor";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        Shiboken::Errors::setPureVirtualMethodError("QRhiTextureRenderTarget.newCompatibleRenderPassDescriptor");
        return nullptr;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRhiTextureRenderTarget", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderPassDescriptor_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QRhiTextureRenderTarget", funcName, Shiboken::SbkType< QRhiRenderPassDescriptor >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QRhiRenderPassDescriptor *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QSize QRhiTextureRenderTargetWrapper::pixelSize() const
{
    if (m_PyMethodCache[4]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QRhiTextureRenderTarget.pixelSize");
        return {};
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return {};
    static PyObject *nameCache[2] = {};
    static const char *funcName = "pixelSize";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        Shiboken::Errors::setPureVirtualMethodError("QRhiTextureRenderTarget.pixelSize");
        return {};
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRhiTextureRenderTarget", funcName);
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QRhiTextureRenderTarget", funcName, Shiboken::SbkType< QSize >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QSize cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QRhiResource::Type QRhiTextureRenderTargetWrapper::resourceType() const
{
    if (m_PyMethodCache[5])
        return this->::QRhiTextureRenderTarget::resourceType();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return QRhiResource::Buffer;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "resourceType";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QRhiTextureRenderTarget::resourceType();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRhiTextureRenderTarget", funcName);
        return QRhiResource::Buffer;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResource_Type_IDX])))->converter, pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QRhiTextureRenderTarget", funcName, Shiboken::SbkType< QRhiResource::Type >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return QRhiResource::Buffer;
    }
    ::QRhiResource::Type cppResult{QRhiResource::Buffer};
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

int QRhiTextureRenderTargetWrapper::sampleCount() const
{
    if (m_PyMethodCache[6]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QRhiTextureRenderTarget.sampleCount");
        return 0;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return 0;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "sampleCount";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        Shiboken::Errors::setPureVirtualMethodError("QRhiTextureRenderTarget.sampleCount");
        return 0;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRhiTextureRenderTarget", funcName);
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QRhiTextureRenderTarget", funcName, "int", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    int cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QRhiTextureRenderTargetWrapper::~QRhiTextureRenderTargetWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QRhiTextureRenderTargetFunc_create(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTextureRenderTarget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTarget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // create()
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QRhiTextureRenderTarget.create");
            return {};
        }
        bool cppResult = cppSelf->create();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiTextureRenderTargetFunc_description(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTextureRenderTarget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTarget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // description()const
        QRhiTextureRenderTargetDescription cppResult = const_cast<const ::QRhiTextureRenderTarget *>(cppSelf)->description();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTargetDescription_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiTextureRenderTargetFunc_flags(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTextureRenderTarget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTarget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // flags()const
        QFlags<QRhiTextureRenderTarget::Flag> cppResult = const_cast<const ::QRhiTextureRenderTarget *>(cppSelf)->flags();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiTextureRenderTarget_Flag_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiTextureRenderTargetFunc_newCompatibleRenderPassDescriptor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTextureRenderTarget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTarget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // newCompatibleRenderPassDescriptor()
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QRhiTextureRenderTarget.newCompatibleRenderPassDescriptor");
            return {};
        }
        QRhiRenderPassDescriptor * cppResult = cppSelf->newCompatibleRenderPassDescriptor();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderPassDescriptor_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiTextureRenderTargetFunc_resourceType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTextureRenderTarget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTarget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // resourceType()const
        QRhiResource::Type cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QRhiTextureRenderTarget *>(cppSelf)->::QRhiTextureRenderTarget::resourceType()
            : const_cast<const ::QRhiTextureRenderTarget *>(cppSelf)->resourceType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResource_Type_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiTextureRenderTargetFunc_setDescription(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTextureRenderTarget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTarget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiTextureRenderTarget::setDescription(QRhiTextureRenderTargetDescription)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTargetDescription_IDX]), (pyArg)))) {
        overloadId = 0; // setDescription(QRhiTextureRenderTargetDescription)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDescription", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTarget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRhiTextureRenderTargetDescription cppArg0_local;
        ::QRhiTextureRenderTargetDescription *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setDescription(QRhiTextureRenderTargetDescription)
            cppSelf->setDescription(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiTextureRenderTargetFunc_setFlags(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTextureRenderTarget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTarget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiTextureRenderTarget::setFlags(QFlags<QRhiTextureRenderTarget::Flag>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiTextureRenderTarget_Flag_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setFlags(QFlags<QRhiTextureRenderTarget::Flag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFlags", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTarget_IDX]);

    // Call function/method
    {
        ::QFlags<QRhiTextureRenderTarget::Flag> cppArg0 = QFlags<QRhiTextureRenderTarget::Flag>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFlags(QFlags<QRhiTextureRenderTarget::Flag>)
            cppSelf->setFlags(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QRhiTextureRenderTarget_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QRhiTextureRenderTarget_EnumFlagInfo[] = {
    "Flag:Flag:Flags",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QRhiTextureRenderTarget_methods[] = {
    {"create", reinterpret_cast<PyCFunction>(Sbk_QRhiTextureRenderTargetFunc_create), METH_NOARGS, nullptr},
    {"description", reinterpret_cast<PyCFunction>(Sbk_QRhiTextureRenderTargetFunc_description), METH_NOARGS, nullptr},
    {"flags", reinterpret_cast<PyCFunction>(Sbk_QRhiTextureRenderTargetFunc_flags), METH_NOARGS, nullptr},
    {"newCompatibleRenderPassDescriptor", reinterpret_cast<PyCFunction>(Sbk_QRhiTextureRenderTargetFunc_newCompatibleRenderPassDescriptor), METH_NOARGS, nullptr},
    {"resourceType", reinterpret_cast<PyCFunction>(Sbk_QRhiTextureRenderTargetFunc_resourceType), METH_NOARGS, nullptr},
    {"setDescription", reinterpret_cast<PyCFunction>(Sbk_QRhiTextureRenderTargetFunc_setDescription), METH_O, nullptr},
    {"setFlags", reinterpret_cast<PyCFunction>(Sbk_QRhiTextureRenderTargetFunc_setFlags), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QRhiTextureRenderTarget_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QRhiTextureRenderTarget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTarget_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QRhiTextureRenderTargetWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

static PyObject *Sbk_QRhiTextureRenderTarget_get_m_desc(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTextureRenderTarget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTarget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    if (reinterpret_cast<void *>(&(cppSelf->m_desc)) == reinterpret_cast<void *>(cppSelf)) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::Object::findColocatedChild(reinterpret_cast<SbkObject *>(self), Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTargetDescription_IDX])));
        if (pyOut != nullptr) {
            Py_IncRef(pyOut);
            return pyOut;
        }
    } else if (Shiboken::BindingManager::instance().hasWrapper(&(cppSelf->m_desc))) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(&(cppSelf->m_desc)));
        Py_IncRef(pyOut);
        return pyOut;
    }
    pyOut = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTargetDescription_IDX]), &(cppSelf->m_desc), false, true);
    Shiboken::Object::setParent(self, pyOut);
    return pyOut;
}
static int Sbk_QRhiTextureRenderTarget_set_m_desc(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiTextureRenderTarget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTarget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_desc");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTargetDescription_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_desc", "QRhiTextureRenderTargetDescription");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->m_desc;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

static PyObject *Sbk_QRhiTextureRenderTarget_get_m_flags(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTextureRenderTarget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTarget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiTextureRenderTarget_Flag_IDX])))->flagsConverter, &cppSelf->m_flags);
    return pyOut;
}
static int Sbk_QRhiTextureRenderTarget_set_m_flags(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiTextureRenderTarget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTarget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_flags");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiTextureRenderTarget_Flag_IDX])))->flagsConverter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_flags", "Flags");
        return -1;
    }

    auto cppOut_local = cppSelf->m_flags;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_flags = cppOut_local;

    return 0;
}

// Getters and Setters for QRhiTextureRenderTarget
static PyGetSetDef Sbk_QRhiTextureRenderTarget_getsetlist[] = {
    {const_cast<char *>("m_desc"), Sbk_QRhiTextureRenderTarget_get_m_desc, Sbk_QRhiTextureRenderTarget_set_m_desc, nullptr, nullptr},
    {const_cast<char *>("m_flags"), Sbk_QRhiTextureRenderTarget_get_m_flags, Sbk_QRhiTextureRenderTarget_set_m_flags, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QRhiTextureRenderTarget_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QRhiTextureRenderTarget_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QRhiTextureRenderTarget_Type = nullptr;
static PyTypeObject *Sbk_QRhiTextureRenderTarget_TypeF(void)
{
    return _Sbk_QRhiTextureRenderTarget_Type;
}

static PyType_Slot Sbk_QRhiTextureRenderTarget_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QRhiTextureRenderTarget_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QRhiTextureRenderTarget_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QRhiTextureRenderTarget_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QRhiTextureRenderTarget_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QRhiTextureRenderTarget_getsetlist)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QRhiTextureRenderTarget_spec = {
    "2:PySide6.QtGui.QRhiTextureRenderTarget",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QRhiTextureRenderTarget_slots
};

} //extern "C"

static void *Sbk_QRhiTextureRenderTarget_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QRhiResource >())
        return dynamic_cast< ::QRhiTextureRenderTarget *>(reinterpret_cast< ::QRhiResource *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QRhiTextureRenderTarget_Flag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhiTextureRenderTarget::Flag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhiTextureRenderTarget::Flag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QRhiTextureRenderTarget_Flag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTarget_Flag_IDX])))
        return Enum_PythonToCpp_QRhiTextureRenderTarget_Flag;
    return {};
}

static PyObject *QRhiTextureRenderTarget_Flag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QRhiTextureRenderTarget::Flag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QRhiTextureRenderTarget::Flag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTarget_Flag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QRhiTextureRenderTarget_Flag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QRhiTextureRenderTarget::Flag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QRhiTextureRenderTarget::Flag> *>(cppOut) = value;

}

static PyObject *QRhiTextureRenderTarget_Flag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QRhiTextureRenderTarget::Flag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTarget_Flag_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QRhiTextureRenderTarget_PythonToCpp_QRhiTextureRenderTarget_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QRhiTextureRenderTarget_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QRhiTextureRenderTarget_PythonToCpp_QRhiTextureRenderTarget_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QRhiTextureRenderTarget_TypeF()))
        return QRhiTextureRenderTarget_PythonToCpp_QRhiTextureRenderTarget_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QRhiTextureRenderTarget_PTR_CppToPython_QRhiTextureRenderTarget(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QRhiTextureRenderTarget *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QRhiTextureRenderTarget_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QRhiTextureRenderTarget_SignatureStrings[] = {
    "PySide6.QtGui.QRhiTextureRenderTarget.create(self)->bool",
    "PySide6.QtGui.QRhiTextureRenderTarget.description(self)->PySide6.QtGui.QRhiTextureRenderTargetDescription",
    "PySide6.QtGui.QRhiTextureRenderTarget.flags(self)->PySide6.QtGui.QRhiTextureRenderTarget.Flag",
    "PySide6.QtGui.QRhiTextureRenderTarget.newCompatibleRenderPassDescriptor(self)->PySide6.QtGui.QRhiRenderPassDescriptor",
    "PySide6.QtGui.QRhiTextureRenderTarget.resourceType(self)->PySide6.QtGui.QRhiResource.Type",
    "PySide6.QtGui.QRhiTextureRenderTarget.setDescription(self,desc:typing.Union[PySide6.QtGui.QRhiTextureRenderTargetDescription, PySide6.QtGui.QRhiColorAttachment])",
    "PySide6.QtGui.QRhiTextureRenderTarget.setFlags(self,f:PySide6.QtGui.QRhiTextureRenderTarget.Flag)",
    nullptr}; // Sentinel
#else
static constexpr size_t QRhiTextureRenderTarget_SignatureByteSize = 201;
static constexpr uint8_t QRhiTextureRenderTarget_SignatureBytes[201] = {
    0x78, 0xda, 0x95, 0x91, 0xbd, 0x0e, 0x82, 0x40, 0x10, 0x84, 0x7b, 0x9e, 0xc2, 0x52, 0x12, 0xbc,
    0xd2, 0x82, 0xc2, 0xc4, 0x60, 0xb0, 0x05, 0xc4, 0xca, 0x58, 0x1c, 0xb0, 0xe0, 0x25, 0xc7, 0x1d,
    0xd9, 0x5b, 0xa2, 0xbc, 0xbd, 0xa0, 0xa2, 0x31, 0xfe, 0xe4, 0x68, 0x77, 0xe7, 0x9b, 0xd9, 0xec,
    0x44, 0xdd, 0x4e, 0x14, 0xb0, 0x64, 0x31, 0x6d, 0x5b, 0xc1, 0xe2, 0xe4, 0x24, 0x52, 0xb8, 0x50,
    0x8b, 0x90, 0x80, 0x2a, 0x00, 0x53, 0x8e, 0x15, 0x10, 0xcb, 0x11, 0x38, 0xc1, 0xdc, 0x80, 0x2c,
    0xdd, 0xc5, 0x2a, 0xd3, 0x5a, 0x3a, 0x91, 0x15, 0x58, 0x80, 0xc9, 0x51, 0x34, 0x24, 0xb4, 0x1a,
    0x69, 0x2b, 0x70, 0xf3, 0xe2, 0x2c, 0x93, 0x4a, 0xc9, 0x2b, 0x33, 0x29, 0x83, 0x85, 0x3d, 0x62,
    0xe9, 0xae, 0xe0, 0x1c, 0xe8, 0xba, 0xe1, 0x24, 0x32, 0xf9, 0xd8, 0x44, 0xdc, 0x98, 0xf1, 0x4c,
    0x8d, 0xbf, 0x93, 0xbf, 0xa9, 0x2d, 0x53, 0x11, 0x8c, 0x6e, 0x31, 0x87, 0xb4, 0x6b, 0xe0, 0x5f,
    0xc0, 0x5d, 0xc5, 0x06, 0x99, 0xa5, 0xb3, 0x79, 0x7b, 0xf1, 0xcd, 0xdb, 0x1b, 0xba, 0xf2, 0xa9,
    0x6b, 0x84, 0xaa, 0xd8, 0x5e, 0xf5, 0xe3, 0xc3, 0xd4, 0xaa, 0xbc, 0xd9, 0x27, 0x11, 0x68, 0xa9,
    0x71, 0x4d, 0xc4, 0xf3, 0x53, 0x0d, 0x8a, 0x8e, 0xae, 0xfd, 0x85, 0xe1, 0xb3, 0x52, 0xaf, 0xf4,
    0xed, 0x2b, 0x75, 0x9d, 0x2b, 0xb5, 0x3f, 0x0c, 0x51
};
#endif

PyTypeObject *init_QRhiTextureRenderTarget(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTarget_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTarget_IDX].type;

    Shiboken::AutoDecRef Sbk_QRhiTextureRenderTarget_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderTarget_IDX]))));

    _Sbk_QRhiTextureRenderTarget_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QRhiTextureRenderTarget",
        "QRhiTextureRenderTarget*",
        &Sbk_QRhiTextureRenderTarget_spec,
        &Shiboken::callCppDestructor< QRhiTextureRenderTarget >,
        Sbk_QRhiTextureRenderTarget_Type_bases.object(),
        0);
    auto *pyType = Sbk_QRhiTextureRenderTarget_TypeF(); // references _Sbk_QRhiTextureRenderTarget_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QRhiTextureRenderTarget_SignatureStrings);
#else
    InitSignatureBytes(pyType, QRhiTextureRenderTarget_SignatureBytes, QRhiTextureRenderTarget_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QRhiTextureRenderTarget_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTarget_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QRhiTextureRenderTarget_PythonToCpp_QRhiTextureRenderTarget_PTR,
        is_QRhiTextureRenderTarget_PythonToCpp_QRhiTextureRenderTarget_PTR_Convertible,
        QRhiTextureRenderTarget_PTR_CppToPython_QRhiTextureRenderTarget);

    Shiboken::Conversions::registerConverterName(converter, "QRhiTextureRenderTarget");
    Shiboken::Conversions::registerConverterName(converter, "QRhiTextureRenderTarget*");
    Shiboken::Conversions::registerConverterName(converter, "QRhiTextureRenderTarget&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QRhiTextureRenderTarget).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QRhiTextureRenderTargetWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QRhiTextureRenderTarget_TypeF(), &Sbk_QRhiTextureRenderTarget_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QRhiTextureRenderTarget_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Flag'.
    const char *Flag_Initializer[] = {
        "PreserveColorContents",
        "PreserveDepthStencilContents",
        "DoNotStoreDepthStencilContents",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Flag_InitializerValues[] = {
        uint8_t(QRhiTextureRenderTarget::Flag::PreserveColorContents),         //  0x01  1
        uint8_t(QRhiTextureRenderTarget::Flag::PreserveDepthStencilContents),  //  0x02  2
        uint8_t(QRhiTextureRenderTarget::Flag::DoNotStoreDepthStencilContents) //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhiTextureRenderTarget_TypeF(),
        "2:PySide6.QtGui.QRhiTextureRenderTarget.Flag",
        Flag_Initializer, Flag_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTarget_Flag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiTextureRenderTarget_Flag_IDX].type =
        EType;
    // Register converter for enum 'QRhiTextureRenderTarget::Flag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhiTextureRenderTarget_Flag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QRhiTextureRenderTarget_Flag,
            is_Enum_PythonToCpp_QRhiTextureRenderTarget_Flag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QRhiTextureRenderTarget::Flag");
        Shiboken::Conversions::registerConverterAlias(converter, "Flag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QRhiTextureRenderTarget_Flag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QRhiTextureRenderTarget_Flag,
            is_Enum_PythonToCpp_QRhiTextureRenderTarget_Flag_Convertible);
        // Register converter for flag 'QFlags<QRhiTextureRenderTarget::Flag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QRhiTextureRenderTarget::Flag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QRhiTextureRenderTarget::Flags");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'Flag' enum/flags.

    qRegisterMetaType< ::QRhiTextureRenderTarget *>();
    qRegisterMetaType< ::QRhiTextureRenderTarget::Flag >("QRhiTextureRenderTarget::Flag");

    return pyType;
}
