// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qrhitexturerendertargetdescription_wrapper.h"

// Argument includes
#include <QList>
#include <rhi/qrhi.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QRhiTextureRenderTargetDescription_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QRhiTextureRenderTargetDescription >()))
        return -1;

    ::QRhiTextureRenderTargetDescription *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QRhiTextureRenderTargetDescription", 0, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QRhiTextureRenderTargetDescription::QRhiTextureRenderTargetDescription()
    // 1: QRhiTextureRenderTargetDescription::QRhiTextureRenderTargetDescription(QRhiColorAttachment)
    // 2: QRhiTextureRenderTargetDescription::QRhiTextureRenderTargetDescription(QRhiColorAttachment,QRhiRenderBuffer*)
    // 3: QRhiTextureRenderTargetDescription::QRhiTextureRenderTargetDescription(QRhiColorAttachment,QRhiTexture*)
    // 4: QRhiTextureRenderTargetDescription::QRhiTextureRenderTargetDescription(QRhiTextureRenderTargetDescription)
    if (numArgs == 0) {
        overloadId = 0; // QRhiTextureRenderTargetDescription()
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiColorAttachment_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QRhiTextureRenderTargetDescription(QRhiColorAttachment)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), (pyArgs[1])))) {
            overloadId = 3; // QRhiTextureRenderTargetDescription(QRhiColorAttachment,QRhiTexture*)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_IDX]), (pyArgs[1])))) {
            overloadId = 2; // QRhiTextureRenderTargetDescription(QRhiColorAttachment,QRhiRenderBuffer*)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTargetDescription_IDX]), (pyArgs[0])))) {
        overloadId = 4; // QRhiTextureRenderTargetDescription(QRhiTextureRenderTargetDescription)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTargetDescription_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTargetDescription_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QRhiTextureRenderTargetDescription()
        {

            // QRhiTextureRenderTargetDescription()
            cptr = new ::QRhiTextureRenderTargetDescription();
            break;
        }
        case 1: // QRhiTextureRenderTargetDescription(const QRhiColorAttachment &colorAttachment)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QRhiColorAttachment cppArg0_local;
            ::QRhiColorAttachment *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QRhiTextureRenderTargetDescription(QRhiColorAttachment)
                cptr = new ::QRhiTextureRenderTargetDescription(*cppArg0);
            }
            break;
        }
        case 2: // QRhiTextureRenderTargetDescription(const QRhiColorAttachment &colorAttachment, QRhiRenderBuffer *depthStencilBuffer)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QRhiColorAttachment cppArg0_local;
            ::QRhiColorAttachment *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QRhiRenderBuffer *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QRhiTextureRenderTargetDescription(QRhiColorAttachment,QRhiRenderBuffer*)
                cptr = new ::QRhiTextureRenderTargetDescription(*cppArg0, cppArg1);
            }
            break;
        }
        case 3: // QRhiTextureRenderTargetDescription(const QRhiColorAttachment &colorAttachment, QRhiTexture *depthTexture)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QRhiColorAttachment cppArg0_local;
            ::QRhiColorAttachment *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QRhiTexture *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QRhiTextureRenderTargetDescription(QRhiColorAttachment,QRhiTexture*)
                cptr = new ::QRhiTextureRenderTargetDescription(*cppArg0, cppArg1);
            }
            break;
        }
        case 4: // QRhiTextureRenderTargetDescription(const QRhiTextureRenderTargetDescription &QRhiTextureRenderTargetDescription)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QRhiTextureRenderTargetDescription cppArg0_local;
            ::QRhiTextureRenderTargetDescription *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QRhiTextureRenderTargetDescription(QRhiTextureRenderTargetDescription)
                cptr = new ::QRhiTextureRenderTargetDescription(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QRhiTextureRenderTargetDescription >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTargetDescription_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QRhiTextureRenderTargetDescriptionFunc_cbeginColorAttachments(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTextureRenderTargetDescription *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTargetDescription_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cbeginColorAttachments()const
        const QRhiColorAttachment * cppResult = const_cast<const ::QRhiTextureRenderTargetDescription *>(cppSelf)->cbeginColorAttachments();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiColorAttachment_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiTextureRenderTargetDescriptionFunc_cendColorAttachments(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTextureRenderTargetDescription *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTargetDescription_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cendColorAttachments()const
        const QRhiColorAttachment * cppResult = const_cast<const ::QRhiTextureRenderTargetDescription *>(cppSelf)->cendColorAttachments();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiColorAttachment_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiTextureRenderTargetDescriptionFunc_colorAttachmentAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTextureRenderTargetDescription *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTargetDescription_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiTextureRenderTargetDescription::colorAttachmentAt(qsizetype)const->const QRhiColorAttachment*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // colorAttachmentAt(qsizetype)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "colorAttachmentAt", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTargetDescription_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // colorAttachmentAt(qsizetype)const
            const QRhiColorAttachment * cppResult = const_cast<const ::QRhiTextureRenderTargetDescription *>(cppSelf)->colorAttachmentAt(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiColorAttachment_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiTextureRenderTargetDescriptionFunc_colorAttachmentCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTextureRenderTargetDescription *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTargetDescription_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // colorAttachmentCount()const
        qsizetype cppResult = const_cast<const ::QRhiTextureRenderTargetDescription *>(cppSelf)->colorAttachmentCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiTextureRenderTargetDescriptionFunc_depthResolveTexture(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTextureRenderTargetDescription *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTargetDescription_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // depthResolveTexture()const
        QRhiTexture * cppResult = const_cast<const ::QRhiTextureRenderTargetDescription *>(cppSelf)->depthResolveTexture();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiTextureRenderTargetDescriptionFunc_depthStencilBuffer(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTextureRenderTargetDescription *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTargetDescription_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // depthStencilBuffer()const
        QRhiRenderBuffer * cppResult = const_cast<const ::QRhiTextureRenderTargetDescription *>(cppSelf)->depthStencilBuffer();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiTextureRenderTargetDescriptionFunc_depthTexture(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTextureRenderTargetDescription *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTargetDescription_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // depthTexture()const
        QRhiTexture * cppResult = const_cast<const ::QRhiTextureRenderTargetDescription *>(cppSelf)->depthTexture();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiTextureRenderTargetDescriptionFunc_setColorAttachments(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTextureRenderTargetDescription *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTargetDescription_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiTextureRenderTargetDescription::setColorAttachments(QList<QRhiColorAttachment>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QRhiColorAttachment_IDX], (pyArg)))) {
        overloadId = 0; // setColorAttachments(QList<QRhiColorAttachment>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setColorAttachments", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTargetDescription_IDX]);

    // Call function/method
    {
        ::QList<QRhiColorAttachment> cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        SBK_UNUSED(cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // setColorAttachments(QList<QRhiColorAttachment>)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtgui.cpp (qrhi-initializer-list)]
            cppSelf->setColorAttachments(cppArg0.cbegin(), cppArg0.cend());
            // END of custom code block [file: ../glue/qtgui.cpp (qrhi-initializer-list)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiTextureRenderTargetDescriptionFunc_setDepthResolveTexture(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTextureRenderTargetDescription *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTargetDescription_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiTextureRenderTargetDescription::setDepthResolveTexture(QRhiTexture*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), (pyArg)))) {
        overloadId = 0; // setDepthResolveTexture(QRhiTexture*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDepthResolveTexture", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTargetDescription_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRhiTexture *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDepthResolveTexture(QRhiTexture*)
            cppSelf->setDepthResolveTexture(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiTextureRenderTargetDescriptionFunc_setDepthStencilBuffer(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTextureRenderTargetDescription *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTargetDescription_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiTextureRenderTargetDescription::setDepthStencilBuffer(QRhiRenderBuffer*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_IDX]), (pyArg)))) {
        overloadId = 0; // setDepthStencilBuffer(QRhiRenderBuffer*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDepthStencilBuffer", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTargetDescription_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRhiRenderBuffer *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDepthStencilBuffer(QRhiRenderBuffer*)
            cppSelf->setDepthStencilBuffer(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiTextureRenderTargetDescriptionFunc_setDepthTexture(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTextureRenderTargetDescription *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTargetDescription_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiTextureRenderTargetDescription::setDepthTexture(QRhiTexture*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), (pyArg)))) {
        overloadId = 0; // setDepthTexture(QRhiTexture*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDepthTexture", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTargetDescription_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRhiTexture *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDepthTexture(QRhiTexture*)
            cppSelf->setDepthTexture(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiTextureRenderTargetDescription__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QRhiTextureRenderTargetDescription *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTargetDescription_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTargetDescription_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QRhiTextureRenderTargetDescription_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QRhiTextureRenderTargetDescription_methods[] = {
    {"cbeginColorAttachments", reinterpret_cast<PyCFunction>(Sbk_QRhiTextureRenderTargetDescriptionFunc_cbeginColorAttachments), METH_NOARGS, nullptr},
    {"cendColorAttachments", reinterpret_cast<PyCFunction>(Sbk_QRhiTextureRenderTargetDescriptionFunc_cendColorAttachments), METH_NOARGS, nullptr},
    {"colorAttachmentAt", reinterpret_cast<PyCFunction>(Sbk_QRhiTextureRenderTargetDescriptionFunc_colorAttachmentAt), METH_O, nullptr},
    {"colorAttachmentCount", reinterpret_cast<PyCFunction>(Sbk_QRhiTextureRenderTargetDescriptionFunc_colorAttachmentCount), METH_NOARGS, nullptr},
    {"depthResolveTexture", reinterpret_cast<PyCFunction>(Sbk_QRhiTextureRenderTargetDescriptionFunc_depthResolveTexture), METH_NOARGS, nullptr},
    {"depthStencilBuffer", reinterpret_cast<PyCFunction>(Sbk_QRhiTextureRenderTargetDescriptionFunc_depthStencilBuffer), METH_NOARGS, nullptr},
    {"depthTexture", reinterpret_cast<PyCFunction>(Sbk_QRhiTextureRenderTargetDescriptionFunc_depthTexture), METH_NOARGS, nullptr},
    {"setColorAttachments", reinterpret_cast<PyCFunction>(Sbk_QRhiTextureRenderTargetDescriptionFunc_setColorAttachments), METH_O, nullptr},
    {"setDepthResolveTexture", reinterpret_cast<PyCFunction>(Sbk_QRhiTextureRenderTargetDescriptionFunc_setDepthResolveTexture), METH_O, nullptr},
    {"setDepthStencilBuffer", reinterpret_cast<PyCFunction>(Sbk_QRhiTextureRenderTargetDescriptionFunc_setDepthStencilBuffer), METH_O, nullptr},
    {"setDepthTexture", reinterpret_cast<PyCFunction>(Sbk_QRhiTextureRenderTargetDescriptionFunc_setDepthTexture), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QRhiTextureRenderTargetDescription__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QRhiTextureRenderTargetDescription_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QRhiTextureRenderTargetDescription_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QRhiTextureRenderTargetDescription_Type = nullptr;
static PyTypeObject *Sbk_QRhiTextureRenderTargetDescription_TypeF(void)
{
    return _Sbk_QRhiTextureRenderTargetDescription_Type;
}

static PyType_Slot Sbk_QRhiTextureRenderTargetDescription_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QRhiTextureRenderTargetDescription_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QRhiTextureRenderTargetDescription_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QRhiTextureRenderTargetDescription_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QRhiTextureRenderTargetDescription_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QRhiTextureRenderTargetDescription_spec = {
    "2:PySide6.QtGui.QRhiTextureRenderTargetDescription",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QRhiTextureRenderTargetDescription_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QRhiTextureRenderTargetDescription_PythonToCpp_QRhiTextureRenderTargetDescription_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QRhiTextureRenderTargetDescription_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QRhiTextureRenderTargetDescription_PythonToCpp_QRhiTextureRenderTargetDescription_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QRhiTextureRenderTargetDescription_TypeF()))
        return QRhiTextureRenderTargetDescription_PythonToCpp_QRhiTextureRenderTargetDescription_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QRhiTextureRenderTargetDescription_PTR_CppToPython_QRhiTextureRenderTargetDescription(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QRhiTextureRenderTargetDescription_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QRhiTextureRenderTargetDescription_COPY_CppToPython_QRhiTextureRenderTargetDescription(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QRhiTextureRenderTargetDescription *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QRhiTextureRenderTargetDescription_TypeF(), new ::QRhiTextureRenderTargetDescription(*source), true, true);
}

// Python to C++ copy conversion.
static void QRhiTextureRenderTargetDescription_PythonToCpp_QRhiTextureRenderTargetDescription_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QRhiTextureRenderTargetDescription *>(cppOut) = *reinterpret_cast< ::QRhiTextureRenderTargetDescription *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTargetDescription_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QRhiTextureRenderTargetDescription_PythonToCpp_QRhiTextureRenderTargetDescription_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QRhiTextureRenderTargetDescription_TypeF()))
        return QRhiTextureRenderTargetDescription_PythonToCpp_QRhiTextureRenderTargetDescription_COPY;
    return {};
}

// Implicit conversions.
static void constQRhiColorAttachmentREF_PythonToCpp_QRhiTextureRenderTargetDescription(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QRhiTextureRenderTargetDescription *>(cppOut) = ::QRhiTextureRenderTargetDescription( *reinterpret_cast< ::QRhiColorAttachment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiColorAttachment_IDX]), reinterpret_cast<SbkObject *>(pyIn))));
}
static PythonToCppFunc is_constQRhiColorAttachmentREF_PythonToCpp_QRhiTextureRenderTargetDescription_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiColorAttachment_IDX]), pyIn))
        return constQRhiColorAttachmentREF_PythonToCpp_QRhiTextureRenderTargetDescription;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QRhiTextureRenderTargetDescription_SignatureStrings[] = {
    "4:PySide6.QtGui.QRhiTextureRenderTargetDescription(self)",
    "3:PySide6.QtGui.QRhiTextureRenderTargetDescription(self,colorAttachment:typing.Union[PySide6.QtGui.QRhiColorAttachment, PySide6.QtGui.QRhiRenderBuffer, PySide6.QtGui.QRhiTexture])",
    "2:PySide6.QtGui.QRhiTextureRenderTargetDescription(self,colorAttachment:typing.Union[PySide6.QtGui.QRhiColorAttachment, PySide6.QtGui.QRhiRenderBuffer, PySide6.QtGui.QRhiTexture],depthStencilBuffer:PySide6.QtGui.QRhiRenderBuffer)",
    "1:PySide6.QtGui.QRhiTextureRenderTargetDescription(self,colorAttachment:typing.Union[PySide6.QtGui.QRhiColorAttachment, PySide6.QtGui.QRhiRenderBuffer, PySide6.QtGui.QRhiTexture],depthTexture:PySide6.QtGui.QRhiTexture)",
    "0:PySide6.QtGui.QRhiTextureRenderTargetDescription(self,QRhiTextureRenderTargetDescription:PySide6.QtGui.QRhiTextureRenderTargetDescription)",
    "PySide6.QtGui.QRhiTextureRenderTargetDescription.cbeginColorAttachments(self)->PySide6.QtGui.QRhiColorAttachment",
    "PySide6.QtGui.QRhiTextureRenderTargetDescription.cendColorAttachments(self)->PySide6.QtGui.QRhiColorAttachment",
    "PySide6.QtGui.QRhiTextureRenderTargetDescription.colorAttachmentAt(self,index:qsizetype)->PySide6.QtGui.QRhiColorAttachment",
    "PySide6.QtGui.QRhiTextureRenderTargetDescription.colorAttachmentCount(self)->qsizetype",
    "PySide6.QtGui.QRhiTextureRenderTargetDescription.depthResolveTexture(self)->PySide6.QtGui.QRhiTexture",
    "PySide6.QtGui.QRhiTextureRenderTargetDescription.depthStencilBuffer(self)->PySide6.QtGui.QRhiRenderBuffer",
    "PySide6.QtGui.QRhiTextureRenderTargetDescription.depthTexture(self)->PySide6.QtGui.QRhiTexture",
    "PySide6.QtGui.QRhiTextureRenderTargetDescription.setColorAttachments(self,bcolor_attachments:QList[PySide6.QtGui.QRhiColorAttachment])",
    "PySide6.QtGui.QRhiTextureRenderTargetDescription.setDepthResolveTexture(self,tex:PySide6.QtGui.QRhiTexture)",
    "PySide6.QtGui.QRhiTextureRenderTargetDescription.setDepthStencilBuffer(self,renderBuffer:PySide6.QtGui.QRhiRenderBuffer)",
    "PySide6.QtGui.QRhiTextureRenderTargetDescription.setDepthTexture(self,texture:PySide6.QtGui.QRhiTexture)",
    "PySide6.QtGui.QRhiTextureRenderTargetDescription.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QRhiTextureRenderTargetDescription_SignatureByteSize = 321;
static constexpr uint8_t QRhiTextureRenderTargetDescription_SignatureBytes[321] = {
    0x78, 0xda, 0xd5, 0x95, 0x4d, 0x6b, 0x83, 0x30, 0x18, 0xc7, 0xef, 0xf9, 0x14, 0x3b, 0x2e, 0x90,
    0xc9, 0xde, 0xd8, 0xc1, 0xc3, 0xa0, 0x6b, 0x61, 0x97, 0x1d, 0xa6, 0x76, 0xa7, 0x51, 0xc4, 0xc6,
    0x47, 0x0d, 0xb8, 0xc4, 0x25, 0x8f, 0xa3, 0xee, 0xd3, 0x4f, 0xaa, 0xdd, 0xda, 0x5a, 0x2b, 0x06,
    0x56, 0xe8, 0x31, 0xf1, 0x9f, 0xe7, 0xf7, 0xbc, 0x7b, 0xef, 0xbe, 0x56, 0x81, 0x88, 0xe1, 0xc1,
    0xf1, 0xf0, 0xb9, 0x14, 0x8e, 0xe7, 0x67, 0x62, 0x0e, 0x2b, 0x2c, 0x35, 0xf8, 0x20, 0x63, 0xd0,
    0xf3, 0x48, 0xa7, 0x80, 0x33, 0x30, 0x5c, 0x8b, 0x02, 0x85, 0x92, 0x97, 0x06, 0xf2, 0x84, 0x92,
    0x3b, 0xbb, 0x87, 0x8c, 0xab, 0x5c, 0xe9, 0x09, 0x62, 0xc4, 0xb3, 0x0f, 0x90, 0xe8, 0x62, 0x55,
    0x08, 0x99, 0x3a, 0x6f, 0xb2, 0x56, 0xbc, 0x77, 0x4d, 0x4e, 0x77, 0xe5, 0xec, 0xa2, 0x2b, 0x69,
    0x70, 0x4f, 0x65, 0x92, 0x80, 0x3e, 0xf4, 0xbd, 0xf5, 0x6a, 0x41, 0xc9, 0xed, 0xd9, 0xf9, 0xcc,
    0x62, 0x28, 0x30, 0x0b, 0x10, 0x24, 0x17, 0x79, 0x23, 0x77, 0x8f, 0x5b, 0xa3, 0xe4, 0xe6, 0x4c,
    0xa3, 0x6c, 0x4f, 0xfd, 0xde, 0x53, 0x72, 0x6d, 0x19, 0xda, 0xb0, 0x6e, 0xb4, 0x61, 0x4a, 0xc6,
    0xbe, 0x70, 0xf8, 0x12, 0x52, 0x21, 0xf7, 0xf2, 0x66, 0x9a, 0x79, 0xba, 0x7a, 0x1c, 0xcc, 0xb0,
    0x05, 0xb0, 0xbe, 0x3f, 0x25, 0x6e, 0xd7, 0xc0, 0x04, 0x9b, 0xe4, 0x8b, 0x5a, 0xbd, 0x72, 0x3f,
    0x8d, 0xf8, 0x86, 0xba, 0xa5, 0xe0, 0x24, 0xec, 0xa9, 0x2a, 0x25, 0x6e, 0x42, 0xfd, 0x45, 0x8f,
    0x37, 0xbb, 0x6e, 0x4c, 0x1f, 0x8c, 0xca, 0xbf, 0xa0, 0x95, 0xf6, 0x27, 0xb0, 0x15, 0x58, 0x52,
    0x76, 0x86, 0xbc, 0x1f, 0xb2, 0x3d, 0x53, 0x96, 0xa4, 0xff, 0x0b, 0xc4, 0x00, 0x1e, 0xec, 0x37,
    0xb6, 0x5c, 0xd7, 0x27, 0x8c, 0xfe, 0xee, 0x5d, 0xef, 0x45, 0x18, 0x1c, 0xde, 0x2b, 0x0b, 0x6a,
    0xe5, 0xc6, 0xac, 0xa7, 0x70, 0x0c, 0xeb, 0x5e, 0x3c, 0xb2, 0x61, 0xac, 0x59, 0xdd, 0xf2, 0x31,
    0xbd, 0x55, 0xaa, 0xc1, 0xad, 0x6d, 0x0d, 0xde, 0x8f, 0x6e, 0x68, 0x87, 0x8e, 0x06, 0x85, 0x21,
    0x57, 0x45, 0x15, 0x86, 0x9b, 0x7e, 0x69, 0xff, 0x0b, 0x41, 0x7d, 0x22, 0x3f, 0xe5, 0x8a, 0x13,
    0xa2
};
#endif

PyTypeObject *init_QRhiTextureRenderTargetDescription(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTargetDescription_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTargetDescription_IDX].type;

    Shiboken::AutoDecRef Sbk_QRhiTextureRenderTargetDescription_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QRhiTextureRenderTargetDescription_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QRhiTextureRenderTargetDescription",
        "QRhiTextureRenderTargetDescription",
        &Sbk_QRhiTextureRenderTargetDescription_spec,
        &Shiboken::callCppDestructor< ::QRhiTextureRenderTargetDescription >,
        Sbk_QRhiTextureRenderTargetDescription_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QRhiTextureRenderTargetDescription_TypeF(); // references _Sbk_QRhiTextureRenderTargetDescription_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QRhiTextureRenderTargetDescription_SignatureStrings);
#else
    InitSignatureBytes(pyType, QRhiTextureRenderTargetDescription_SignatureBytes, QRhiTextureRenderTargetDescription_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QRhiTextureRenderTargetDescription_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTargetDescription_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QRhiTextureRenderTargetDescription_PythonToCpp_QRhiTextureRenderTargetDescription_PTR,
        is_QRhiTextureRenderTargetDescription_PythonToCpp_QRhiTextureRenderTargetDescription_PTR_Convertible,
        QRhiTextureRenderTargetDescription_PTR_CppToPython_QRhiTextureRenderTargetDescription,
        QRhiTextureRenderTargetDescription_COPY_CppToPython_QRhiTextureRenderTargetDescription);

    Shiboken::Conversions::registerConverterName(converter, "QRhiTextureRenderTargetDescription");
    Shiboken::Conversions::registerConverterName(converter, "QRhiTextureRenderTargetDescription*");
    Shiboken::Conversions::registerConverterName(converter, "QRhiTextureRenderTargetDescription&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QRhiTextureRenderTargetDescription).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QRhiTextureRenderTargetDescription_PythonToCpp_QRhiTextureRenderTargetDescription_COPY,
        is_QRhiTextureRenderTargetDescription_PythonToCpp_QRhiTextureRenderTargetDescription_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        constQRhiColorAttachmentREF_PythonToCpp_QRhiTextureRenderTargetDescription,
        is_constQRhiColorAttachmentREF_PythonToCpp_QRhiTextureRenderTargetDescription_Convertible);

    qRegisterMetaType< ::QRhiTextureRenderTargetDescription >("QRhiTextureRenderTargetDescription");

    return pyType;
}
