// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qrhivertexinputlayout_wrapper.h"

// Argument includes
#include <QList>
#include <rhi/qrhi.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QRhiVertexInputLayout_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QRhiVertexInputLayout >()))
        return -1;

    ::QRhiVertexInputLayout *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QRhiVertexInputLayout", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QRhiVertexInputLayout::QRhiVertexInputLayout()
    // 1: QRhiVertexInputLayout::QRhiVertexInputLayout(QRhiVertexInputLayout)
    if (numArgs == 0) {
        overloadId = 0; // QRhiVertexInputLayout()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputLayout_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QRhiVertexInputLayout(QRhiVertexInputLayout)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputLayout_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputLayout_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QRhiVertexInputLayout()
        {

            // QRhiVertexInputLayout()
            cptr = new ::QRhiVertexInputLayout();
            break;
        }
        case 1: // QRhiVertexInputLayout(const QRhiVertexInputLayout &QRhiVertexInputLayout)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QRhiVertexInputLayout cppArg0_local;
            ::QRhiVertexInputLayout *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QRhiVertexInputLayout(QRhiVertexInputLayout)
                cptr = new ::QRhiVertexInputLayout(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QRhiVertexInputLayout >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputLayout_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QRhiVertexInputLayoutFunc_attributeAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiVertexInputLayout *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputLayout_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiVertexInputLayout::attributeAt(qsizetype)const->const QRhiVertexInputAttribute*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // attributeAt(qsizetype)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "attributeAt", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputLayout_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // attributeAt(qsizetype)const
            const QRhiVertexInputAttribute * cppResult = const_cast<const ::QRhiVertexInputLayout *>(cppSelf)->attributeAt(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputAttribute_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiVertexInputLayoutFunc_attributeCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiVertexInputLayout *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputLayout_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // attributeCount()const
        qsizetype cppResult = const_cast<const ::QRhiVertexInputLayout *>(cppSelf)->attributeCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiVertexInputLayoutFunc_bindingAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiVertexInputLayout *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputLayout_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiVertexInputLayout::bindingAt(qsizetype)const->const QRhiVertexInputBinding*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // bindingAt(qsizetype)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "bindingAt", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputLayout_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // bindingAt(qsizetype)const
            const QRhiVertexInputBinding * cppResult = const_cast<const ::QRhiVertexInputLayout *>(cppSelf)->bindingAt(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputBinding_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiVertexInputLayoutFunc_bindingCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiVertexInputLayout *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputLayout_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // bindingCount()const
        qsizetype cppResult = const_cast<const ::QRhiVertexInputLayout *>(cppSelf)->bindingCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiVertexInputLayoutFunc_cbeginAttributes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiVertexInputLayout *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputLayout_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cbeginAttributes()const
        const QRhiVertexInputAttribute * cppResult = const_cast<const ::QRhiVertexInputLayout *>(cppSelf)->cbeginAttributes();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputAttribute_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiVertexInputLayoutFunc_cbeginBindings(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiVertexInputLayout *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputLayout_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cbeginBindings()const
        const QRhiVertexInputBinding * cppResult = const_cast<const ::QRhiVertexInputLayout *>(cppSelf)->cbeginBindings();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputBinding_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiVertexInputLayoutFunc_cendAttributes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiVertexInputLayout *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputLayout_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cendAttributes()const
        const QRhiVertexInputAttribute * cppResult = const_cast<const ::QRhiVertexInputLayout *>(cppSelf)->cendAttributes();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputAttribute_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiVertexInputLayoutFunc_cendBindings(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiVertexInputLayout *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputLayout_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cendBindings()const
        const QRhiVertexInputBinding * cppResult = const_cast<const ::QRhiVertexInputLayout *>(cppSelf)->cendBindings();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputBinding_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiVertexInputLayoutFunc_setAttributes(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiVertexInputLayout *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputLayout_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiVertexInputLayout::setAttributes(QList<QRhiVertexInputAttribute>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QRhiVertexInputAttribute_IDX], (pyArg)))) {
        overloadId = 0; // setAttributes(QList<QRhiVertexInputAttribute>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAttributes", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputLayout_IDX]);

    // Call function/method
    {
        ::QList<QRhiVertexInputAttribute> cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        SBK_UNUSED(cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAttributes(QList<QRhiVertexInputAttribute>)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtgui.cpp (qrhi-initializer-list)]
            cppSelf->setAttributes(cppArg0.cbegin(), cppArg0.cend());
            // END of custom code block [file: ../glue/qtgui.cpp (qrhi-initializer-list)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiVertexInputLayoutFunc_setBindings(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiVertexInputLayout *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputLayout_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiVertexInputLayout::setBindings(QList<QRhiVertexInputBinding>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QRhiVertexInputBinding_IDX], (pyArg)))) {
        overloadId = 0; // setBindings(QList<QRhiVertexInputBinding>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBindings", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputLayout_IDX]);

    // Call function/method
    {
        ::QList<QRhiVertexInputBinding> cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        SBK_UNUSED(cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // setBindings(QList<QRhiVertexInputBinding>)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtgui.cpp (qrhi-initializer-list)]
            cppSelf->setBindings(cppArg0.cbegin(), cppArg0.cend());
            // END of custom code block [file: ../glue/qtgui.cpp (qrhi-initializer-list)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiVertexInputLayout__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QRhiVertexInputLayout *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputLayout_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputLayout_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QRhiVertexInputLayout_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QRhiVertexInputLayout_methods[] = {
    {"attributeAt", reinterpret_cast<PyCFunction>(Sbk_QRhiVertexInputLayoutFunc_attributeAt), METH_O, nullptr},
    {"attributeCount", reinterpret_cast<PyCFunction>(Sbk_QRhiVertexInputLayoutFunc_attributeCount), METH_NOARGS, nullptr},
    {"bindingAt", reinterpret_cast<PyCFunction>(Sbk_QRhiVertexInputLayoutFunc_bindingAt), METH_O, nullptr},
    {"bindingCount", reinterpret_cast<PyCFunction>(Sbk_QRhiVertexInputLayoutFunc_bindingCount), METH_NOARGS, nullptr},
    {"cbeginAttributes", reinterpret_cast<PyCFunction>(Sbk_QRhiVertexInputLayoutFunc_cbeginAttributes), METH_NOARGS, nullptr},
    {"cbeginBindings", reinterpret_cast<PyCFunction>(Sbk_QRhiVertexInputLayoutFunc_cbeginBindings), METH_NOARGS, nullptr},
    {"cendAttributes", reinterpret_cast<PyCFunction>(Sbk_QRhiVertexInputLayoutFunc_cendAttributes), METH_NOARGS, nullptr},
    {"cendBindings", reinterpret_cast<PyCFunction>(Sbk_QRhiVertexInputLayoutFunc_cendBindings), METH_NOARGS, nullptr},
    {"setAttributes", reinterpret_cast<PyCFunction>(Sbk_QRhiVertexInputLayoutFunc_setAttributes), METH_O, nullptr},
    {"setBindings", reinterpret_cast<PyCFunction>(Sbk_QRhiVertexInputLayoutFunc_setBindings), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QRhiVertexInputLayout__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QRhiVertexInputLayout_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QRhiVertexInputLayout *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputLayout_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputLayout_IDX]), (pyArg)))) {
                // operator!=(const QRhiVertexInputLayout &b)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QRhiVertexInputLayout cppArg0_local;
                ::QRhiVertexInputLayout *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputLayout_IDX]), (pyArg)))) {
                // operator==(const QRhiVertexInputLayout &b)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QRhiVertexInputLayout cppArg0_local;
                ::QRhiVertexInputLayout *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static Py_hash_t Sbk_QRhiVertexInputLayout_HashFunc(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiVertexInputLayout *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputLayout_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return Py_hash_t(qHash(*cppSelf));
}

static int Sbk_QRhiVertexInputLayout_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QRhiVertexInputLayout_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QRhiVertexInputLayout__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiVertexInputLayout *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputLayout_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QRhiVertexInputLayout_Type = nullptr;
static PyTypeObject *Sbk_QRhiVertexInputLayout_TypeF(void)
{
    return _Sbk_QRhiVertexInputLayout_Type;
}

static PyType_Slot Sbk_QRhiVertexInputLayout_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QRhiVertexInputLayout__repr__)},
    {Py_tp_hash,        reinterpret_cast<void *>(&Sbk_QRhiVertexInputLayout_HashFunc)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QRhiVertexInputLayout_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QRhiVertexInputLayout_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QRhiVertexInputLayout_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QRhiVertexInputLayout_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QRhiVertexInputLayout_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QRhiVertexInputLayout_spec = {
    "2:PySide6.QtGui.QRhiVertexInputLayout",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QRhiVertexInputLayout_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QRhiVertexInputLayout_PythonToCpp_QRhiVertexInputLayout_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QRhiVertexInputLayout_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QRhiVertexInputLayout_PythonToCpp_QRhiVertexInputLayout_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QRhiVertexInputLayout_TypeF()))
        return QRhiVertexInputLayout_PythonToCpp_QRhiVertexInputLayout_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QRhiVertexInputLayout_PTR_CppToPython_QRhiVertexInputLayout(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QRhiVertexInputLayout_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QRhiVertexInputLayout_COPY_CppToPython_QRhiVertexInputLayout(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QRhiVertexInputLayout *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QRhiVertexInputLayout_TypeF(), new ::QRhiVertexInputLayout(*source), true, true);
}

// Python to C++ copy conversion.
static void QRhiVertexInputLayout_PythonToCpp_QRhiVertexInputLayout_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QRhiVertexInputLayout *>(cppOut) = *reinterpret_cast< ::QRhiVertexInputLayout *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputLayout_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QRhiVertexInputLayout_PythonToCpp_QRhiVertexInputLayout_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QRhiVertexInputLayout_TypeF()))
        return QRhiVertexInputLayout_PythonToCpp_QRhiVertexInputLayout_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QRhiVertexInputLayout_SignatureStrings[] = {
    "1:PySide6.QtGui.QRhiVertexInputLayout(self)",
    "0:PySide6.QtGui.QRhiVertexInputLayout(self,QRhiVertexInputLayout:PySide6.QtGui.QRhiVertexInputLayout)",
    "PySide6.QtGui.QRhiVertexInputLayout.attributeAt(self,index:qsizetype)->PySide6.QtGui.QRhiVertexInputAttribute",
    "PySide6.QtGui.QRhiVertexInputLayout.attributeCount(self)->qsizetype",
    "PySide6.QtGui.QRhiVertexInputLayout.bindingAt(self,index:qsizetype)->PySide6.QtGui.QRhiVertexInputBinding",
    "PySide6.QtGui.QRhiVertexInputLayout.bindingCount(self)->qsizetype",
    "PySide6.QtGui.QRhiVertexInputLayout.cbeginAttributes(self)->PySide6.QtGui.QRhiVertexInputAttribute",
    "PySide6.QtGui.QRhiVertexInputLayout.cbeginBindings(self)->PySide6.QtGui.QRhiVertexInputBinding",
    "PySide6.QtGui.QRhiVertexInputLayout.cendAttributes(self)->PySide6.QtGui.QRhiVertexInputAttribute",
    "PySide6.QtGui.QRhiVertexInputLayout.cendBindings(self)->PySide6.QtGui.QRhiVertexInputBinding",
    "PySide6.QtGui.QRhiVertexInputLayout.setAttributes(self,attributes:QList[PySide6.QtGui.QRhiVertexInputAttribute])",
    "PySide6.QtGui.QRhiVertexInputLayout.setBindings(self,bindings:QList[PySide6.QtGui.QRhiVertexInputBinding])",
    "PySide6.QtGui.QRhiVertexInputLayout.__copy__(self)->typing.Self",
    "PySide6.QtGui.QRhiVertexInputLayout.__ne__(self,b:PySide6.QtGui.QRhiVertexInputLayout)->bool",
    "PySide6.QtGui.QRhiVertexInputLayout.__eq__(self,b:PySide6.QtGui.QRhiVertexInputLayout)->bool",
    "PySide6.QtGui.QRhiVertexInputLayout.__hash__(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t QRhiVertexInputLayout_SignatureByteSize = 250;
static constexpr uint8_t QRhiVertexInputLayout_SignatureBytes[250] = {
    0x78, 0xda, 0xb5, 0x94, 0x41, 0x6b, 0x83, 0x40, 0x10, 0x85, 0xef, 0xfe, 0x92, 0x0a, 0x2a, 0xed,
    0xa5, 0x07, 0x0f, 0x82, 0xcd, 0xa1, 0x14, 0x3c, 0xd4, 0x04, 0x72, 0x29, 0x41, 0x5c, 0x9d, 0xc6,
    0x01, 0xd9, 0x35, 0xd9, 0x59, 0x88, 0xf9, 0xf5, 0x59, 0x70, 0x35, 0x24, 0x94, 0x30, 0xb6, 0xf5,
    0xb8, 0xec, 0xbe, 0xf7, 0xbd, 0x79, 0x0c, 0xfb, 0x12, 0x7f, 0xf6, 0x1b, 0xac, 0xe1, 0x35, 0xca,
    0xe9, 0xdd, 0x60, 0x94, 0xaf, 0x1b, 0xdc, 0xc2, 0x91, 0xe0, 0xf4, 0x21, 0x3b, 0x43, 0x59, 0xd9,
    0x2b, 0x43, 0x4f, 0x1a, 0xda, 0x6f, 0xdf, 0x7b, 0x66, 0xbf, 0x0d, 0x7e, 0xbc, 0xe2, 0xc8, 0x7d,
    0x8f, 0xf1, 0x28, 0x2a, 0x89, 0x8e, 0x28, 0x0c, 0x41, 0xea, 0x78, 0x28, 0x6b, 0x38, 0xc5, 0x07,
    0x8d, 0x67, 0xa0, 0xbe, 0x03, 0x3f, 0x4c, 0x1e, 0xda, 0xa4, 0xa3, 0x7e, 0x1e, 0x6d, 0xa5, 0x8c,
    0x74, 0x65, 0x84, 0xc9, 0x04, 0x63, 0x79, 0x08, 0x9b, 0x10, 0xe5, 0xfe, 0x97, 0x79, 0xdf, 0x06,
    0xf5, 0x1c, 0xd2, 0x1f, 0xb2, 0x56, 0x02, 0xf6, 0x28, 0xa7, 0x8e, 0xf4, 0xe8, 0xf2, 0x8f, 0x95,
    0x0e, 0x08, 0x37, 0x16, 0x0f, 0x30, 0xa7, 0x83, 0x0a, 0x64, 0xbd, 0x6c, 0x7e, 0x0b, 0x58, 0x2c,
    0xbd, 0x06, 0xba, 0x0b, 0x1f, 0x4c, 0x2b, 0xa8, 0xe3, 0x3c, 0x43, 0x4d, 0x5f, 0xbc, 0x59, 0x76,
    0x3e, 0x17, 0x78, 0x33, 0x4c, 0xe0, 0x76, 0x88, 0x05, 0x73, 0x4a, 0x26, 0xaa, 0x28, 0x2a, 0xd5,
    0xf5, 0x45, 0x31, 0x96, 0x66, 0x97, 0xd2, 0x8a, 0xa3, 0x8d, 0x3d, 0x31, 0xf5, 0x12, 0x9c, 0x3a,
    0x10, 0xac, 0x0f, 0x25, 0x4c, 0x84, 0x52, 0x2d, 0xd3, 0x1c, 0x0e, 0x0b, 0x9a, 0x37, 0xa5, 0x6e,
    0xae, 0x93, 0xa3, 0x24, 0xef, 0x02, 0x84, 0xe0, 0x09, 0x9e
};
#endif

PyTypeObject *init_QRhiVertexInputLayout(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputLayout_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputLayout_IDX].type;

    Shiboken::AutoDecRef Sbk_QRhiVertexInputLayout_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QRhiVertexInputLayout_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QRhiVertexInputLayout",
        "QRhiVertexInputLayout",
        &Sbk_QRhiVertexInputLayout_spec,
        &Shiboken::callCppDestructor< ::QRhiVertexInputLayout >,
        Sbk_QRhiVertexInputLayout_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QRhiVertexInputLayout_TypeF(); // references _Sbk_QRhiVertexInputLayout_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QRhiVertexInputLayout_SignatureStrings);
#else
    InitSignatureBytes(pyType, QRhiVertexInputLayout_SignatureBytes, QRhiVertexInputLayout_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QRhiVertexInputLayout_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputLayout_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QRhiVertexInputLayout_PythonToCpp_QRhiVertexInputLayout_PTR,
        is_QRhiVertexInputLayout_PythonToCpp_QRhiVertexInputLayout_PTR_Convertible,
        QRhiVertexInputLayout_PTR_CppToPython_QRhiVertexInputLayout,
        QRhiVertexInputLayout_COPY_CppToPython_QRhiVertexInputLayout);

    Shiboken::Conversions::registerConverterName(converter, "QRhiVertexInputLayout");
    Shiboken::Conversions::registerConverterName(converter, "QRhiVertexInputLayout*");
    Shiboken::Conversions::registerConverterName(converter, "QRhiVertexInputLayout&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QRhiVertexInputLayout).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QRhiVertexInputLayout_PythonToCpp_QRhiVertexInputLayout_COPY,
        is_QRhiVertexInputLayout_PythonToCpp_QRhiVertexInputLayout_COPY_Convertible);

    qRegisterMetaType< ::QRhiVertexInputLayout >("QRhiVertexInputLayout");

    return pyType;
}
