// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qrhiviewport_wrapper.h"

// Argument includes
#include <array>
#include <rhi/qrhi.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QRhiViewport_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QRhiViewport >()))
        return -1;

    ::QRhiViewport *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[6];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 6));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiViewport_IDX]);
    if (numArgs == 2 || numArgs == 3)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiViewport_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOOO:QRhiViewport", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QRhiViewport::QRhiViewport()
    // 1: QRhiViewport::QRhiViewport(QRhiViewport)
    // 2: QRhiViewport::QRhiViewport(float,float,float,float,float=,float=)
    if (numArgs == 0) {
        overloadId = 0; // QRhiViewport()
    } else if (numArgs >= 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[3])))) {
        if (numArgs == 4) {
            overloadId = 2; // QRhiViewport(float,float,float,float,float,float)
        } else if (numArgs >= 5
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[4])))) {
            if (numArgs == 5) {
                overloadId = 2; // QRhiViewport(float,float,float,float,float,float)
            } else if (numArgs >= 6
                && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[5])))) {
                overloadId = 2; // QRhiViewport(float,float,float,float,float,float)
            }
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiViewport_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QRhiViewport(QRhiViewport)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiViewport_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QRhiViewport_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QRhiViewport()
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiViewport_IDX]);
            }

            // QRhiViewport()
            cptr = new ::QRhiViewport();
            break;
        }
        case 1: // QRhiViewport(const QRhiViewport &QRhiViewport)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiViewport_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QRhiViewport cppArg0_local;
            ::QRhiViewport *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QRhiViewport(QRhiViewport)
                cptr = new ::QRhiViewport(*cppArg0);
            }
            break;
        }
        case 2: // QRhiViewport(float x, float y, float w, float h, float minDepth, float maxDepth)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_minDepth = Shiboken::String::createStaticString("minDepth");
                if (PyDict_Contains(kwds, key_minDepth) != 0) {
                    value = PyDict_GetItem(kwds, key_minDepth);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_minDepth);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiViewport_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiViewport_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_minDepth);
                }
                static PyObject *const key_maxDepth = Shiboken::String::createStaticString("maxDepth");
                if (PyDict_Contains(kwds, key_maxDepth) != 0) {
                    value = PyDict_GetItem(kwds, key_maxDepth);
                    if (value != nullptr && pyArgs[5] != nullptr ) {
                        errInfo.reset(key_maxDepth);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiViewport_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[5] = value;
                        if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[5]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiViewport_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_maxDepth);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiViewport_IDX]);
                }
            }
            float cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            float cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            float cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            float cppArg4 = 0.0f;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);
            float cppArg5 = 1.0f;
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QRhiViewport(float,float,float,float,float,float)
                cptr = new ::QRhiViewport(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QRhiViewport >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiViewport_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QRhiViewportFunc_maxDepth(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiViewport *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiViewport_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maxDepth()const
        float cppResult = const_cast<const ::QRhiViewport *>(cppSelf)->maxDepth();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiViewportFunc_minDepth(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiViewport *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiViewport_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // minDepth()const
        float cppResult = const_cast<const ::QRhiViewport *>(cppSelf)->minDepth();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiViewportFunc_setMaxDepth(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiViewport *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiViewport_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiViewport::setMaxDepth(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setMaxDepth(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMaxDepth", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiViewport_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMaxDepth(float)
            cppSelf->setMaxDepth(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiViewportFunc_setMinDepth(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiViewport *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiViewport_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiViewport::setMinDepth(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setMinDepth(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMinDepth", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiViewport_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMinDepth(float)
            cppSelf->setMinDepth(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiViewportFunc_setViewport(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiViewport *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiViewport_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setViewport", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRhiViewport::setViewport(float,float,float,float)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[3])))) {
        overloadId = 0; // setViewport(float,float,float,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setViewport", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiViewport_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        float cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        float cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setViewport(float,float,float,float)
            cppSelf->setViewport(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiViewportFunc_viewport(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiViewport *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiViewport_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // viewport()const
        std::array<float,4> cppResult = const_cast<const ::QRhiViewport *>(cppSelf)->viewport();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_std_array_float_4_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiViewport__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QRhiViewport *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiViewport_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiViewport_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QRhiViewport_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QRhiViewport_methods[] = {
    {"maxDepth", reinterpret_cast<PyCFunction>(Sbk_QRhiViewportFunc_maxDepth), METH_NOARGS, nullptr},
    {"minDepth", reinterpret_cast<PyCFunction>(Sbk_QRhiViewportFunc_minDepth), METH_NOARGS, nullptr},
    {"setMaxDepth", reinterpret_cast<PyCFunction>(Sbk_QRhiViewportFunc_setMaxDepth), METH_O, nullptr},
    {"setMinDepth", reinterpret_cast<PyCFunction>(Sbk_QRhiViewportFunc_setMinDepth), METH_O, nullptr},
    {"setViewport", reinterpret_cast<PyCFunction>(Sbk_QRhiViewportFunc_setViewport), METH_VARARGS, nullptr},
    {"viewport", reinterpret_cast<PyCFunction>(Sbk_QRhiViewportFunc_viewport), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QRhiViewport__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QRhiViewport_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QRhiViewport *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiViewport_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiViewport_IDX]), (pyArg)))) {
                // operator!=(const QRhiViewport &b)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QRhiViewport cppArg0_local;
                ::QRhiViewport *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiViewport_IDX]), (pyArg)))) {
                // operator==(const QRhiViewport &b)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QRhiViewport cppArg0_local;
                ::QRhiViewport *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static Py_hash_t Sbk_QRhiViewport_HashFunc(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiViewport *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiViewport_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return Py_hash_t(qHash(*cppSelf));
}

static int Sbk_QRhiViewport_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QRhiViewport_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QRhiViewport__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiViewport *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiViewport_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QRhiViewport_Type = nullptr;
static PyTypeObject *Sbk_QRhiViewport_TypeF(void)
{
    return _Sbk_QRhiViewport_Type;
}

static PyType_Slot Sbk_QRhiViewport_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QRhiViewport__repr__)},
    {Py_tp_hash,        reinterpret_cast<void *>(&Sbk_QRhiViewport_HashFunc)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QRhiViewport_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QRhiViewport_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QRhiViewport_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QRhiViewport_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QRhiViewport_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QRhiViewport_spec = {
    "2:PySide6.QtGui.QRhiViewport",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QRhiViewport_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QRhiViewport_PythonToCpp_QRhiViewport_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QRhiViewport_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QRhiViewport_PythonToCpp_QRhiViewport_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QRhiViewport_TypeF()))
        return QRhiViewport_PythonToCpp_QRhiViewport_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QRhiViewport_PTR_CppToPython_QRhiViewport(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QRhiViewport_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QRhiViewport_COPY_CppToPython_QRhiViewport(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QRhiViewport *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QRhiViewport_TypeF(), new ::QRhiViewport(*source), true, true);
}

// Python to C++ copy conversion.
static void QRhiViewport_PythonToCpp_QRhiViewport_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QRhiViewport *>(cppOut) = *reinterpret_cast< ::QRhiViewport *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiViewport_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QRhiViewport_PythonToCpp_QRhiViewport_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QRhiViewport_TypeF()))
        return QRhiViewport_PythonToCpp_QRhiViewport_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QRhiViewport_SignatureStrings[] = {
    "2:PySide6.QtGui.QRhiViewport(self)",
    "1:PySide6.QtGui.QRhiViewport(self,QRhiViewport:PySide6.QtGui.QRhiViewport)",
    "0:PySide6.QtGui.QRhiViewport(self,x:float,y:float,w:float,h:float,minDepth:float=0.0f,maxDepth:float=1.0f)",
    "PySide6.QtGui.QRhiViewport.maxDepth(self)->float",
    "PySide6.QtGui.QRhiViewport.minDepth(self)->float",
    "PySide6.QtGui.QRhiViewport.setMaxDepth(self,maxDepth:float)",
    "PySide6.QtGui.QRhiViewport.setMinDepth(self,minDepth:float)",
    "PySide6.QtGui.QRhiViewport.setViewport(self,x:float,y:float,w:float,h:float)",
    "PySide6.QtGui.QRhiViewport.viewport(self)->std.array[float, 4]",
    "PySide6.QtGui.QRhiViewport.__copy__(self)->typing.Self",
    "PySide6.QtGui.QRhiViewport.__ne__(self,b:PySide6.QtGui.QRhiViewport)->bool",
    "PySide6.QtGui.QRhiViewport.__eq__(self,b:PySide6.QtGui.QRhiViewport)->bool",
    "PySide6.QtGui.QRhiViewport.__hash__(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t QRhiViewport_SignatureByteSize = 215;
static constexpr uint8_t QRhiViewport_SignatureBytes[215] = {
    0x78, 0xda, 0xad, 0x92, 0x41, 0x0b, 0x82, 0x40, 0x10, 0x85, 0xef, 0xfb, 0x2b, 0x3a, 0x26, 0xe8,
    0xa2, 0x11, 0x1d, 0x84, 0x3c, 0x05, 0x9d, 0x82, 0x4c, 0xe8, 0x12, 0xb1, 0xac, 0xb5, 0xe6, 0x82,
    0xba, 0xa6, 0x53, 0xba, 0xff, 0x3e, 0xc9, 0x95, 0x4c, 0x68, 0x2d, 0xe8, 0x34, 0xcc, 0xf0, 0xbe,
    0xf7, 0x76, 0x96, 0x99, 0xb9, 0x5b, 0x19, 0xf0, 0x33, 0x5b, 0x60, 0x1f, 0xd6, 0x37, 0x8e, 0xfd,
    0x5d, 0xcc, 0xf7, 0x9c, 0x55, 0xb9, 0x28, 0x60, 0x5a, 0xb2, 0x24, 0x32, 0x90, 0x33, 0x26, 0x31,
    0xfb, 0x13, 0x8d, 0xd8, 0x40, 0xf6, 0xa8, 0x55, 0xed, 0x46, 0x89, 0xa0, 0x60, 0x4a, 0x55, 0x2b,
    0x55, 0x63, 0x55, 0x53, 0x9e, 0xad, 0x58, 0x0e, 0xaa, 0x5d, 0xda, 0xd8, 0x8e, 0xcc, 0x94, 0xd6,
    0xfd, 0x99, 0xd3, 0xcc, 0x0c, 0xf4, 0x39, 0x08, 0x77, 0xfa, 0x76, 0x3f, 0xcb, 0x7b, 0x62, 0x5a,
    0x40, 0x85, 0x7e, 0x0d, 0x94, 0x0c, 0x36, 0xfd, 0x90, 0xc1, 0x13, 0x8d, 0x31, 0xb6, 0x9f, 0x37,
    0x58, 0x79, 0x8c, 0xfd, 0xe9, 0x3b, 0xb5, 0x66, 0xf7, 0xb7, 0x33, 0xb0, 0xbc, 0x12, 0xce, 0x98,
    0x16, 0x05, 0x95, 0x87, 0xd6, 0x63, 0x32, 0x3f, 0xea, 0x70, 0x42, 0x4e, 0x22, 0x97, 0x84, 0x74,
    0x38, 0xc8, 0x9c, 0x67, 0x17, 0x1c, 0x34, 0x9d, 0x1e, 0xcb, 0x98, 0x82, 0xcc, 0x50, 0x77, 0x4c,
    0x96, 0x17, 0x0a, 0x91, 0xe8, 0xad, 0xd8, 0xf5, 0x6f, 0x56, 0x31, 0x2d, 0xe3, 0xd7, 0x32, 0x3c,
    0x03, 0xf4, 0x00, 0x9f, 0x3f, 0x28, 0x1c
};
#endif

PyTypeObject *init_QRhiViewport(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QRhiViewport_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QRhiViewport_IDX].type;

    Shiboken::AutoDecRef Sbk_QRhiViewport_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QRhiViewport_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QRhiViewport",
        "QRhiViewport",
        &Sbk_QRhiViewport_spec,
        &Shiboken::callCppDestructor< ::QRhiViewport >,
        Sbk_QRhiViewport_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QRhiViewport_TypeF(); // references _Sbk_QRhiViewport_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QRhiViewport_SignatureStrings);
#else
    InitSignatureBytes(pyType, QRhiViewport_SignatureBytes, QRhiViewport_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QRhiViewport_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiViewport_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QRhiViewport_PythonToCpp_QRhiViewport_PTR,
        is_QRhiViewport_PythonToCpp_QRhiViewport_PTR_Convertible,
        QRhiViewport_PTR_CppToPython_QRhiViewport,
        QRhiViewport_COPY_CppToPython_QRhiViewport);

    Shiboken::Conversions::registerConverterName(converter, "QRhiViewport");
    Shiboken::Conversions::registerConverterName(converter, "QRhiViewport*");
    Shiboken::Conversions::registerConverterName(converter, "QRhiViewport&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QRhiViewport).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QRhiViewport_PythonToCpp_QRhiViewport_COPY,
        is_QRhiViewport_PythonToCpp_QRhiViewport_COPY_Convertible);

    qRegisterMetaType< ::QRhiViewport >("QRhiViewport");

    return pyType;
}
