// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qscreen_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QtGui/qpixmap.h>
#include <QtGui/qscreen.h>
#include <QtGui/qtransform.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qrect.h>
#include <qsize.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QScreenWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

void QScreenWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QScreen", funcName);
        return;
    }
}

void QScreenWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QScreen", funcName);
        return;
    }
}

void QScreenWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QScreen", funcName);
        return;
    }
}

void QScreenWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QScreen", funcName);
        return;
    }
}

bool QScreenWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QScreen", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QScreen", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QScreenWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QScreen", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QScreen", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QScreenWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QScreen", funcName);
        return;
    }
}

const QMetaObject *QScreenWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QScreen::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QScreenWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QScreen::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QScreenWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QScreenWrapper *>(this));
    return QScreen::qt_metacast(_clname);
}

QScreenWrapper::~QScreenWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QScreenFunc_angleBetween(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScreen *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "angleBetween", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QScreen::angleBetween(Qt::ScreenOrientation,Qt::ScreenOrientation)const->int
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ScreenOrientation_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ScreenOrientation_IDX])))->converter, (pyArgs[1])))) {
        overloadId = 0; // angleBetween(Qt::ScreenOrientation,Qt::ScreenOrientation)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "angleBetween", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]);

    // Call function/method
    {
        ::Qt::ScreenOrientation cppArg0{Qt::PrimaryOrientation};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::Qt::ScreenOrientation cppArg1{Qt::PrimaryOrientation};
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // angleBetween(Qt::ScreenOrientation,Qt::ScreenOrientation)const
            int cppResult = const_cast<const ::QScreen *>(cppSelf)->angleBetween(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScreenFunc_availableGeometry(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScreen *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // availableGeometry()const
        QRect cppResult = const_cast<const ::QScreen *>(cppSelf)->availableGeometry();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScreenFunc_availableSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScreen *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // availableSize()const
        QSize cppResult = const_cast<const ::QScreen *>(cppSelf)->availableSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScreenFunc_availableVirtualGeometry(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScreen *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // availableVirtualGeometry()const
        QRect cppResult = const_cast<const ::QScreen *>(cppSelf)->availableVirtualGeometry();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScreenFunc_availableVirtualSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScreen *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // availableVirtualSize()const
        QSize cppResult = const_cast<const ::QScreen *>(cppSelf)->availableVirtualSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScreenFunc_depth(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScreen *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // depth()const
        int cppResult = const_cast<const ::QScreen *>(cppSelf)->depth();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScreenFunc_devicePixelRatio(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScreen *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // devicePixelRatio()const
        qreal cppResult = const_cast<const ::QScreen *>(cppSelf)->devicePixelRatio();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScreenFunc_geometry(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScreen *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // geometry()const
        QRect cppResult = const_cast<const ::QScreen *>(cppSelf)->geometry();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScreenFunc_grabWindow(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScreen *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "grabWindow", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOO:grabWindow", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QScreen::grabWindow(long=,int=,int=,int=,int=)->QPixmap
    if (numArgs == 0) {
        overloadId = 0; // grabWindow(WId,int,int,int,int)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<long>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // grabWindow(WId,int,int,int,int)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // grabWindow(WId,int,int,int,int)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // grabWindow(WId,int,int,int,int)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
                    if (numArgs == 4) {
                        overloadId = 0; // grabWindow(WId,int,int,int,int)
                    } else if (numArgs >= 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))) {
                        overloadId = 0; // grabWindow(WId,int,int,int,int)
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "grabWindow", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_window = Shiboken::String::createStaticString("window");
            if (PyDict_Contains(kwds, key_window) != 0) {
                value = PyDict_GetItem(kwds, key_window);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_window);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "grabWindow", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<long>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "grabWindow", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_window);
            }
            static PyObject *const key_x = Shiboken::String::createStaticString("x");
            if (PyDict_Contains(kwds, key_x) != 0) {
                value = PyDict_GetItem(kwds, key_x);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_x);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "grabWindow", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "grabWindow", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_x);
            }
            static PyObject *const key_y = Shiboken::String::createStaticString("y");
            if (PyDict_Contains(kwds, key_y) != 0) {
                value = PyDict_GetItem(kwds, key_y);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_y);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "grabWindow", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "grabWindow", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_y);
            }
            static PyObject *const key_w = Shiboken::String::createStaticString("w");
            if (PyDict_Contains(kwds, key_w) != 0) {
                value = PyDict_GetItem(kwds, key_w);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_w);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "grabWindow", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, "grabWindow", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_w);
            }
            static PyObject *const key_h = Shiboken::String::createStaticString("h");
            if (PyDict_Contains(kwds, key_h) != 0) {
                value = PyDict_GetItem(kwds, key_h);
                if (value != nullptr && pyArgs[4] != nullptr ) {
                    errInfo.reset(key_h);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "grabWindow", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[4] = value;
                    if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4]))))
                        return Shiboken::returnWrongArguments(args, "grabWindow", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_h);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "grabWindow", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]);
            }
        }
        long cppArg0 = 0;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1 = 0;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2 = 0;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3 = -1;
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);
        int cppArg4 = -1;
        if (pythonToCpp[4])
            pythonToCpp[4](pyArgs[4], &cppArg4);

        if (Shiboken::Errors::occurred() == nullptr) {
            // grabWindow(WId,int,int,int,int)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtgui.cpp (qscreen-grabWindow)]
            WId id = cppArg0;
            ::QPixmap retval = cppSelf->grabWindow(id, cppArg1, cppArg2, cppArg3, cppArg4);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), &retval);
            // END of custom code block [file: ../glue/qtgui.cpp (qscreen-grabWindow)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScreenFunc_isLandscape(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScreen *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QScreen::isLandscape(Qt::ScreenOrientation)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ScreenOrientation_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // isLandscape(Qt::ScreenOrientation)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isLandscape", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]);

    // Call function/method
    {
        ::Qt::ScreenOrientation cppArg0{Qt::PrimaryOrientation};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isLandscape(Qt::ScreenOrientation)const
            bool cppResult = const_cast<const ::QScreen *>(cppSelf)->isLandscape(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScreenFunc_isPortrait(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScreen *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QScreen::isPortrait(Qt::ScreenOrientation)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ScreenOrientation_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // isPortrait(Qt::ScreenOrientation)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isPortrait", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]);

    // Call function/method
    {
        ::Qt::ScreenOrientation cppArg0{Qt::PrimaryOrientation};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isPortrait(Qt::ScreenOrientation)const
            bool cppResult = const_cast<const ::QScreen *>(cppSelf)->isPortrait(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScreenFunc_logicalDotsPerInch(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScreen *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // logicalDotsPerInch()const
        qreal cppResult = const_cast<const ::QScreen *>(cppSelf)->logicalDotsPerInch();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScreenFunc_logicalDotsPerInchX(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScreen *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // logicalDotsPerInchX()const
        qreal cppResult = const_cast<const ::QScreen *>(cppSelf)->logicalDotsPerInchX();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScreenFunc_logicalDotsPerInchY(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScreen *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // logicalDotsPerInchY()const
        qreal cppResult = const_cast<const ::QScreen *>(cppSelf)->logicalDotsPerInchY();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScreenFunc_manufacturer(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScreen *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // manufacturer()const
        QString cppResult = const_cast<const ::QScreen *>(cppSelf)->manufacturer();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScreenFunc_mapBetween(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScreen *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "mapBetween", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QScreen::mapBetween(Qt::ScreenOrientation,Qt::ScreenOrientation,QRect)const->QRect
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ScreenOrientation_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ScreenOrientation_IDX])))->converter, (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[2])))) {
        overloadId = 0; // mapBetween(Qt::ScreenOrientation,Qt::ScreenOrientation,QRect)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "mapBetween", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]);

    // Call function/method
    {
        ::Qt::ScreenOrientation cppArg0{Qt::PrimaryOrientation};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::Qt::ScreenOrientation cppArg1{Qt::PrimaryOrientation};
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QRect cppArg2_local;
        ::QRect *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2].isValue())
            pythonToCpp[2](pyArgs[2], &cppArg2_local);
        else
            pythonToCpp[2](pyArgs[2], &cppArg2);


        if (Shiboken::Errors::occurred() == nullptr) {
            // mapBetween(Qt::ScreenOrientation,Qt::ScreenOrientation,QRect)const
            QRect cppResult = const_cast<const ::QScreen *>(cppSelf)->mapBetween(cppArg0, cppArg1, *cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScreenFunc_model(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScreen *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // model()const
        QString cppResult = const_cast<const ::QScreen *>(cppSelf)->model();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScreenFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScreen *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // name()const
        QString cppResult = const_cast<const ::QScreen *>(cppSelf)->name();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScreenFunc_nativeInterface(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScreen *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // nativeInterface()const
        // Begin code injection
        // ========================================================================
        // START of custom code block [file: ../glue/qtgui.cpp (qscreen-nativeInterface)]
        bool hasNativeScreen = false;
#ifdef Q_OS_WIN
        if (auto *winScreen = cppSelf->nativeInterface<QNativeInterface::QWindowsScreen>()) {
            hasNativeScreen = true;
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QNativeInterface_QWindowsScreen_IDX]), winScreen);
        }
#endif
        if (!hasNativeScreen) {
            Py_INCREF(Py_None);
            pyResult = Py_None;
        }
        // END of custom code block [file: ../glue/qtgui.cpp (qscreen-nativeInterface)]
        // ========================================================================
        // End of code injection


        // Ownership transferences.
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScreenFunc_nativeOrientation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScreen *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // nativeOrientation()const
        Qt::ScreenOrientation cppResult = const_cast<const ::QScreen *>(cppSelf)->nativeOrientation();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ScreenOrientation_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScreenFunc_orientation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScreen *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // orientation()const
        Qt::ScreenOrientation cppResult = const_cast<const ::QScreen *>(cppSelf)->orientation();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ScreenOrientation_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScreenFunc_physicalDotsPerInch(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScreen *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // physicalDotsPerInch()const
        qreal cppResult = const_cast<const ::QScreen *>(cppSelf)->physicalDotsPerInch();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScreenFunc_physicalDotsPerInchX(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScreen *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // physicalDotsPerInchX()const
        qreal cppResult = const_cast<const ::QScreen *>(cppSelf)->physicalDotsPerInchX();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScreenFunc_physicalDotsPerInchY(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScreen *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // physicalDotsPerInchY()const
        qreal cppResult = const_cast<const ::QScreen *>(cppSelf)->physicalDotsPerInchY();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScreenFunc_physicalSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScreen *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // physicalSize()const
        QSizeF cppResult = const_cast<const ::QScreen *>(cppSelf)->physicalSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScreenFunc_primaryOrientation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScreen *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // primaryOrientation()const
        Qt::ScreenOrientation cppResult = const_cast<const ::QScreen *>(cppSelf)->primaryOrientation();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ScreenOrientation_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScreenFunc_refreshRate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScreen *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // refreshRate()const
        qreal cppResult = const_cast<const ::QScreen *>(cppSelf)->refreshRate();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScreenFunc_resolveInterface(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScreen *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "resolveInterface", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QScreen::resolveInterface(const char*,int)const->void*
    if (numArgs == 2
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // resolveInterface(const char*,int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "resolveInterface", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // resolveInterface(const char*,int)const
            void * cppResult = const_cast<const ::QScreen *>(cppSelf)->resolveInterface(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScreenFunc_serialNumber(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScreen *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // serialNumber()const
        QString cppResult = const_cast<const ::QScreen *>(cppSelf)->serialNumber();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScreenFunc_size(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScreen *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // size()const
        QSize cppResult = const_cast<const ::QScreen *>(cppSelf)->size();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScreenFunc_transformBetween(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScreen *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "transformBetween", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QScreen::transformBetween(Qt::ScreenOrientation,Qt::ScreenOrientation,QRect)const->QTransform
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ScreenOrientation_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ScreenOrientation_IDX])))->converter, (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[2])))) {
        overloadId = 0; // transformBetween(Qt::ScreenOrientation,Qt::ScreenOrientation,QRect)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "transformBetween", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]);

    // Call function/method
    {
        ::Qt::ScreenOrientation cppArg0{Qt::PrimaryOrientation};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::Qt::ScreenOrientation cppArg1{Qt::PrimaryOrientation};
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QRect cppArg2_local;
        ::QRect *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2].isValue())
            pythonToCpp[2](pyArgs[2], &cppArg2_local);
        else
            pythonToCpp[2](pyArgs[2], &cppArg2);


        if (Shiboken::Errors::occurred() == nullptr) {
            // transformBetween(Qt::ScreenOrientation,Qt::ScreenOrientation,QRect)const
            QTransform cppResult = const_cast<const ::QScreen *>(cppSelf)->transformBetween(cppArg0, cppArg1, *cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScreenFunc_virtualGeometry(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScreen *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // virtualGeometry()const
        QRect cppResult = const_cast<const ::QScreen *>(cppSelf)->virtualGeometry();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScreenFunc_virtualSiblingAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScreen *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QScreen::virtualSiblingAt(QPoint)->QScreen*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArg)))) {
        overloadId = 0; // virtualSiblingAt(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "virtualSiblingAt", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPoint cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // virtualSiblingAt(QPoint)
            QScreen * cppResult = cppSelf->virtualSiblingAt(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScreenFunc_virtualSiblings(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScreen *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // virtualSiblings()const
        QList<QScreen*> cppResult = const_cast<const ::QScreen *>(cppSelf)->virtualSiblings();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QScreenPTR_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScreenFunc_virtualSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScreen *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // virtualSize()const
        QSize cppResult = const_cast<const ::QScreen *>(cppSelf)->virtualSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QScreen_PropertyStrings[] = {
    "availableGeometry:",
    "availableSize:",
    "availableVirtualGeometry:",
    "availableVirtualSize:",
    "depth:",
    "devicePixelRatio:",
    "geometry:",
    "logicalDotsPerInch:",
    "logicalDotsPerInchX:",
    "logicalDotsPerInchY:",
    "manufacturer:",
    "model:",
    "name:",
    "nativeOrientation:",
    "orientation:",
    "physicalDotsPerInch:",
    "physicalDotsPerInchX:",
    "physicalDotsPerInchY:",
    "physicalSize:",
    "primaryOrientation:",
    "refreshRate:",
    "serialNumber:",
    "size:",
    "virtualGeometry:",
    "virtualSize:",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QScreen_methods[] = {
    {"angleBetween", reinterpret_cast<PyCFunction>(Sbk_QScreenFunc_angleBetween), METH_VARARGS, nullptr},
    {"availableGeometry", reinterpret_cast<PyCFunction>(Sbk_QScreenFunc_availableGeometry), METH_NOARGS, nullptr},
    {"availableSize", reinterpret_cast<PyCFunction>(Sbk_QScreenFunc_availableSize), METH_NOARGS, nullptr},
    {"availableVirtualGeometry", reinterpret_cast<PyCFunction>(Sbk_QScreenFunc_availableVirtualGeometry), METH_NOARGS, nullptr},
    {"availableVirtualSize", reinterpret_cast<PyCFunction>(Sbk_QScreenFunc_availableVirtualSize), METH_NOARGS, nullptr},
    {"depth", reinterpret_cast<PyCFunction>(Sbk_QScreenFunc_depth), METH_NOARGS, nullptr},
    {"devicePixelRatio", reinterpret_cast<PyCFunction>(Sbk_QScreenFunc_devicePixelRatio), METH_NOARGS, nullptr},
    {"geometry", reinterpret_cast<PyCFunction>(Sbk_QScreenFunc_geometry), METH_NOARGS, nullptr},
    {"grabWindow", reinterpret_cast<PyCFunction>(Sbk_QScreenFunc_grabWindow), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"isLandscape", reinterpret_cast<PyCFunction>(Sbk_QScreenFunc_isLandscape), METH_O, nullptr},
    {"isPortrait", reinterpret_cast<PyCFunction>(Sbk_QScreenFunc_isPortrait), METH_O, nullptr},
    {"logicalDotsPerInch", reinterpret_cast<PyCFunction>(Sbk_QScreenFunc_logicalDotsPerInch), METH_NOARGS, nullptr},
    {"logicalDotsPerInchX", reinterpret_cast<PyCFunction>(Sbk_QScreenFunc_logicalDotsPerInchX), METH_NOARGS, nullptr},
    {"logicalDotsPerInchY", reinterpret_cast<PyCFunction>(Sbk_QScreenFunc_logicalDotsPerInchY), METH_NOARGS, nullptr},
    {"manufacturer", reinterpret_cast<PyCFunction>(Sbk_QScreenFunc_manufacturer), METH_NOARGS, nullptr},
    {"mapBetween", reinterpret_cast<PyCFunction>(Sbk_QScreenFunc_mapBetween), METH_VARARGS, nullptr},
    {"model", reinterpret_cast<PyCFunction>(Sbk_QScreenFunc_model), METH_NOARGS, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_QScreenFunc_name), METH_NOARGS, nullptr},
    {"nativeInterface", reinterpret_cast<PyCFunction>(Sbk_QScreenFunc_nativeInterface), METH_NOARGS, nullptr},
    {"nativeOrientation", reinterpret_cast<PyCFunction>(Sbk_QScreenFunc_nativeOrientation), METH_NOARGS, nullptr},
    {"orientation", reinterpret_cast<PyCFunction>(Sbk_QScreenFunc_orientation), METH_NOARGS, nullptr},
    {"physicalDotsPerInch", reinterpret_cast<PyCFunction>(Sbk_QScreenFunc_physicalDotsPerInch), METH_NOARGS, nullptr},
    {"physicalDotsPerInchX", reinterpret_cast<PyCFunction>(Sbk_QScreenFunc_physicalDotsPerInchX), METH_NOARGS, nullptr},
    {"physicalDotsPerInchY", reinterpret_cast<PyCFunction>(Sbk_QScreenFunc_physicalDotsPerInchY), METH_NOARGS, nullptr},
    {"physicalSize", reinterpret_cast<PyCFunction>(Sbk_QScreenFunc_physicalSize), METH_NOARGS, nullptr},
    {"primaryOrientation", reinterpret_cast<PyCFunction>(Sbk_QScreenFunc_primaryOrientation), METH_NOARGS, nullptr},
    {"refreshRate", reinterpret_cast<PyCFunction>(Sbk_QScreenFunc_refreshRate), METH_NOARGS, nullptr},
    {"resolveInterface", reinterpret_cast<PyCFunction>(Sbk_QScreenFunc_resolveInterface), METH_VARARGS, nullptr},
    {"serialNumber", reinterpret_cast<PyCFunction>(Sbk_QScreenFunc_serialNumber), METH_NOARGS, nullptr},
    {"size", reinterpret_cast<PyCFunction>(Sbk_QScreenFunc_size), METH_NOARGS, nullptr},
    {"transformBetween", reinterpret_cast<PyCFunction>(Sbk_QScreenFunc_transformBetween), METH_VARARGS, nullptr},
    {"virtualGeometry", reinterpret_cast<PyCFunction>(Sbk_QScreenFunc_virtualGeometry), METH_NOARGS, nullptr},
    {"virtualSiblingAt", reinterpret_cast<PyCFunction>(Sbk_QScreenFunc_virtualSiblingAt), METH_O, nullptr},
    {"virtualSiblings", reinterpret_cast<PyCFunction>(Sbk_QScreenFunc_virtualSiblings), METH_NOARGS, nullptr},
    {"virtualSize", reinterpret_cast<PyCFunction>(Sbk_QScreenFunc_virtualSize), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QScreen_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QScreen *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QScreenWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QScreen_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QScreen_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QScreen__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScreen *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QScreen_Type = nullptr;
static PyTypeObject *Sbk_QScreen_TypeF(void)
{
    return _Sbk_QScreen_Type;
}

static PyType_Slot Sbk_QScreen_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QScreen__repr__)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QScreen_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QScreen_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QScreen_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QScreen_methods)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QScreen_spec = {
    "2:PySide6.QtGui.QScreen",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QScreen_slots
};

} //extern "C"

static void *Sbk_QScreen_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QScreen *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QScreen_PythonToCpp_QScreen_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QScreen_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QScreen_PythonToCpp_QScreen_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QScreen_TypeF()))
        return QScreen_PythonToCpp_QScreen_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QScreen_PTR_CppToPython_QScreen(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QScreen *>(const_cast<void *>(cppIn)), Sbk_QScreen_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QScreen_SignatureStrings[] = {
    "PySide6.QtGui.QScreen.angleBetween(self,a:PySide6.QtCore.Qt.ScreenOrientation,b:PySide6.QtCore.Qt.ScreenOrientation)->int",
    "PySide6.QtGui.QScreen.availableGeometry(self)->PySide6.QtCore.QRect",
    "PySide6.QtGui.QScreen.availableSize(self)->PySide6.QtCore.QSize",
    "PySide6.QtGui.QScreen.availableVirtualGeometry(self)->PySide6.QtCore.QRect",
    "PySide6.QtGui.QScreen.availableVirtualSize(self)->PySide6.QtCore.QSize",
    "PySide6.QtGui.QScreen.depth(self)->int",
    "PySide6.QtGui.QScreen.devicePixelRatio(self)->qreal",
    "PySide6.QtGui.QScreen.geometry(self)->PySide6.QtCore.QRect",
    "PySide6.QtGui.QScreen.grabWindow(self,window:long=0,x:int=0,y:int=0,w:int=-1,h:int=-1)->PySide6.QtGui.QPixmap",
    "PySide6.QtGui.QScreen.isLandscape(self,orientation:PySide6.QtCore.Qt.ScreenOrientation)->bool",
    "PySide6.QtGui.QScreen.isPortrait(self,orientation:PySide6.QtCore.Qt.ScreenOrientation)->bool",
    "PySide6.QtGui.QScreen.logicalDotsPerInch(self)->qreal",
    "PySide6.QtGui.QScreen.logicalDotsPerInchX(self)->qreal",
    "PySide6.QtGui.QScreen.logicalDotsPerInchY(self)->qreal",
    "PySide6.QtGui.QScreen.manufacturer(self)->QString",
    "PySide6.QtGui.QScreen.mapBetween(self,a:PySide6.QtCore.Qt.ScreenOrientation,b:PySide6.QtCore.Qt.ScreenOrientation,rect:PySide6.QtCore.QRect)->PySide6.QtCore.QRect",
    "PySide6.QtGui.QScreen.model(self)->QString",
    "PySide6.QtGui.QScreen.name(self)->QString",
    "PySide6.QtGui.QScreen.nativeInterface(self)->PyObject",
    "PySide6.QtGui.QScreen.nativeOrientation(self)->PySide6.QtCore.Qt.ScreenOrientation",
    "PySide6.QtGui.QScreen.orientation(self)->PySide6.QtCore.Qt.ScreenOrientation",
    "PySide6.QtGui.QScreen.physicalDotsPerInch(self)->qreal",
    "PySide6.QtGui.QScreen.physicalDotsPerInchX(self)->qreal",
    "PySide6.QtGui.QScreen.physicalDotsPerInchY(self)->qreal",
    "PySide6.QtGui.QScreen.physicalSize(self)->PySide6.QtCore.QSizeF",
    "PySide6.QtGui.QScreen.primaryOrientation(self)->PySide6.QtCore.Qt.ScreenOrientation",
    "PySide6.QtGui.QScreen.refreshRate(self)->qreal",
    "PySide6.QtGui.QScreen.resolveInterface(self,name:char*,revision:int)->void",
    "PySide6.QtGui.QScreen.serialNumber(self)->QString",
    "PySide6.QtGui.QScreen.size(self)->PySide6.QtCore.QSize",
    "PySide6.QtGui.QScreen.transformBetween(self,a:PySide6.QtCore.Qt.ScreenOrientation,b:PySide6.QtCore.Qt.ScreenOrientation,target:PySide6.QtCore.QRect)->PySide6.QtGui.QTransform",
    "PySide6.QtGui.QScreen.virtualGeometry(self)->PySide6.QtCore.QRect",
    "PySide6.QtGui.QScreen.virtualSiblingAt(self,point:PySide6.QtCore.QPoint)->PySide6.QtGui.QScreen",
    "PySide6.QtGui.QScreen.virtualSiblings(self)->QList[PySide6.QtGui.QScreen]",
    "PySide6.QtGui.QScreen.virtualSize(self)->PySide6.QtCore.QSize",
    nullptr}; // Sentinel
#else
static constexpr size_t QScreen_SignatureByteSize = 487;
static constexpr uint8_t QScreen_SignatureBytes[487] = {
    0x78, 0xda, 0xb5, 0x55, 0x4d, 0x6f, 0xd4, 0x30, 0x10, 0xbd, 0xf3, 0x4b, 0x00, 0xa5, 0x2b, 0xb8,
    0x70, 0x88, 0x04, 0x12, 0x1f, 0xa2, 0xaa, 0x54, 0xd1, 0x6c, 0x17, 0x41, 0xab, 0x8a, 0xc3, 0x24,
    0x99, 0x4d, 0x06, 0x39, 0x9e, 0x30, 0x76, 0xb2, 0x0d, 0xbf, 0x1e, 0xef, 0x66, 0x53, 0x4a, 0x1b,
    0x2b, 0x6e, 0xd8, 0x3d, 0xd9, 0x51, 0xe6, 0x3d, 0x3f, 0xcf, 0xbc, 0x19, 0x27, 0xdd, 0x8a, 0x72,
    0x7c, 0xb3, 0x58, 0xda, 0xd3, 0x86, 0x16, 0xcb, 0x55, 0x26, 0x88, 0x7a, 0x01, 0xba, 0x50, 0xf8,
    0x01, 0xed, 0xc6, 0x7d, 0x3c, 0x37, 0xa8, 0xd6, 0x11, 0xc4, 0xc9, 0x5d, 0xe4, 0x47, 0x16, 0x74,
    0xcb, 0xa2, 0x0f, 0xbe, 0x10, 0x42, 0x6d, 0xc1, 0x12, 0xeb, 0x28, 0x0d, 0x89, 0x7a, 0x71, 0xf2,
    0x8e, 0xb4, 0x7d, 0x96, 0x8c, 0x9f, 0xdc, 0x02, 0x29, 0x48, 0x15, 0x9e, 0x22, 0x57, 0x68, 0xa5,
    0xdb, 0x1d, 0xef, 0x20, 0x0f, 0x89, 0x2f, 0x31, 0x9b, 0xe4, 0x58, 0xd1, 0x6f, 0xf4, 0xe1, 0xb7,
    0xff, 0xa6, 0xf0, 0xdf, 0x48, 0x6c, 0x03, 0xea, 0x10, 0x52, 0xf6, 0x54, 0x33, 0x15, 0xe5, 0x58,
    0xdb, 0x72, 0xc0, 0xf9, 0x93, 0x97, 0x63, 0x4b, 0x19, 0x26, 0x74, 0x8b, 0xea, 0x72, 0x9b, 0xea,
    0x01, 0xf1, 0x4b, 0x10, 0x94, 0x07, 0x53, 0xcc, 0xbf, 0x5c, 0x21, 0x90, 0x7e, 0x27, 0x9d, 0xf3,
    0xa6, 0xf7, 0xc8, 0x66, 0xb7, 0x8f, 0x15, 0xeb, 0xe2, 0xed, 0xab, 0xe8, 0x36, 0x76, 0x42, 0xdd,
    0xda, 0xed, 0xd7, 0xcd, 0x6e, 0x3d, 0x79, 0x1d, 0x95, 0xfb, 0xcd, 0x3f, 0x87, 0xed, 0x78, 0x9d,
    0xf2, 0x0a, 0x6a, 0xcf, 0x69, 0x64, 0xce, 0x41, 0xe7, 0x26, 0x83, 0xba, 0xcf, 0x60, 0xc4, 0x7f,
    0x2d, 0x15, 0x68, 0xbb, 0x94, 0x59, 0x79, 0xd9, 0x13, 0x16, 0x2b, 0x40, 0xf6, 0x08, 0xe4, 0x8a,
    0x0b, 0xca, 0x40, 0x7d, 0x62, 0x6b, 0x12, 0x94, 0x33, 0x9d, 0x95, 0x21, 0x95, 0x79, 0x8c, 0xba,
    0x9a, 0x07, 0xbb, 0x0e, 0x81, 0x55, 0xa0, 0x9b, 0x35, 0x64, 0xb6, 0x11, 0x94, 0x21, 0x7e, 0xb9,
    0xb2, 0x42, 0xba, 0xf0, 0x22, 0xea, 0x63, 0x8d, 0x88, 0x48, 0x9c, 0xeb, 0xe2, 0x31, 0x2b, 0x3e,
    0xcd, 0xa1, 0x15, 0xe7, 0xa8, 0xc2, 0x6e, 0xa3, 0xa1, 0xc2, 0xd0, 0x48, 0x4b, 0x2d, 0x9e, 0x69,
    0x8b, 0xe2, 0x12, 0x76, 0xaf, 0x9d, 0x2f, 0xd2, 0x9f, 0x7e, 0x29, 0x3d, 0xea, 0xde, 0x1d, 0x7d,
    0x0d, 0x37, 0x92, 0x0e, 0x0f, 0x25, 0x1f, 0x92, 0xac, 0x2e, 0x3b, 0x33, 0xc3, 0xa4, 0x23, 0xb0,
    0xab, 0x99, 0xb8, 0xeb, 0xa7, 0xe0, 0xa6, 0x06, 0xe9, 0x67, 0x1f, 0x5e, 0xa8, 0x02, 0xe9, 0x0e,
    0x5a, 0x07, 0xc1, 0xb5, 0xa0, 0x29, 0xdd, 0xc8, 0xc5, 0x90, 0x2b, 0xb8, 0x58, 0x56, 0x0f, 0x0d,
    0x14, 0x6d, 0xfd, 0x17, 0x67, 0x25, 0xc8, 0x4b, 0x67, 0xfe, 0x96, 0xcc, 0x76, 0xf0, 0xb8, 0x39,
    0xe9, 0xb8, 0x5a, 0xa6, 0xdc, 0x43, 0x65, 0x50, 0x08, 0xd4, 0x97, 0xa6, 0x4a, 0x43, 0x9b, 0xd6,
    0xcc, 0x7b, 0x80, 0xdc, 0x64, 0xd4, 0x66, 0xcd, 0x52, 0x1d, 0xad, 0xe3, 0x2d, 0x48, 0x81, 0x01,
    0x3d, 0xbf, 0x53, 0xf5, 0x75, 0x90, 0xe3, 0x91, 0xdb, 0xfe, 0xf7, 0xc3, 0xdd, 0x0e, 0xef, 0x75,
    0xaa, 0x5c, 0x32, 0xdf, 0xef, 0x5f, 0x85, 0x9a, 0x5d, 0x49, 0x1e, 0x69, 0x4c, 0xb8, 0x2f, 0xd4,
    0x28, 0x53, 0x10, 0xbf, 0xb9, 0x2b, 0xde, 0x39, 0x19, 0x7b, 0x33, 0x0a, 0xf9, 0x31, 0xc5, 0x34,
    0x51, 0xd8, 0x3f, 0x83, 0xb8, 0x89, 0xca
};
#endif

PyTypeObject *init_QScreen(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX].type;

    Shiboken::AutoDecRef Sbk_QScreen_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QScreen_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QScreen",
        "QScreen*",
        &Sbk_QScreen_spec,
        &Shiboken::callCppDestructor< QScreen >,
        Sbk_QScreen_Type_bases.object(),
        0);
    auto *pyType = Sbk_QScreen_TypeF(); // references _Sbk_QScreen_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QScreen_SignatureStrings);
#else
    InitSignatureBytes(pyType, QScreen_SignatureBytes, QScreen_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QScreen_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QScreen_PythonToCpp_QScreen_PTR,
        is_QScreen_PythonToCpp_QScreen_PTR_Convertible,
        QScreen_PTR_CppToPython_QScreen);

    Shiboken::Conversions::registerConverterName(converter, "QScreen");
    Shiboken::Conversions::registerConverterName(converter, "QScreen*");
    Shiboken::Conversions::registerConverterName(converter, "QScreen&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QScreen).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QScreenWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QScreen_TypeF(), &Sbk_QScreen_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::QScreen::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QScreen::staticMetaObject, sizeof(QScreenWrapper));

    return pyType;
}
