// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qscrollevent_wrapper.h"

// Argument includes
#include <QtGui/qevent.h>
#include <qcoreevent.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QScrollEventWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QScrollEventWrapper::QScrollEventWrapper(const ::QPointF & contentPos, const ::QPointF & overshoot, ::QScrollEvent::ScrollState scrollState) : QScrollEvent(contentPos, overshoot, scrollState)
{
}

::QScrollEvent * QScrollEventWrapper::clone() const
{
    if (m_PyMethodCache[0])
        return this->::QScrollEvent::clone();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "clone";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QScrollEvent::clone();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QScrollEvent", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScrollEvent_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QScrollEvent", funcName, Shiboken::SbkType< QScrollEvent >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QScrollEvent *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QScrollEventWrapper::setAccepted(bool accepted)
{
    if (m_PyMethodCache[1]) {
        return this->::QEvent::setAccepted(accepted);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setAccepted";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QEvent::setAccepted(accepted);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &accepted)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &accepted)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QScrollEvent", funcName);
        return;
    }
}

QScrollEventWrapper::~QScrollEventWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QScrollEvent_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QScrollEvent >()))
        return -1;

    QScrollEventWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 2)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QScrollEvent_IDX]);

    if (PyArg_UnpackTuple(args, "QScrollEvent", 1, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QScrollEvent::QScrollEvent(QPointF,QPointF,QScrollEvent::ScrollState)
    // 1: QScrollEvent::QScrollEvent(QScrollEvent)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScrollEvent_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QScrollEvent(QScrollEvent)
    } else if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScrollEvent_ScrollState_IDX])))->converter, (pyArgs[2])))) {
        overloadId = 0; // QScrollEvent(QPointF,QPointF,QScrollEvent::ScrollState)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QScrollEvent_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QScrollEvent_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QScrollEvent(const QPointF &contentPos, const QPointF &overshoot, QScrollEvent::ScrollState scrollState)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPointF cppArg0_local;
            ::QPointF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QPointF cppArg1_local;
            ::QPointF *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            ::QScrollEvent::ScrollState cppArg2{QScrollEvent::ScrollStarted};
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QScrollEvent(QPointF,QPointF,QScrollEvent::ScrollState)
                cptr = new QScrollEventWrapper(*cppArg0, *cppArg1, cppArg2);
            }
            break;
        }
        case 1: // QScrollEvent(const QScrollEvent &arg__1)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QScrollEvent *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QScrollEvent(QScrollEvent)
                cptr = new QScrollEventWrapper(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QScrollEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QScrollEvent_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QScrollEventFunc_clone(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScrollEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScrollEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clone()const
        QScrollEvent * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QScrollEvent *>(cppSelf)->::QScrollEvent::clone()
            : const_cast<const ::QScrollEvent *>(cppSelf)->clone();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScrollEvent_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScrollEventFunc_contentPos(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScrollEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScrollEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // contentPos()const
        QPointF cppResult = const_cast<const ::QScrollEvent *>(cppSelf)->contentPos();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScrollEventFunc_overshootDistance(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScrollEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScrollEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // overshootDistance()const
        QPointF cppResult = const_cast<const ::QScrollEvent *>(cppSelf)->overshootDistance();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScrollEventFunc_scrollState(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScrollEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScrollEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // scrollState()const
        QScrollEvent::ScrollState cppResult = const_cast<const ::QScrollEvent *>(cppSelf)->scrollState();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScrollEvent_ScrollState_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QScrollEvent_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QScrollEvent_EnumFlagInfo[] = {
    "ScrollState:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QScrollEvent_methods[] = {
    {"clone", reinterpret_cast<PyCFunction>(Sbk_QScrollEventFunc_clone), METH_NOARGS, nullptr},
    {"contentPos", reinterpret_cast<PyCFunction>(Sbk_QScrollEventFunc_contentPos), METH_NOARGS, nullptr},
    {"overshootDistance", reinterpret_cast<PyCFunction>(Sbk_QScrollEventFunc_overshootDistance), METH_NOARGS, nullptr},
    {"scrollState", reinterpret_cast<PyCFunction>(Sbk_QScrollEventFunc_scrollState), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QScrollEvent_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QScrollEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScrollEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QScrollEventWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QScrollEvent_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QScrollEvent_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QScrollEvent_Type = nullptr;
static PyTypeObject *Sbk_QScrollEvent_TypeF(void)
{
    return _Sbk_QScrollEvent_Type;
}

static PyType_Slot Sbk_QScrollEvent_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QScrollEvent_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QScrollEvent_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QScrollEvent_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QScrollEvent_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QScrollEvent_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QScrollEvent_spec = {
    "2:PySide6.QtGui.QScrollEvent",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QScrollEvent_slots
};

} //extern "C"

static void *Sbk_QScrollEvent_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if ( reinterpret_cast< ::QEvent *>(cptr)->type() == QEvent::Scroll)
        return cptr;
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QScrollEvent_ScrollState(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QScrollEvent::ScrollState>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QScrollEvent::ScrollState *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QScrollEvent_ScrollState_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScrollEvent_ScrollState_IDX])))
        return Enum_PythonToCpp_QScrollEvent_ScrollState;
    return {};
}

static PyObject *QScrollEvent_ScrollState_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QScrollEvent::ScrollState>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QScrollEvent::ScrollState *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScrollEvent_ScrollState_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QScrollEvent_PythonToCpp_QScrollEvent_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QScrollEvent_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QScrollEvent_PythonToCpp_QScrollEvent_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QScrollEvent_TypeF()))
        return QScrollEvent_PythonToCpp_QScrollEvent_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QScrollEvent_PTR_CppToPython_QScrollEvent(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QScrollEvent *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QScrollEvent_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QScrollEvent_SignatureStrings[] = {
    "1:PySide6.QtGui.QScrollEvent(self,contentPos:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],overshoot:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],scrollState:PySide6.QtGui.QScrollEvent.ScrollState)",
    "0:PySide6.QtGui.QScrollEvent(self,arg__1:PySide6.QtGui.QScrollEvent)",
    "PySide6.QtGui.QScrollEvent.clone(self)->PySide6.QtGui.QScrollEvent",
    "PySide6.QtGui.QScrollEvent.contentPos(self)->PySide6.QtCore.QPointF",
    "PySide6.QtGui.QScrollEvent.overshootDistance(self)->PySide6.QtCore.QPointF",
    "PySide6.QtGui.QScrollEvent.scrollState(self)->PySide6.QtGui.QScrollEvent.ScrollState",
    nullptr}; // Sentinel
#else
static constexpr size_t QScrollEvent_SignatureByteSize = 190;
static constexpr uint8_t QScrollEvent_SignatureBytes[190] = {
    0x78, 0xda, 0xb5, 0x91, 0x31, 0x0b, 0xc2, 0x30, 0x10, 0x85, 0xf7, 0xfe, 0x0a, 0x47, 0x0b, 0x35,
    0xd8, 0xc5, 0xa1, 0x83, 0x8b, 0x56, 0xd7, 0x94, 0xe2, 0x24, 0x52, 0x42, 0x3c, 0xdb, 0x40, 0xcc,
    0x49, 0x72, 0x16, 0xfa, 0xef, 0x2d, 0x1d, 0xda, 0x80, 0x9a, 0x82, 0xe0, 0x78, 0x8f, 0x77, 0xef,
    0x71, 0xdf, 0xa5, 0x19, 0xef, 0x4a, 0x75, 0x85, 0x0d, 0x2b, 0xe8, 0xf8, 0x54, 0xac, 0x28, 0xa5,
    0x45, 0xad, 0xf3, 0x16, 0x0c, 0x2d, 0x1d, 0xe8, 0x5b, 0x22, 0xd1, 0x50, 0x3f, 0x70, 0x74, 0x19,
    0x75, 0x0f, 0x65, 0x6a, 0x76, 0x32, 0x0a, 0xcd, 0x79, 0xda, 0xdb, 0xa1, 0x05, 0x56, 0x70, 0x54,
    0x86, 0x0e, 0xc9, 0xe2, 0xa3, 0xee, 0xcb, 0x43, 0x0d, 0x17, 0xbd, 0x0a, 0x96, 0x0b, 0x6a, 0x58,
    0xae, 0xe1, 0xde, 0x37, 0x5c, 0x12, 0x6c, 0xc1, 0xba, 0x06, 0x91, 0xfe, 0xde, 0xe4, 0x86, 0x2b,
    0x4b, 0x12, 0x04, 0x01, 0x00, 0xac, 0x9c, 0x6c, 0x71, 0xb4, 0x9e, 0x45, 0x25, 0x6c, 0x5d, 0x55,
    0x69, 0xc0, 0x16, 0x47, 0x81, 0x32, 0xa9, 0xd1, 0xc0, 0x10, 0x14, 0xaf, 0xb6, 0xdf, 0x7d, 0xc1,
    0x88, 0xf1, 0x57, 0xef, 0x39, 0x3e, 0xbb, 0x50, 0xc6, 0xf8, 0x84, 0xbd, 0x72, 0x24, 0x8c, 0x84,
    0xdf, 0xa3, 0x3c, 0xca, 0xf3, 0x77, 0xf9, 0xb0, 0xa3, 0x17, 0xa0, 0xf1, 0xed, 0xcd
};
#endif

PyTypeObject *init_QScrollEvent(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QScrollEvent_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QScrollEvent_IDX].type;

    Shiboken::AutoDecRef Sbk_QScrollEvent_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]))));

    _Sbk_QScrollEvent_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QScrollEvent",
        "QScrollEvent*",
        &Sbk_QScrollEvent_spec,
        &Shiboken::callCppDestructor< QScrollEvent >,
        Sbk_QScrollEvent_Type_bases.object(),
        0);
    auto *pyType = Sbk_QScrollEvent_TypeF(); // references _Sbk_QScrollEvent_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QScrollEvent_SignatureStrings);
#else
    InitSignatureBytes(pyType, QScrollEvent_SignatureBytes, QScrollEvent_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QScrollEvent_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QScrollEvent_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QScrollEvent_PythonToCpp_QScrollEvent_PTR,
        is_QScrollEvent_PythonToCpp_QScrollEvent_PTR_Convertible,
        QScrollEvent_PTR_CppToPython_QScrollEvent);

    Shiboken::Conversions::registerConverterName(converter, "QScrollEvent");
    Shiboken::Conversions::registerConverterName(converter, "QScrollEvent*");
    Shiboken::Conversions::registerConverterName(converter, "QScrollEvent&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QScrollEvent).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QScrollEventWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QScrollEvent_TypeF(), &Sbk_QScrollEvent_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QScrollEvent_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'ScrollState'.
    const char *ScrollState_Initializer[] = {
        "ScrollStarted",
        "ScrollUpdated",
        "ScrollFinished",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ScrollState_InitializerValues[] = {
        uint8_t(QScrollEvent::ScrollState::ScrollStarted), //  0x00  0
        uint8_t(QScrollEvent::ScrollState::ScrollUpdated), //  0x01  1
        uint8_t(QScrollEvent::ScrollState::ScrollFinished) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QScrollEvent_TypeF(),
        "2:PySide6.QtGui.QScrollEvent.ScrollState",
        ScrollState_Initializer, ScrollState_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QScrollEvent_ScrollState_IDX].type = EType;
    // Register converter for enum 'QScrollEvent::ScrollState'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QScrollEvent_ScrollState_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QScrollEvent_ScrollState,
            is_Enum_PythonToCpp_QScrollEvent_ScrollState_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QScrollEvent::ScrollState");
        Shiboken::Conversions::registerConverterAlias(converter, "ScrollState");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ScrollState' enum.

    qRegisterMetaType< ::QScrollEvent::ScrollState >("QScrollEvent::ScrollState");

    return pyType;
}
