// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qscrollprepareevent_wrapper.h"

// Argument includes
#include <QtGui/qevent.h>
#include <qcoreevent.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qrect.h>
#include <qsize.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QScrollPrepareEventWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QScrollPrepareEventWrapper::QScrollPrepareEventWrapper(const ::QPointF & startPos) : QScrollPrepareEvent(startPos)
{
}

::QScrollPrepareEvent * QScrollPrepareEventWrapper::clone() const
{
    if (m_PyMethodCache[0])
        return this->::QScrollPrepareEvent::clone();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "clone";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QScrollPrepareEvent::clone();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QScrollPrepareEvent", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScrollPrepareEvent_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QScrollPrepareEvent", funcName, Shiboken::SbkType< QScrollPrepareEvent >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QScrollPrepareEvent *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QScrollPrepareEventWrapper::setAccepted(bool accepted)
{
    if (m_PyMethodCache[1]) {
        return this->::QEvent::setAccepted(accepted);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setAccepted";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QEvent::setAccepted(accepted);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &accepted)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &accepted)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QScrollPrepareEvent", funcName);
        return;
    }
}

QScrollPrepareEventWrapper::~QScrollPrepareEventWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QScrollPrepareEvent_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QScrollPrepareEvent >()))
        return -1;

    QScrollPrepareEventWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QScrollPrepareEvent", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QScrollPrepareEvent::QScrollPrepareEvent(QPointF)
    // 1: QScrollPrepareEvent::QScrollPrepareEvent(QScrollPrepareEvent)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScrollPrepareEvent_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QScrollPrepareEvent(QScrollPrepareEvent)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QScrollPrepareEvent(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QScrollPrepareEvent_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QScrollPrepareEvent_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QScrollPrepareEvent(const QPointF &startPos)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPointF cppArg0_local;
            ::QPointF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QScrollPrepareEvent(QPointF)
                cptr = new QScrollPrepareEventWrapper(*cppArg0);
            }
            break;
        }
        case 1: // QScrollPrepareEvent(const QScrollPrepareEvent &arg__1)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QScrollPrepareEvent *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QScrollPrepareEvent(QScrollPrepareEvent)
                cptr = new QScrollPrepareEventWrapper(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QScrollPrepareEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QScrollPrepareEvent_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QScrollPrepareEventFunc_clone(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScrollPrepareEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScrollPrepareEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clone()const
        QScrollPrepareEvent * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QScrollPrepareEvent *>(cppSelf)->::QScrollPrepareEvent::clone()
            : const_cast<const ::QScrollPrepareEvent *>(cppSelf)->clone();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScrollPrepareEvent_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScrollPrepareEventFunc_contentPos(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScrollPrepareEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScrollPrepareEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // contentPos()const
        QPointF cppResult = const_cast<const ::QScrollPrepareEvent *>(cppSelf)->contentPos();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScrollPrepareEventFunc_contentPosRange(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScrollPrepareEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScrollPrepareEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // contentPosRange()const
        QRectF cppResult = const_cast<const ::QScrollPrepareEvent *>(cppSelf)->contentPosRange();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScrollPrepareEventFunc_setContentPos(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScrollPrepareEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScrollPrepareEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QScrollPrepareEvent::setContentPos(QPointF)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArg)))) {
        overloadId = 0; // setContentPos(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setContentPos", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QScrollPrepareEvent_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPointF cppArg0_local;
        ::QPointF *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setContentPos(QPointF)
            cppSelf->setContentPos(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QScrollPrepareEventFunc_setContentPosRange(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScrollPrepareEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScrollPrepareEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QScrollPrepareEvent::setContentPosRange(QRectF)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArg)))) {
        overloadId = 0; // setContentPosRange(QRectF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setContentPosRange", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QScrollPrepareEvent_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRectF cppArg0_local;
        ::QRectF *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setContentPosRange(QRectF)
            cppSelf->setContentPosRange(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QScrollPrepareEventFunc_setViewportSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScrollPrepareEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScrollPrepareEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QScrollPrepareEvent::setViewportSize(QSizeF)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), (pyArg)))) {
        overloadId = 0; // setViewportSize(QSizeF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setViewportSize", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QScrollPrepareEvent_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSizeF cppArg0_local;
        ::QSizeF *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setViewportSize(QSizeF)
            cppSelf->setViewportSize(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QScrollPrepareEventFunc_startPos(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScrollPrepareEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScrollPrepareEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // startPos()const
        QPointF cppResult = const_cast<const ::QScrollPrepareEvent *>(cppSelf)->startPos();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScrollPrepareEventFunc_viewportSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScrollPrepareEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScrollPrepareEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // viewportSize()const
        QSizeF cppResult = const_cast<const ::QScrollPrepareEvent *>(cppSelf)->viewportSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QScrollPrepareEvent_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QScrollPrepareEvent_methods[] = {
    {"clone", reinterpret_cast<PyCFunction>(Sbk_QScrollPrepareEventFunc_clone), METH_NOARGS, nullptr},
    {"contentPos", reinterpret_cast<PyCFunction>(Sbk_QScrollPrepareEventFunc_contentPos), METH_NOARGS, nullptr},
    {"contentPosRange", reinterpret_cast<PyCFunction>(Sbk_QScrollPrepareEventFunc_contentPosRange), METH_NOARGS, nullptr},
    {"setContentPos", reinterpret_cast<PyCFunction>(Sbk_QScrollPrepareEventFunc_setContentPos), METH_O, nullptr},
    {"setContentPosRange", reinterpret_cast<PyCFunction>(Sbk_QScrollPrepareEventFunc_setContentPosRange), METH_O, nullptr},
    {"setViewportSize", reinterpret_cast<PyCFunction>(Sbk_QScrollPrepareEventFunc_setViewportSize), METH_O, nullptr},
    {"startPos", reinterpret_cast<PyCFunction>(Sbk_QScrollPrepareEventFunc_startPos), METH_NOARGS, nullptr},
    {"viewportSize", reinterpret_cast<PyCFunction>(Sbk_QScrollPrepareEventFunc_viewportSize), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QScrollPrepareEvent_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QScrollPrepareEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScrollPrepareEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QScrollPrepareEventWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QScrollPrepareEvent_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QScrollPrepareEvent_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QScrollPrepareEvent_Type = nullptr;
static PyTypeObject *Sbk_QScrollPrepareEvent_TypeF(void)
{
    return _Sbk_QScrollPrepareEvent_Type;
}

static PyType_Slot Sbk_QScrollPrepareEvent_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QScrollPrepareEvent_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QScrollPrepareEvent_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QScrollPrepareEvent_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QScrollPrepareEvent_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QScrollPrepareEvent_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QScrollPrepareEvent_spec = {
    "2:PySide6.QtGui.QScrollPrepareEvent",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QScrollPrepareEvent_slots
};

} //extern "C"

static void *Sbk_QScrollPrepareEvent_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if ( reinterpret_cast< ::QEvent *>(cptr)->type() == QEvent::ScrollPrepare)
        return cptr;
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QScrollPrepareEvent_PythonToCpp_QScrollPrepareEvent_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QScrollPrepareEvent_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QScrollPrepareEvent_PythonToCpp_QScrollPrepareEvent_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QScrollPrepareEvent_TypeF()))
        return QScrollPrepareEvent_PythonToCpp_QScrollPrepareEvent_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QScrollPrepareEvent_PTR_CppToPython_QScrollPrepareEvent(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QScrollPrepareEvent *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QScrollPrepareEvent_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QScrollPrepareEvent_SignatureStrings[] = {
    "1:PySide6.QtGui.QScrollPrepareEvent(self,startPos:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element])",
    "0:PySide6.QtGui.QScrollPrepareEvent(self,arg__1:PySide6.QtGui.QScrollPrepareEvent)",
    "PySide6.QtGui.QScrollPrepareEvent.clone(self)->PySide6.QtGui.QScrollPrepareEvent",
    "PySide6.QtGui.QScrollPrepareEvent.contentPos(self)->PySide6.QtCore.QPointF",
    "PySide6.QtGui.QScrollPrepareEvent.contentPosRange(self)->PySide6.QtCore.QRectF",
    "PySide6.QtGui.QScrollPrepareEvent.setContentPos(self,pos:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element])",
    "PySide6.QtGui.QScrollPrepareEvent.setContentPosRange(self,rect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect])",
    "PySide6.QtGui.QScrollPrepareEvent.setViewportSize(self,size:typing.Union[PySide6.QtCore.QSizeF, PySide6.QtCore.QSize])",
    "PySide6.QtGui.QScrollPrepareEvent.startPos(self)->PySide6.QtCore.QPointF",
    "PySide6.QtGui.QScrollPrepareEvent.viewportSize(self)->PySide6.QtCore.QSizeF",
    nullptr}; // Sentinel
#else
static constexpr size_t QScrollPrepareEvent_SignatureByteSize = 234;
static constexpr uint8_t QScrollPrepareEvent_SignatureBytes[234] = {
    0x78, 0xda, 0xbd, 0x53, 0x3d, 0x0b, 0xc2, 0x30, 0x10, 0xdd, 0xfb, 0x2b, 0x1c, 0x2d, 0xd4, 0xa0,
    0x8b, 0x83, 0x83, 0x8b, 0xa8, 0x6b, 0xda, 0xa2, 0x8b, 0x88, 0x84, 0x7a, 0xd6, 0x40, 0x4c, 0xca,
    0x25, 0x2a, 0xfa, 0xeb, 0x4d, 0x8b, 0xd0, 0x6a, 0x6b, 0x1b, 0x11, 0xdc, 0xc2, 0xe3, 0xdd, 0xfb,
    0xb8, 0x24, 0xa3, 0x09, 0xbd, 0xc5, 0x7c, 0x0f, 0x63, 0x12, 0x9a, 0xe5, 0x99, 0x93, 0x30, 0x4e,
    0x50, 0x09, 0x41, 0x11, 0x32, 0x86, 0x30, 0xbf, 0x80, 0x34, 0x7d, 0x0d, 0xe2, 0x10, 0x68, 0xc3,
    0xd0, 0x50, 0xa5, 0x27, 0xe6, 0x96, 0x71, 0x99, 0x92, 0x95, 0xe4, 0x4a, 0x6e, 0xca, 0xe1, 0x99,
    0x42, 0x20, 0x21, 0x55, 0x5c, 0x9a, 0x45, 0xd0, 0x6b, 0xc4, 0xab, 0x70, 0xe1, 0x45, 0x99, 0x45,
    0x01, 0x29, 0x33, 0x47, 0x32, 0x17, 0x70, 0xb2, 0x66, 0x5b, 0xdf, 0x1b, 0xba, 0x46, 0x62, 0x98,
    0xee, 0x76, 0xa3, 0x6e, 0xb6, 0xef, 0x75, 0x52, 0x48, 0x22, 0x94, 0x84, 0x42, 0xd6, 0x1f, 0x4c,
    0x3b, 0xe9, 0x2e, 0x82, 0xca, 0x56, 0x93, 0xf9, 0xc6, 0xea, 0xaa, 0xd5, 0x5d, 0x7d, 0x25, 0x15,
    0x31, 0x99, 0xc2, 0x27, 0xbd, 0x08, 0x12, 0x27, 0x39, 0x0d, 0x76, 0xe0, 0x25, 0x5c, 0x90, 0xfd,
    0xe3, 0x5e, 0xbf, 0x4c, 0x56, 0x76, 0x0d, 0xd0, 0x36, 0x6b, 0xcf, 0x57, 0x74, 0xaf, 0xc7, 0xcb,
    0x61, 0x57, 0xe7, 0x35, 0x87, 0x6b, 0xa6, 0xd0, 0xc4, 0xfc, 0xfe, 0xb4, 0xd5, 0xf6, 0xd4, 0x6e,
    0x9b, 0x73, 0x1b, 0x6c, 0x73, 0xd8, 0xcd, 0xf6, 0xf9, 0xa9, 0x7e, 0x7e, 0x22, 0x97, 0xf7, 0xf0,
    0x0d, 0x62, 0x45, 0x58, 0xef, 0x01, 0x48, 0xaf, 0x6b, 0x8e
};
#endif

PyTypeObject *init_QScrollPrepareEvent(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QScrollPrepareEvent_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QScrollPrepareEvent_IDX].type;

    Shiboken::AutoDecRef Sbk_QScrollPrepareEvent_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]))));

    _Sbk_QScrollPrepareEvent_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QScrollPrepareEvent",
        "QScrollPrepareEvent*",
        &Sbk_QScrollPrepareEvent_spec,
        &Shiboken::callCppDestructor< QScrollPrepareEvent >,
        Sbk_QScrollPrepareEvent_Type_bases.object(),
        0);
    auto *pyType = Sbk_QScrollPrepareEvent_TypeF(); // references _Sbk_QScrollPrepareEvent_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QScrollPrepareEvent_SignatureStrings);
#else
    InitSignatureBytes(pyType, QScrollPrepareEvent_SignatureBytes, QScrollPrepareEvent_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QScrollPrepareEvent_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QScrollPrepareEvent_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QScrollPrepareEvent_PythonToCpp_QScrollPrepareEvent_PTR,
        is_QScrollPrepareEvent_PythonToCpp_QScrollPrepareEvent_PTR_Convertible,
        QScrollPrepareEvent_PTR_CppToPython_QScrollPrepareEvent);

    Shiboken::Conversions::registerConverterName(converter, "QScrollPrepareEvent");
    Shiboken::Conversions::registerConverterName(converter, "QScrollPrepareEvent*");
    Shiboken::Conversions::registerConverterName(converter, "QScrollPrepareEvent&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QScrollPrepareEvent).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QScrollPrepareEventWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QScrollPrepareEvent_TypeF(), &Sbk_QScrollPrepareEvent_typeDiscovery);


    return pyType;
}
