// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qsessionmanager_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QStringList>
#include <QtGui/qsessionmanager.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QSessionManagerFunc_allowsErrorInteraction(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSessionManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSessionManager_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // allowsErrorInteraction()
        bool cppResult = cppSelf->allowsErrorInteraction();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSessionManagerFunc_allowsInteraction(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSessionManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSessionManager_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // allowsInteraction()
        bool cppResult = cppSelf->allowsInteraction();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSessionManagerFunc_cancel(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSessionManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSessionManager_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cancel()
        cppSelf->cancel();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSessionManagerFunc_discardCommand(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSessionManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSessionManager_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // discardCommand()const
        QStringList cppResult = const_cast<const ::QSessionManager *>(cppSelf)->discardCommand();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSessionManagerFunc_isPhase2(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSessionManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSessionManager_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isPhase2()const
        bool cppResult = const_cast<const ::QSessionManager *>(cppSelf)->isPhase2();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSessionManagerFunc_release(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSessionManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSessionManager_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // release()
        cppSelf->release();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSessionManagerFunc_requestPhase2(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSessionManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSessionManager_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // requestPhase2()
        cppSelf->requestPhase2();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSessionManagerFunc_restartCommand(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSessionManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSessionManager_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // restartCommand()const
        QStringList cppResult = const_cast<const ::QSessionManager *>(cppSelf)->restartCommand();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSessionManagerFunc_restartHint(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSessionManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSessionManager_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // restartHint()const
        QSessionManager::RestartHint cppResult = const_cast<const ::QSessionManager *>(cppSelf)->restartHint();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSessionManager_RestartHint_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSessionManagerFunc_sessionId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSessionManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSessionManager_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sessionId()const
        QString cppResult = const_cast<const ::QSessionManager *>(cppSelf)->sessionId();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSessionManagerFunc_sessionKey(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSessionManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSessionManager_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sessionKey()const
        QString cppResult = const_cast<const ::QSessionManager *>(cppSelf)->sessionKey();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSessionManagerFunc_setDiscardCommand(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSessionManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSessionManager_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSessionManager::setDiscardCommand(QStringList)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // setDiscardCommand(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDiscardCommand", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QSessionManager_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDiscardCommand(QStringList)
            cppSelf->setDiscardCommand(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSessionManagerFunc_setManagerProperty(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSessionManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSessionManager_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setManagerProperty", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSessionManager::setManagerProperty(QString,QString)
    // 1: QSessionManager::setManagerProperty(QString,QStringList)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[1])))) {
            overloadId = 1; // setManagerProperty(QString,QStringList)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 0; // setManagerProperty(QString,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setManagerProperty", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QSessionManager_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setManagerProperty(const QString &name, const QString &value)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setManagerProperty(QString,QString)
                cppSelf->setManagerProperty(cppArg0, cppArg1);
            }
            break;
        }
        case 1: // setManagerProperty(const QString &name, const QStringList &value)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QStringList cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setManagerProperty(QString,QStringList)
                cppSelf->setManagerProperty(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSessionManagerFunc_setRestartCommand(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSessionManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSessionManager_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSessionManager::setRestartCommand(QStringList)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // setRestartCommand(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRestartCommand", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QSessionManager_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRestartCommand(QStringList)
            cppSelf->setRestartCommand(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSessionManagerFunc_setRestartHint(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSessionManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSessionManager_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSessionManager::setRestartHint(QSessionManager::RestartHint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSessionManager_RestartHint_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setRestartHint(QSessionManager::RestartHint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRestartHint", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QSessionManager_IDX]);

    // Call function/method
    {
        ::QSessionManager::RestartHint cppArg0{QSessionManager::RestartIfRunning};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRestartHint(QSessionManager::RestartHint)
            cppSelf->setRestartHint(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QSessionManager_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QSessionManager_EnumFlagInfo[] = {
    "RestartHint:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSessionManager_methods[] = {
    {"allowsErrorInteraction", reinterpret_cast<PyCFunction>(Sbk_QSessionManagerFunc_allowsErrorInteraction), METH_NOARGS, nullptr},
    {"allowsInteraction", reinterpret_cast<PyCFunction>(Sbk_QSessionManagerFunc_allowsInteraction), METH_NOARGS, nullptr},
    {"cancel", reinterpret_cast<PyCFunction>(Sbk_QSessionManagerFunc_cancel), METH_NOARGS, nullptr},
    {"discardCommand", reinterpret_cast<PyCFunction>(Sbk_QSessionManagerFunc_discardCommand), METH_NOARGS, nullptr},
    {"isPhase2", reinterpret_cast<PyCFunction>(Sbk_QSessionManagerFunc_isPhase2), METH_NOARGS, nullptr},
    {"release", reinterpret_cast<PyCFunction>(Sbk_QSessionManagerFunc_release), METH_NOARGS, nullptr},
    {"requestPhase2", reinterpret_cast<PyCFunction>(Sbk_QSessionManagerFunc_requestPhase2), METH_NOARGS, nullptr},
    {"restartCommand", reinterpret_cast<PyCFunction>(Sbk_QSessionManagerFunc_restartCommand), METH_NOARGS, nullptr},
    {"restartHint", reinterpret_cast<PyCFunction>(Sbk_QSessionManagerFunc_restartHint), METH_NOARGS, nullptr},
    {"sessionId", reinterpret_cast<PyCFunction>(Sbk_QSessionManagerFunc_sessionId), METH_NOARGS, nullptr},
    {"sessionKey", reinterpret_cast<PyCFunction>(Sbk_QSessionManagerFunc_sessionKey), METH_NOARGS, nullptr},
    {"setDiscardCommand", reinterpret_cast<PyCFunction>(Sbk_QSessionManagerFunc_setDiscardCommand), METH_O, nullptr},
    {"setManagerProperty", reinterpret_cast<PyCFunction>(Sbk_QSessionManagerFunc_setManagerProperty), METH_VARARGS, nullptr},
    {"setRestartCommand", reinterpret_cast<PyCFunction>(Sbk_QSessionManagerFunc_setRestartCommand), METH_O, nullptr},
    {"setRestartHint", reinterpret_cast<PyCFunction>(Sbk_QSessionManagerFunc_setRestartHint), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QSessionManager_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QSessionManager_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSessionManager_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSessionManager_Type = nullptr;
static PyTypeObject *Sbk_QSessionManager_TypeF(void)
{
    return _Sbk_QSessionManager_Type;
}

static PyType_Slot Sbk_QSessionManager_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(SbkDeallocWrapperWithPrivateDtor)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QSessionManager_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSessionManager_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSessionManager_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSessionManager_methods)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSessionManager_spec = {
    "2:PySide6.QtGui.QSessionManager",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSessionManager_slots
};

} //extern "C"

static void *Sbk_QSessionManager_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QSessionManager *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QSessionManager_RestartHint(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSessionManager::RestartHint>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSessionManager::RestartHint *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QSessionManager_RestartHint_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSessionManager_RestartHint_IDX])))
        return Enum_PythonToCpp_QSessionManager_RestartHint;
    return {};
}

static PyObject *QSessionManager_RestartHint_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QSessionManager::RestartHint>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QSessionManager::RestartHint *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSessionManager_RestartHint_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSessionManager_PythonToCpp_QSessionManager_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSessionManager_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSessionManager_PythonToCpp_QSessionManager_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSessionManager_TypeF()))
        return QSessionManager_PythonToCpp_QSessionManager_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSessionManager_PTR_CppToPython_QSessionManager(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QSessionManager *>(const_cast<void *>(cppIn)), Sbk_QSessionManager_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSessionManager_SignatureStrings[] = {
    "PySide6.QtGui.QSessionManager.allowsErrorInteraction(self)->bool",
    "PySide6.QtGui.QSessionManager.allowsInteraction(self)->bool",
    "PySide6.QtGui.QSessionManager.cancel(self)",
    "PySide6.QtGui.QSessionManager.discardCommand(self)->QStringList",
    "PySide6.QtGui.QSessionManager.isPhase2(self)->bool",
    "PySide6.QtGui.QSessionManager.release(self)",
    "PySide6.QtGui.QSessionManager.requestPhase2(self)",
    "PySide6.QtGui.QSessionManager.restartCommand(self)->QStringList",
    "PySide6.QtGui.QSessionManager.restartHint(self)->PySide6.QtGui.QSessionManager.RestartHint",
    "PySide6.QtGui.QSessionManager.sessionId(self)->QString",
    "PySide6.QtGui.QSessionManager.sessionKey(self)->QString",
    "PySide6.QtGui.QSessionManager.setDiscardCommand(self,arg__1:QStringList)",
    "1:PySide6.QtGui.QSessionManager.setManagerProperty(self,name:QString,value:QString)",
    "0:PySide6.QtGui.QSessionManager.setManagerProperty(self,name:QString,value:QStringList)",
    "PySide6.QtGui.QSessionManager.setRestartCommand(self,arg__1:QStringList)",
    "PySide6.QtGui.QSessionManager.setRestartHint(self,arg__1:PySide6.QtGui.QSessionManager.RestartHint)",
    nullptr}; // Sentinel
#else
static constexpr size_t QSessionManager_SignatureByteSize = 243;
static constexpr uint8_t QSessionManager_SignatureBytes[243] = {
    0x78, 0xda, 0xad, 0x92, 0xc1, 0x6e, 0xc2, 0x30, 0x0c, 0x86, 0xef, 0x7d, 0x92, 0x55, 0xea, 0x2a,
    0xe0, 0xb0, 0x03, 0x87, 0x5d, 0xc6, 0x34, 0x10, 0x4c, 0x6a, 0xe9, 0x03, 0x20, 0xaf, 0x35, 0x5d,
    0xa4, 0x34, 0x01, 0xdb, 0xdd, 0xc4, 0xdb, 0x0f, 0xa9, 0xb4, 0xab, 0x56, 0xb4, 0x84, 0x8a, 0x5b,
    0xac, 0xe4, 0xfb, 0xf2, 0x3b, 0x71, 0x72, 0xca, 0x54, 0x81, 0x4f, 0x71, 0x2a, 0x6f, 0xb5, 0x8a,
    0xd3, 0x0c, 0x99, 0x95, 0x35, 0xef, 0x60, 0xa0, 0x44, 0x8a, 0x41, 0x6b, 0xfb, 0xcd, 0xaf, 0x44,
    0x96, 0x56, 0x46, 0x90, 0x20, 0x97, 0xf3, 0xee, 0x03, 0xa3, 0xde, 0x87, 0x8f, 0xcf, 0x1f, 0xd6,
    0xea, 0x20, 0xf1, 0x10, 0x8c, 0x63, 0x73, 0x30, 0x39, 0xea, 0x06, 0x70, 0x1c, 0x2d, 0x14, 0xe7,
    0x40, 0xc5, 0x8b, 0xad, 0x2a, 0x30, 0x45, 0x7b, 0x47, 0x9a, 0x09, 0x29, 0x53, 0x6e, 0x14, 0x8b,
    0x83, 0x57, 0x9c, 0x7c, 0x02, 0xe3, 0xec, 0x86, 0x74, 0x84, 0x1a, 0xcf, 0x88, 0x57, 0x3c, 0xc2,
    0x63, 0x8d, 0x2c, 0xfd, 0x3b, 0x9c, 0x04, 0x0b, 0x90, 0x8c, 0x6e, 0xe8, 0xc2, 0x2f, 0x95, 0x91,
    0x16, 0xfe, 0x1f, 0xd8, 0xfe, 0x02, 0x0e, 0x35, 0x37, 0xe5, 0xea, 0x6f, 0x2a, 0x3f, 0x6c, 0x8d,
    0xa7, 0x5b, 0x39, 0x59, 0x0c, 0x7f, 0x37, 0x02, 0x2a, 0x77, 0xbb, 0xe9, 0xbc, 0xf7, 0x22, 0x61,
    0x30, 0x9d, 0x3b, 0x55, 0x97, 0x65, 0x42, 0xf6, 0x80, 0x24, 0x4d, 0x94, 0xc8, 0x40, 0x85, 0xad,
    0x29, 0xfa, 0x02, 0x5d, 0x77, 0x55, 0x18, 0x4c, 0xee, 0xee, 0x6c, 0xb2, 0x3a, 0xad, 0xdb, 0xe1,
    0x04, 0x5c, 0x6d, 0xda, 0x57, 0xd4, 0x8d, 0x42, 0x6b, 0xf1, 0x9e, 0x87, 0x30, 0xf8, 0x01, 0x05,
    0x0e, 0x83, 0x32
};
#endif

PyTypeObject *init_QSessionManager(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QSessionManager_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QSessionManager_IDX].type;

    Shiboken::AutoDecRef Sbk_QSessionManager_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QSessionManager_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSessionManager",
        "QSessionManager*",
        &Sbk_QSessionManager_spec,
        nullptr,
        Sbk_QSessionManager_Type_bases.object(),
        0);
    auto *pyType = Sbk_QSessionManager_TypeF(); // references _Sbk_QSessionManager_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSessionManager_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSessionManager_SignatureBytes, QSessionManager_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSessionManager_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QSessionManager_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSessionManager_PythonToCpp_QSessionManager_PTR,
        is_QSessionManager_PythonToCpp_QSessionManager_PTR_Convertible,
        QSessionManager_PTR_CppToPython_QSessionManager);

    Shiboken::Conversions::registerConverterName(converter, "QSessionManager");
    Shiboken::Conversions::registerConverterName(converter, "QSessionManager*");
    Shiboken::Conversions::registerConverterName(converter, "QSessionManager&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSessionManager).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QSessionManager_TypeF(), &Sbk_QSessionManager_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QSessionManager_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'RestartHint'.
    const char *RestartHint_Initializer[] = {
        "RestartIfRunning",
        "RestartAnyway",
        "RestartImmediately",
        "RestartNever",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t RestartHint_InitializerValues[] = {
        uint8_t(QSessionManager::RestartHint::RestartIfRunning),   //  0x00  0
        uint8_t(QSessionManager::RestartHint::RestartAnyway),      //  0x01  1
        uint8_t(QSessionManager::RestartHint::RestartImmediately), //  0x02  2
        uint8_t(QSessionManager::RestartHint::RestartNever)        //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSessionManager_TypeF(),
        "2:PySide6.QtGui.QSessionManager.RestartHint",
        RestartHint_Initializer, RestartHint_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QSessionManager_RestartHint_IDX].type = EType;
    // Register converter for enum 'QSessionManager::RestartHint'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSessionManager_RestartHint_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QSessionManager_RestartHint,
            is_Enum_PythonToCpp_QSessionManager_RestartHint_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QSessionManager::RestartHint");
        Shiboken::Conversions::registerConverterAlias(converter, "RestartHint");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'RestartHint' enum.

    qRegisterMetaType< ::QSessionManager::RestartHint >("QSessionManager::RestartHint");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QSessionManager::staticMetaObject, sizeof(::QSessionManager));

    return pyType;
}
