// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QSinglePointEventWrapper_H
#define SBK_QSinglePointEventWrapper_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtGui/qevent.h>

class QSinglePointEventWrapper : public QSinglePointEvent
{
public:
    QSinglePointEventWrapper(const QSinglePointEventWrapper &) = delete;
    QSinglePointEventWrapper& operator=(const QSinglePointEventWrapper &) = delete;
    QSinglePointEventWrapper(QSinglePointEventWrapper &&) = delete;
    QSinglePointEventWrapper& operator=(QSinglePointEventWrapper &&) = delete;

    QSinglePointEventWrapper(::QEvent::Type type, const ::QPointingDevice * dev, const ::QEventPoint & point, ::Qt::MouseButton button, ::QFlags<Qt::MouseButton> buttons, ::QFlags<Qt::KeyboardModifier> modifiers, ::Qt::MouseEventSource source);
    QSinglePointEventWrapper(::QEvent::Type type, const ::QPointingDevice * dev, const ::QPointF & localPos, const ::QPointF & scenePos, const ::QPointF & globalPos, ::Qt::MouseButton button, ::QFlags<Qt::MouseButton> buttons, ::QFlags<Qt::KeyboardModifier> modifiers, ::Qt::MouseEventSource source = Qt::MouseEventNotSynthesized);
    QSinglePointEventWrapper(const QSinglePointEvent& self) : QSinglePointEvent(self)
    {
    }

    ::QSinglePointEvent * clone() const override;
    bool isBeginEvent() const override;
    bool isEndEvent() const override;
    bool isUpdateEvent() const override;
    void setAccepted(bool accepted) override;
    void setTimestamp(quint64 timestamp) override;
    ~QSinglePointEventWrapper() override;
    static void pysideInitQtMetaTypes();
    void resetPyMethodCache();
private:
    mutable bool m_PyMethodCache[6] = {false, false, false, false, false, false};
};

#endif // SBK_QSinglePointEventWrapper_H

