// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qstatustipevent_wrapper.h"

// Argument includes
#include <QString>
#include <QtGui/qevent.h>
#include <qcoreevent.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QStatusTipEventWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QStatusTipEventWrapper::QStatusTipEventWrapper(const ::QString & tip) : QStatusTipEvent(tip)
{
}

::QStatusTipEvent * QStatusTipEventWrapper::clone() const
{
    if (m_PyMethodCache[0])
        return this->::QStatusTipEvent::clone();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "clone";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QStatusTipEvent::clone();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QStatusTipEvent", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStatusTipEvent_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QStatusTipEvent", funcName, Shiboken::SbkType< QStatusTipEvent >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QStatusTipEvent *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QStatusTipEventWrapper::setAccepted(bool accepted)
{
    if (m_PyMethodCache[1]) {
        return this->::QEvent::setAccepted(accepted);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setAccepted";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QEvent::setAccepted(accepted);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &accepted)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &accepted)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QStatusTipEvent", funcName);
        return;
    }
}

QStatusTipEventWrapper::~QStatusTipEventWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStatusTipEvent_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QStatusTipEvent >()))
        return -1;

    QStatusTipEventWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QStatusTipEvent", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QStatusTipEvent::QStatusTipEvent(QStatusTipEvent)
    // 1: QStatusTipEvent::QStatusTipEvent(QString)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 1; // QStatusTipEvent(QString)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStatusTipEvent_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QStatusTipEvent(QStatusTipEvent)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QStatusTipEvent_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QStatusTipEvent_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QStatusTipEvent(const QStatusTipEvent &arg__1)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QStatusTipEvent *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QStatusTipEvent(QStatusTipEvent)
                cptr = new QStatusTipEventWrapper(*cppArg0);
            }
            break;
        }
        case 1: // QStatusTipEvent(const QString &tip)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QStatusTipEvent(QString)
                cptr = new QStatusTipEventWrapper(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QStatusTipEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QStatusTipEvent_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QStatusTipEventFunc_clone(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStatusTipEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStatusTipEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clone()const
        QStatusTipEvent * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QStatusTipEvent *>(cppSelf)->::QStatusTipEvent::clone()
            : const_cast<const ::QStatusTipEvent *>(cppSelf)->clone();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStatusTipEvent_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStatusTipEventFunc_tip(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStatusTipEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStatusTipEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // tip()const
        QString cppResult = const_cast<const ::QStatusTipEvent *>(cppSelf)->tip();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QStatusTipEvent_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QStatusTipEvent_methods[] = {
    {"clone", reinterpret_cast<PyCFunction>(Sbk_QStatusTipEventFunc_clone), METH_NOARGS, nullptr},
    {"tip", reinterpret_cast<PyCFunction>(Sbk_QStatusTipEventFunc_tip), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QStatusTipEvent_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QStatusTipEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStatusTipEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QStatusTipEventWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QStatusTipEvent_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QStatusTipEvent_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QStatusTipEvent_Type = nullptr;
static PyTypeObject *Sbk_QStatusTipEvent_TypeF(void)
{
    return _Sbk_QStatusTipEvent_Type;
}

static PyType_Slot Sbk_QStatusTipEvent_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QStatusTipEvent_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QStatusTipEvent_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QStatusTipEvent_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QStatusTipEvent_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QStatusTipEvent_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QStatusTipEvent_spec = {
    "2:PySide6.QtGui.QStatusTipEvent",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QStatusTipEvent_slots
};

} //extern "C"

static void *Sbk_QStatusTipEvent_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if ( reinterpret_cast< ::QEvent *>(cptr)->type() == QEvent::StatusTip)
        return cptr;
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QStatusTipEvent_PythonToCpp_QStatusTipEvent_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QStatusTipEvent_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QStatusTipEvent_PythonToCpp_QStatusTipEvent_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QStatusTipEvent_TypeF()))
        return QStatusTipEvent_PythonToCpp_QStatusTipEvent_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QStatusTipEvent_PTR_CppToPython_QStatusTipEvent(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QStatusTipEvent *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QStatusTipEvent_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QStatusTipEvent_SignatureStrings[] = {
    "1:PySide6.QtGui.QStatusTipEvent(self,arg__1:PySide6.QtGui.QStatusTipEvent)",
    "0:PySide6.QtGui.QStatusTipEvent(self,tip:QString)",
    "PySide6.QtGui.QStatusTipEvent.clone(self)->PySide6.QtGui.QStatusTipEvent",
    "PySide6.QtGui.QStatusTipEvent.tip(self)->QString",
    nullptr}; // Sentinel
#else
static constexpr size_t QStatusTipEvent_SignatureByteSize = 96;
static constexpr uint8_t QStatusTipEvent_SignatureBytes[96] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0x2f,
    0xcd, 0xd4, 0x0b, 0x0c, 0x2e, 0x49, 0x2c, 0x29, 0x2d, 0x0e, 0xc9, 0x2c, 0x70, 0x2d, 0x4b, 0xcd,
    0x2b, 0xd1, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0x49, 0x2c, 0x4a, 0x8f, 0x8f, 0x37, 0xc4, 0xaf, 0x52,
    0x93, 0xcb, 0x80, 0x18, 0xa3, 0x4a, 0x32, 0x0b, 0xac, 0x80, 0x12, 0x45, 0x99, 0x79, 0xe9, 0x9a,
    0x5c, 0x78, 0xd5, 0xeb, 0x25, 0xe7, 0xe4, 0xe7, 0xa5, 0x82, 0x75, 0x69, 0xea, 0xda, 0xe1, 0x55,
    0x4a, 0xc0, 0x20, 0xa0, 0x9d, 0x30, 0x63, 0xa0, 0x56, 0x73, 0x01, 0x00, 0x97, 0xd2, 0x58, 0x20
};
#endif

PyTypeObject *init_QStatusTipEvent(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QStatusTipEvent_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QStatusTipEvent_IDX].type;

    Shiboken::AutoDecRef Sbk_QStatusTipEvent_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]))));

    _Sbk_QStatusTipEvent_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QStatusTipEvent",
        "QStatusTipEvent*",
        &Sbk_QStatusTipEvent_spec,
        &Shiboken::callCppDestructor< QStatusTipEvent >,
        Sbk_QStatusTipEvent_Type_bases.object(),
        0);
    auto *pyType = Sbk_QStatusTipEvent_TypeF(); // references _Sbk_QStatusTipEvent_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QStatusTipEvent_SignatureStrings);
#else
    InitSignatureBytes(pyType, QStatusTipEvent_SignatureBytes, QStatusTipEvent_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QStatusTipEvent_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QStatusTipEvent_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QStatusTipEvent_PythonToCpp_QStatusTipEvent_PTR,
        is_QStatusTipEvent_PythonToCpp_QStatusTipEvent_PTR_Convertible,
        QStatusTipEvent_PTR_CppToPython_QStatusTipEvent);

    Shiboken::Conversions::registerConverterName(converter, "QStatusTipEvent");
    Shiboken::Conversions::registerConverterName(converter, "QStatusTipEvent*");
    Shiboken::Conversions::registerConverterName(converter, "QStatusTipEvent&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QStatusTipEvent).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QStatusTipEventWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QStatusTipEvent_TypeF(), &Sbk_QStatusTipEvent_typeDiscovery);


    return pyType;
}
