// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qstylehints_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <qbytearray.h>
#include <qchar.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QStyleHintsWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

void QStyleHintsWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QStyleHints", funcName);
        return;
    }
}

void QStyleHintsWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QStyleHints", funcName);
        return;
    }
}

void QStyleHintsWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QStyleHints", funcName);
        return;
    }
}

void QStyleHintsWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QStyleHints", funcName);
        return;
    }
}

bool QStyleHintsWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QStyleHints", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QStyleHints", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QStyleHintsWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QStyleHints", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QStyleHints", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QStyleHintsWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QStyleHints", funcName);
        return;
    }
}

const QMetaObject *QStyleHintsWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QStyleHints::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QStyleHintsWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QStyleHints::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QStyleHintsWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QStyleHintsWrapper *>(this));
    return QStyleHints::qt_metacast(_clname);
}

QStyleHintsWrapper::~QStyleHintsWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QStyleHintsFunc_colorScheme(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleHints *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // colorScheme()const
        Qt::ColorScheme cppResult = const_cast<const ::QStyleHints *>(cppSelf)->colorScheme();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ColorScheme_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleHintsFunc_contextMenuTrigger(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleHints *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // contextMenuTrigger()const
        Qt::ContextMenuTrigger cppResult = const_cast<const ::QStyleHints *>(cppSelf)->contextMenuTrigger();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ContextMenuTrigger_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleHintsFunc_cursorFlashTime(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleHints *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cursorFlashTime()const
        int cppResult = const_cast<const ::QStyleHints *>(cppSelf)->cursorFlashTime();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleHintsFunc_fontSmoothingGamma(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleHints *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // fontSmoothingGamma()const
        qreal cppResult = const_cast<const ::QStyleHints *>(cppSelf)->fontSmoothingGamma();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleHintsFunc_keyboardAutoRepeatRate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleHints *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QStyleHints", "keyboardAutoRepeatRate() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // keyboardAutoRepeatRate()const
        int cppResult = const_cast<const ::QStyleHints *>(cppSelf)->keyboardAutoRepeatRate();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleHintsFunc_keyboardAutoRepeatRateF(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleHints *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // keyboardAutoRepeatRateF()const
        qreal cppResult = const_cast<const ::QStyleHints *>(cppSelf)->keyboardAutoRepeatRateF();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleHintsFunc_keyboardInputInterval(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleHints *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // keyboardInputInterval()const
        int cppResult = const_cast<const ::QStyleHints *>(cppSelf)->keyboardInputInterval();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleHintsFunc_mouseDoubleClickDistance(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleHints *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // mouseDoubleClickDistance()const
        int cppResult = const_cast<const ::QStyleHints *>(cppSelf)->mouseDoubleClickDistance();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleHintsFunc_mouseDoubleClickInterval(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleHints *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // mouseDoubleClickInterval()const
        int cppResult = const_cast<const ::QStyleHints *>(cppSelf)->mouseDoubleClickInterval();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleHintsFunc_mousePressAndHoldInterval(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleHints *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // mousePressAndHoldInterval()const
        int cppResult = const_cast<const ::QStyleHints *>(cppSelf)->mousePressAndHoldInterval();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleHintsFunc_mouseQuickSelectionThreshold(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleHints *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // mouseQuickSelectionThreshold()const
        int cppResult = const_cast<const ::QStyleHints *>(cppSelf)->mouseQuickSelectionThreshold();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleHintsFunc_passwordMaskCharacter(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleHints *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // passwordMaskCharacter()const
        QChar cppResult = const_cast<const ::QStyleHints *>(cppSelf)->passwordMaskCharacter();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QChar_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleHintsFunc_passwordMaskDelay(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleHints *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // passwordMaskDelay()const
        int cppResult = const_cast<const ::QStyleHints *>(cppSelf)->passwordMaskDelay();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleHintsFunc_setColorScheme(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleHints *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QStyleHints::setColorScheme(Qt::ColorScheme)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ColorScheme_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setColorScheme(Qt::ColorScheme)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setColorScheme", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]);

    // Call function/method
    {
        ::Qt::ColorScheme cppArg0{Qt::ColorScheme::Unknown};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setColorScheme(Qt::ColorScheme)
            cppSelf->setColorScheme(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStyleHintsFunc_setContextMenuTrigger(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleHints *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QStyleHints::setContextMenuTrigger(Qt::ContextMenuTrigger)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ContextMenuTrigger_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setContextMenuTrigger(Qt::ContextMenuTrigger)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setContextMenuTrigger", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]);

    // Call function/method
    {
        ::Qt::ContextMenuTrigger cppArg0{Qt::ContextMenuTrigger::Press};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setContextMenuTrigger(Qt::ContextMenuTrigger)
            cppSelf->setContextMenuTrigger(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStyleHintsFunc_setCursorFlashTime(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleHints *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QStyleHints::setCursorFlashTime(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setCursorFlashTime(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCursorFlashTime", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCursorFlashTime(int)
            cppSelf->setCursorFlashTime(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStyleHintsFunc_setFocusOnTouchRelease(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleHints *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // setFocusOnTouchRelease()const
        bool cppResult = const_cast<const ::QStyleHints *>(cppSelf)->setFocusOnTouchRelease();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleHintsFunc_setKeyboardInputInterval(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleHints *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QStyleHints::setKeyboardInputInterval(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setKeyboardInputInterval(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setKeyboardInputInterval", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setKeyboardInputInterval(int)
            cppSelf->setKeyboardInputInterval(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStyleHintsFunc_setMouseDoubleClickInterval(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleHints *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QStyleHints::setMouseDoubleClickInterval(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setMouseDoubleClickInterval(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMouseDoubleClickInterval", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMouseDoubleClickInterval(int)
            cppSelf->setMouseDoubleClickInterval(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStyleHintsFunc_setMousePressAndHoldInterval(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleHints *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QStyleHints::setMousePressAndHoldInterval(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setMousePressAndHoldInterval(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMousePressAndHoldInterval", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMousePressAndHoldInterval(int)
            cppSelf->setMousePressAndHoldInterval(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStyleHintsFunc_setMouseQuickSelectionThreshold(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleHints *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QStyleHints::setMouseQuickSelectionThreshold(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setMouseQuickSelectionThreshold(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMouseQuickSelectionThreshold", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMouseQuickSelectionThreshold(int)
            cppSelf->setMouseQuickSelectionThreshold(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStyleHintsFunc_setShowShortcutsInContextMenus(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleHints *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QStyleHints::setShowShortcutsInContextMenus(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setShowShortcutsInContextMenus(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setShowShortcutsInContextMenus", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setShowShortcutsInContextMenus(bool)
            cppSelf->setShowShortcutsInContextMenus(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStyleHintsFunc_setStartDragDistance(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleHints *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QStyleHints::setStartDragDistance(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setStartDragDistance(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStartDragDistance", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStartDragDistance(int)
            cppSelf->setStartDragDistance(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStyleHintsFunc_setStartDragTime(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleHints *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QStyleHints::setStartDragTime(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setStartDragTime(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStartDragTime", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStartDragTime(int)
            cppSelf->setStartDragTime(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStyleHintsFunc_setTabFocusBehavior(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleHints *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QStyleHints::setTabFocusBehavior(Qt::TabFocusBehavior)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_TabFocusBehavior_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setTabFocusBehavior(Qt::TabFocusBehavior)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTabFocusBehavior", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]);

    // Call function/method
    {
        ::Qt::TabFocusBehavior cppArg0{Qt::NoTabFocus};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTabFocusBehavior(Qt::TabFocusBehavior)
            cppSelf->setTabFocusBehavior(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStyleHintsFunc_setUseHoverEffects(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleHints *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QStyleHints::setUseHoverEffects(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setUseHoverEffects(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUseHoverEffects", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setUseHoverEffects(bool)
            cppSelf->setUseHoverEffects(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStyleHintsFunc_setWheelScrollLines(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleHints *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QStyleHints::setWheelScrollLines(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setWheelScrollLines(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setWheelScrollLines", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setWheelScrollLines(int)
            cppSelf->setWheelScrollLines(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStyleHintsFunc_showIsFullScreen(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleHints *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // showIsFullScreen()const
        bool cppResult = const_cast<const ::QStyleHints *>(cppSelf)->showIsFullScreen();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleHintsFunc_showIsMaximized(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleHints *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // showIsMaximized()const
        bool cppResult = const_cast<const ::QStyleHints *>(cppSelf)->showIsMaximized();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleHintsFunc_showShortcutsInContextMenus(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleHints *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // showShortcutsInContextMenus()const
        bool cppResult = const_cast<const ::QStyleHints *>(cppSelf)->showShortcutsInContextMenus();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleHintsFunc_singleClickActivation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleHints *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // singleClickActivation()const
        bool cppResult = const_cast<const ::QStyleHints *>(cppSelf)->singleClickActivation();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleHintsFunc_startDragDistance(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleHints *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // startDragDistance()const
        int cppResult = const_cast<const ::QStyleHints *>(cppSelf)->startDragDistance();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleHintsFunc_startDragTime(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleHints *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // startDragTime()const
        int cppResult = const_cast<const ::QStyleHints *>(cppSelf)->startDragTime();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleHintsFunc_startDragVelocity(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleHints *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // startDragVelocity()const
        int cppResult = const_cast<const ::QStyleHints *>(cppSelf)->startDragVelocity();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleHintsFunc_tabFocusBehavior(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleHints *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // tabFocusBehavior()const
        Qt::TabFocusBehavior cppResult = const_cast<const ::QStyleHints *>(cppSelf)->tabFocusBehavior();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_TabFocusBehavior_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleHintsFunc_touchDoubleTapDistance(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleHints *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // touchDoubleTapDistance()const
        int cppResult = const_cast<const ::QStyleHints *>(cppSelf)->touchDoubleTapDistance();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleHintsFunc_unsetColorScheme(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleHints *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // unsetColorScheme()
        cppSelf->unsetColorScheme();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStyleHintsFunc_useHoverEffects(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleHints *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // useHoverEffects()const
        bool cppResult = const_cast<const ::QStyleHints *>(cppSelf)->useHoverEffects();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleHintsFunc_useRtlExtensions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleHints *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // useRtlExtensions()const
        bool cppResult = const_cast<const ::QStyleHints *>(cppSelf)->useRtlExtensions();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleHintsFunc_wheelScrollLines(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleHints *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // wheelScrollLines()const
        int cppResult = const_cast<const ::QStyleHints *>(cppSelf)->wheelScrollLines();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QStyleHints_PropertyStrings[] = {
    "colorScheme::",
    "contextMenuTrigger::",
    "cursorFlashTime:",
    "fontSmoothingGamma:",
    "keyboardAutoRepeatRate:",
    "keyboardAutoRepeatRateF:",
    "keyboardInputInterval:",
    "mouseDoubleClickDistance:",
    "mouseDoubleClickInterval:",
    "mousePressAndHoldInterval:",
    "mouseQuickSelectionThreshold::",
    "passwordMaskCharacter:",
    "passwordMaskDelay:",
    "setFocusOnTouchRelease:",
    "showIsFullScreen:",
    "showIsMaximized:",
    "showShortcutsInContextMenus::",
    "singleClickActivation:",
    "startDragDistance:",
    "startDragTime:",
    "startDragVelocity:",
    "tabFocusBehavior:",
    "touchDoubleTapDistance:",
    "useHoverEffects::",
    "useRtlExtensions:",
    "wheelScrollLines:",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QStyleHints_methods[] = {
    {"colorScheme", reinterpret_cast<PyCFunction>(Sbk_QStyleHintsFunc_colorScheme), METH_NOARGS, nullptr},
    {"contextMenuTrigger", reinterpret_cast<PyCFunction>(Sbk_QStyleHintsFunc_contextMenuTrigger), METH_NOARGS, nullptr},
    {"cursorFlashTime", reinterpret_cast<PyCFunction>(Sbk_QStyleHintsFunc_cursorFlashTime), METH_NOARGS, nullptr},
    {"fontSmoothingGamma", reinterpret_cast<PyCFunction>(Sbk_QStyleHintsFunc_fontSmoothingGamma), METH_NOARGS, nullptr},
    {"keyboardAutoRepeatRate", reinterpret_cast<PyCFunction>(Sbk_QStyleHintsFunc_keyboardAutoRepeatRate), METH_NOARGS, nullptr},
    {"keyboardAutoRepeatRateF", reinterpret_cast<PyCFunction>(Sbk_QStyleHintsFunc_keyboardAutoRepeatRateF), METH_NOARGS, nullptr},
    {"keyboardInputInterval", reinterpret_cast<PyCFunction>(Sbk_QStyleHintsFunc_keyboardInputInterval), METH_NOARGS, nullptr},
    {"mouseDoubleClickDistance", reinterpret_cast<PyCFunction>(Sbk_QStyleHintsFunc_mouseDoubleClickDistance), METH_NOARGS, nullptr},
    {"mouseDoubleClickInterval", reinterpret_cast<PyCFunction>(Sbk_QStyleHintsFunc_mouseDoubleClickInterval), METH_NOARGS, nullptr},
    {"mousePressAndHoldInterval", reinterpret_cast<PyCFunction>(Sbk_QStyleHintsFunc_mousePressAndHoldInterval), METH_NOARGS, nullptr},
    {"mouseQuickSelectionThreshold", reinterpret_cast<PyCFunction>(Sbk_QStyleHintsFunc_mouseQuickSelectionThreshold), METH_NOARGS, nullptr},
    {"passwordMaskCharacter", reinterpret_cast<PyCFunction>(Sbk_QStyleHintsFunc_passwordMaskCharacter), METH_NOARGS, nullptr},
    {"passwordMaskDelay", reinterpret_cast<PyCFunction>(Sbk_QStyleHintsFunc_passwordMaskDelay), METH_NOARGS, nullptr},
    {"setColorScheme", reinterpret_cast<PyCFunction>(Sbk_QStyleHintsFunc_setColorScheme), METH_O, nullptr},
    {"setContextMenuTrigger", reinterpret_cast<PyCFunction>(Sbk_QStyleHintsFunc_setContextMenuTrigger), METH_O, nullptr},
    {"setCursorFlashTime", reinterpret_cast<PyCFunction>(Sbk_QStyleHintsFunc_setCursorFlashTime), METH_O, nullptr},
    {"setFocusOnTouchRelease", reinterpret_cast<PyCFunction>(Sbk_QStyleHintsFunc_setFocusOnTouchRelease), METH_NOARGS, nullptr},
    {"setKeyboardInputInterval", reinterpret_cast<PyCFunction>(Sbk_QStyleHintsFunc_setKeyboardInputInterval), METH_O, nullptr},
    {"setMouseDoubleClickInterval", reinterpret_cast<PyCFunction>(Sbk_QStyleHintsFunc_setMouseDoubleClickInterval), METH_O, nullptr},
    {"setMousePressAndHoldInterval", reinterpret_cast<PyCFunction>(Sbk_QStyleHintsFunc_setMousePressAndHoldInterval), METH_O, nullptr},
    {"setMouseQuickSelectionThreshold", reinterpret_cast<PyCFunction>(Sbk_QStyleHintsFunc_setMouseQuickSelectionThreshold), METH_O, nullptr},
    {"setShowShortcutsInContextMenus", reinterpret_cast<PyCFunction>(Sbk_QStyleHintsFunc_setShowShortcutsInContextMenus), METH_O, nullptr},
    {"setStartDragDistance", reinterpret_cast<PyCFunction>(Sbk_QStyleHintsFunc_setStartDragDistance), METH_O, nullptr},
    {"setStartDragTime", reinterpret_cast<PyCFunction>(Sbk_QStyleHintsFunc_setStartDragTime), METH_O, nullptr},
    {"setTabFocusBehavior", reinterpret_cast<PyCFunction>(Sbk_QStyleHintsFunc_setTabFocusBehavior), METH_O, nullptr},
    {"setUseHoverEffects", reinterpret_cast<PyCFunction>(Sbk_QStyleHintsFunc_setUseHoverEffects), METH_O, nullptr},
    {"setWheelScrollLines", reinterpret_cast<PyCFunction>(Sbk_QStyleHintsFunc_setWheelScrollLines), METH_O, nullptr},
    {"showIsFullScreen", reinterpret_cast<PyCFunction>(Sbk_QStyleHintsFunc_showIsFullScreen), METH_NOARGS, nullptr},
    {"showIsMaximized", reinterpret_cast<PyCFunction>(Sbk_QStyleHintsFunc_showIsMaximized), METH_NOARGS, nullptr},
    {"showShortcutsInContextMenus", reinterpret_cast<PyCFunction>(Sbk_QStyleHintsFunc_showShortcutsInContextMenus), METH_NOARGS, nullptr},
    {"singleClickActivation", reinterpret_cast<PyCFunction>(Sbk_QStyleHintsFunc_singleClickActivation), METH_NOARGS, nullptr},
    {"startDragDistance", reinterpret_cast<PyCFunction>(Sbk_QStyleHintsFunc_startDragDistance), METH_NOARGS, nullptr},
    {"startDragTime", reinterpret_cast<PyCFunction>(Sbk_QStyleHintsFunc_startDragTime), METH_NOARGS, nullptr},
    {"startDragVelocity", reinterpret_cast<PyCFunction>(Sbk_QStyleHintsFunc_startDragVelocity), METH_NOARGS, nullptr},
    {"tabFocusBehavior", reinterpret_cast<PyCFunction>(Sbk_QStyleHintsFunc_tabFocusBehavior), METH_NOARGS, nullptr},
    {"touchDoubleTapDistance", reinterpret_cast<PyCFunction>(Sbk_QStyleHintsFunc_touchDoubleTapDistance), METH_NOARGS, nullptr},
    {"unsetColorScheme", reinterpret_cast<PyCFunction>(Sbk_QStyleHintsFunc_unsetColorScheme), METH_NOARGS, nullptr},
    {"useHoverEffects", reinterpret_cast<PyCFunction>(Sbk_QStyleHintsFunc_useHoverEffects), METH_NOARGS, nullptr},
    {"useRtlExtensions", reinterpret_cast<PyCFunction>(Sbk_QStyleHintsFunc_useRtlExtensions), METH_NOARGS, nullptr},
    {"wheelScrollLines", reinterpret_cast<PyCFunction>(Sbk_QStyleHintsFunc_wheelScrollLines), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QStyleHints_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QStyleHints *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QStyleHintsWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QStyleHints_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QStyleHints_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QStyleHints_Type = nullptr;
static PyTypeObject *Sbk_QStyleHints_TypeF(void)
{
    return _Sbk_QStyleHints_Type;
}

static PyType_Slot Sbk_QStyleHints_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QStyleHints_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QStyleHints_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QStyleHints_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QStyleHints_methods)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QStyleHints_spec = {
    "2:PySide6.QtGui.QStyleHints",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QStyleHints_slots
};

} //extern "C"

static void *Sbk_QStyleHints_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QStyleHints *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QStyleHints_PythonToCpp_QStyleHints_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QStyleHints_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QStyleHints_PythonToCpp_QStyleHints_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QStyleHints_TypeF()))
        return QStyleHints_PythonToCpp_QStyleHints_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QStyleHints_PTR_CppToPython_QStyleHints(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QStyleHints *>(const_cast<void *>(cppIn)), Sbk_QStyleHints_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QStyleHints_SignatureStrings[] = {
    "PySide6.QtGui.QStyleHints.colorScheme(self)->PySide6.QtCore.Qt.ColorScheme",
    "PySide6.QtGui.QStyleHints.contextMenuTrigger(self)->PySide6.QtCore.Qt.ContextMenuTrigger",
    "PySide6.QtGui.QStyleHints.cursorFlashTime(self)->int",
    "PySide6.QtGui.QStyleHints.fontSmoothingGamma(self)->qreal",
    "PySide6.QtGui.QStyleHints.keyboardAutoRepeatRate(self)->int",
    "PySide6.QtGui.QStyleHints.keyboardAutoRepeatRateF(self)->qreal",
    "PySide6.QtGui.QStyleHints.keyboardInputInterval(self)->int",
    "PySide6.QtGui.QStyleHints.mouseDoubleClickDistance(self)->int",
    "PySide6.QtGui.QStyleHints.mouseDoubleClickInterval(self)->int",
    "PySide6.QtGui.QStyleHints.mousePressAndHoldInterval(self)->int",
    "PySide6.QtGui.QStyleHints.mouseQuickSelectionThreshold(self)->int",
    "PySide6.QtGui.QStyleHints.passwordMaskCharacter(self)->QChar",
    "PySide6.QtGui.QStyleHints.passwordMaskDelay(self)->int",
    "PySide6.QtGui.QStyleHints.setColorScheme(self,scheme:PySide6.QtCore.Qt.ColorScheme)",
    "PySide6.QtGui.QStyleHints.setContextMenuTrigger(self,contextMenuTrigger:PySide6.QtCore.Qt.ContextMenuTrigger)",
    "PySide6.QtGui.QStyleHints.setCursorFlashTime(self,cursorFlashTime:int)",
    "PySide6.QtGui.QStyleHints.setFocusOnTouchRelease(self)->bool",
    "PySide6.QtGui.QStyleHints.setKeyboardInputInterval(self,keyboardInputInterval:int)",
    "PySide6.QtGui.QStyleHints.setMouseDoubleClickInterval(self,mouseDoubleClickInterval:int)",
    "PySide6.QtGui.QStyleHints.setMousePressAndHoldInterval(self,mousePressAndHoldInterval:int)",
    "PySide6.QtGui.QStyleHints.setMouseQuickSelectionThreshold(self,threshold:int)",
    "PySide6.QtGui.QStyleHints.setShowShortcutsInContextMenus(self,showShortcutsInContextMenus:bool)",
    "PySide6.QtGui.QStyleHints.setStartDragDistance(self,startDragDistance:int)",
    "PySide6.QtGui.QStyleHints.setStartDragTime(self,startDragTime:int)",
    "PySide6.QtGui.QStyleHints.setTabFocusBehavior(self,tabFocusBehavior:PySide6.QtCore.Qt.TabFocusBehavior)",
    "PySide6.QtGui.QStyleHints.setUseHoverEffects(self,useHoverEffects:bool)",
    "PySide6.QtGui.QStyleHints.setWheelScrollLines(self,scrollLines:int)",
    "PySide6.QtGui.QStyleHints.showIsFullScreen(self)->bool",
    "PySide6.QtGui.QStyleHints.showIsMaximized(self)->bool",
    "PySide6.QtGui.QStyleHints.showShortcutsInContextMenus(self)->bool",
    "PySide6.QtGui.QStyleHints.singleClickActivation(self)->bool",
    "PySide6.QtGui.QStyleHints.startDragDistance(self)->int",
    "PySide6.QtGui.QStyleHints.startDragTime(self)->int",
    "PySide6.QtGui.QStyleHints.startDragVelocity(self)->int",
    "PySide6.QtGui.QStyleHints.tabFocusBehavior(self)->PySide6.QtCore.Qt.TabFocusBehavior",
    "PySide6.QtGui.QStyleHints.touchDoubleTapDistance(self)->int",
    "PySide6.QtGui.QStyleHints.unsetColorScheme(self)",
    "PySide6.QtGui.QStyleHints.useHoverEffects(self)->bool",
    "PySide6.QtGui.QStyleHints.useRtlExtensions(self)->bool",
    "PySide6.QtGui.QStyleHints.wheelScrollLines(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t QStyleHints_SignatureByteSize = 549;
static constexpr uint8_t QStyleHints_SignatureBytes[549] = {
    0x78, 0xda, 0x9d, 0x56, 0x4d, 0x8f, 0xda, 0x30, 0x10, 0xbd, 0xf7, 0x97, 0x74, 0xa5, 0x94, 0x63,
    0x0f, 0x1c, 0x2a, 0x51, 0x58, 0x16, 0xd4, 0xa2, 0x02, 0x49, 0xdb, 0xf3, 0xe0, 0x0c, 0xc4, 0xc2,
    0xb1, 0xa9, 0x67, 0xcc, 0x47, 0x7f, 0x7d, 0xcd, 0x16, 0x96, 0xdd, 0xac, 0x71, 0x0c, 0x87, 0x28,
    0xc9, 0x64, 0xde, 0x1b, 0xdb, 0xf3, 0x9e, 0x9d, 0xe9, 0x21, 0x97, 0x25, 0x7e, 0xee, 0xcc, 0xf8,
    0xc9, 0xc9, 0xce, 0x2c, 0xe7, 0x83, 0xc2, 0x91, 0xd4, 0x4c, 0x1d, 0x61, 0x94, 0xb1, 0xb9, 0xa8,
    0xb0, 0xc6, 0x8f, 0x84, 0x6a, 0xf9, 0xf0, 0xe9, 0xcb, 0xf4, 0x25, 0xb9, 0x6f, 0x2c, 0xfa, 0x5b,
    0xa7, 0x7f, 0x49, 0xfa, 0x30, 0x8d, 0x50, 0x69, 0xc6, 0x3d, 0x4f, 0x50, 0xbb, 0xc2, 0xca, 0xd5,
    0x0a, 0x6d, 0x8c, 0xb1, 0x99, 0x1b, 0x23, 0x76, 0x96, 0x8c, 0x1d, 0x2a, 0xa0, 0xaa, 0x90, 0x97,
    0x71, 0xfa, 0x6f, 0x11, 0xd0, 0xd2, 0x57, 0xc8, 0x6b, 0x63, 0xb8, 0x92, 0x7a, 0xf5, 0x04, 0x75,
    0x0d, 0x67, 0xdc, 0x1f, 0x8b, 0xa0, 0x22, 0xc8, 0x35, 0x1e, 0x16, 0x06, 0x6c, 0xd9, 0x73, 0x6c,
    0xe6, 0xb8, 0x41, 0xe0, 0x39, 0x70, 0x62, 0xd5, 0x30, 0x76, 0x78, 0x6b, 0xe9, 0xb1, 0xde, 0x38,
    0x1e, 0xfb, 0x25, 0xb2, 0x5b, 0x50, 0x69, 0x95, 0x6b, 0xe3, 0x08, 0x07, 0xc6, 0x2d, 0x14, 0xf6,
    0x95, 0x14, 0xeb, 0x81, 0x24, 0x06, 0x2d, 0xf0, 0x3e, 0xf4, 0x1d, 0xb5, 0xa7, 0x16, 0x89, 0x7a,
    0xba, 0x1c, 0x19, 0x55, 0xde, 0x01, 0x9f, 0x39, 0x5f, 0x36, 0x47, 0x85, 0x82, 0xa5, 0xd1, 0x45,
    0xe5, 0xd9, 0x2a, 0xcf, 0x94, 0xc6, 0xb0, 0x01, 0xa2, 0x9d, 0xb1, 0xe5, 0x04, 0x68, 0xdd, 0xaf,
    0xc0, 0x82, 0xe0, 0x8b, 0xfa, 0x66, 0xc7, 0x48, 0x22, 0x78, 0x80, 0x0a, 0x0e, 0x69, 0x35, 0x09,
    0xb9, 0xdf, 0x30, 0x4f, 0x46, 0xcf, 0xcf, 0xdd, 0xa8, 0x83, 0x1e, 0xda, 0x38, 0x83, 0x2e, 0xca,
    0xde, 0xbb, 0xab, 0x9b, 0x62, 0xab, 0xb6, 0x6a, 0x01, 0x6b, 0x65, 0x0d, 0xbf, 0x75, 0x7d, 0x72,
    0x0b, 0xcd, 0xd0, 0x08, 0x47, 0x3f, 0x74, 0x61, 0x9c, 0xa8, 0xe6, 0xbe, 0x87, 0x40, 0x2f, 0xba,
    0x5b, 0x18, 0xa3, 0xe2, 0xe0, 0x6f, 0x57, 0x45, 0x9f, 0x05, 0xfd, 0x90, 0x30, 0x9e, 0x49, 0x4c,
    0xce, 0xd9, 0x35, 0xb1, 0xa7, 0x12, 0x5f, 0x55, 0x7a, 0x76, 0xd5, 0x08, 0xa9, 0xd4, 0x31, 0x17,
    0x64, 0x7c, 0x7e, 0x4d, 0x60, 0xcb, 0x2b, 0xb3, 0xf3, 0x97, 0x65, 0xe1, 0x98, 0xc6, 0xfa, 0x95,
    0x30, 0xe8, 0x24, 0xd5, 0xeb, 0x09, 0xdd, 0x63, 0xcf, 0xda, 0xf8, 0x19, 0x2c, 0x0f, 0x2c, 0xac,
    0xde, 0xec, 0x33, 0x19, 0x35, 0xc3, 0x29, 0x43, 0x3d, 0x63, 0x2e, 0x0a, 0xa4, 0xd7, 0xa1, 0x04,
    0x8a, 0x02, 0x16, 0xcf, 0x12, 0xfc, 0x8a, 0x15, 0x6c, 0xa5, 0x39, 0x59, 0x86, 0x1b, 0xd1, 0x80,
    0x61, 0x9a, 0xc0, 0x96, 0x3a, 0x3f, 0x09, 0x47, 0x66, 0x8b, 0xf6, 0x71, 0xb9, 0xf4, 0x1d, 0x3a,
    0xad, 0xa4, 0x7b, 0x1b, 0x4c, 0x59, 0xbd, 0xdf, 0x15, 0xa2, 0xca, 0x85, 0x35, 0x4a, 0x7d, 0x97,
    0x1a, 0xcf, 0x2d, 0xb9, 0x04, 0x5a, 0xe7, 0xec, 0xbb, 0x37, 0xa6, 0xa1, 0x53, 0x47, 0x16, 0x44,
    0x9d, 0xea, 0xb6, 0x67, 0xd8, 0x04, 0xf6, 0xb2, 0x96, 0x7f, 0xb1, 0xbc, 0x01, 0x15, 0xd3, 0x52,
    0x02, 0x83, 0x3f, 0x83, 0x4f, 0x66, 0xeb, 0x79, 0x65, 0x6f, 0xe1, 0xa8, 0xee, 0x54, 0x6c, 0x50,
    0x69, 0xed, 0xdb, 0xf3, 0x3b, 0x55, 0xa5, 0x43, 0x7e, 0xa1, 0x32, 0x42, 0x72, 0xe2, 0x41, 0xc0,
    0x21, 0xf1, 0x05, 0xff, 0x7a, 0x9a, 0x6a, 0x8b, 0x91, 0x1e, 0xb7, 0xd2, 0xff, 0x7b, 0x54, 0x01,
    0x9b, 0xdb, 0xa6, 0xee, 0x74, 0xe0, 0x6c, 0x8a, 0xa9, 0xc9, 0x05, 0x64, 0xdd, 0xde, 0x18, 0x8f,
    0x9a, 0xb3, 0x7a, 0xdc, 0x33, 0x6a, 0xf2, 0xed, 0x4c, 0x85, 0xed, 0x42, 0xda, 0x3f, 0xcd, 0xe9,
    0x1f, 0x71, 0x0e, 0xed, 0xe5
};
#endif

PyTypeObject *init_QStyleHints(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX].type;

    Shiboken::AutoDecRef Sbk_QStyleHints_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QStyleHints_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QStyleHints",
        "QStyleHints*",
        &Sbk_QStyleHints_spec,
        &Shiboken::callCppDestructor< QStyleHints >,
        Sbk_QStyleHints_Type_bases.object(),
        0);
    auto *pyType = Sbk_QStyleHints_TypeF(); // references _Sbk_QStyleHints_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QStyleHints_SignatureStrings);
#else
    InitSignatureBytes(pyType, QStyleHints_SignatureBytes, QStyleHints_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QStyleHints_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QStyleHints_PythonToCpp_QStyleHints_PTR,
        is_QStyleHints_PythonToCpp_QStyleHints_PTR_Convertible,
        QStyleHints_PTR_CppToPython_QStyleHints);

    Shiboken::Conversions::registerConverterName(converter, "QStyleHints");
    Shiboken::Conversions::registerConverterName(converter, "QStyleHints*");
    Shiboken::Conversions::registerConverterName(converter, "QStyleHints&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QStyleHints).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QStyleHintsWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QStyleHints_TypeF(), &Sbk_QStyleHints_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::QStyleHints::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QStyleHints::staticMetaObject, sizeof(QStyleHintsWrapper));

    return pyType;
}
