// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qt_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QString>
#include <qnamespace.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QtFunc_convertFromPlainText(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "convertFromPlainText", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QtGuiQt_IDX]);

    if (PyArg_ParseTuple(args, "|OO:convertFromPlainText", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static Qt::convertFromPlainText(QString,Qt::WhiteSpaceMode=)->QString
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // convertFromPlainText(QString,Qt::WhiteSpaceMode)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_WhiteSpaceMode_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // convertFromPlainText(QString,Qt::WhiteSpaceMode)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "convertFromPlainText", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QtGuiQt_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
            if (PyDict_Contains(kwds, key_mode) != 0) {
                value = PyDict_GetItem(kwds, key_mode);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_mode);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "convertFromPlainText", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QtGuiQt_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_WhiteSpaceMode_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "convertFromPlainText", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QtGuiQt_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_mode);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "convertFromPlainText", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QtGuiQt_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::Qt::WhiteSpaceMode cppArg1(Qt::WhiteSpaceMode::WhiteSpacePre);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // convertFromPlainText(QString,Qt::WhiteSpaceMode)
            QString cppResult = ::Qt::convertFromPlainText(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QtFunc_mightBeRichText(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static Qt::mightBeRichText(QAnyStringView)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // mightBeRichText(QAnyStringView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mightBeRichText", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QtGuiQt_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mightBeRichText(QAnyStringView)
            bool cppResult = ::Qt::mightBeRichText(QAnyStringView(cppArg0));
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_Qt_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_Qt_methods[] = {
    {"convertFromPlainText", reinterpret_cast<PyCFunction>(Sbk_QtFunc_convertFromPlainText), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"mightBeRichText", reinterpret_cast<PyCFunction>(Sbk_QtFunc_mightBeRichText), METH_O|METH_STATIC, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_Qt_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Qt_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Qt_Type = nullptr;
static PyTypeObject *Sbk_Qt_TypeF(void)
{
    return _Sbk_Qt_Type;
}

static PyType_Slot Sbk_Qt_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(Sbk_object_dealloc /* PYSIDE-832: Prevent replacement of "0" with subtype_dealloc. */)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt_methods)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt_spec = {
    "2:PySide6.QtGui.Qt",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt_slots
};

} //extern "C"

// Type conversion functions.

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QtGuiQt_SignatureStrings[] = {
    "PySide6.QtGui.Qt.convertFromPlainText(plain:QString,mode:PySide6.QtCore.Qt.WhiteSpaceMode=Qt.WhiteSpaceMode.WhiteSpacePre)->QString",
    "PySide6.QtGui.Qt.mightBeRichText(arg__1:QString)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QtGuiQt_SignatureByteSize = 129;
static constexpr uint8_t QtGuiQt_SignatureBytes[129] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0x2f, 0xcd, 0x04,
    0x92, 0x7a, 0xc9, 0xf9, 0x79, 0x65, 0xa9, 0x45, 0x25, 0x6e, 0x45, 0xf9, 0xb9, 0x01, 0x39, 0x89,
    0x99, 0x79, 0x21, 0xa9, 0x15, 0x25, 0x1a, 0x05, 0x20, 0x96, 0x55, 0x60, 0x70, 0x49, 0x51, 0x66,
    0x5e, 0xba, 0x4e, 0x6e, 0x7e, 0x4a, 0xaa, 0x55, 0x00, 0x5c, 0xa3, 0x73, 0x7e, 0x51, 0x2a, 0x48,
    0x67, 0x78, 0x46, 0x66, 0x49, 0x6a, 0x70, 0x41, 0x62, 0x72, 0xaa, 0x2f, 0x50, 0x81, 0x2d, 0x86,
    0x08, 0x12, 0x37, 0xa0, 0x28, 0x55, 0x53, 0xd7, 0x0e, 0x6a, 0x1e, 0x57, 0x00, 0xba, 0x1b, 0x72,
    0x33, 0xd3, 0x33, 0x4a, 0x9c, 0x52, 0x83, 0x32, 0x93, 0x33, 0xc0, 0xd6, 0x27, 0x16, 0xa5, 0xc7,
    0xc7, 0x1b, 0xc2, 0xec, 0x07, 0xea, 0x4c, 0xca, 0xcf, 0xcf, 0xe1, 0x02, 0x00, 0x11, 0xe0, 0x43,
    0x57
};
#endif

PyTypeObject *init_QtGuiQt(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QtGuiQt_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QtGuiQt_IDX].type;

    Shiboken::AutoDecRef Sbk_Qt_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreQt_IDX]))));

    _Sbk_Qt_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "Qt",
        "Qt",
        &Sbk_Qt_spec,
        nullptr,
        Sbk_Qt_Type_bases.object(),
        0);
    auto *pyType = Sbk_Qt_TypeF(); // references _Sbk_Qt_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QtGuiQt_SignatureStrings);
#else
    InitSignatureBytes(pyType, QtGuiQt_SignatureBytes, QtGuiQt_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Qt_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QtGuiQt_IDX].type = pyType;



    return pyType;
}
