// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qtextblock_wrapper.h"

// inner classes
#include "qtextblock_iterator_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QTextBlock>
#include <QTextLayout>
#include <QtGui/qtextdocument.h>
#include <QtGui/qtextformat.h>
#include <QtGui/qtextlayout.h>
#include <QtGui/qtextlist.h>
#include <QtGui/qtextobject.h>
#include <qnamespace.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTextBlock_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QTextBlock >()))
        return -1;

    ::QTextBlock *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QTextBlock", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QTextBlock::QTextBlock()
    // 1: QTextBlock::QTextBlock(QTextBlock)
    if (numArgs == 0) {
        overloadId = 0; // QTextBlock()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QTextBlock(QTextBlock)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QTextBlock()
        {

            // QTextBlock()
            cptr = new ::QTextBlock();
            break;
        }
        case 1: // QTextBlock(const QTextBlock &o)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QTextBlock cppArg0_local;
            ::QTextBlock *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QTextBlock(QTextBlock)
                cptr = new ::QTextBlock(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QTextBlock >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QTextBlockFunc___iter__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlock *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // __iter__()
        // Begin code injection
        // TEMPLATE - __iter_parent__ - START
        QTextBlock::iterator _tmp = cppSelf->begin();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_iterator_IDX]), &_tmp);
        // TEMPLATE - __iter_parent__ - END
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBlockFunc_begin(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlock *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // begin()const
        QTextBlock::iterator cppResult = const_cast<const ::QTextBlock *>(cppSelf)->begin();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_iterator_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBlockFunc_blockFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlock *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // blockFormat()const
        QTextBlockFormat cppResult = const_cast<const ::QTextBlock *>(cppSelf)->blockFormat();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBlockFunc_blockFormatIndex(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlock *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // blockFormatIndex()const
        int cppResult = const_cast<const ::QTextBlock *>(cppSelf)->blockFormatIndex();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBlockFunc_blockNumber(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlock *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // blockNumber()const
        int cppResult = const_cast<const ::QTextBlock *>(cppSelf)->blockNumber();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBlockFunc_charFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlock *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // charFormat()const
        QTextCharFormat cppResult = const_cast<const ::QTextBlock *>(cppSelf)->charFormat();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBlockFunc_charFormatIndex(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlock *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // charFormatIndex()const
        int cppResult = const_cast<const ::QTextBlock *>(cppSelf)->charFormatIndex();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBlockFunc_clearLayout(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlock *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clearLayout()
        cppSelf->clearLayout();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextBlockFunc_contains(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlock *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextBlock::contains(int)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // contains(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "contains", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // contains(int)const
            bool cppResult = const_cast<const ::QTextBlock *>(cppSelf)->contains(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBlockFunc_document(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlock *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // document()const
        const QTextDocument * cppResult = const_cast<const ::QTextBlock *>(cppSelf)->document();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBlockFunc_end(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlock *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // end()const
        QTextBlock::iterator cppResult = const_cast<const ::QTextBlock *>(cppSelf)->end();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_iterator_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBlockFunc_firstLineNumber(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlock *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // firstLineNumber()const
        int cppResult = const_cast<const ::QTextBlock *>(cppSelf)->firstLineNumber();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBlockFunc_fragmentIndex(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlock *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // fragmentIndex()const
        int cppResult = const_cast<const ::QTextBlock *>(cppSelf)->fragmentIndex();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBlockFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlock *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QTextBlock *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBlockFunc_isVisible(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlock *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isVisible()const
        bool cppResult = const_cast<const ::QTextBlock *>(cppSelf)->isVisible();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBlockFunc_layout(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlock *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // layout()const
        QTextLayout * cppResult = const_cast<const ::QTextBlock *>(cppSelf)->layout();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLayout_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBlockFunc_length(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlock *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // length()const
        int cppResult = const_cast<const ::QTextBlock *>(cppSelf)->length();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBlockFunc_lineCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlock *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lineCount()const
        int cppResult = const_cast<const ::QTextBlock *>(cppSelf)->lineCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBlockFunc_next(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlock *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // next()const
        QTextBlock cppResult = const_cast<const ::QTextBlock *>(cppSelf)->next();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBlockFunc_position(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlock *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // position()const
        int cppResult = const_cast<const ::QTextBlock *>(cppSelf)->position();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBlockFunc_previous(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlock *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // previous()const
        QTextBlock cppResult = const_cast<const ::QTextBlock *>(cppSelf)->previous();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBlockFunc_revision(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlock *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // revision()const
        int cppResult = const_cast<const ::QTextBlock *>(cppSelf)->revision();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBlockFunc_setLineCount(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlock *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextBlock::setLineCount(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setLineCount(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLineCount", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLineCount(int)
            cppSelf->setLineCount(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextBlockFunc_setRevision(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlock *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextBlock::setRevision(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setRevision(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRevision", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRevision(int)
            cppSelf->setRevision(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextBlockFunc_setUserData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlock *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextBlock::setUserData(QTextBlockUserData*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockUserData_IDX]), (pyArg)))) {
        overloadId = 0; // setUserData(QTextBlockUserData*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUserData", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTextBlockUserData *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setUserData(QTextBlockUserData*)
            cppSelf->setUserData(cppArg0);
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtgui.cpp (qtextblock-setuserdata)]
            const QTextDocument *doc = cppSelf->document();
            if (doc) {
                Shiboken::AutoDecRef pyDocument(Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), doc));
                Shiboken::Object::setParent(pyDocument, pyArg);
            }
            // END of custom code block [file: ../glue/qtgui.cpp (qtextblock-setuserdata)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextBlockFunc_setUserState(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlock *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextBlock::setUserState(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setUserState(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUserState", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setUserState(int)
            cppSelf->setUserState(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextBlockFunc_setVisible(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlock *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextBlock::setVisible(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setVisible(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setVisible", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setVisible(bool)
            cppSelf->setVisible(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextBlockFunc_text(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlock *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // text()const
        QString cppResult = const_cast<const ::QTextBlock *>(cppSelf)->text();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBlockFunc_textDirection(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlock *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // textDirection()const
        Qt::LayoutDirection cppResult = const_cast<const ::QTextBlock *>(cppSelf)->textDirection();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_LayoutDirection_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBlockFunc_textFormats(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlock *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // textFormats()const
        QList<QTextLayout::FormatRange> cppResult = const_cast<const ::QTextBlock *>(cppSelf)->textFormats();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QTextLayout_FormatRange_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBlockFunc_textList(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlock *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // textList()const
        QTextList * cppResult = const_cast<const ::QTextBlock *>(cppSelf)->textList();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextList_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBlockFunc_userData(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlock *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // userData()const
        QTextBlockUserData * cppResult = const_cast<const ::QTextBlock *>(cppSelf)->userData();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockUserData_IDX]), cppResult);
        // Begin code injection
        // ========================================================================
        // START of custom code block [file: ../glue/qtgui.cpp (qtextblock-userdata)]
        const QTextDocument *doc = cppSelf->document();
        if (doc) {
            Shiboken::AutoDecRef pyDocument(Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), doc));
            Shiboken::Object::setParent(pyDocument, pyResult);
        }
        // END of custom code block [file: ../glue/qtgui.cpp (qtextblock-userdata)]
        // ========================================================================
        // End of code injection


        // Ownership transferences.
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBlockFunc_userState(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlock *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // userState()const
        int cppResult = const_cast<const ::QTextBlock *>(cppSelf)->userState();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBlock__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QTextBlock *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QTextBlock_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QTextBlock_methods[] = {
    {"begin", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFunc_begin), METH_NOARGS, nullptr},
    {"blockFormat", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFunc_blockFormat), METH_NOARGS, nullptr},
    {"blockFormatIndex", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFunc_blockFormatIndex), METH_NOARGS, nullptr},
    {"blockNumber", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFunc_blockNumber), METH_NOARGS, nullptr},
    {"charFormat", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFunc_charFormat), METH_NOARGS, nullptr},
    {"charFormatIndex", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFunc_charFormatIndex), METH_NOARGS, nullptr},
    {"clearLayout", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFunc_clearLayout), METH_NOARGS, nullptr},
    {"contains", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFunc_contains), METH_O, nullptr},
    {"document", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFunc_document), METH_NOARGS, nullptr},
    {"end", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFunc_end), METH_NOARGS, nullptr},
    {"firstLineNumber", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFunc_firstLineNumber), METH_NOARGS, nullptr},
    {"fragmentIndex", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFunc_fragmentIndex), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFunc_isValid), METH_NOARGS, nullptr},
    {"isVisible", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFunc_isVisible), METH_NOARGS, nullptr},
    {"layout", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFunc_layout), METH_NOARGS, nullptr},
    {"length", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFunc_length), METH_NOARGS, nullptr},
    {"lineCount", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFunc_lineCount), METH_NOARGS, nullptr},
    {"next", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFunc_next), METH_NOARGS, nullptr},
    {"position", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFunc_position), METH_NOARGS, nullptr},
    {"previous", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFunc_previous), METH_NOARGS, nullptr},
    {"revision", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFunc_revision), METH_NOARGS, nullptr},
    {"setLineCount", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFunc_setLineCount), METH_O, nullptr},
    {"setRevision", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFunc_setRevision), METH_O, nullptr},
    {"setUserData", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFunc_setUserData), METH_O, nullptr},
    {"setUserState", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFunc_setUserState), METH_O, nullptr},
    {"setVisible", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFunc_setVisible), METH_O, nullptr},
    {"text", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFunc_text), METH_NOARGS, nullptr},
    {"textDirection", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFunc_textDirection), METH_NOARGS, nullptr},
    {"textFormats", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFunc_textFormats), METH_NOARGS, nullptr},
    {"textList", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFunc_textList), METH_NOARGS, nullptr},
    {"userData", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFunc_userData), METH_NOARGS, nullptr},
    {"userState", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFunc_userState), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QTextBlock__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QTextBlock_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QTextBlock *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), (pyArg)))) {
                // operator!=(const QTextBlock &o) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QTextBlock cppArg0_local;
                ::QTextBlock *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_LT:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), (pyArg)))) {
                // operator<(const QTextBlock &o) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QTextBlock cppArg0_local;
                ::QTextBlock *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf < (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), (pyArg)))) {
                // operator==(const QTextBlock &o) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QTextBlock cppArg0_local;
                ::QTextBlock *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QTextBlock_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QTextBlock_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QTextBlock_Type = nullptr;
static PyTypeObject *Sbk_QTextBlock_TypeF(void)
{
    return _Sbk_QTextBlock_Type;
}

static PyType_Slot Sbk_QTextBlock_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QTextBlock_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QTextBlock_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QTextBlock_richcompare)},
    {Py_tp_iter,        reinterpret_cast<void *>(Sbk_QTextBlockFunc___iter__)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QTextBlock_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QTextBlock_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QTextBlock_spec = {
    "2:PySide6.QtGui.QTextBlock",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QTextBlock_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QTextBlock_PythonToCpp_QTextBlock_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QTextBlock_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QTextBlock_PythonToCpp_QTextBlock_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QTextBlock_TypeF()))
        return QTextBlock_PythonToCpp_QTextBlock_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QTextBlock_PTR_CppToPython_QTextBlock(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QTextBlock_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QTextBlock_COPY_CppToPython_QTextBlock(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QTextBlock *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QTextBlock_TypeF(), new ::QTextBlock(*source), true, true);
}

// Python to C++ copy conversion.
static void QTextBlock_PythonToCpp_QTextBlock_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QTextBlock *>(cppOut) = *reinterpret_cast< ::QTextBlock *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QTextBlock_PythonToCpp_QTextBlock_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QTextBlock_TypeF()))
        return QTextBlock_PythonToCpp_QTextBlock_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QTextBlock_SignatureStrings[] = {
    "1:PySide6.QtGui.QTextBlock(self)",
    "0:PySide6.QtGui.QTextBlock(self,o:PySide6.QtGui.QTextBlock)",
    "PySide6.QtGui.QTextBlock.__iter__(self)->PyObject",
    "PySide6.QtGui.QTextBlock.begin(self)->PySide6.QtGui.QTextBlock.iterator",
    "PySide6.QtGui.QTextBlock.blockFormat(self)->PySide6.QtGui.QTextBlockFormat",
    "PySide6.QtGui.QTextBlock.blockFormatIndex(self)->int",
    "PySide6.QtGui.QTextBlock.blockNumber(self)->int",
    "PySide6.QtGui.QTextBlock.charFormat(self)->PySide6.QtGui.QTextCharFormat",
    "PySide6.QtGui.QTextBlock.charFormatIndex(self)->int",
    "PySide6.QtGui.QTextBlock.clearLayout(self)",
    "PySide6.QtGui.QTextBlock.contains(self,position:int)->bool",
    "PySide6.QtGui.QTextBlock.document(self)->PySide6.QtGui.QTextDocument",
    "PySide6.QtGui.QTextBlock.end(self)->PySide6.QtGui.QTextBlock.iterator",
    "PySide6.QtGui.QTextBlock.firstLineNumber(self)->int",
    "PySide6.QtGui.QTextBlock.fragmentIndex(self)->int",
    "PySide6.QtGui.QTextBlock.isValid(self)->bool",
    "PySide6.QtGui.QTextBlock.isVisible(self)->bool",
    "PySide6.QtGui.QTextBlock.layout(self)->PySide6.QtGui.QTextLayout",
    "PySide6.QtGui.QTextBlock.length(self)->int",
    "PySide6.QtGui.QTextBlock.lineCount(self)->int",
    "PySide6.QtGui.QTextBlock.next(self)->PySide6.QtGui.QTextBlock",
    "PySide6.QtGui.QTextBlock.position(self)->int",
    "PySide6.QtGui.QTextBlock.previous(self)->PySide6.QtGui.QTextBlock",
    "PySide6.QtGui.QTextBlock.revision(self)->int",
    "PySide6.QtGui.QTextBlock.setLineCount(self,count:int)",
    "PySide6.QtGui.QTextBlock.setRevision(self,rev:int)",
    "PySide6.QtGui.QTextBlock.setUserData(self,data:PySide6.QtGui.QTextBlockUserData)",
    "PySide6.QtGui.QTextBlock.setUserState(self,state:int)",
    "PySide6.QtGui.QTextBlock.setVisible(self,visible:bool)",
    "PySide6.QtGui.QTextBlock.text(self)->QString",
    "PySide6.QtGui.QTextBlock.textDirection(self)->PySide6.QtCore.Qt.LayoutDirection",
    "PySide6.QtGui.QTextBlock.textFormats(self)->QList[PySide6.QtGui.QTextLayout.FormatRange]",
    "PySide6.QtGui.QTextBlock.textList(self)->PySide6.QtGui.QTextList",
    "PySide6.QtGui.QTextBlock.userData(self)->PySide6.QtGui.QTextBlockUserData",
    "PySide6.QtGui.QTextBlock.userState(self)->int",
    "PySide6.QtGui.QTextBlock.__copy__(self)->typing.Self",
    "PySide6.QtGui.QTextBlock.__ne__(self,o:PySide6.QtGui.QTextBlock)->bool",
    "PySide6.QtGui.QTextBlock.__lt__(self,o:PySide6.QtGui.QTextBlock)->bool",
    "PySide6.QtGui.QTextBlock.__eq__(self,o:PySide6.QtGui.QTextBlock)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QTextBlock_SignatureByteSize = 448;
static constexpr uint8_t QTextBlock_SignatureBytes[448] = {
    0x78, 0xda, 0xad, 0x55, 0xb1, 0x6e, 0xdb, 0x30, 0x10, 0xdd, 0xf3, 0x25, 0x31, 0xa0, 0x08, 0xc9,
    0xd2, 0xc1, 0x43, 0x87, 0xda, 0x48, 0x51, 0xc0, 0x48, 0x62, 0xbb, 0xed, 0x52, 0x14, 0x02, 0x25,
    0x9d, 0x95, 0x6b, 0x68, 0xd2, 0x25, 0x4f, 0x46, 0xf4, 0xf7, 0xa5, 0x4c, 0xcb, 0xd2, 0x50, 0x1e,
    0xd9, 0xc2, 0x8b, 0x4d, 0x81, 0xef, 0xbd, 0x3b, 0xdd, 0x7b, 0x22, 0x1f, 0xe6, 0x2f, 0xdd, 0x16,
    0x6b, 0xf8, 0x90, 0xaf, 0xe9, 0x73, 0x8b, 0xf9, 0xfa, 0x2b, 0xbc, 0xd3, 0x27, 0xa9, 0xab, 0xb7,
    0x5b, 0x0b, 0x72, 0x37, 0xbb, 0xb9, 0xe7, 0x01, 0x99, 0x0e, 0xee, 0xcf, 0x6e, 0x42, 0x3b, 0x79,
    0x51, 0x20, 0x81, 0x29, 0x0a, 0x5f, 0xe3, 0xee, 0xe3, 0x4b, 0xf7, 0x5c, 0xfe, 0x82, 0x8a, 0xc2,
    0x8c, 0x12, 0x1a, 0x54, 0x23, 0x3c, 0x80, 0xea, 0x55, 0x05, 0x69, 0xc3, 0xe8, 0xf4, 0xbf, 0x8f,
    0xda, 0xec, 0x05, 0xc5, 0xd4, 0x3c, 0x2a, 0x49, 0xea, 0x8b, 0xaa, 0xe1, 0x7d, 0xd0, 0x43, 0x15,
    0x23, 0x3d, 0xb5, 0xfb, 0x12, 0x4c, 0x12, 0xbe, 0x7a, 0x15, 0x26, 0xda, 0xee, 0xe2, 0x02, 0x4a,
    0x11, 0x4a, 0x6f, 0xb6, 0x92, 0x20, 0xcc, 0x4a, 0x74, 0xba, 0x3d, 0x57, 0x67, 0xa0, 0x5a, 0x91,
    0x40, 0x65, 0x7d, 0x28, 0x0e, 0xda, 0x22, 0xa1, 0x56, 0x73, 0x27, 0xef, 0x8a, 0x94, 0x5a, 0xcb,
    0x30, 0xb5, 0xd6, 0x55, 0xbb, 0x07, 0xc5, 0xbd, 0xe0, 0xf2, 0x0c, 0x09, 0x8b, 0x80, 0xaa, 0xaf,
    0x90, 0x8e, 0x1d, 0x1a, 0x4b, 0x2b, 0x54, 0xf0, 0x0f, 0x0e, 0xed, 0x8c, 0x68, 0xfa, 0xde, 0xd2,
    0xc7, 0x8a, 0xf6, 0xbb, 0x90, 0x78, 0xe9, 0x97, 0x9f, 0x8e, 0x03, 0xa3, 0xc5, 0x52, 0x42, 0x1a,
    0x5c, 0x4e, 0xdc, 0xfa, 0xeb, 0x28, 0xbc, 0x9d, 0x8c, 0x00, 0xa8, 0x86, 0x5e, 0x93, 0xde, 0x43,
    0xba, 0x41, 0x2d, 0x74, 0x3b, 0x3a, 0xc7, 0xa2, 0x95, 0x5b, 0xc5, 0x2c, 0x0a, 0xb3, 0x87, 0x44,
    0x25, 0x95, 0x3a, 0x18, 0x38, 0xa2, 0x6e, 0xed, 0xff, 0x97, 0xeb, 0x05, 0x6c, 0x6a, 0x39, 0x0b,
    0xa7, 0xcc, 0x8c, 0xa3, 0xc8, 0xaa, 0x7e, 0x79, 0x0a, 0x3f, 0xcb, 0xda, 0x4c, 0xab, 0x64, 0xae,
    0x66, 0x9c, 0xf2, 0xcd, 0x82, 0x59, 0x0a, 0x12, 0x9e, 0x52, 0xbb, 0x55, 0xf0, 0xfc, 0x1d, 0xa0,
    0x71, 0xc1, 0x2d, 0x09, 0xf2, 0xf9, 0xca, 0x6c, 0xbf, 0x8c, 0xb7, 0x31, 0xcd, 0x64, 0x76, 0xf4,
    0x0f, 0xf3, 0x3e, 0x99, 0x0c, 0x8d, 0x26, 0x01, 0x58, 0x6f, 0xc9, 0xa0, 0x6a, 0x78, 0xf0, 0x12,
    0x8d, 0xbb, 0x13, 0x26, 0x2e, 0x8c, 0xe8, 0x85, 0x36, 0xe0, 0xfe, 0x72, 0x9f, 0xe6, 0x0b, 0x90,
    0xd7, 0xf3, 0xc7, 0xdf, 0x25, 0x15, 0xeb, 0x15, 0x5a, 0xfa, 0x11, 0xfc, 0x44, 0x72, 0x0f, 0xdf,
    0x08, 0xd5, 0xc0, 0x4f, 0x5e, 0xb8, 0x17, 0xe2, 0x3e, 0x39, 0xb7, 0x1d, 0x16, 0x68, 0xa7, 0x8e,
    0x32, 0x61, 0x1d, 0xec, 0xe4, 0x95, 0x46, 0x2b, 0x63, 0xa9, 0x2d, 0x8a, 0x4a, 0x1f, 0xba, 0xf1,
    0x0e, 0xa6, 0xee, 0xe0, 0x1c, 0xc9, 0xb7, 0xee, 0x89, 0x23, 0x29, 0x38, 0x53, 0xb8, 0x9b, 0x3f,
    0x76, 0x4a, 0x15, 0x85, 0xa4, 0xab, 0xc8, 0xc0, 0xef, 0x74, 0x99, 0x3f, 0x76, 0x70, 0x2b, 0xe0
};
#endif

PyTypeObject *init_QTextBlock(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX].type;

    Shiboken::AutoDecRef Sbk_QTextBlock_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QTextBlock_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QTextBlock",
        "QTextBlock",
        &Sbk_QTextBlock_spec,
        &Shiboken::callCppDestructor< ::QTextBlock >,
        Sbk_QTextBlock_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QTextBlock_TypeF(); // references _Sbk_QTextBlock_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QTextBlock_SignatureStrings);
#else
    InitSignatureBytes(pyType, QTextBlock_SignatureBytes, QTextBlock_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QTextBlock_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QTextBlock_PythonToCpp_QTextBlock_PTR,
        is_QTextBlock_PythonToCpp_QTextBlock_PTR_Convertible,
        QTextBlock_PTR_CppToPython_QTextBlock,
        QTextBlock_COPY_CppToPython_QTextBlock);

    Shiboken::Conversions::registerConverterName(converter, "QTextBlock");
    Shiboken::Conversions::registerConverterName(converter, "QTextBlock*");
    Shiboken::Conversions::registerConverterName(converter, "QTextBlock&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QTextBlock).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QTextBlock_PythonToCpp_QTextBlock_COPY,
        is_QTextBlock_PythonToCpp_QTextBlock_COPY_Convertible);

    qRegisterMetaType< ::QTextBlock >("QTextBlock");

    return pyType;
}
