// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qtextblockformat_wrapper.h"

// Argument includes
#include <QList>
#include <QMap>
#include <QString>
#include <QtGui/qbrush.h>
#include <QtGui/qcolor.h>
#include <QtGui/qpen.h>
#include <QtGui/qtextformat.h>
#include <QtGui/qtextoption.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTextBlockFormat_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QTextBlockFormat >()))
        return -1;

    ::QTextBlockFormat *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QTextBlockFormat", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QTextBlockFormat::QTextBlockFormat()
    // 1: QTextBlockFormat::QTextBlockFormat(QTextBlockFormat)
    // 2: QTextBlockFormat::QTextBlockFormat(QTextFormat)
    if (numArgs == 0) {
        overloadId = 0; // QTextBlockFormat()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QTextBlockFormat(QTextBlockFormat)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QTextBlockFormat(QTextFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QTextBlockFormat()
        {

            // QTextBlockFormat()
            cptr = new ::QTextBlockFormat();
            break;
        }
        case 1: // QTextBlockFormat(const QTextBlockFormat &QTextBlockFormat)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QTextBlockFormat cppArg0_local;
            ::QTextBlockFormat *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QTextBlockFormat(QTextBlockFormat)
                cptr = new ::QTextBlockFormat(*cppArg0);
            }
            break;
        }
        case 2: // QTextBlockFormat(const QTextFormat &fmt)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QTextFormat cppArg0_local;
            ::QTextFormat *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QTextBlockFormat(QTextFormat)
                cptr = new ::QTextBlockFormat(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QTextBlockFormat >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QTextBlockFormatFunc_alignment(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlockFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // alignment()const
        QFlags<Qt::AlignmentFlag> cppResult = const_cast<const ::QTextBlockFormat *>(cppSelf)->alignment();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_AlignmentFlag_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBlockFormatFunc_bottomMargin(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlockFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // bottomMargin()const
        qreal cppResult = const_cast<const ::QTextBlockFormat *>(cppSelf)->bottomMargin();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBlockFormatFunc_headingLevel(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlockFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // headingLevel()const
        int cppResult = const_cast<const ::QTextBlockFormat *>(cppSelf)->headingLevel();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBlockFormatFunc_indent(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlockFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // indent()const
        int cppResult = const_cast<const ::QTextBlockFormat *>(cppSelf)->indent();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBlockFormatFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlockFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QTextBlockFormat *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBlockFormatFunc_leftMargin(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlockFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // leftMargin()const
        qreal cppResult = const_cast<const ::QTextBlockFormat *>(cppSelf)->leftMargin();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBlockFormatFunc_lineHeight(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlockFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 1)
        return Shiboken::returnWrongArguments(args, "lineHeight", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]);

    if (PyArg_UnpackTuple(args, "lineHeight", 0, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTextBlockFormat::lineHeight()const->qreal
    // 1: QTextBlockFormat::lineHeight(qreal,qreal)const->qreal
    if (numArgs == 0) {
        overloadId = 0; // lineHeight()const
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))) {
        overloadId = 1; // lineHeight(qreal,qreal)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "lineHeight", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // lineHeight() const
        {

            // lineHeight()const
            qreal cppResult = const_cast<const ::QTextBlockFormat *>(cppSelf)->lineHeight();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
            break;
        }
        case 1: // lineHeight(qreal scriptLineHeight, qreal scaling) const
        {
            qreal cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // lineHeight(qreal,qreal)const
                qreal cppResult = const_cast<const ::QTextBlockFormat *>(cppSelf)->lineHeight(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBlockFormatFunc_lineHeightType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlockFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lineHeightType()const
        int cppResult = const_cast<const ::QTextBlockFormat *>(cppSelf)->lineHeightType();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBlockFormatFunc_marker(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlockFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // marker()const
        QTextBlockFormat::MarkerType cppResult = const_cast<const ::QTextBlockFormat *>(cppSelf)->marker();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_MarkerType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBlockFormatFunc_nonBreakableLines(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlockFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // nonBreakableLines()const
        bool cppResult = const_cast<const ::QTextBlockFormat *>(cppSelf)->nonBreakableLines();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBlockFormatFunc_pageBreakPolicy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlockFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pageBreakPolicy()const
        QFlags<QTextFormat::PageBreakFlag> cppResult = const_cast<const ::QTextBlockFormat *>(cppSelf)->pageBreakPolicy();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QTextFormat_PageBreakFlag_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBlockFormatFunc_rightMargin(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlockFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rightMargin()const
        qreal cppResult = const_cast<const ::QTextBlockFormat *>(cppSelf)->rightMargin();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBlockFormatFunc_setAlignment(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlockFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextBlockFormat::setAlignment(QFlags<Qt::AlignmentFlag>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_AlignmentFlag_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setAlignment(QFlags<Qt::AlignmentFlag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAlignment", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]);

    // Call function/method
    {
        ::QFlags<Qt::AlignmentFlag> cppArg0 = QFlags<Qt::AlignmentFlag>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAlignment(QFlags<Qt::AlignmentFlag>)
            cppSelf->setAlignment(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextBlockFormatFunc_setBottomMargin(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlockFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextBlockFormat::setBottomMargin(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setBottomMargin(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBottomMargin", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setBottomMargin(qreal)
            cppSelf->setBottomMargin(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextBlockFormatFunc_setHeadingLevel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlockFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextBlockFormat::setHeadingLevel(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setHeadingLevel(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHeadingLevel", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHeadingLevel(int)
            cppSelf->setHeadingLevel(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextBlockFormatFunc_setIndent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlockFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextBlockFormat::setIndent(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setIndent(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setIndent", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setIndent(int)
            cppSelf->setIndent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextBlockFormatFunc_setLeftMargin(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlockFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextBlockFormat::setLeftMargin(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setLeftMargin(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLeftMargin", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLeftMargin(qreal)
            cppSelf->setLeftMargin(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextBlockFormatFunc_setLineHeight(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlockFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setLineHeight", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTextBlockFormat::setLineHeight(qreal,int)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // setLineHeight(qreal,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setLineHeight", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLineHeight(qreal,int)
            cppSelf->setLineHeight(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextBlockFormatFunc_setMarker(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlockFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextBlockFormat::setMarker(QTextBlockFormat::MarkerType)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_MarkerType_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setMarker(QTextBlockFormat::MarkerType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMarker", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]);

    // Call function/method
    {
        ::QTextBlockFormat::MarkerType cppArg0{QTextBlockFormat::MarkerType::NoMarker};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMarker(QTextBlockFormat::MarkerType)
            cppSelf->setMarker(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextBlockFormatFunc_setNonBreakableLines(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlockFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextBlockFormat::setNonBreakableLines(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setNonBreakableLines(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setNonBreakableLines", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setNonBreakableLines(bool)
            cppSelf->setNonBreakableLines(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextBlockFormatFunc_setPageBreakPolicy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlockFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextBlockFormat::setPageBreakPolicy(QFlags<QTextFormat::PageBreakFlag>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QTextFormat_PageBreakFlag_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setPageBreakPolicy(QFlags<QTextFormat::PageBreakFlag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPageBreakPolicy", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]);

    // Call function/method
    {
        ::QFlags<QTextFormat::PageBreakFlag> cppArg0 = QFlags<QTextFormat::PageBreakFlag>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPageBreakPolicy(QFlags<QTextFormat::PageBreakFlag>)
            cppSelf->setPageBreakPolicy(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextBlockFormatFunc_setRightMargin(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlockFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextBlockFormat::setRightMargin(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setRightMargin(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRightMargin", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRightMargin(qreal)
            cppSelf->setRightMargin(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextBlockFormatFunc_setTabPositions(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlockFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextBlockFormat::setTabPositions(QList<QTextOption::Tab>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QTextOption_Tab_IDX], (pyArg)))) {
        overloadId = 0; // setTabPositions(QList<QTextOption::Tab>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTabPositions", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]);

    // Call function/method
    {
        ::QList<QTextOption::Tab> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTabPositions(QList<QTextOption::Tab>)
            cppSelf->setTabPositions(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextBlockFormatFunc_setTextIndent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlockFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextBlockFormat::setTextIndent(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setTextIndent(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTextIndent", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTextIndent(qreal)
            cppSelf->setTextIndent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextBlockFormatFunc_setTopMargin(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlockFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextBlockFormat::setTopMargin(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setTopMargin(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTopMargin", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTopMargin(qreal)
            cppSelf->setTopMargin(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextBlockFormatFunc_tabPositions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlockFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // tabPositions()const
        QList<QTextOption::Tab> cppResult = const_cast<const ::QTextBlockFormat *>(cppSelf)->tabPositions();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QTextOption_Tab_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBlockFormatFunc_textIndent(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlockFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // textIndent()const
        qreal cppResult = const_cast<const ::QTextBlockFormat *>(cppSelf)->textIndent();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBlockFormatFunc_topMargin(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBlockFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // topMargin()const
        qreal cppResult = const_cast<const ::QTextBlockFormat *>(cppSelf)->topMargin();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBlockFormat__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QTextBlockFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QTextBlockFormat_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QTextBlockFormat_EnumFlagInfo[] = {
    "LineHeightTypes:Enum",
    "MarkerType:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QTextBlockFormat_methods[] = {
    {"alignment", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFormatFunc_alignment), METH_NOARGS, nullptr},
    {"bottomMargin", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFormatFunc_bottomMargin), METH_NOARGS, nullptr},
    {"headingLevel", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFormatFunc_headingLevel), METH_NOARGS, nullptr},
    {"indent", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFormatFunc_indent), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFormatFunc_isValid), METH_NOARGS, nullptr},
    {"leftMargin", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFormatFunc_leftMargin), METH_NOARGS, nullptr},
    {"lineHeight", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFormatFunc_lineHeight), METH_VARARGS, nullptr},
    {"lineHeightType", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFormatFunc_lineHeightType), METH_NOARGS, nullptr},
    {"marker", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFormatFunc_marker), METH_NOARGS, nullptr},
    {"nonBreakableLines", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFormatFunc_nonBreakableLines), METH_NOARGS, nullptr},
    {"pageBreakPolicy", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFormatFunc_pageBreakPolicy), METH_NOARGS, nullptr},
    {"rightMargin", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFormatFunc_rightMargin), METH_NOARGS, nullptr},
    {"setAlignment", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFormatFunc_setAlignment), METH_O, nullptr},
    {"setBottomMargin", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFormatFunc_setBottomMargin), METH_O, nullptr},
    {"setHeadingLevel", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFormatFunc_setHeadingLevel), METH_O, nullptr},
    {"setIndent", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFormatFunc_setIndent), METH_O, nullptr},
    {"setLeftMargin", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFormatFunc_setLeftMargin), METH_O, nullptr},
    {"setLineHeight", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFormatFunc_setLineHeight), METH_VARARGS, nullptr},
    {"setMarker", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFormatFunc_setMarker), METH_O, nullptr},
    {"setNonBreakableLines", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFormatFunc_setNonBreakableLines), METH_O, nullptr},
    {"setPageBreakPolicy", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFormatFunc_setPageBreakPolicy), METH_O, nullptr},
    {"setRightMargin", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFormatFunc_setRightMargin), METH_O, nullptr},
    {"setTabPositions", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFormatFunc_setTabPositions), METH_O, nullptr},
    {"setTextIndent", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFormatFunc_setTextIndent), METH_O, nullptr},
    {"setTopMargin", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFormatFunc_setTopMargin), METH_O, nullptr},
    {"tabPositions", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFormatFunc_tabPositions), METH_NOARGS, nullptr},
    {"textIndent", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFormatFunc_textIndent), METH_NOARGS, nullptr},
    {"topMargin", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFormatFunc_topMargin), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QTextBlockFormat__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QTextBlockFormat_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QTextBlockFormat_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QTextBlockFormat_Type = nullptr;
static PyTypeObject *Sbk_QTextBlockFormat_TypeF(void)
{
    return _Sbk_QTextBlockFormat_Type;
}

static PyType_Slot Sbk_QTextBlockFormat_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QTextBlockFormat_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QTextBlockFormat_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QTextBlockFormat_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QTextBlockFormat_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QTextBlockFormat_spec = {
    "2:PySide6.QtGui.QTextBlockFormat",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QTextBlockFormat_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QTextBlockFormat_LineHeightTypes(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QTextBlockFormat::LineHeightTypes>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QTextBlockFormat::LineHeightTypes *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QTextBlockFormat_LineHeightTypes_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_LineHeightTypes_IDX])))
        return Enum_PythonToCpp_QTextBlockFormat_LineHeightTypes;
    return {};
}

static PyObject *QTextBlockFormat_LineHeightTypes_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QTextBlockFormat::LineHeightTypes>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QTextBlockFormat::LineHeightTypes *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_LineHeightTypes_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QTextBlockFormat_MarkerType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QTextBlockFormat::MarkerType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QTextBlockFormat::MarkerType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QTextBlockFormat_MarkerType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_MarkerType_IDX])))
        return Enum_PythonToCpp_QTextBlockFormat_MarkerType;
    return {};
}

static PyObject *QTextBlockFormat_MarkerType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QTextBlockFormat::MarkerType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QTextBlockFormat::MarkerType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_MarkerType_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QTextBlockFormat_PythonToCpp_QTextBlockFormat_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QTextBlockFormat_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QTextBlockFormat_PythonToCpp_QTextBlockFormat_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QTextBlockFormat_TypeF()))
        return QTextBlockFormat_PythonToCpp_QTextBlockFormat_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QTextBlockFormat_PTR_CppToPython_QTextBlockFormat(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QTextBlockFormat_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QTextBlockFormat_COPY_CppToPython_QTextBlockFormat(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QTextBlockFormat *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QTextBlockFormat_TypeF(), new ::QTextBlockFormat(*source), true, true);
}

// Python to C++ copy conversion.
static void QTextBlockFormat_PythonToCpp_QTextBlockFormat_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QTextBlockFormat *>(cppOut) = *reinterpret_cast< ::QTextBlockFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QTextBlockFormat_PythonToCpp_QTextBlockFormat_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QTextBlockFormat_TypeF()))
        return QTextBlockFormat_PythonToCpp_QTextBlockFormat_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QTextBlockFormat_SignatureStrings[] = {
    "2:PySide6.QtGui.QTextBlockFormat(self)",
    "1:PySide6.QtGui.QTextBlockFormat(self,QTextBlockFormat:PySide6.QtGui.QTextBlockFormat)",
    "0:PySide6.QtGui.QTextBlockFormat(self,fmt:PySide6.QtGui.QTextFormat)",
    "PySide6.QtGui.QTextBlockFormat.alignment(self)->PySide6.QtCore.Qt.AlignmentFlag",
    "PySide6.QtGui.QTextBlockFormat.bottomMargin(self)->qreal",
    "PySide6.QtGui.QTextBlockFormat.headingLevel(self)->int",
    "PySide6.QtGui.QTextBlockFormat.indent(self)->int",
    "PySide6.QtGui.QTextBlockFormat.isValid(self)->bool",
    "PySide6.QtGui.QTextBlockFormat.leftMargin(self)->qreal",
    "1:PySide6.QtGui.QTextBlockFormat.lineHeight(self)->qreal",
    "0:PySide6.QtGui.QTextBlockFormat.lineHeight(self,scriptLineHeight:qreal,scaling:qreal)->qreal",
    "PySide6.QtGui.QTextBlockFormat.lineHeightType(self)->int",
    "PySide6.QtGui.QTextBlockFormat.marker(self)->PySide6.QtGui.QTextBlockFormat.MarkerType",
    "PySide6.QtGui.QTextBlockFormat.nonBreakableLines(self)->bool",
    "PySide6.QtGui.QTextBlockFormat.pageBreakPolicy(self)->PySide6.QtGui.QTextFormat.PageBreakFlag",
    "PySide6.QtGui.QTextBlockFormat.rightMargin(self)->qreal",
    "PySide6.QtGui.QTextBlockFormat.setAlignment(self,alignment:PySide6.QtCore.Qt.AlignmentFlag)",
    "PySide6.QtGui.QTextBlockFormat.setBottomMargin(self,margin:qreal)",
    "PySide6.QtGui.QTextBlockFormat.setHeadingLevel(self,alevel:int)",
    "PySide6.QtGui.QTextBlockFormat.setIndent(self,indent:int)",
    "PySide6.QtGui.QTextBlockFormat.setLeftMargin(self,margin:qreal)",
    "PySide6.QtGui.QTextBlockFormat.setLineHeight(self,height:qreal,heightType:int)",
    "PySide6.QtGui.QTextBlockFormat.setMarker(self,marker:PySide6.QtGui.QTextBlockFormat.MarkerType)",
    "PySide6.QtGui.QTextBlockFormat.setNonBreakableLines(self,b:bool)",
    "PySide6.QtGui.QTextBlockFormat.setPageBreakPolicy(self,flags:PySide6.QtGui.QTextFormat.PageBreakFlag)",
    "PySide6.QtGui.QTextBlockFormat.setRightMargin(self,margin:qreal)",
    "PySide6.QtGui.QTextBlockFormat.setTabPositions(self,tabs:QList[PySide6.QtGui.QTextOption.Tab])",
    "PySide6.QtGui.QTextBlockFormat.setTextIndent(self,aindent:qreal)",
    "PySide6.QtGui.QTextBlockFormat.setTopMargin(self,margin:qreal)",
    "PySide6.QtGui.QTextBlockFormat.tabPositions(self)->QList[PySide6.QtGui.QTextOption.Tab]",
    "PySide6.QtGui.QTextBlockFormat.textIndent(self)->qreal",
    "PySide6.QtGui.QTextBlockFormat.topMargin(self)->qreal",
    "PySide6.QtGui.QTextBlockFormat.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QTextBlockFormat_SignatureByteSize = 446;
static constexpr uint8_t QTextBlockFormat_SignatureBytes[446] = {
    0x78, 0xda, 0x9d, 0x54, 0xd1, 0x4e, 0x83, 0x30, 0x14, 0x7d, 0xdf, 0x97, 0xb8, 0x04, 0x89, 0xfa,
    0xe0, 0x03, 0x0f, 0x26, 0x9b, 0xc9, 0x9c, 0x09, 0x53, 0xe6, 0x16, 0x5f, 0x8c, 0x21, 0x65, 0x5c,
    0xa0, 0x59, 0x69, 0x91, 0x56, 0x23, 0x7f, 0x6f, 0x61, 0x30, 0x06, 0x92, 0xf5, 0xb2, 0x27, 0xca,
    0xcd, 0x3d, 0xa7, 0xf7, 0xb4, 0xe7, 0xf4, 0xce, 0xf1, 0x8a, 0x0d, 0x0d, 0xe1, 0xde, 0x5e, 0xab,
    0xa7, 0x6f, 0x6a, 0xaf, 0xb7, 0xf0, 0xab, 0xe6, 0x4c, 0xec, 0xf6, 0x0b, 0x91, 0xa7, 0x44, 0x5d,
    0x49, 0x60, 0xd1, 0x74, 0x72, 0x8b, 0x69, 0xb3, 0xfa, 0x55, 0x03, 0x68, 0x3a, 0xb9, 0x41, 0xd1,
    0x46, 0xe9, 0x20, 0x53, 0x43, 0x72, 0x9e, 0xc2, 0x26, 0x8c, 0xc6, 0x3c, 0x05, 0x5e, 0x4b, 0xb9,
    0x7e, 0x68, 0xfb, 0x1f, 0x45, 0x0e, 0xfa, 0x63, 0xcf, 0x9a, 0x96, 0x05, 0x23, 0xb1, 0x89, 0x2f,
    0x10, 0x4a, 0x89, 0x74, 0x45, 0xf2, 0x98, 0xf2, 0x86, 0xf2, 0x2b, 0x07, 0xc2, 0x4c, 0xc0, 0x04,
    0x48, 0x48, 0x79, 0xec, 0xc2, 0x0f, 0xb0, 0x06, 0x48, 0xb9, 0x32, 0xc1, 0x28, 0x0f, 0x4f, 0x86,
    0xc7, 0x00, 0xe4, 0xbb, 0xd6, 0x1c, 0x36, 0x88, 0x40, 0x08, 0xe3, 0x68, 0x0c, 0x22, 0x35, 0xa4,
    0xc8, 0x74, 0xed, 0x36, 0xa3, 0x1c, 0x96, 0x40, 0xe3, 0x44, 0x75, 0x81, 0x37, 0x23, 0x81, 0x96,
    0xdc, 0xe5, 0x34, 0x53, 0xee, 0xb1, 0xea, 0x54, 0x3c, 0xba, 0xac, 0xa5, 0xf0, 0xf8, 0xf0, 0x87,
    0x3d, 0xe8, 0x96, 0x7b, 0x5b, 0x64, 0x30, 0xe2, 0xe4, 0x52, 0x92, 0xef, 0x21, 0xff, 0xef, 0x93,
    0xc1, 0xe6, 0x55, 0xd5, 0x5c, 0xee, 0x60, 0xa2, 0xe5, 0x82, 0xcf, 0xf5, 0xdc, 0x7b, 0x12, 0x30,
    0x28, 0x15, 0xca, 0x31, 0x57, 0x93, 0x91, 0x18, 0x2a, 0xb4, 0x27, 0x18, 0xdd, 0x15, 0x67, 0x86,
    0xab, 0x01, 0x5e, 0x03, 0xc0, 0x98, 0x39, 0x2f, 0x4f, 0xe9, 0x02, 0x2f, 0x4b, 0x50, 0xb3, 0x4e,
    0xae, 0xac, 0x63, 0xcc, 0x1c, 0x43, 0xbe, 0xa6, 0x08, 0xee, 0x79, 0x3f, 0x63, 0x56, 0x5a, 0xad,
    0x6b, 0x1f, 0x20, 0x18, 0x96, 0xfd, 0xb0, 0xe9, 0x01, 0xcb, 0xb5, 0xa3, 0x6d, 0x80, 0xc1, 0x3f,
    0xb7, 0xa9, 0xb3, 0x0e, 0x09, 0xc4, 0x22, 0xdd, 0x6e, 0x96, 0x46, 0x4f, 0xee, 0xf6, 0x92, 0x91,
    0x9c, 0xe6, 0x21, 0x39, 0xda, 0x1a, 0x3b, 0xce, 0xaa, 0xf5, 0xb4, 0x75, 0xf0, 0xb7, 0x83, 0x36,
    0x36, 0x86, 0xff, 0x65, 0xd0, 0xdc, 0x56, 0xe0, 0x94, 0xe6, 0xc6, 0x10, 0x78, 0x03, 0x06, 0xb7,
    0x22, 0x6d, 0x14, 0xe9, 0x20, 0x4d, 0x8e, 0xd9, 0xe5, 0xad, 0x67, 0xf4, 0xd1, 0xd7, 0xb2, 0x25,
    0x81, 0x27, 0x24, 0x55, 0x54, 0xf0, 0x5a, 0xa2, 0x22, 0x81, 0x74, 0xd6, 0x2e, 0x95, 0xea, 0x63,
    0x00, 0xfe, 0x9a, 0x95, 0xad, 0xb6, 0x86, 0x7d, 0xa2, 0xe8, 0x75, 0xe9, 0xd4, 0x73, 0xa4, 0x36,
    0x1d, 0x7e, 0x3e, 0x91, 0x5d, 0x2c, 0x4f, 0xf5, 0xb5, 0xe9, 0x67, 0x00, 0x23, 0xcc, 0xc8, 0xdb,
    0x15, 0x85, 0x7d, 0x5c, 0x54, 0x47, 0x0a, 0x16, 0xe5, 0xfb, 0x3b, 0x91, 0x15, 0xbe, 0xdf, 0x80,
    0x54, 0x91, 0xe9, 0x07, 0xc0, 0xde, 0xe8, 0xbf, 0xc9, 0x1f, 0x58, 0x67, 0x3a, 0x0c
};
#endif

PyTypeObject *init_QTextBlockFormat(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX].type;

    Shiboken::AutoDecRef Sbk_QTextBlockFormat_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]))));

    _Sbk_QTextBlockFormat_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QTextBlockFormat",
        "QTextBlockFormat",
        &Sbk_QTextBlockFormat_spec,
        &Shiboken::callCppDestructor< ::QTextBlockFormat >,
        Sbk_QTextBlockFormat_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QTextBlockFormat_TypeF(); // references _Sbk_QTextBlockFormat_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QTextBlockFormat_SignatureStrings);
#else
    InitSignatureBytes(pyType, QTextBlockFormat_SignatureBytes, QTextBlockFormat_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QTextBlockFormat_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QTextBlockFormat_PythonToCpp_QTextBlockFormat_PTR,
        is_QTextBlockFormat_PythonToCpp_QTextBlockFormat_PTR_Convertible,
        QTextBlockFormat_PTR_CppToPython_QTextBlockFormat,
        QTextBlockFormat_COPY_CppToPython_QTextBlockFormat);

    Shiboken::Conversions::registerConverterName(converter, "QTextBlockFormat");
    Shiboken::Conversions::registerConverterName(converter, "QTextBlockFormat*");
    Shiboken::Conversions::registerConverterName(converter, "QTextBlockFormat&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QTextBlockFormat).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QTextBlockFormat_PythonToCpp_QTextBlockFormat_COPY,
        is_QTextBlockFormat_PythonToCpp_QTextBlockFormat_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QTextBlockFormat_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'LineHeightTypes'.
    const char *LineHeightTypes_Initializer[] = {
        "SingleHeight",
        "ProportionalHeight",
        "FixedHeight",
        "MinimumHeight",
        "LineDistanceHeight",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t LineHeightTypes_InitializerValues[] = {
        uint8_t(QTextBlockFormat::LineHeightTypes::SingleHeight),       //  0x00  0
        uint8_t(QTextBlockFormat::LineHeightTypes::ProportionalHeight), //  0x01  1
        uint8_t(QTextBlockFormat::LineHeightTypes::FixedHeight),        //  0x02  2
        uint8_t(QTextBlockFormat::LineHeightTypes::MinimumHeight),      //  0x03  3
        uint8_t(QTextBlockFormat::LineHeightTypes::LineDistanceHeight)  //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QTextBlockFormat_TypeF(),
        "2:PySide6.QtGui.QTextBlockFormat.LineHeightTypes",
        LineHeightTypes_Initializer, LineHeightTypes_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_LineHeightTypes_IDX].type = EType;
    // Register converter for enum 'QTextBlockFormat::LineHeightTypes'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QTextBlockFormat_LineHeightTypes_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QTextBlockFormat_LineHeightTypes,
            is_Enum_PythonToCpp_QTextBlockFormat_LineHeightTypes_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QTextBlockFormat::LineHeightTypes");
        Shiboken::Conversions::registerConverterAlias(converter, "LineHeightTypes");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'LineHeightTypes' enum.

    // Initialization of enum 'MarkerType'.
    const char *MarkerType_Initializer[] = {
        "NoMarker",
        "Unchecked",
        "Checked",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t MarkerType_InitializerValues[] = {
        int8_t(QTextBlockFormat::MarkerType::NoMarker),  //  0x00  0
        int8_t(QTextBlockFormat::MarkerType::Unchecked), //  0x01  1
        int8_t(QTextBlockFormat::MarkerType::Checked)    //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QTextBlockFormat_TypeF(),
        "2:PySide6.QtGui.QTextBlockFormat.MarkerType",
        MarkerType_Initializer, MarkerType_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_MarkerType_IDX].type = EType;
    // Register converter for enum 'QTextBlockFormat::MarkerType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QTextBlockFormat_MarkerType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QTextBlockFormat_MarkerType,
            is_Enum_PythonToCpp_QTextBlockFormat_MarkerType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QTextBlockFormat::MarkerType");
        Shiboken::Conversions::registerConverterAlias(converter, "MarkerType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'MarkerType' enum.

    qRegisterMetaType< ::QTextBlockFormat >("QTextBlockFormat");
    qRegisterMetaType< ::QTextBlockFormat::LineHeightTypes >("QTextBlockFormat::LineHeightTypes");
    qRegisterMetaType< ::QTextBlockFormat::MarkerType >("QTextBlockFormat::MarkerType");

    return pyType;
}
