// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qtextblockuserdata_wrapper.h"

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

QTextBlockUserDataWrapper::QTextBlockUserDataWrapper()
{
}

QTextBlockUserDataWrapper::~QTextBlockUserDataWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTextBlockUserData_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QTextBlockUserData >()))
        return -1;

    QTextBlockUserDataWrapper *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockUserData_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QTextBlockUserData()
        cptr = new QTextBlockUserDataWrapper();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QTextBlockUserData >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}


static const char *Sbk_QTextBlockUserData_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QTextBlockUserData_methods[] = {
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QTextBlockUserData_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QTextBlockUserData_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QTextBlockUserData_Type = nullptr;
static PyTypeObject *Sbk_QTextBlockUserData_TypeF(void)
{
    return _Sbk_QTextBlockUserData_Type;
}

static PyType_Slot Sbk_QTextBlockUserData_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QTextBlockUserData_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QTextBlockUserData_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QTextBlockUserData_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QTextBlockUserData_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QTextBlockUserData_spec = {
    "2:PySide6.QtGui.QTextBlockUserData",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QTextBlockUserData_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QTextBlockUserData_PythonToCpp_QTextBlockUserData_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QTextBlockUserData_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QTextBlockUserData_PythonToCpp_QTextBlockUserData_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QTextBlockUserData_TypeF()))
        return QTextBlockUserData_PythonToCpp_QTextBlockUserData_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QTextBlockUserData_PTR_CppToPython_QTextBlockUserData(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QTextBlockUserData *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QTextBlockUserData_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QTextBlockUserData_SignatureStrings[] = {
    "PySide6.QtGui.QTextBlockUserData(self)",
    nullptr}; // Sentinel
#else
static constexpr size_t QTextBlockUserData_SignatureByteSize = 47;
static constexpr uint8_t QTextBlockUserData_SignatureBytes[47] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0x2f, 0xcd, 0xd4,
    0x0b, 0x0c, 0x49, 0xad, 0x28, 0x71, 0xca, 0xc9, 0x4f, 0xce, 0x0e, 0x2d, 0x4e, 0x2d, 0x72, 0x49,
    0x2c, 0x49, 0xd4, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0xe4, 0x02, 0x00, 0x18, 0x66, 0x0d, 0xca
};
#endif

PyTypeObject *init_QTextBlockUserData(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockUserData_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockUserData_IDX].type;

    Shiboken::AutoDecRef Sbk_QTextBlockUserData_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QTextBlockUserData_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QTextBlockUserData",
        "QTextBlockUserData*",
        &Sbk_QTextBlockUserData_spec,
        &Shiboken::callCppDestructor< QTextBlockUserData >,
        Sbk_QTextBlockUserData_Type_bases.object(),
        0);
    auto *pyType = Sbk_QTextBlockUserData_TypeF(); // references _Sbk_QTextBlockUserData_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QTextBlockUserData_SignatureStrings);
#else
    InitSignatureBytes(pyType, QTextBlockUserData_SignatureBytes, QTextBlockUserData_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QTextBlockUserData_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockUserData_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QTextBlockUserData_PythonToCpp_QTextBlockUserData_PTR,
        is_QTextBlockUserData_PythonToCpp_QTextBlockUserData_PTR_Convertible,
        QTextBlockUserData_PTR_CppToPython_QTextBlockUserData);

    Shiboken::Conversions::registerConverterName(converter, "QTextBlockUserData");
    Shiboken::Conversions::registerConverterName(converter, "QTextBlockUserData*");
    Shiboken::Conversions::registerConverterName(converter, "QTextBlockUserData&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QTextBlockUserData).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QTextBlockUserDataWrapper).name());

    qRegisterMetaType< ::QTextBlockUserData *>();

    return pyType;
}
