// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qtextcursor_wrapper.h"

// Extra includes
#include <QTextBlock>
#include <QTextDocumentFragment>

// Argument includes
#include <QString>
#include <QtGui/qimage.h>
#include <QtGui/qtextcursor.h>
#include <QtGui/qtextdocument.h>
#include <QtGui/qtextdocumentfragment.h>
#include <QtGui/qtextformat.h>
#include <QtGui/qtextlist.h>
#include <QtGui/qtextobject.h>
#include <QtGui/qtexttable.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTextCursor_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QTextCursor >()))
        return -1;

    ::QTextCursor *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QTextCursor", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QTextCursor::QTextCursor()
    // 1: QTextCursor::QTextCursor(QTextDocument*)
    // 2: QTextCursor::QTextCursor(QTextFrame*)
    // 3: QTextCursor::QTextCursor(QTextBlock)
    // 4: QTextCursor::QTextCursor(QTextCursor)
    if (numArgs == 0) {
        overloadId = 0; // QTextCursor()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), (pyArgs[0])))) {
        overloadId = 4; // QTextCursor(QTextCursor)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), (pyArgs[0])))) {
        overloadId = 3; // QTextCursor(QTextBlock)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFrame_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QTextCursor(QTextFrame*)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QTextCursor(QTextDocument*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QTextCursor()
        {

            // QTextCursor()
            cptr = new ::QTextCursor();
            break;
        }
        case 1: // QTextCursor(QTextDocument *document)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QTextDocument *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QTextCursor(QTextDocument*)
                cptr = new ::QTextCursor(cppArg0);
            }
            break;
        }
        case 2: // QTextCursor(QTextFrame *frame)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QTextFrame *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QTextCursor(QTextFrame*)
                cptr = new ::QTextCursor(cppArg0);
            }
            break;
        }
        case 3: // QTextCursor(const QTextBlock &block)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QTextBlock cppArg0_local;
            ::QTextBlock *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QTextCursor(QTextBlock)
                cptr = new ::QTextCursor(*cppArg0);
            }
            break;
        }
        case 4: // QTextCursor(const QTextCursor &cursor)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QTextCursor cppArg0_local;
            ::QTextCursor *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QTextCursor(QTextCursor)
                cptr = new ::QTextCursor(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QTextCursor >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QTextCursorFunc_anchor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // anchor()const
        int cppResult = const_cast<const ::QTextCursor *>(cppSelf)->anchor();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCursorFunc_atBlockEnd(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // atBlockEnd()const
        bool cppResult = const_cast<const ::QTextCursor *>(cppSelf)->atBlockEnd();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCursorFunc_atBlockStart(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // atBlockStart()const
        bool cppResult = const_cast<const ::QTextCursor *>(cppSelf)->atBlockStart();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCursorFunc_atEnd(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // atEnd()const
        bool cppResult = const_cast<const ::QTextCursor *>(cppSelf)->atEnd();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCursorFunc_atStart(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // atStart()const
        bool cppResult = const_cast<const ::QTextCursor *>(cppSelf)->atStart();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCursorFunc_beginEditBlock(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // beginEditBlock()
        cppSelf->beginEditBlock();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCursorFunc_block(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // block()const
        QTextBlock cppResult = const_cast<const ::QTextCursor *>(cppSelf)->block();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCursorFunc_blockCharFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // blockCharFormat()const
        QTextCharFormat cppResult = const_cast<const ::QTextCursor *>(cppSelf)->blockCharFormat();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCursorFunc_blockFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // blockFormat()const
        QTextBlockFormat cppResult = const_cast<const ::QTextCursor *>(cppSelf)->blockFormat();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCursorFunc_blockNumber(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // blockNumber()const
        int cppResult = const_cast<const ::QTextCursor *>(cppSelf)->blockNumber();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCursorFunc_charFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // charFormat()const
        QTextCharFormat cppResult = const_cast<const ::QTextCursor *>(cppSelf)->charFormat();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCursorFunc_clearSelection(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clearSelection()
        cppSelf->clearSelection();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCursorFunc_columnNumber(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // columnNumber()const
        int cppResult = const_cast<const ::QTextCursor *>(cppSelf)->columnNumber();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCursorFunc_createList(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCursor::createList(QTextListFormat::Style)->QTextList*
    // 1: QTextCursor::createList(QTextListFormat)->QTextList*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextListFormat_IDX]), (pyArg)))) {
        overloadId = 1; // createList(QTextListFormat)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextListFormat_Style_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // createList(QTextListFormat::Style)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "createList", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // createList(QTextListFormat::Style style)
        {
            ::QTextListFormat::Style cppArg0{QTextListFormat::ListStyleUndefined};
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // createList(QTextListFormat::Style)
                QTextList * cppResult = cppSelf->createList(cppArg0);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextList_IDX]), cppResult);
            }
            break;
        }
        case 1: // createList(const QTextListFormat &format)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QTextListFormat cppArg0_local;
            ::QTextListFormat *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // createList(QTextListFormat)
                QTextList * cppResult = cppSelf->createList(*cppArg0);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextList_IDX]), cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCursorFunc_currentFrame(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // currentFrame()const
        QTextFrame * cppResult = const_cast<const ::QTextCursor *>(cppSelf)->currentFrame();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFrame_IDX]), cppResult);

        // Ownership transferences.
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCursorFunc_currentList(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // currentList()const
        QTextList * cppResult = const_cast<const ::QTextCursor *>(cppSelf)->currentList();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextList_IDX]), cppResult);

        // Ownership transferences.
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCursorFunc_currentTable(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // currentTable()const
        QTextTable * cppResult = const_cast<const ::QTextCursor *>(cppSelf)->currentTable();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextTable_IDX]), cppResult);

        // Ownership transferences.
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCursorFunc_deleteChar(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // deleteChar()
        cppSelf->deleteChar();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCursorFunc_deletePreviousChar(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // deletePreviousChar()
        cppSelf->deletePreviousChar();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCursorFunc_document(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // document()const
        QTextDocument * cppResult = const_cast<const ::QTextCursor *>(cppSelf)->document();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCursorFunc_endEditBlock(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // endEditBlock()
        cppSelf->endEditBlock();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCursorFunc_hasComplexSelection(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hasComplexSelection()const
        bool cppResult = const_cast<const ::QTextCursor *>(cppSelf)->hasComplexSelection();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCursorFunc_hasSelection(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hasSelection()const
        bool cppResult = const_cast<const ::QTextCursor *>(cppSelf)->hasSelection();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCursorFunc_insertBlock(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "insertBlock", 0, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTextCursor::insertBlock()
    // 1: QTextCursor::insertBlock(QTextBlockFormat)
    // 2: QTextCursor::insertBlock(QTextBlockFormat,QTextCharFormat)
    if (numArgs == 0) {
        overloadId = 0; // insertBlock()
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // insertBlock(QTextBlockFormat)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), (pyArgs[1])))) {
            overloadId = 2; // insertBlock(QTextBlockFormat,QTextCharFormat)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "insertBlock", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // insertBlock()
        {

            // insertBlock()
            cppSelf->insertBlock();
            break;
        }
        case 1: // insertBlock(const QTextBlockFormat &format)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QTextBlockFormat cppArg0_local;
            ::QTextBlockFormat *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // insertBlock(QTextBlockFormat)
                cppSelf->insertBlock(*cppArg0);
            }
            break;
        }
        case 2: // insertBlock(const QTextBlockFormat &format, const QTextCharFormat &charFormat)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QTextBlockFormat cppArg0_local;
            ::QTextBlockFormat *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QTextCharFormat cppArg1_local;
            ::QTextCharFormat *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // insertBlock(QTextBlockFormat,QTextCharFormat)
                cppSelf->insertBlock(*cppArg0, *cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCursorFunc_insertFragment(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCursor::insertFragment(QTextDocumentFragment)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentFragment_IDX]), (pyArg)))) {
        overloadId = 0; // insertFragment(QTextDocumentFragment)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "insertFragment", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTextDocumentFragment cppArg0_local;
        ::QTextDocumentFragment *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // insertFragment(QTextDocumentFragment)
            cppSelf->insertFragment(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCursorFunc_insertFrame(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCursor::insertFrame(QTextFrameFormat)->QTextFrame*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFrameFormat_IDX]), (pyArg)))) {
        overloadId = 0; // insertFrame(QTextFrameFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "insertFrame", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTextFrameFormat cppArg0_local;
        ::QTextFrameFormat *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // insertFrame(QTextFrameFormat)
            QTextFrame * cppResult = cppSelf->insertFrame(*cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFrame_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCursorFunc_insertHtml(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCursor::insertHtml(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // insertHtml(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "insertHtml", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // insertHtml(QString)
            cppSelf->insertHtml(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCursorFunc_insertImage(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "insertImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);

    if (PyArg_ParseTuple(args, "|OO:insertImage", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTextCursor::insertImage(QImage,const QString&=)
    // 1: QTextCursor::insertImage(QString)
    // 2: QTextCursor::insertImage(QTextImageFormat)
    // 3: QTextCursor::insertImage(QTextImageFormat,QTextFrameFormat::Position)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextImageFormat_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 2; // insertImage(QTextImageFormat)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFrameFormat_Position_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 3; // insertImage(QTextImageFormat,QTextFrameFormat::Position)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 1; // insertImage(QString)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImage_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // insertImage(QImage,QString)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 0; // insertImage(QImage,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "insertImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // insertImage(const QImage &image, const QString &name)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_name = Shiboken::String::createStaticString("name");
                if (PyDict_Contains(kwds, key_name) != 0) {
                    value = PyDict_GetItem(kwds, key_name);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_name);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "insertImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "insertImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_name);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "insertImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QImage cppArg0_local;
            ::QImage *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QString cppArg1 = QString();
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // insertImage(QImage,QString)
                cppSelf->insertImage(*cppArg0, cppArg1);
            }
            break;
        }
        case 1: // insertImage(const QString &name)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "insertImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // insertImage(QString)
                cppSelf->insertImage(cppArg0);
            }
            break;
        }
        case 2: // insertImage(const QTextImageFormat &format)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "insertImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QTextImageFormat cppArg0_local;
            ::QTextImageFormat *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // insertImage(QTextImageFormat)
                cppSelf->insertImage(*cppArg0);
            }
            break;
        }
        case 3: // insertImage(const QTextImageFormat &format, QTextFrameFormat::Position alignment)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "insertImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QTextImageFormat cppArg0_local;
            ::QTextImageFormat *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QTextFrameFormat::Position cppArg1{QTextFrameFormat::InFlow};
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // insertImage(QTextImageFormat,QTextFrameFormat::Position)
                cppSelf->insertImage(*cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCursorFunc_insertList(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCursor::insertList(QTextListFormat::Style)->QTextList*
    // 1: QTextCursor::insertList(QTextListFormat)->QTextList*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextListFormat_IDX]), (pyArg)))) {
        overloadId = 1; // insertList(QTextListFormat)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextListFormat_Style_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // insertList(QTextListFormat::Style)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "insertList", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // insertList(QTextListFormat::Style style)
        {
            ::QTextListFormat::Style cppArg0{QTextListFormat::ListStyleUndefined};
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // insertList(QTextListFormat::Style)
                QTextList * cppResult = cppSelf->insertList(cppArg0);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextList_IDX]), cppResult);
            }
            break;
        }
        case 1: // insertList(const QTextListFormat &format)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QTextListFormat cppArg0_local;
            ::QTextListFormat *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // insertList(QTextListFormat)
                QTextList * cppResult = cppSelf->insertList(*cppArg0);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextList_IDX]), cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCursorFunc_insertMarkdown(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "insertMarkdown", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);

    if (PyArg_ParseTuple(args, "|OO:insertMarkdown", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTextCursor::insertMarkdown(QString,QFlags<QTextDocument::MarkdownFeature>=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // insertMarkdown(QString,QFlags<QTextDocument::MarkdownFeature>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QTextDocument_MarkdownFeature_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 0; // insertMarkdown(QString,QFlags<QTextDocument::MarkdownFeature>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "insertMarkdown", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_features = Shiboken::String::createStaticString("features");
            if (PyDict_Contains(kwds, key_features) != 0) {
                value = PyDict_GetItem(kwds, key_features);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_features);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "insertMarkdown", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QTextDocument_MarkdownFeature_IDX])))->flagsConverter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "insertMarkdown", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_features);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "insertMarkdown", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<QTextDocument::MarkdownFeature> cppArg1(QTextDocument::MarkdownDialectGitHub);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // insertMarkdown(QString,QFlags<QTextDocument::MarkdownFeature>)
            cppSelf->insertMarkdown(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCursorFunc_insertTable(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "insertTable", 2, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTextCursor::insertTable(int,int)->QTextTable*
    // 1: QTextCursor::insertTable(int,int,QTextTableFormat)->QTextTable*
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // insertTable(int,int)
        } else if (numArgs == 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextTableFormat_IDX]), (pyArgs[2])))) {
            overloadId = 1; // insertTable(int,int,QTextTableFormat)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "insertTable", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // insertTable(int rows, int cols)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // insertTable(int,int)
                QTextTable * cppResult = cppSelf->insertTable(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextTable_IDX]), cppResult);

                // Ownership transferences.
            }
            break;
        }
        case 1: // insertTable(int rows, int cols, const QTextTableFormat &format)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QTextTableFormat cppArg2_local;
            ::QTextTableFormat *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);


            if (Shiboken::Errors::occurred() == nullptr) {
                // insertTable(int,int,QTextTableFormat)
                QTextTable * cppResult = cppSelf->insertTable(cppArg0, cppArg1, *cppArg2);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextTable_IDX]), cppResult);

                // Ownership transferences.
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCursorFunc_insertText(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "insertText", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTextCursor::insertText(QString)
    // 1: QTextCursor::insertText(QString,QTextCharFormat)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // insertText(QString)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), (pyArgs[1])))) {
            overloadId = 1; // insertText(QString,QTextCharFormat)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "insertText", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // insertText(const QString &text)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // insertText(QString)
                cppSelf->insertText(cppArg0);
            }
            break;
        }
        case 1: // insertText(const QString &text, const QTextCharFormat &format)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QTextCharFormat cppArg1_local;
            ::QTextCharFormat *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // insertText(QString,QTextCharFormat)
                cppSelf->insertText(cppArg0, *cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCursorFunc_isCopyOf(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCursor::isCopyOf(QTextCursor)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), (pyArg)))) {
        overloadId = 0; // isCopyOf(QTextCursor)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isCopyOf", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTextCursor cppArg0_local;
        ::QTextCursor *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // isCopyOf(QTextCursor)const
            bool cppResult = const_cast<const ::QTextCursor *>(cppSelf)->isCopyOf(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCursorFunc_isNull(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isNull()const
        bool cppResult = const_cast<const ::QTextCursor *>(cppSelf)->isNull();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCursorFunc_joinPreviousEditBlock(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // joinPreviousEditBlock()
        cppSelf->joinPreviousEditBlock();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCursorFunc_keepPositionOnInsert(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // keepPositionOnInsert()const
        bool cppResult = const_cast<const ::QTextCursor *>(cppSelf)->keepPositionOnInsert();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCursorFunc_mergeBlockCharFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCursor::mergeBlockCharFormat(QTextCharFormat)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), (pyArg)))) {
        overloadId = 0; // mergeBlockCharFormat(QTextCharFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mergeBlockCharFormat", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTextCharFormat cppArg0_local;
        ::QTextCharFormat *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // mergeBlockCharFormat(QTextCharFormat)
            cppSelf->mergeBlockCharFormat(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCursorFunc_mergeBlockFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCursor::mergeBlockFormat(QTextBlockFormat)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]), (pyArg)))) {
        overloadId = 0; // mergeBlockFormat(QTextBlockFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mergeBlockFormat", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTextBlockFormat cppArg0_local;
        ::QTextBlockFormat *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // mergeBlockFormat(QTextBlockFormat)
            cppSelf->mergeBlockFormat(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCursorFunc_mergeCharFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCursor::mergeCharFormat(QTextCharFormat)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), (pyArg)))) {
        overloadId = 0; // mergeCharFormat(QTextCharFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mergeCharFormat", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTextCharFormat cppArg0_local;
        ::QTextCharFormat *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // mergeCharFormat(QTextCharFormat)
            cppSelf->mergeCharFormat(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCursorFunc_movePosition(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "movePosition", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:movePosition", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTextCursor::movePosition(QTextCursor::MoveOperation,QTextCursor::MoveMode=,int=)->bool
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_MoveOperation_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // movePosition(QTextCursor::MoveOperation,QTextCursor::MoveMode,int)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_MoveMode_IDX])))->converter, (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // movePosition(QTextCursor::MoveOperation,QTextCursor::MoveMode,int)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
                overloadId = 0; // movePosition(QTextCursor::MoveOperation,QTextCursor::MoveMode,int)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "movePosition", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_arg__2 = Shiboken::String::createStaticString("arg__2");
            if (PyDict_Contains(kwds, key_arg__2) != 0) {
                value = PyDict_GetItem(kwds, key_arg__2);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_arg__2);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "movePosition", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_MoveMode_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "movePosition", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_arg__2);
            }
            static PyObject *const key_n = Shiboken::String::createStaticString("n");
            if (PyDict_Contains(kwds, key_n) != 0) {
                value = PyDict_GetItem(kwds, key_n);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_n);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "movePosition", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "movePosition", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_n);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "movePosition", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);
            }
        }
        ::QTextCursor::MoveOperation cppArg0{QTextCursor::NoMove};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QTextCursor::MoveMode cppArg1(QTextCursor::MoveMode::MoveAnchor);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2 = 1;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // movePosition(QTextCursor::MoveOperation,QTextCursor::MoveMode,int)
            bool cppResult = cppSelf->movePosition(cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCursorFunc_position(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // position()const
        int cppResult = const_cast<const ::QTextCursor *>(cppSelf)->position();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCursorFunc_positionInBlock(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // positionInBlock()const
        int cppResult = const_cast<const ::QTextCursor *>(cppSelf)->positionInBlock();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCursorFunc_removeSelectedText(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // removeSelectedText()
        cppSelf->removeSelectedText();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCursorFunc_select(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCursor::select(QTextCursor::SelectionType)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_SelectionType_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // select(QTextCursor::SelectionType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "select", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);

    // Call function/method
    {
        ::QTextCursor::SelectionType cppArg0{QTextCursor::WordUnderCursor};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // select(QTextCursor::SelectionType)
            cppSelf->select(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCursorFunc_selectedTableCells(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // selectedTableCells(int*,int*,int*,int*)const
            // Begin code injection
            // TEMPLATE - fix_number*,number*,number*,number* - START
            int a, b, c, d;
            cppSelf->::QTextCursor::selectedTableCells(&a, &b, &c, &d);
            // TEMPLATE - tuple_abcd_same_type - START
            pyResult = PyTuple_New(4);
            PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &a));
            PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &b));
            PyTuple_SetItem(pyResult, 2, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &c));
            PyTuple_SetItem(pyResult, 3, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &d));
            // TEMPLATE - tuple_abcd_same_type - END
            // TEMPLATE - fix_number*,number*,number*,number* - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCursorFunc_selectedText(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // selectedText()const
        QString cppResult = const_cast<const ::QTextCursor *>(cppSelf)->selectedText();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCursorFunc_selection(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // selection()const
        QTextDocumentFragment cppResult = const_cast<const ::QTextCursor *>(cppSelf)->selection();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentFragment_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCursorFunc_selectionEnd(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // selectionEnd()const
        int cppResult = const_cast<const ::QTextCursor *>(cppSelf)->selectionEnd();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCursorFunc_selectionStart(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // selectionStart()const
        int cppResult = const_cast<const ::QTextCursor *>(cppSelf)->selectionStart();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCursorFunc_setBlockCharFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCursor::setBlockCharFormat(QTextCharFormat)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), (pyArg)))) {
        overloadId = 0; // setBlockCharFormat(QTextCharFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBlockCharFormat", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTextCharFormat cppArg0_local;
        ::QTextCharFormat *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setBlockCharFormat(QTextCharFormat)
            cppSelf->setBlockCharFormat(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCursorFunc_setBlockFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCursor::setBlockFormat(QTextBlockFormat)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]), (pyArg)))) {
        overloadId = 0; // setBlockFormat(QTextBlockFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBlockFormat", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTextBlockFormat cppArg0_local;
        ::QTextBlockFormat *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setBlockFormat(QTextBlockFormat)
            cppSelf->setBlockFormat(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCursorFunc_setCharFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCursor::setCharFormat(QTextCharFormat)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), (pyArg)))) {
        overloadId = 0; // setCharFormat(QTextCharFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCharFormat", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTextCharFormat cppArg0_local;
        ::QTextCharFormat *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setCharFormat(QTextCharFormat)
            cppSelf->setCharFormat(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCursorFunc_setKeepPositionOnInsert(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCursor::setKeepPositionOnInsert(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setKeepPositionOnInsert(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setKeepPositionOnInsert", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setKeepPositionOnInsert(bool)
            cppSelf->setKeepPositionOnInsert(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCursorFunc_setPosition(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setPosition", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setPosition", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTextCursor::setPosition(int,QTextCursor::MoveMode=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setPosition(int,QTextCursor::MoveMode)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_MoveMode_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // setPosition(int,QTextCursor::MoveMode)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setPosition", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
            if (PyDict_Contains(kwds, key_mode) != 0) {
                value = PyDict_GetItem(kwds, key_mode);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_mode);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setPosition", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_MoveMode_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "setPosition", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_mode);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setPosition", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);
            }
        }
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QTextCursor::MoveMode cppArg1(QTextCursor::MoveMode::MoveAnchor);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPosition(int,QTextCursor::MoveMode)
            cppSelf->setPosition(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCursorFunc_setVerticalMovementX(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCursor::setVerticalMovementX(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setVerticalMovementX(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setVerticalMovementX", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setVerticalMovementX(int)
            cppSelf->setVerticalMovementX(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCursorFunc_setVisualNavigation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCursor::setVisualNavigation(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setVisualNavigation(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setVisualNavigation", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setVisualNavigation(bool)
            cppSelf->setVisualNavigation(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCursorFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCursor::swap(QTextCursor&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QTextCursor&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTextCursor cppArg0_local;
        ::QTextCursor *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QTextCursor&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCursorFunc_verticalMovementX(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // verticalMovementX()const
        int cppResult = const_cast<const ::QTextCursor *>(cppSelf)->verticalMovementX();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCursorFunc_visualNavigation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // visualNavigation()const
        bool cppResult = const_cast<const ::QTextCursor *>(cppSelf)->visualNavigation();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCursor__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QTextCursor_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QTextCursor_EnumFlagInfo[] = {
    "MoveMode:Enum",
    "MoveOperation:Enum",
    "SelectionType:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QTextCursor_methods[] = {
    {"anchor", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_anchor), METH_NOARGS, nullptr},
    {"atBlockEnd", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_atBlockEnd), METH_NOARGS, nullptr},
    {"atBlockStart", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_atBlockStart), METH_NOARGS, nullptr},
    {"atEnd", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_atEnd), METH_NOARGS, nullptr},
    {"atStart", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_atStart), METH_NOARGS, nullptr},
    {"beginEditBlock", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_beginEditBlock), METH_NOARGS, nullptr},
    {"block", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_block), METH_NOARGS, nullptr},
    {"blockCharFormat", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_blockCharFormat), METH_NOARGS, nullptr},
    {"blockFormat", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_blockFormat), METH_NOARGS, nullptr},
    {"blockNumber", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_blockNumber), METH_NOARGS, nullptr},
    {"charFormat", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_charFormat), METH_NOARGS, nullptr},
    {"clearSelection", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_clearSelection), METH_NOARGS, nullptr},
    {"columnNumber", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_columnNumber), METH_NOARGS, nullptr},
    {"createList", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_createList), METH_O, nullptr},
    {"currentFrame", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_currentFrame), METH_NOARGS, nullptr},
    {"currentList", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_currentList), METH_NOARGS, nullptr},
    {"currentTable", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_currentTable), METH_NOARGS, nullptr},
    {"deleteChar", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_deleteChar), METH_NOARGS, nullptr},
    {"deletePreviousChar", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_deletePreviousChar), METH_NOARGS, nullptr},
    {"document", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_document), METH_NOARGS, nullptr},
    {"endEditBlock", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_endEditBlock), METH_NOARGS, nullptr},
    {"hasComplexSelection", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_hasComplexSelection), METH_NOARGS, nullptr},
    {"hasSelection", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_hasSelection), METH_NOARGS, nullptr},
    {"insertBlock", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_insertBlock), METH_VARARGS, nullptr},
    {"insertFragment", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_insertFragment), METH_O, nullptr},
    {"insertFrame", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_insertFrame), METH_O, nullptr},
    {"insertHtml", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_insertHtml), METH_O, nullptr},
    {"insertImage", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_insertImage), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"insertList", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_insertList), METH_O, nullptr},
    {"insertMarkdown", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_insertMarkdown), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"insertTable", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_insertTable), METH_VARARGS, nullptr},
    {"insertText", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_insertText), METH_VARARGS, nullptr},
    {"isCopyOf", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_isCopyOf), METH_O, nullptr},
    {"isNull", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_isNull), METH_NOARGS, nullptr},
    {"joinPreviousEditBlock", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_joinPreviousEditBlock), METH_NOARGS, nullptr},
    {"keepPositionOnInsert", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_keepPositionOnInsert), METH_NOARGS, nullptr},
    {"mergeBlockCharFormat", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_mergeBlockCharFormat), METH_O, nullptr},
    {"mergeBlockFormat", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_mergeBlockFormat), METH_O, nullptr},
    {"mergeCharFormat", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_mergeCharFormat), METH_O, nullptr},
    {"movePosition", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_movePosition), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"position", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_position), METH_NOARGS, nullptr},
    {"positionInBlock", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_positionInBlock), METH_NOARGS, nullptr},
    {"removeSelectedText", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_removeSelectedText), METH_NOARGS, nullptr},
    {"select", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_select), METH_O, nullptr},
    {"selectedTableCells", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_selectedTableCells), METH_NOARGS, nullptr},
    {"selectedText", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_selectedText), METH_NOARGS, nullptr},
    {"selection", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_selection), METH_NOARGS, nullptr},
    {"selectionEnd", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_selectionEnd), METH_NOARGS, nullptr},
    {"selectionStart", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_selectionStart), METH_NOARGS, nullptr},
    {"setBlockCharFormat", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_setBlockCharFormat), METH_O, nullptr},
    {"setBlockFormat", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_setBlockFormat), METH_O, nullptr},
    {"setCharFormat", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_setCharFormat), METH_O, nullptr},
    {"setKeepPositionOnInsert", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_setKeepPositionOnInsert), METH_O, nullptr},
    {"setPosition", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_setPosition), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setVerticalMovementX", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_setVerticalMovementX), METH_O, nullptr},
    {"setVisualNavigation", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_setVisualNavigation), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_swap), METH_O, nullptr},
    {"verticalMovementX", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_verticalMovementX), METH_NOARGS, nullptr},
    {"visualNavigation", reinterpret_cast<PyCFunction>(Sbk_QTextCursorFunc_visualNavigation), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QTextCursor__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QTextCursor___nb_bool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return !cppSelf->isNull() ? 1 : 0;
}

// Rich comparison
static PyObject * Sbk_QTextCursor_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), (pyArg)))) {
                // operator!=(const QTextCursor &rhs) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QTextCursor cppArg0_local;
                ::QTextCursor *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_LT:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), (pyArg)))) {
                // operator<(const QTextCursor &rhs) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QTextCursor cppArg0_local;
                ::QTextCursor *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf < (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_LE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), (pyArg)))) {
                // operator<=(const QTextCursor &rhs) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QTextCursor cppArg0_local;
                ::QTextCursor *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf <= (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), (pyArg)))) {
                // operator==(const QTextCursor &rhs) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QTextCursor cppArg0_local;
                ::QTextCursor *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        case Py_GT:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), (pyArg)))) {
                // operator>(const QTextCursor &rhs) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QTextCursor cppArg0_local;
                ::QTextCursor *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf > (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_GE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), (pyArg)))) {
                // operator>=(const QTextCursor &rhs) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QTextCursor cppArg0_local;
                ::QTextCursor *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf >= (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QTextCursor_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QTextCursor_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QTextCursor_Type = nullptr;
static PyTypeObject *Sbk_QTextCursor_TypeF(void)
{
    return _Sbk_QTextCursor_Type;
}

static PyType_Slot Sbk_QTextCursor_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QTextCursor_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QTextCursor_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QTextCursor_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QTextCursor_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QTextCursor_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_bool,        reinterpret_cast<void *>(Sbk_QTextCursor___nb_bool)},
    {0, nullptr}
};
static PyType_Spec Sbk_QTextCursor_spec = {
    "2:PySide6.QtGui.QTextCursor",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QTextCursor_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QTextCursor_MoveMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QTextCursor::MoveMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QTextCursor::MoveMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QTextCursor_MoveMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_MoveMode_IDX])))
        return Enum_PythonToCpp_QTextCursor_MoveMode;
    return {};
}

static PyObject *QTextCursor_MoveMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QTextCursor::MoveMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QTextCursor::MoveMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_MoveMode_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QTextCursor_MoveOperation(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QTextCursor::MoveOperation>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QTextCursor::MoveOperation *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QTextCursor_MoveOperation_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_MoveOperation_IDX])))
        return Enum_PythonToCpp_QTextCursor_MoveOperation;
    return {};
}

static PyObject *QTextCursor_MoveOperation_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QTextCursor::MoveOperation>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QTextCursor::MoveOperation *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_MoveOperation_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QTextCursor_SelectionType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QTextCursor::SelectionType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QTextCursor::SelectionType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QTextCursor_SelectionType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_SelectionType_IDX])))
        return Enum_PythonToCpp_QTextCursor_SelectionType;
    return {};
}

static PyObject *QTextCursor_SelectionType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QTextCursor::SelectionType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QTextCursor::SelectionType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_SelectionType_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QTextCursor_PythonToCpp_QTextCursor_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QTextCursor_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QTextCursor_PythonToCpp_QTextCursor_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QTextCursor_TypeF()))
        return QTextCursor_PythonToCpp_QTextCursor_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QTextCursor_PTR_CppToPython_QTextCursor(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QTextCursor_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QTextCursor_COPY_CppToPython_QTextCursor(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QTextCursor *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QTextCursor_TypeF(), new ::QTextCursor(*source), true, true);
}

// Python to C++ copy conversion.
static void QTextCursor_PythonToCpp_QTextCursor_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QTextCursor *>(cppOut) = *reinterpret_cast< ::QTextCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QTextCursor_PythonToCpp_QTextCursor_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QTextCursor_TypeF()))
        return QTextCursor_PythonToCpp_QTextCursor_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QTextCursor_SignatureStrings[] = {
    "4:PySide6.QtGui.QTextCursor(self)",
    "3:PySide6.QtGui.QTextCursor(self,document:PySide6.QtGui.QTextDocument)",
    "2:PySide6.QtGui.QTextCursor(self,frame:PySide6.QtGui.QTextFrame)",
    "1:PySide6.QtGui.QTextCursor(self,block:PySide6.QtGui.QTextBlock)",
    "0:PySide6.QtGui.QTextCursor(self,cursor:PySide6.QtGui.QTextCursor)",
    "PySide6.QtGui.QTextCursor.anchor(self)->int",
    "PySide6.QtGui.QTextCursor.atBlockEnd(self)->bool",
    "PySide6.QtGui.QTextCursor.atBlockStart(self)->bool",
    "PySide6.QtGui.QTextCursor.atEnd(self)->bool",
    "PySide6.QtGui.QTextCursor.atStart(self)->bool",
    "PySide6.QtGui.QTextCursor.beginEditBlock(self)",
    "PySide6.QtGui.QTextCursor.block(self)->PySide6.QtGui.QTextBlock",
    "PySide6.QtGui.QTextCursor.blockCharFormat(self)->PySide6.QtGui.QTextCharFormat",
    "PySide6.QtGui.QTextCursor.blockFormat(self)->PySide6.QtGui.QTextBlockFormat",
    "PySide6.QtGui.QTextCursor.blockNumber(self)->int",
    "PySide6.QtGui.QTextCursor.charFormat(self)->PySide6.QtGui.QTextCharFormat",
    "PySide6.QtGui.QTextCursor.clearSelection(self)",
    "PySide6.QtGui.QTextCursor.columnNumber(self)->int",
    "1:PySide6.QtGui.QTextCursor.createList(self,style:PySide6.QtGui.QTextListFormat.Style)->PySide6.QtGui.QTextList",
    "0:PySide6.QtGui.QTextCursor.createList(self,format:PySide6.QtGui.QTextListFormat)->PySide6.QtGui.QTextList",
    "PySide6.QtGui.QTextCursor.currentFrame(self)->PySide6.QtGui.QTextFrame",
    "PySide6.QtGui.QTextCursor.currentList(self)->PySide6.QtGui.QTextList",
    "PySide6.QtGui.QTextCursor.currentTable(self)->PySide6.QtGui.QTextTable",
    "PySide6.QtGui.QTextCursor.deleteChar(self)",
    "PySide6.QtGui.QTextCursor.deletePreviousChar(self)",
    "PySide6.QtGui.QTextCursor.document(self)->PySide6.QtGui.QTextDocument",
    "PySide6.QtGui.QTextCursor.endEditBlock(self)",
    "PySide6.QtGui.QTextCursor.hasComplexSelection(self)->bool",
    "PySide6.QtGui.QTextCursor.hasSelection(self)->bool",
    "2:PySide6.QtGui.QTextCursor.insertBlock(self)",
    "1:PySide6.QtGui.QTextCursor.insertBlock(self,format:PySide6.QtGui.QTextBlockFormat)",
    "0:PySide6.QtGui.QTextCursor.insertBlock(self,format:PySide6.QtGui.QTextBlockFormat,charFormat:PySide6.QtGui.QTextCharFormat)",
    "PySide6.QtGui.QTextCursor.insertFragment(self,fragment:PySide6.QtGui.QTextDocumentFragment)",
    "PySide6.QtGui.QTextCursor.insertFrame(self,format:PySide6.QtGui.QTextFrameFormat)->PySide6.QtGui.QTextFrame",
    "PySide6.QtGui.QTextCursor.insertHtml(self,html:QString)",
    "3:PySide6.QtGui.QTextCursor.insertImage(self,image:PySide6.QtGui.QImage,name:QString=QString())",
    "2:PySide6.QtGui.QTextCursor.insertImage(self,name:QString)",
    "1:PySide6.QtGui.QTextCursor.insertImage(self,format:PySide6.QtGui.QTextImageFormat)",
    "0:PySide6.QtGui.QTextCursor.insertImage(self,format:PySide6.QtGui.QTextImageFormat,alignment:PySide6.QtGui.QTextFrameFormat.Position)",
    "1:PySide6.QtGui.QTextCursor.insertList(self,style:PySide6.QtGui.QTextListFormat.Style)->PySide6.QtGui.QTextList",
    "0:PySide6.QtGui.QTextCursor.insertList(self,format:PySide6.QtGui.QTextListFormat)->PySide6.QtGui.QTextList",
    "PySide6.QtGui.QTextCursor.insertMarkdown(self,markdown:QString,features:PySide6.QtGui.QTextDocument.MarkdownFeature=QTextDocument.MarkdownDialectGitHub)",
    "1:PySide6.QtGui.QTextCursor.insertTable(self,rows:int,cols:int)->PySide6.QtGui.QTextTable",
    "0:PySide6.QtGui.QTextCursor.insertTable(self,rows:int,cols:int,format:PySide6.QtGui.QTextTableFormat)->PySide6.QtGui.QTextTable",
    "1:PySide6.QtGui.QTextCursor.insertText(self,text:QString)",
    "0:PySide6.QtGui.QTextCursor.insertText(self,text:QString,format:PySide6.QtGui.QTextCharFormat)",
    "PySide6.QtGui.QTextCursor.isCopyOf(self,other:PySide6.QtGui.QTextCursor)->bool",
    "PySide6.QtGui.QTextCursor.isNull(self)->bool",
    "PySide6.QtGui.QTextCursor.joinPreviousEditBlock(self)",
    "PySide6.QtGui.QTextCursor.keepPositionOnInsert(self)->bool",
    "PySide6.QtGui.QTextCursor.mergeBlockCharFormat(self,modifier:PySide6.QtGui.QTextCharFormat)",
    "PySide6.QtGui.QTextCursor.mergeBlockFormat(self,modifier:PySide6.QtGui.QTextBlockFormat)",
    "PySide6.QtGui.QTextCursor.mergeCharFormat(self,modifier:PySide6.QtGui.QTextCharFormat)",
    "PySide6.QtGui.QTextCursor.movePosition(self,op:PySide6.QtGui.QTextCursor.MoveOperation,arg__2:PySide6.QtGui.QTextCursor.MoveMode=QTextCursor.MoveMode.MoveAnchor,n:int=1)->bool",
    "PySide6.QtGui.QTextCursor.position(self)->int",
    "PySide6.QtGui.QTextCursor.positionInBlock(self)->int",
    "PySide6.QtGui.QTextCursor.removeSelectedText(self)",
    "PySide6.QtGui.QTextCursor.select(self,selection:PySide6.QtGui.QTextCursor.SelectionType)",
    "PySide6.QtGui.QTextCursor.selectedTableCells(self)->PyObject",
    "PySide6.QtGui.QTextCursor.selectedText(self)->QString",
    "PySide6.QtGui.QTextCursor.selection(self)->PySide6.QtGui.QTextDocumentFragment",
    "PySide6.QtGui.QTextCursor.selectionEnd(self)->int",
    "PySide6.QtGui.QTextCursor.selectionStart(self)->int",
    "PySide6.QtGui.QTextCursor.setBlockCharFormat(self,format:PySide6.QtGui.QTextCharFormat)",
    "PySide6.QtGui.QTextCursor.setBlockFormat(self,format:PySide6.QtGui.QTextBlockFormat)",
    "PySide6.QtGui.QTextCursor.setCharFormat(self,format:PySide6.QtGui.QTextCharFormat)",
    "PySide6.QtGui.QTextCursor.setKeepPositionOnInsert(self,b:bool)",
    "PySide6.QtGui.QTextCursor.setPosition(self,pos:int,mode:PySide6.QtGui.QTextCursor.MoveMode=QTextCursor.MoveMode.MoveAnchor)",
    "PySide6.QtGui.QTextCursor.setVerticalMovementX(self,x:int)",
    "PySide6.QtGui.QTextCursor.setVisualNavigation(self,b:bool)",
    "PySide6.QtGui.QTextCursor.swap(self,other:PySide6.QtGui.QTextCursor)",
    "PySide6.QtGui.QTextCursor.verticalMovementX(self)->int",
    "PySide6.QtGui.QTextCursor.visualNavigation(self)->bool",
    "PySide6.QtGui.QTextCursor.__copy__(self)->typing.Self",
    "PySide6.QtGui.QTextCursor.__ne__(self,rhs:PySide6.QtGui.QTextCursor)->bool",
    "PySide6.QtGui.QTextCursor.__lt__(self,rhs:PySide6.QtGui.QTextCursor)->bool",
    "PySide6.QtGui.QTextCursor.__le__(self,rhs:PySide6.QtGui.QTextCursor)->bool",
    "PySide6.QtGui.QTextCursor.__eq__(self,rhs:PySide6.QtGui.QTextCursor)->bool",
    "PySide6.QtGui.QTextCursor.__gt__(self,rhs:PySide6.QtGui.QTextCursor)->bool",
    "PySide6.QtGui.QTextCursor.__ge__(self,rhs:PySide6.QtGui.QTextCursor)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QTextCursor_SignatureByteSize = 920;
static constexpr uint8_t QTextCursor_SignatureBytes[920] = {
    0x78, 0xda, 0xbd, 0x57, 0x5b, 0x4f, 0xdb, 0x30, 0x14, 0x7e, 0xef, 0x2f, 0xa1, 0x52, 0x88, 0x80,
    0x4d, 0x7b, 0xa8, 0x04, 0xd2, 0x5a, 0x2e, 0x43, 0x1b, 0x14, 0x54, 0x34, 0xed, 0xad, 0x72, 0x12,
    0x37, 0x35, 0x38, 0x76, 0xe6, 0x38, 0x85, 0xfe, 0xfb, 0xf9, 0x92, 0x34, 0x69, 0x49, 0x8f, 0x5d,
    0x5a, 0xf6, 0x44, 0xa8, 0xbf, 0xef, 0x3b, 0xc7, 0xc7, 0xe7, 0x62, 0x7f, 0x1d, 0x3c, 0x2c, 0x27,
    0x24, 0xc1, 0xdf, 0xc2, 0x47, 0x79, 0x53, 0x92, 0xf0, 0xf1, 0x09, 0xbf, 0xc9, 0x51, 0x29, 0x0a,
    0x2e, 0x8e, 0x0a, 0x4c, 0x67, 0xfd, 0xde, 0x17, 0x07, 0x22, 0x48, 0x78, 0x5c, 0x66, 0x98, 0xc9,
    0x2e, 0xdc, 0x65, 0xb5, 0xd6, 0xef, 0x9d, 0xb9, 0x64, 0x66, 0x02, 0x65, 0xb8, 0x0b, 0x74, 0xad,
    0x17, 0xfa, 0xbd, 0x53, 0x97, 0x40, 0x44, 0x79, 0xfc, 0xd2, 0x05, 0x1a, 0xea, 0x85, 0x7e, 0xef,
    0xc4, 0x25, 0x10, 0x9b, 0xef, 0xed, 0xa8, 0x7e, 0x6f, 0xeb, 0x52, 0x88, 0x58, 0x3c, 0xaf, 0x43,
    0x76, 0x7c, 0x41, 0x98, 0x84, 0xb0, 0xd6, 0xa3, 0x2b, 0x96, 0xd4, 0xf8, 0x88, 0x73, 0xea, 0x26,
    0x4c, 0x24, 0x12, 0xd2, 0x9b, 0xb2, 0x8b, 0xfc, 0x2e, 0xca, 0x11, 0x4e, 0x09, 0xbb, 0x4a, 0x88,
    0xf5, 0xa9, 0x4a, 0x12, 0x00, 0xde, 0xa0, 0x8e, 0x2f, 0xb6, 0x1d, 0x8e, 0x8b, 0x3f, 0x9a, 0x23,
    0x71, 0xcd, 0x45, 0x86, 0x24, 0xa0, 0xd4, 0x80, 0x5c, 0x72, 0x4e, 0xa9, 0x61, 0x83, 0x72, 0x69,
    0xdd, 0x97, 0x59, 0x84, 0x3d, 0x0f, 0x3e, 0x3e, 0xd8, 0x36, 0x62, 0x8a, 0x91, 0x98, 0x60, 0x8a,
    0x63, 0x49, 0x38, 0x73, 0x1e, 0x42, 0xcc, 0x69, 0x99, 0xb1, 0xf7, 0xae, 0x02, 0x35, 0x15, 0xc6,
    0x02, 0x23, 0x89, 0x7f, 0x91, 0xc2, 0x3a, 0x1b, 0x14, 0x72, 0x49, 0x3b, 0xeb, 0x53, 0x43, 0xac,
    0xc3, 0xe1, 0x44, 0x63, 0xba, 0xb7, 0xa5, 0x51, 0x50, 0x09, 0xbe, 0xb3, 0x37, 0x33, 0x92, 0xb0,
    0x41, 0xc0, 0x14, 0x60, 0xa8, 0x14, 0x42, 0xb5, 0x24, 0xd3, 0x56, 0x80, 0x73, 0x30, 0xeb, 0x6e,
    0x99, 0x95, 0xc3, 0xfb, 0xf8, 0xf2, 0x84, 0x22, 0x0a, 0xf9, 0x62, 0xd6, 0x01, 0x99, 0x44, 0x65,
    0x82, 0xc4, 0x3a, 0x73, 0x9c, 0xa9, 0x60, 0xa1, 0x0f, 0x02, 0x2f, 0x08, 0x2f, 0x0b, 0x3f, 0x4a,
    0xd5, 0xc4, 0x01, 0x07, 0xeb, 0x3e, 0x0f, 0xa8, 0x60, 0x96, 0xf8, 0x77, 0x8d, 0x39, 0x2a, 0x46,
    0x3c, 0xcb, 0x29, 0x7e, 0xdb, 0x48, 0x72, 0x67, 0x7b, 0x52, 0xcc, 0x6e, 0x0a, 0x30, 0x80, 0x42,
    0xc2, 0x0a, 0x2c, 0xd6, 0x5c, 0x3b, 0xdd, 0x01, 0x0d, 0xa4, 0x6a, 0xab, 0x91, 0x80, 0x03, 0xe8,
    0x83, 0x9a, 0x41, 0xd3, 0x51, 0x06, 0x60, 0x2b, 0x81, 0x62, 0x6d, 0x4d, 0xab, 0x74, 0x4f, 0x57,
    0x87, 0xac, 0x87, 0x71, 0xea, 0x9a, 0xe9, 0x35, 0xc3, 0x4b, 0xbb, 0x2a, 0x35, 0x60, 0x5b, 0x06,
    0x04, 0x95, 0xb5, 0xab, 0x20, 0xad, 0xad, 0x1f, 0x32, 0xa3, 0xd6, 0xd4, 0x5c, 0x7d, 0x0d, 0x1e,
    0x27, 0x52, 0x10, 0x96, 0x82, 0xd7, 0x98, 0x8a, 0x79, 0x9b, 0xa1, 0xb4, 0xf2, 0x92, 0xe8, 0xcf,
    0x4d, 0x82, 0x59, 0x0f, 0x98, 0xbe, 0xa5, 0x54, 0xaa, 0xe7, 0xd5, 0xdf, 0xa3, 0x7e, 0xdf, 0x23,
    0xbd, 0x5a, 0xfa, 0x6d, 0x11, 0x9f, 0x5c, 0x6b, 0x51, 0xb7, 0x07, 0xd0, 0x80, 0xfc, 0x73, 0x6d,
    0x57, 0xcd, 0x00, 0x51, 0x92, 0xb2, 0x6d, 0x49, 0xd1, 0x3a, 0xbd, 0xf0, 0x81, 0x17, 0x44, 0x97,
    0x9f, 0xcf, 0xce, 0xfe, 0xdf, 0x7c, 0xd9, 0xb4, 0xf7, 0x69, 0xf3, 0xc5, 0x1a, 0xba, 0x43, 0xe2,
    0x25, 0xe1, 0xaf, 0xb6, 0x07, 0x05, 0x59, 0xf5, 0x5f, 0x7d, 0xe8, 0xc1, 0x4c, 0x0d, 0xbb, 0x52,
    0xe0, 0x02, 0x2a, 0xb0, 0xb0, 0xd6, 0xb8, 0xb6, 0xe0, 0xf3, 0xee, 0xd5, 0x4b, 0x82, 0x74, 0xbf,
    0xbb, 0x21, 0xf2, 0x47, 0x19, 0xf9, 0xc4, 0xbc, 0x99, 0x36, 0x81, 0xe0, 0xaf, 0xc5, 0x40, 0xdd,
    0x04, 0x02, 0x75, 0x43, 0x30, 0x1f, 0xd0, 0xfc, 0x39, 0xd9, 0x4b, 0x19, 0x08, 0xb8, 0xa1, 0x41,
    0x11, 0xb7, 0xf6, 0x3d, 0x76, 0xa6, 0x7e, 0xb0, 0xe6, 0xa5, 0xfa, 0x6a, 0x2a, 0xec, 0xe4, 0x83,
    0x4c, 0xc0, 0x67, 0xcf, 0xde, 0xaa, 0xc6, 0x58, 0xbe, 0x1c, 0xcf, 0xac, 0x34, 0x97, 0x73, 0x0c,
    0xbd, 0x2f, 0x9c, 0xc3, 0x8d, 0x14, 0xf7, 0x25, 0xa5, 0x9e, 0x93, 0xf0, 0x99, 0x13, 0x56, 0xcf,
    0x79, 0xff, 0xc9, 0xfb, 0x82, 0x71, 0x5e, 0x17, 0xf0, 0x98, 0xdd, 0x9a, 0xe0, 0x78, 0x1a, 0xcc,
    0xb0, 0x48, 0xf1, 0xb0, 0xe3, 0xbe, 0x1e, 0x64, 0x3c, 0x21, 0x33, 0xb2, 0x65, 0xef, 0x5e, 0x81,
    0x6c, 0xb4, 0x7d, 0x75, 0xd7, 0x46, 0xaf, 0x43, 0xf8, 0x13, 0xfc, 0xe5, 0x0b, 0x5c, 0x87, 0xb1,
    0x3a, 0xfc, 0x1c, 0x48, 0xc2, 0x3b, 0x05, 0x1f, 0xe7, 0x58, 0x20, 0x8d, 0x0f, 0x90, 0x48, 0xa7,
    0xd3, 0x33, 0x07, 0xfc, 0x8e, 0x27, 0x55, 0x47, 0xd8, 0xf8, 0xd1, 0x7c, 0x7c, 0x37, 0xef, 0xd1,
    0x80, 0xe9, 0xca, 0x3b, 0x3f, 0x75, 0x9f, 0x5d, 0xde, 0xf6, 0xd5, 0xf9, 0x90, 0xa9, 0xd1, 0xb7,
    0x6c, 0xd8, 0x7e, 0xde, 0xc1, 0x24, 0x81, 0x75, 0x50, 0xec, 0xe5, 0x0c, 0x27, 0xab, 0x82, 0x83,
    0xa2, 0x58, 0x18, 0x70, 0x35, 0x1f, 0xea, 0x5b, 0x1d, 0x10, 0x97, 0xd5, 0xcd, 0xef, 0x69, 0x99,
    0x63, 0xb7, 0xb0, 0xf2, 0x42, 0x37, 0x96, 0x11, 0xa6, 0xb4, 0x68, 0x2e, 0xb7, 0xe3, 0xe8, 0x59,
    0xad, 0xf9, 0x90, 0x57, 0x5b, 0x38, 0xbe, 0xa8, 0x1a, 0x86, 0x93, 0xd5, 0x0a, 0xb1, 0xc7, 0xd5,
    0xca, 0x47, 0xae, 0xf5, 0xce, 0x27, 0x7e, 0x8c, 0xb5, 0xd7, 0xbe, 0x8b, 0x23, 0x3b, 0x0b, 0x7a,
    0xdf, 0xbe, 0x58, 0xeb, 0xfa, 0x69, 0x7a, 0x96, 0xb2, 0x12, 0xfd, 0x04, 0x3f, 0x7f, 0x6e, 0x6b,
    0x88, 0x41, 0x34, 0xd0, 0x45, 0xe5, 0xa0, 0xaf, 0x37, 0x01, 0x55, 0x38, 0x66, 0x16, 0xaa, 0x06,
    0x83, 0x0f, 0x50, 0xdf, 0x0e, 0xdb, 0xbf, 0x95, 0xab, 0x24, 0x46, 0x54, 0x13, 0x74, 0x3a, 0xfd,
    0xb1, 0x4e, 0xbc, 0x99, 0x41, 0xef, 0xa0, 0x92, 0xa2, 0x44, 0xf4, 0x1e, 0x2d, 0x48, 0x8a, 0x1a,
    0xf7, 0x3d, 0x76, 0xfc, 0x8a, 0x72, 0xbf, 0x61, 0x07, 0x88, 0x2c, 0x3a, 0xfd, 0x76, 0x26, 0xeb,
    0xa2, 0xcb, 0x67, 0x77, 0xeb, 0x9b, 0x4e, 0x63, 0x35, 0xa3, 0xa7, 0xd3, 0x1a, 0x2e, 0x97, 0xb9,
    0xaa, 0x64, 0xdd, 0x4b, 0x66, 0x20, 0x8b, 0xe1, 0x8a, 0x13, 0x88, 0x79, 0xb1, 0xcf, 0x54, 0x9f,
    0x4e, 0xa9, 0x3c, 0x9c, 0xd4, 0xe1, 0xbc, 0xc2, 0x7f, 0x0f, 0x26, 0x95, 0x1e, 0x6e, 0x83, 0xe9,
    0x6e, 0x1b, 0xfc, 0x07, 0x78, 0x73, 0x48, 0x87
};
#endif

PyTypeObject *init_QTextCursor(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX].type;

    Shiboken::AutoDecRef Sbk_QTextCursor_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QTextCursor_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QTextCursor",
        "QTextCursor",
        &Sbk_QTextCursor_spec,
        &Shiboken::callCppDestructor< ::QTextCursor >,
        Sbk_QTextCursor_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QTextCursor_TypeF(); // references _Sbk_QTextCursor_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QTextCursor_SignatureStrings);
#else
    InitSignatureBytes(pyType, QTextCursor_SignatureBytes, QTextCursor_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QTextCursor_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QTextCursor_PythonToCpp_QTextCursor_PTR,
        is_QTextCursor_PythonToCpp_QTextCursor_PTR_Convertible,
        QTextCursor_PTR_CppToPython_QTextCursor,
        QTextCursor_COPY_CppToPython_QTextCursor);

    Shiboken::Conversions::registerConverterName(converter, "QTextCursor");
    Shiboken::Conversions::registerConverterName(converter, "QTextCursor*");
    Shiboken::Conversions::registerConverterName(converter, "QTextCursor&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QTextCursor).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QTextCursor_PythonToCpp_QTextCursor_COPY,
        is_QTextCursor_PythonToCpp_QTextCursor_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QTextCursor_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'MoveMode'.
    const char *MoveMode_Initializer[] = {
        "MoveAnchor",
        "KeepAnchor",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t MoveMode_InitializerValues[] = {
        uint8_t(QTextCursor::MoveMode::MoveAnchor), //  0x00  0
        uint8_t(QTextCursor::MoveMode::KeepAnchor)  //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QTextCursor_TypeF(),
        "2:PySide6.QtGui.QTextCursor.MoveMode",
        MoveMode_Initializer, MoveMode_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_MoveMode_IDX].type = EType;
    // Register converter for enum 'QTextCursor::MoveMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QTextCursor_MoveMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QTextCursor_MoveMode,
            is_Enum_PythonToCpp_QTextCursor_MoveMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QTextCursor::MoveMode");
        Shiboken::Conversions::registerConverterAlias(converter, "MoveMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'MoveMode' enum.

    // Initialization of enum 'MoveOperation'.
    const char *MoveOperation_Initializer[] = {
        "NoMove",
        "Start",
        "Up",
        "StartOfLine",
        "StartOfBlock",
        "StartOfWord",
        "PreviousBlock",
        "PreviousCharacter",
        "PreviousWord",
        "Left",
        "WordLeft",
        "End",
        "Down",
        "EndOfLine",
        "EndOfWord",
        "EndOfBlock",
        "NextBlock",
        "NextCharacter",
        "NextWord",
        "Right",
        "WordRight",
        "NextCell",
        "PreviousCell",
        "NextRow",
        "PreviousRow",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t MoveOperation_InitializerValues[] = {
        uint8_t(QTextCursor::MoveOperation::NoMove),            //  0x00  0
        uint8_t(QTextCursor::MoveOperation::Start),             //  0x01  1
        uint8_t(QTextCursor::MoveOperation::Up),                //  0x02  2
        uint8_t(QTextCursor::MoveOperation::StartOfLine),       //  0x03  3
        uint8_t(QTextCursor::MoveOperation::StartOfBlock),      //  0x04  4
        uint8_t(QTextCursor::MoveOperation::StartOfWord),       //  0x05  5
        uint8_t(QTextCursor::MoveOperation::PreviousBlock),     //  0x06  6
        uint8_t(QTextCursor::MoveOperation::PreviousCharacter), //  0x07  7
        uint8_t(QTextCursor::MoveOperation::PreviousWord),      //  0x08  8
        uint8_t(QTextCursor::MoveOperation::Left),              //  0x09  9
        uint8_t(QTextCursor::MoveOperation::WordLeft),          //  0x0a  10
        uint8_t(QTextCursor::MoveOperation::End),               //  0x0b  11
        uint8_t(QTextCursor::MoveOperation::Down),              //  0x0c  12
        uint8_t(QTextCursor::MoveOperation::EndOfLine),         //  0x0d  13
        uint8_t(QTextCursor::MoveOperation::EndOfWord),         //  0x0e  14
        uint8_t(QTextCursor::MoveOperation::EndOfBlock),        //  0x0f  15
        uint8_t(QTextCursor::MoveOperation::NextBlock),         //  0x10  16
        uint8_t(QTextCursor::MoveOperation::NextCharacter),     //  0x11  17
        uint8_t(QTextCursor::MoveOperation::NextWord),          //  0x12  18
        uint8_t(QTextCursor::MoveOperation::Right),             //  0x13  19
        uint8_t(QTextCursor::MoveOperation::WordRight),         //  0x14  20
        uint8_t(QTextCursor::MoveOperation::NextCell),          //  0x15  21
        uint8_t(QTextCursor::MoveOperation::PreviousCell),      //  0x16  22
        uint8_t(QTextCursor::MoveOperation::NextRow),           //  0x17  23
        uint8_t(QTextCursor::MoveOperation::PreviousRow)        //  0x18  24
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QTextCursor_TypeF(),
        "2:PySide6.QtGui.QTextCursor.MoveOperation",
        MoveOperation_Initializer, MoveOperation_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_MoveOperation_IDX].type = EType;
    // Register converter for enum 'QTextCursor::MoveOperation'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QTextCursor_MoveOperation_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QTextCursor_MoveOperation,
            is_Enum_PythonToCpp_QTextCursor_MoveOperation_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QTextCursor::MoveOperation");
        Shiboken::Conversions::registerConverterAlias(converter, "MoveOperation");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'MoveOperation' enum.

    // Initialization of enum 'SelectionType'.
    const char *SelectionType_Initializer[] = {
        "WordUnderCursor",
        "LineUnderCursor",
        "BlockUnderCursor",
        "Document",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t SelectionType_InitializerValues[] = {
        uint8_t(QTextCursor::SelectionType::WordUnderCursor),  //  0x00  0
        uint8_t(QTextCursor::SelectionType::LineUnderCursor),  //  0x01  1
        uint8_t(QTextCursor::SelectionType::BlockUnderCursor), //  0x02  2
        uint8_t(QTextCursor::SelectionType::Document)          //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QTextCursor_TypeF(),
        "2:PySide6.QtGui.QTextCursor.SelectionType",
        SelectionType_Initializer, SelectionType_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_SelectionType_IDX].type = EType;
    // Register converter for enum 'QTextCursor::SelectionType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QTextCursor_SelectionType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QTextCursor_SelectionType,
            is_Enum_PythonToCpp_QTextCursor_SelectionType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QTextCursor::SelectionType");
        Shiboken::Conversions::registerConverterAlias(converter, "SelectionType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'SelectionType' enum.

    qRegisterMetaType< ::QTextCursor >("QTextCursor");
    qRegisterMetaType< ::QTextCursor::MoveMode >("QTextCursor::MoveMode");
    qRegisterMetaType< ::QTextCursor::MoveOperation >("QTextCursor::MoveOperation");
    qRegisterMetaType< ::QTextCursor::SelectionType >("QTextCursor::SelectionType");

    return pyType;
}
