// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qtextdocumentfragment_wrapper.h"

// Argument includes
#include <QString>
#include <QtGui/qtextcursor.h>
#include <QtGui/qtextdocument.h>
#include <QtGui/qtextdocumentfragment.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTextDocumentFragment_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QTextDocumentFragment >()))
        return -1;

    ::QTextDocumentFragment *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QTextDocumentFragment", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QTextDocumentFragment::QTextDocumentFragment()
    // 1: QTextDocumentFragment::QTextDocumentFragment(QTextCursor)
    // 2: QTextDocumentFragment::QTextDocumentFragment(const QTextDocument*)
    // 3: QTextDocumentFragment::QTextDocumentFragment(QTextDocumentFragment)
    if (numArgs == 0) {
        overloadId = 0; // QTextDocumentFragment()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentFragment_IDX]), (pyArgs[0])))) {
        overloadId = 3; // QTextDocumentFragment(QTextDocumentFragment)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QTextDocumentFragment(const QTextDocument*)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QTextDocumentFragment(QTextCursor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentFragment_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentFragment_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QTextDocumentFragment()
        {

            // QTextDocumentFragment()
            cptr = new ::QTextDocumentFragment();
            break;
        }
        case 1: // QTextDocumentFragment(const QTextCursor &range)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QTextCursor cppArg0_local;
            ::QTextCursor *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QTextDocumentFragment(QTextCursor)
                cptr = new ::QTextDocumentFragment(*cppArg0);
            }
            break;
        }
        case 2: // QTextDocumentFragment(const QTextDocument *document)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QTextDocument *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QTextDocumentFragment(const QTextDocument*)
                cptr = new ::QTextDocumentFragment(cppArg0);
            }
            break;
        }
        case 3: // QTextDocumentFragment(const QTextDocumentFragment &rhs)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QTextDocumentFragment cppArg0_local;
            ::QTextDocumentFragment *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QTextDocumentFragment(QTextDocumentFragment)
                cptr = new ::QTextDocumentFragment(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QTextDocumentFragment >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentFragment_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QTextDocumentFragmentFunc_fromHtml(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "fromHtml", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentFragment_IDX]);

    if (PyArg_ParseTuple(args, "|OO:fromHtml", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTextDocumentFragment::fromHtml(QString,const QTextDocument*=)->QTextDocumentFragment
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // fromHtml(QString,const QTextDocument*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), (pyArgs[1])))) {
            overloadId = 0; // fromHtml(QString,const QTextDocument*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fromHtml", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentFragment_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_resourceProvider = Shiboken::String::createStaticString("resourceProvider");
            if (PyDict_Contains(kwds, key_resourceProvider) != 0) {
                value = PyDict_GetItem(kwds, key_resourceProvider);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_resourceProvider);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "fromHtml", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentFragment_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "fromHtml", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentFragment_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_resourceProvider);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "fromHtml", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentFragment_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QTextDocument *cppArg1 = nullptr;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromHtml(QString,const QTextDocument*)
            QTextDocumentFragment cppResult = ::QTextDocumentFragment::fromHtml(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentFragment_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFragmentFunc_fromMarkdown(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "fromMarkdown", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentFragment_IDX]);

    if (PyArg_ParseTuple(args, "|OO:fromMarkdown", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTextDocumentFragment::fromMarkdown(QString,QFlags<QTextDocument::MarkdownFeature>=)->QTextDocumentFragment
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // fromMarkdown(QString,QFlags<QTextDocument::MarkdownFeature>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QTextDocument_MarkdownFeature_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 0; // fromMarkdown(QString,QFlags<QTextDocument::MarkdownFeature>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fromMarkdown", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentFragment_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_features = Shiboken::String::createStaticString("features");
            if (PyDict_Contains(kwds, key_features) != 0) {
                value = PyDict_GetItem(kwds, key_features);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_features);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "fromMarkdown", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentFragment_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QTextDocument_MarkdownFeature_IDX])))->flagsConverter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "fromMarkdown", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentFragment_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_features);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "fromMarkdown", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentFragment_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<QTextDocument::MarkdownFeature> cppArg1(QTextDocument::MarkdownDialectGitHub);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromMarkdown(QString,QFlags<QTextDocument::MarkdownFeature>)
            QTextDocumentFragment cppResult = ::QTextDocumentFragment::fromMarkdown(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentFragment_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFragmentFunc_fromPlainText(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QTextDocumentFragment::fromPlainText(QString)->QTextDocumentFragment
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // fromPlainText(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fromPlainText", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentFragment_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromPlainText(QString)
            QTextDocumentFragment cppResult = ::QTextDocumentFragment::fromPlainText(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentFragment_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFragmentFunc_isEmpty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocumentFragment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentFragment_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isEmpty()const
        bool cppResult = const_cast<const ::QTextDocumentFragment *>(cppSelf)->isEmpty();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFragmentFunc_toHtml(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocumentFragment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentFragment_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toHtml()const
        QString cppResult = const_cast<const ::QTextDocumentFragment *>(cppSelf)->toHtml();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFragmentFunc_toMarkdown(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocumentFragment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentFragment_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "toMarkdown", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentFragment_IDX]);

    if (PyArg_ParseTuple(args, "|O:toMarkdown", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTextDocumentFragment::toMarkdown(QFlags<QTextDocument::MarkdownFeature>=)const->QString
    if (numArgs == 0) {
        overloadId = 0; // toMarkdown(QFlags<QTextDocument::MarkdownFeature>)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QTextDocument_MarkdownFeature_IDX])))->flagsConverter, (pyArgs[0])))) {
        overloadId = 0; // toMarkdown(QFlags<QTextDocument::MarkdownFeature>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "toMarkdown", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentFragment_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_features = Shiboken::String::createStaticString("features");
            if (PyDict_Contains(kwds, key_features) != 0) {
                value = PyDict_GetItem(kwds, key_features);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_features);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "toMarkdown", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentFragment_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QTextDocument_MarkdownFeature_IDX])))->flagsConverter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "toMarkdown", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentFragment_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_features);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "toMarkdown", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentFragment_IDX]);
            }
        }
        ::QFlags<QTextDocument::MarkdownFeature> cppArg0(QTextDocument::MarkdownDialectGitHub);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toMarkdown(QFlags<QTextDocument::MarkdownFeature>)const
            QString cppResult = const_cast<const ::QTextDocumentFragment *>(cppSelf)->toMarkdown(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFragmentFunc_toPlainText(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocumentFragment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentFragment_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toPlainText()const
        QString cppResult = const_cast<const ::QTextDocumentFragment *>(cppSelf)->toPlainText();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFragmentFunc_toRawText(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocumentFragment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentFragment_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toRawText()const
        QString cppResult = const_cast<const ::QTextDocumentFragment *>(cppSelf)->toRawText();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFragment__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QTextDocumentFragment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentFragment_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentFragment_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QTextDocumentFragment_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QTextDocumentFragment_methods[] = {
    {"fromHtml", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFragmentFunc_fromHtml), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"fromMarkdown", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFragmentFunc_fromMarkdown), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"fromPlainText", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFragmentFunc_fromPlainText), METH_O|METH_STATIC, nullptr},
    {"isEmpty", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFragmentFunc_isEmpty), METH_NOARGS, nullptr},
    {"toHtml", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFragmentFunc_toHtml), METH_NOARGS, nullptr},
    {"toMarkdown", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFragmentFunc_toMarkdown), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toPlainText", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFragmentFunc_toPlainText), METH_NOARGS, nullptr},
    {"toRawText", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFragmentFunc_toRawText), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFragment__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QTextDocumentFragment_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QTextDocumentFragment_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QTextDocumentFragment_Type = nullptr;
static PyTypeObject *Sbk_QTextDocumentFragment_TypeF(void)
{
    return _Sbk_QTextDocumentFragment_Type;
}

static PyType_Slot Sbk_QTextDocumentFragment_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QTextDocumentFragment_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QTextDocumentFragment_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QTextDocumentFragment_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QTextDocumentFragment_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QTextDocumentFragment_spec = {
    "2:PySide6.QtGui.QTextDocumentFragment",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QTextDocumentFragment_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QTextDocumentFragment_PythonToCpp_QTextDocumentFragment_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QTextDocumentFragment_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QTextDocumentFragment_PythonToCpp_QTextDocumentFragment_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QTextDocumentFragment_TypeF()))
        return QTextDocumentFragment_PythonToCpp_QTextDocumentFragment_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QTextDocumentFragment_PTR_CppToPython_QTextDocumentFragment(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QTextDocumentFragment_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QTextDocumentFragment_COPY_CppToPython_QTextDocumentFragment(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QTextDocumentFragment *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QTextDocumentFragment_TypeF(), new ::QTextDocumentFragment(*source), true, true);
}

// Python to C++ copy conversion.
static void QTextDocumentFragment_PythonToCpp_QTextDocumentFragment_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QTextDocumentFragment *>(cppOut) = *reinterpret_cast< ::QTextDocumentFragment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentFragment_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QTextDocumentFragment_PythonToCpp_QTextDocumentFragment_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QTextDocumentFragment_TypeF()))
        return QTextDocumentFragment_PythonToCpp_QTextDocumentFragment_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QTextDocumentFragment_SignatureStrings[] = {
    "3:PySide6.QtGui.QTextDocumentFragment(self)",
    "2:PySide6.QtGui.QTextDocumentFragment(self,range:PySide6.QtGui.QTextCursor)",
    "1:PySide6.QtGui.QTextDocumentFragment(self,document:PySide6.QtGui.QTextDocument)",
    "0:PySide6.QtGui.QTextDocumentFragment(self,rhs:PySide6.QtGui.QTextDocumentFragment)",
    "PySide6.QtGui.QTextDocumentFragment.fromHtml(html:QString,resourceProvider:PySide6.QtGui.QTextDocument=nullptr)->PySide6.QtGui.QTextDocumentFragment",
    "PySide6.QtGui.QTextDocumentFragment.fromMarkdown(markdown:QString,features:PySide6.QtGui.QTextDocument.MarkdownFeature=QTextDocument.MarkdownDialectGitHub)->PySide6.QtGui.QTextDocumentFragment",
    "PySide6.QtGui.QTextDocumentFragment.fromPlainText(plainText:QString)->PySide6.QtGui.QTextDocumentFragment",
    "PySide6.QtGui.QTextDocumentFragment.isEmpty(self)->bool",
    "PySide6.QtGui.QTextDocumentFragment.toHtml(self)->QString",
    "PySide6.QtGui.QTextDocumentFragment.toMarkdown(self,features:PySide6.QtGui.QTextDocument.MarkdownFeature=QTextDocument.MarkdownDialectGitHub)->QString",
    "PySide6.QtGui.QTextDocumentFragment.toPlainText(self)->QString",
    "PySide6.QtGui.QTextDocumentFragment.toRawText(self)->QString",
    "PySide6.QtGui.QTextDocumentFragment.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QTextDocumentFragment_SignatureByteSize = 265;
static constexpr uint8_t QTextDocumentFragment_SignatureBytes[265] = {
    0x78, 0xda, 0xb5, 0x92, 0xcb, 0x6e, 0xc2, 0x30, 0x10, 0x45, 0xf7, 0xfe, 0x92, 0x58, 0x02, 0xab,
    0x0f, 0xa9, 0x0b, 0x24, 0xd8, 0x94, 0x02, 0x9b, 0x4a, 0x49, 0xd3, 0x7d, 0x64, 0x12, 0x27, 0x58,
    0xf5, 0x4b, 0x93, 0x71, 0x69, 0xfe, 0xbe, 0x06, 0x12, 0xba, 0x41, 0x91, 0x41, 0x74, 0xe3, 0xe7,
    0x3d, 0x33, 0x77, 0x3c, 0x7e, 0x9e, 0xa5, 0x5d, 0x2e, 0x2b, 0xf1, 0xc2, 0x32, 0x5c, 0x7b, 0xc9,
    0xb2, 0x4f, 0xf1, 0x83, 0x4b, 0x5b, 0x7a, 0x2d, 0x0c, 0xae, 0x80, 0x37, 0x87, 0x39, 0x69, 0x85,
    0xaa, 0x29, 0x79, 0x8a, 0xd6, 0x4e, 0x80, 0x9b, 0x46, 0x5c, 0x92, 0xbf, 0x7a, 0x68, 0x2d, 0x50,
    0xf2, 0x18, 0x1f, 0xab, 0xea, 0x4f, 0xc7, 0x08, 0x4a, 0x1e, 0xae, 0x30, 0xb7, 0x6b, 0x63, 0xc4,
    0x94, 0x44, 0x88, 0x58, 0x0d, 0x56, 0x6f, 0x50, 0xab, 0x64, 0x17, 0x86, 0x59, 0x96, 0x23, 0x48,
    0xd3, 0x4c, 0x40, 0xb4, 0xd6, 0x43, 0x29, 0x52, 0xb0, 0xdf, 0x21, 0x04, 0x8c, 0xe5, 0x9b, 0x1b,
    0xaf, 0x94, 0x43, 0xa0, 0xd3, 0x45, 0x44, 0xc2, 0x68, 0x53, 0xef, 0x1c, 0xbe, 0x2a, 0xbb, 0x37,
    0x89, 0xee, 0x17, 0x67, 0x73, 0xb5, 0xe0, 0xe8, 0x83, 0xc3, 0x31, 0x53, 0x6c, 0xc0, 0x57, 0x27,
    0xf1, 0xfc, 0xf2, 0xed, 0x52, 0x72, 0x25, 0x4a, 0x5c, 0x4b, 0xdc, 0xf8, 0xed, 0x9d, 0x0b, 0x48,
    0x15, 0x97, 0xe6, 0x70, 0x9b, 0xb8, 0x61, 0x35, 0x94, 0x70, 0xc7, 0x4c, 0xb2, 0x7d, 0xd3, 0x0e,
    0xbb, 0xd3, 0x17, 0x9f, 0x2e, 0xb6, 0xd6, 0xaa, 0x28, 0x0e, 0xed, 0xb1, 0xeb, 0x3d, 0xd6, 0xfb,
    0x8a, 0x24, 0xcf, 0xad, 0x39, 0x7e, 0xc7, 0x7f, 0x6c, 0xc7, 0x75, 0xb6, 0xfe, 0x1e, 0xfc, 0xa6,
    0xaa, 0x3e, 0xf8, 0xfe, 0x56, 0xb8, 0x28, 0x4a, 0xeb, 0xba, 0xa2, 0x18, 0x58, 0xec, 0x5c, 0x40,
    0x59, 0x1e, 0x76, 0xe4, 0x17, 0x08, 0xc3, 0xb5, 0x7e
};
#endif

PyTypeObject *init_QTextDocumentFragment(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentFragment_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentFragment_IDX].type;

    Shiboken::AutoDecRef Sbk_QTextDocumentFragment_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QTextDocumentFragment_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QTextDocumentFragment",
        "QTextDocumentFragment",
        &Sbk_QTextDocumentFragment_spec,
        &Shiboken::callCppDestructor< ::QTextDocumentFragment >,
        Sbk_QTextDocumentFragment_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QTextDocumentFragment_TypeF(); // references _Sbk_QTextDocumentFragment_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QTextDocumentFragment_SignatureStrings);
#else
    InitSignatureBytes(pyType, QTextDocumentFragment_SignatureBytes, QTextDocumentFragment_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QTextDocumentFragment_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentFragment_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QTextDocumentFragment_PythonToCpp_QTextDocumentFragment_PTR,
        is_QTextDocumentFragment_PythonToCpp_QTextDocumentFragment_PTR_Convertible,
        QTextDocumentFragment_PTR_CppToPython_QTextDocumentFragment,
        QTextDocumentFragment_COPY_CppToPython_QTextDocumentFragment);

    Shiboken::Conversions::registerConverterName(converter, "QTextDocumentFragment");
    Shiboken::Conversions::registerConverterName(converter, "QTextDocumentFragment*");
    Shiboken::Conversions::registerConverterName(converter, "QTextDocumentFragment&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QTextDocumentFragment).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QTextDocumentFragment_PythonToCpp_QTextDocumentFragment_COPY,
        is_QTextDocumentFragment_PythonToCpp_QTextDocumentFragment_COPY_Convertible);

    qRegisterMetaType< ::QTextDocumentFragment >("QTextDocumentFragment");

    return pyType;
}
