// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qtextdocumentwriter_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtGui/qtextdocument.h>
#include <QtGui/qtextdocumentfragment.h>
#include <qbytearray.h>
#include <qiodevice.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTextDocumentWriter_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QTextDocumentWriter >()))
        return -1;

    ::QTextDocumentWriter *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentWriter_IDX]);

    if (PyArg_ParseTuple(args, "|OO:QTextDocumentWriter", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QTextDocumentWriter::QTextDocumentWriter()
    // 1: QTextDocumentWriter::QTextDocumentWriter(QIODevice*,QByteArray)
    // 2: QTextDocumentWriter::QTextDocumentWriter(QString,const QByteArray&=)
    if (numArgs == 0) {
        overloadId = 0; // QTextDocumentWriter()
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
        overloadId = 1; // QTextDocumentWriter(QIODevice*,QByteArray)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 2; // QTextDocumentWriter(QString,QByteArray)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
            overloadId = 2; // QTextDocumentWriter(QString,QByteArray)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentWriter_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentWriter_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QTextDocumentWriter()
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentWriter_IDX]);
            }

            // QTextDocumentWriter()
            cptr = new ::QTextDocumentWriter();
            break;
        }
        case 1: // QTextDocumentWriter(QIODevice *device, const QByteArray &format)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentWriter_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QIODevice *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QByteArray cppArg1_local;
            ::QByteArray *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QTextDocumentWriter(QIODevice*,QByteArray)
                cptr = new ::QTextDocumentWriter(cppArg0, *cppArg1);
            }
            break;
        }
        case 2: // QTextDocumentWriter(const QString &fileName, const QByteArray &format)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_format = Shiboken::String::createStaticString("format");
                if (PyDict_Contains(kwds, key_format) != 0) {
                    value = PyDict_GetItem(kwds, key_format);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_format);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentWriter_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentWriter_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_format);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentWriter_IDX]);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QByteArray cppArg1_local = QByteArray();
            ::QByteArray *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1]) {
                if (pythonToCpp[1].isValue())
                    pythonToCpp[1](pyArgs[1], &cppArg1_local);
                else
                    pythonToCpp[1](pyArgs[1], &cppArg1);
                }

            if (Shiboken::Errors::occurred() == nullptr) {
                // QTextDocumentWriter(QString,QByteArray)
                cptr = new ::QTextDocumentWriter(cppArg0, *cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QTextDocumentWriter >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentWriter_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QTextDocumentWriterFunc_device(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocumentWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // device()const
        QIODevice * cppResult = const_cast<const ::QTextDocumentWriter *>(cppSelf)->device();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentWriterFunc_fileName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocumentWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // fileName()const
        QString cppResult = const_cast<const ::QTextDocumentWriter *>(cppSelf)->fileName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentWriterFunc_format(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocumentWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // format()const
        QByteArray cppResult = const_cast<const ::QTextDocumentWriter *>(cppSelf)->format();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentWriterFunc_setDevice(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocumentWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextDocumentWriter::setDevice(QIODevice*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), (pyArg)))) {
        overloadId = 0; // setDevice(QIODevice*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDevice", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentWriter_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QIODevice *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDevice(QIODevice*)
            cppSelf->setDevice(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextDocumentWriterFunc_setFileName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocumentWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextDocumentWriter::setFileName(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setFileName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFileName", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentWriter_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFileName(QString)
            cppSelf->setFileName(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextDocumentWriterFunc_setFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocumentWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextDocumentWriter::setFormat(QByteArray)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // setFormat(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFormat", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentWriter_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setFormat(QByteArray)
            cppSelf->setFormat(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextDocumentWriterFunc_supportedDocumentFormats(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // supportedDocumentFormats()
        QList<QByteArray> cppResult = ::QTextDocumentWriter::supportedDocumentFormats();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QByteArray_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentWriterFunc_write(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocumentWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextDocumentWriter::write(const QTextDocument*)->bool
    // 1: QTextDocumentWriter::write(QTextDocumentFragment)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentFragment_IDX]), (pyArg)))) {
        overloadId = 1; // write(QTextDocumentFragment)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), (pyArg)))) {
        overloadId = 0; // write(const QTextDocument*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "write", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentWriter_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // write(const QTextDocument *document)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QTextDocument *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // write(const QTextDocument*)
                bool cppResult = cppSelf->write(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // write(const QTextDocumentFragment &fragment)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QTextDocumentFragment cppArg0_local;
            ::QTextDocumentFragment *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // write(QTextDocumentFragment)
                bool cppResult = cppSelf->write(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QTextDocumentWriter_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QTextDocumentWriter_methods[] = {
    {"device", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentWriterFunc_device), METH_NOARGS, nullptr},
    {"fileName", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentWriterFunc_fileName), METH_NOARGS, nullptr},
    {"format", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentWriterFunc_format), METH_NOARGS, nullptr},
    {"setDevice", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentWriterFunc_setDevice), METH_O, nullptr},
    {"setFileName", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentWriterFunc_setFileName), METH_O, nullptr},
    {"setFormat", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentWriterFunc_setFormat), METH_O, nullptr},
    {"supportedDocumentFormats", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentWriterFunc_supportedDocumentFormats), METH_NOARGS|METH_STATIC, nullptr},
    {"write", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentWriterFunc_write), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QTextDocumentWriter_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QTextDocumentWriter_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QTextDocumentWriter_Type = nullptr;
static PyTypeObject *Sbk_QTextDocumentWriter_TypeF(void)
{
    return _Sbk_QTextDocumentWriter_Type;
}

static PyType_Slot Sbk_QTextDocumentWriter_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QTextDocumentWriter_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QTextDocumentWriter_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QTextDocumentWriter_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QTextDocumentWriter_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QTextDocumentWriter_spec = {
    "2:PySide6.QtGui.QTextDocumentWriter",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QTextDocumentWriter_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QTextDocumentWriter_PythonToCpp_QTextDocumentWriter_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QTextDocumentWriter_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QTextDocumentWriter_PythonToCpp_QTextDocumentWriter_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QTextDocumentWriter_TypeF()))
        return QTextDocumentWriter_PythonToCpp_QTextDocumentWriter_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QTextDocumentWriter_PTR_CppToPython_QTextDocumentWriter(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QTextDocumentWriter_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QTextDocumentWriter_SignatureStrings[] = {
    "2:PySide6.QtGui.QTextDocumentWriter(self)",
    "1:PySide6.QtGui.QTextDocumentWriter(self,device:PySide6.QtCore.QIODevice,format:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "0:PySide6.QtGui.QTextDocumentWriter(self,fileName:QString,format:typing.Union[PySide6.QtCore.QByteArray, char*]=QByteArray())",
    "PySide6.QtGui.QTextDocumentWriter.device(self)->PySide6.QtCore.QIODevice",
    "PySide6.QtGui.QTextDocumentWriter.fileName(self)->QString",
    "PySide6.QtGui.QTextDocumentWriter.format(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtGui.QTextDocumentWriter.setDevice(self,device:PySide6.QtCore.QIODevice)",
    "PySide6.QtGui.QTextDocumentWriter.setFileName(self,fileName:QString)",
    "PySide6.QtGui.QTextDocumentWriter.setFormat(self,format:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "PySide6.QtGui.QTextDocumentWriter.supportedDocumentFormats()->QList[PySide6.QtCore.QByteArray]",
    "1:PySide6.QtGui.QTextDocumentWriter.write(self,document:PySide6.QtGui.QTextDocument)->bool",
    "0:PySide6.QtGui.QTextDocumentWriter.write(self,fragment:PySide6.QtGui.QTextDocumentFragment)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QTextDocumentWriter_SignatureByteSize = 260;
static constexpr uint8_t QTextDocumentWriter_SignatureBytes[260] = {
    0x78, 0xda, 0x9d, 0x93, 0x4f, 0x6b, 0x83, 0x40, 0x10, 0xc5, 0xef, 0x7e, 0x8a, 0x1e, 0xdd, 0x62,
    0x96, 0xb6, 0x87, 0x1e, 0x84, 0x04, 0xda, 0x4a, 0x4a, 0xa1, 0x24, 0x95, 0x24, 0xe4, 0x10, 0x72,
    0xd8, 0xea, 0x98, 0x2e, 0xa8, 0x2b, 0xe3, 0xd8, 0xd6, 0x6f, 0x9f, 0x3f, 0x6a, 0x94, 0x06, 0xeb,
    0x90, 0xd3, 0xc2, 0xee, 0xdb, 0xf7, 0x9b, 0x37, 0xb3, 0xfb, 0xe0, 0x7e, 0x94, 0x0b, 0x1d, 0xc2,
    0xa3, 0xf4, 0xe9, 0xb5, 0xd0, 0xd2, 0x5f, 0xc2, 0x2f, 0x79, 0x26, 0x28, 0x12, 0x48, 0x69, 0x8d,
    0x9a, 0x00, 0xed, 0x1c, 0xe2, 0x48, 0x58, 0xf7, 0x4c, 0xa5, 0x13, 0xc2, 0xb7, 0x0e, 0xa0, 0xa3,
    0x7e, 0x31, 0x08, 0xd2, 0x7f, 0x9b, 0x7b, 0xa7, 0x03, 0x27, 0x32, 0x98, 0x28, 0x72, 0xa9, 0xcc,
    0x74, 0xba, 0x93, 0xab, 0x54, 0x9b, 0x74, 0xf3, 0x57, 0xfc, 0x5c, 0x12, 0x3c, 0x21, 0xaa, 0xd2,
    0xb9, 0x09, 0xbe, 0x14, 0xde, 0x6e, 0x85, 0x75, 0xc7, 0xe5, 0x47, 0x3a, 0x86, 0x99, 0x4a, 0xc0,
    0xf5, 0x17, 0x84, 0x07, 0xc4, 0x75, 0xc0, 0x71, 0xbb, 0x65, 0x0b, 0x61, 0x0d, 0xb2, 0x65, 0x15,
    0xbb, 0x6a, 0xd6, 0x68, 0xd2, 0x97, 0x9e, 0x61, 0xd4, 0xd4, 0xdf, 0x58, 0xd5, 0x31, 0x38, 0x37,
    0x4f, 0x41, 0xfb, 0x4a, 0x38, 0xe7, 0x61, 0x38, 0xe5, 0x40, 0x5e, 0x9b, 0x67, 0x68, 0xa4, 0x82,
    0xe7, 0x38, 0xed, 0x06, 0xbb, 0x18, 0x13, 0xd7, 0xa4, 0xcd, 0x78, 0xed, 0x4b, 0x62, 0x70, 0x8a,
    0x2c, 0x33, 0x48, 0x10, 0x36, 0xfb, 0x15, 0x35, 0xb7, 0x8f, 0xe3, 0x78, 0xd7, 0x39, 0xf5, 0x63,
    0xb6, 0x9c, 0x8f, 0x22, 0x7f, 0x8e, 0x4b, 0xdd, 0xdb, 0xfa, 0xe4, 0xbf, 0x5b, 0x07, 0xec, 0xa7,
    0x31, 0x31, 0xe7, 0x0f, 0x74, 0xad, 0x23, 0x54, 0xbb, 0x21, 0xeb, 0x69, 0xad, 0x69, 0x10, 0x7b,
    0x12, 0xaf, 0x79, 0x1f
};
#endif

PyTypeObject *init_QTextDocumentWriter(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentWriter_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentWriter_IDX].type;

    Shiboken::AutoDecRef Sbk_QTextDocumentWriter_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QTextDocumentWriter_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QTextDocumentWriter",
        "QTextDocumentWriter*",
        &Sbk_QTextDocumentWriter_spec,
        &Shiboken::callCppDestructor< ::QTextDocumentWriter >,
        Sbk_QTextDocumentWriter_Type_bases.object(),
        0);
    auto *pyType = Sbk_QTextDocumentWriter_TypeF(); // references _Sbk_QTextDocumentWriter_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QTextDocumentWriter_SignatureStrings);
#else
    InitSignatureBytes(pyType, QTextDocumentWriter_SignatureBytes, QTextDocumentWriter_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QTextDocumentWriter_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QTextDocumentWriter_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QTextDocumentWriter_PythonToCpp_QTextDocumentWriter_PTR,
        is_QTextDocumentWriter_PythonToCpp_QTextDocumentWriter_PTR_Convertible,
        QTextDocumentWriter_PTR_CppToPython_QTextDocumentWriter);

    Shiboken::Conversions::registerConverterName(converter, "QTextDocumentWriter");
    Shiboken::Conversions::registerConverterName(converter, "QTextDocumentWriter*");
    Shiboken::Conversions::registerConverterName(converter, "QTextDocumentWriter&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QTextDocumentWriter).name());

    qRegisterMetaType< ::QTextDocumentWriter *>();

    return pyType;
}
