// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qtextformat_wrapper.h"

// Argument includes
#include <QList>
#include <QMap>
#include <QString>
#include <QtGui/qbrush.h>
#include <QtGui/qcolor.h>
#include <QtGui/qpen.h>
#include <QtGui/qtextformat.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTextFormat_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QTextFormat >()))
        return -1;

    ::QTextFormat *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QTextFormat", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QTextFormat::QTextFormat()
    // 1: QTextFormat::QTextFormat(QTextFormat)
    // 2: QTextFormat::QTextFormat(int)
    if (numArgs == 0) {
        overloadId = 0; // QTextFormat()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 2; // QTextFormat(int)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QTextFormat(QTextFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QTextFormat()
        {

            // QTextFormat()
            cptr = new ::QTextFormat();
            break;
        }
        case 1: // QTextFormat(const QTextFormat &rhs)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QTextFormat cppArg0_local;
            ::QTextFormat *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QTextFormat(QTextFormat)
                cptr = new ::QTextFormat(*cppArg0);
            }
            break;
        }
        case 2: // QTextFormat(int type)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QTextFormat(int)
                cptr = new ::QTextFormat(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QTextFormat >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QTextFormatFunc_background(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // background()const
        QBrush cppResult = const_cast<const ::QTextFormat *>(cppSelf)->background();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextFormatFunc_boolProperty(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextFormat::boolProperty(int)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // boolProperty(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "boolProperty", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // boolProperty(int)const
            bool cppResult = const_cast<const ::QTextFormat *>(cppSelf)->boolProperty(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextFormatFunc_brushProperty(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextFormat::brushProperty(int)const->QBrush
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // brushProperty(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "brushProperty", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // brushProperty(int)const
            QBrush cppResult = const_cast<const ::QTextFormat *>(cppSelf)->brushProperty(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextFormatFunc_clearBackground(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clearBackground()
        cppSelf->clearBackground();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextFormatFunc_clearForeground(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clearForeground()
        cppSelf->clearForeground();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextFormatFunc_clearProperty(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextFormat::clearProperty(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // clearProperty(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "clearProperty", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // clearProperty(int)
            cppSelf->clearProperty(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextFormatFunc_colorProperty(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextFormat::colorProperty(int)const->QColor
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // colorProperty(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "colorProperty", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // colorProperty(int)const
            QColor cppResult = const_cast<const ::QTextFormat *>(cppSelf)->colorProperty(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextFormatFunc_doubleProperty(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextFormat::doubleProperty(int)const->qreal
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // doubleProperty(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "doubleProperty", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // doubleProperty(int)const
            qreal cppResult = const_cast<const ::QTextFormat *>(cppSelf)->doubleProperty(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextFormatFunc_foreground(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // foreground()const
        QBrush cppResult = const_cast<const ::QTextFormat *>(cppSelf)->foreground();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextFormatFunc_hasProperty(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextFormat::hasProperty(int)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // hasProperty(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "hasProperty", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // hasProperty(int)const
            bool cppResult = const_cast<const ::QTextFormat *>(cppSelf)->hasProperty(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextFormatFunc_intProperty(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextFormat::intProperty(int)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // intProperty(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "intProperty", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // intProperty(int)const
            int cppResult = const_cast<const ::QTextFormat *>(cppSelf)->intProperty(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextFormatFunc_isBlockFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isBlockFormat()const
        bool cppResult = const_cast<const ::QTextFormat *>(cppSelf)->isBlockFormat();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextFormatFunc_isCharFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isCharFormat()const
        bool cppResult = const_cast<const ::QTextFormat *>(cppSelf)->isCharFormat();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextFormatFunc_isEmpty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isEmpty()const
        bool cppResult = const_cast<const ::QTextFormat *>(cppSelf)->isEmpty();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextFormatFunc_isFrameFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isFrameFormat()const
        bool cppResult = const_cast<const ::QTextFormat *>(cppSelf)->isFrameFormat();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextFormatFunc_isImageFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isImageFormat()const
        bool cppResult = const_cast<const ::QTextFormat *>(cppSelf)->isImageFormat();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextFormatFunc_isListFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isListFormat()const
        bool cppResult = const_cast<const ::QTextFormat *>(cppSelf)->isListFormat();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextFormatFunc_isTableCellFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isTableCellFormat()const
        bool cppResult = const_cast<const ::QTextFormat *>(cppSelf)->isTableCellFormat();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextFormatFunc_isTableFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isTableFormat()const
        bool cppResult = const_cast<const ::QTextFormat *>(cppSelf)->isTableFormat();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextFormatFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QTextFormat *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextFormatFunc_layoutDirection(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // layoutDirection()const
        Qt::LayoutDirection cppResult = const_cast<const ::QTextFormat *>(cppSelf)->layoutDirection();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_LayoutDirection_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextFormatFunc_lengthProperty(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextFormat::lengthProperty(int)const->QTextLength
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // lengthProperty(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "lengthProperty", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // lengthProperty(int)const
            QTextLength cppResult = const_cast<const ::QTextFormat *>(cppSelf)->lengthProperty(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLength_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextFormatFunc_lengthVectorProperty(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextFormat::lengthVectorProperty(int)const->QList<QTextLength>
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // lengthVectorProperty(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "lengthVectorProperty", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // lengthVectorProperty(int)const
            QList<QTextLength> cppResult = const_cast<const ::QTextFormat *>(cppSelf)->lengthVectorProperty(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QTextLength_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextFormatFunc_merge(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextFormat::merge(QTextFormat)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), (pyArg)))) {
        overloadId = 0; // merge(QTextFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "merge", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTextFormat cppArg0_local;
        ::QTextFormat *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // merge(QTextFormat)
            cppSelf->merge(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextFormatFunc_objectIndex(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // objectIndex()const
        int cppResult = const_cast<const ::QTextFormat *>(cppSelf)->objectIndex();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextFormatFunc_objectType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // objectType()const
        int cppResult = const_cast<const ::QTextFormat *>(cppSelf)->objectType();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextFormatFunc_penProperty(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextFormat::penProperty(int)const->QPen
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // penProperty(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "penProperty", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // penProperty(int)const
            QPen cppResult = const_cast<const ::QTextFormat *>(cppSelf)->penProperty(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPen_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextFormatFunc_properties(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // properties()const
        QMap<int,QVariant> cppResult = const_cast<const ::QTextFormat *>(cppSelf)->properties();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QMap_int_QVariant_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextFormatFunc_property(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextFormat::property(int)const->QVariant
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // property(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "property", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // property(int)const
            QVariant cppResult = const_cast<const ::QTextFormat *>(cppSelf)->property(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextFormatFunc_propertyCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // propertyCount()const
        int cppResult = const_cast<const ::QTextFormat *>(cppSelf)->propertyCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextFormatFunc_setBackground(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextFormat::setBackground(QBrush)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArg)))) {
        overloadId = 0; // setBackground(QBrush)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBackground", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QBrush cppArg0_local;
        ::QBrush *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setBackground(QBrush)
            cppSelf->setBackground(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextFormatFunc_setForeground(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextFormat::setForeground(QBrush)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArg)))) {
        overloadId = 0; // setForeground(QBrush)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setForeground", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QBrush cppArg0_local;
        ::QBrush *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setForeground(QBrush)
            cppSelf->setForeground(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextFormatFunc_setLayoutDirection(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextFormat::setLayoutDirection(Qt::LayoutDirection)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_LayoutDirection_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setLayoutDirection(Qt::LayoutDirection)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLayoutDirection", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]);

    // Call function/method
    {
        ::Qt::LayoutDirection cppArg0{Qt::LeftToRight};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLayoutDirection(Qt::LayoutDirection)
            cppSelf->setLayoutDirection(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextFormatFunc_setObjectIndex(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextFormat::setObjectIndex(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setObjectIndex(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setObjectIndex", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setObjectIndex(int)
            cppSelf->setObjectIndex(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextFormatFunc_setObjectType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextFormat::setObjectType(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setObjectType(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setObjectType", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setObjectType(int)
            cppSelf->setObjectType(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextFormatFunc_setProperty(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setProperty", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTextFormat::setProperty(int,QList<QTextLength>)
    // 1: QTextFormat::setProperty(int,QVariant)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QTextLength_IDX], (pyArgs[1])))) {
            overloadId = 0; // setProperty(int,QList<QTextLength>)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[1])))) {
            overloadId = 1; // setProperty(int,QVariant)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setProperty", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setProperty(int propertyId, const QList<QTextLength> &lengths)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QList<QTextLength> cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setProperty(int,QList<QTextLength>)
                cppSelf->setProperty(cppArg0, cppArg1);
            }
            break;
        }
        case 1: // setProperty(int propertyId, const QVariant &value)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QVariant cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setProperty(int,QVariant)
                cppSelf->setProperty(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextFormatFunc_stringProperty(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextFormat::stringProperty(int)const->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // stringProperty(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "stringProperty", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // stringProperty(int)const
            QString cppResult = const_cast<const ::QTextFormat *>(cppSelf)->stringProperty(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextFormatFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextFormat::swap(QTextFormat&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QTextFormat&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTextFormat cppArg0_local;
        ::QTextFormat *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QTextFormat&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextFormatFunc_toBlockFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toBlockFormat()const
        QTextBlockFormat cppResult = const_cast<const ::QTextFormat *>(cppSelf)->toBlockFormat();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlockFormat_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextFormatFunc_toCharFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toCharFormat()const
        QTextCharFormat cppResult = const_cast<const ::QTextFormat *>(cppSelf)->toCharFormat();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextFormatFunc_toFrameFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toFrameFormat()const
        QTextFrameFormat cppResult = const_cast<const ::QTextFormat *>(cppSelf)->toFrameFormat();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFrameFormat_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextFormatFunc_toImageFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toImageFormat()const
        QTextImageFormat cppResult = const_cast<const ::QTextFormat *>(cppSelf)->toImageFormat();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextImageFormat_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextFormatFunc_toListFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toListFormat()const
        QTextListFormat cppResult = const_cast<const ::QTextFormat *>(cppSelf)->toListFormat();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextListFormat_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextFormatFunc_toTableCellFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toTableCellFormat()const
        QTextTableCellFormat cppResult = const_cast<const ::QTextFormat *>(cppSelf)->toTableCellFormat();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextTableCellFormat_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextFormatFunc_toTableFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toTableFormat()const
        QTextTableFormat cppResult = const_cast<const ::QTextFormat *>(cppSelf)->toTableFormat();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextTableFormat_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextFormatFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        int cppResult = const_cast<const ::QTextFormat *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextFormat__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QTextFormat_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QTextFormat_EnumFlagInfo[] = {
    "FormatType:IntEnum",
    "ObjectTypes:IntEnum",
    "PageBreakFlag:Flag:PageBreakFlags",
    "Property:IntEnum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QTextFormat_methods[] = {
    {"background", reinterpret_cast<PyCFunction>(Sbk_QTextFormatFunc_background), METH_NOARGS, nullptr},
    {"boolProperty", reinterpret_cast<PyCFunction>(Sbk_QTextFormatFunc_boolProperty), METH_O, nullptr},
    {"brushProperty", reinterpret_cast<PyCFunction>(Sbk_QTextFormatFunc_brushProperty), METH_O, nullptr},
    {"clearBackground", reinterpret_cast<PyCFunction>(Sbk_QTextFormatFunc_clearBackground), METH_NOARGS, nullptr},
    {"clearForeground", reinterpret_cast<PyCFunction>(Sbk_QTextFormatFunc_clearForeground), METH_NOARGS, nullptr},
    {"clearProperty", reinterpret_cast<PyCFunction>(Sbk_QTextFormatFunc_clearProperty), METH_O, nullptr},
    {"colorProperty", reinterpret_cast<PyCFunction>(Sbk_QTextFormatFunc_colorProperty), METH_O, nullptr},
    {"doubleProperty", reinterpret_cast<PyCFunction>(Sbk_QTextFormatFunc_doubleProperty), METH_O, nullptr},
    {"foreground", reinterpret_cast<PyCFunction>(Sbk_QTextFormatFunc_foreground), METH_NOARGS, nullptr},
    {"hasProperty", reinterpret_cast<PyCFunction>(Sbk_QTextFormatFunc_hasProperty), METH_O, nullptr},
    {"intProperty", reinterpret_cast<PyCFunction>(Sbk_QTextFormatFunc_intProperty), METH_O, nullptr},
    {"isBlockFormat", reinterpret_cast<PyCFunction>(Sbk_QTextFormatFunc_isBlockFormat), METH_NOARGS, nullptr},
    {"isCharFormat", reinterpret_cast<PyCFunction>(Sbk_QTextFormatFunc_isCharFormat), METH_NOARGS, nullptr},
    {"isEmpty", reinterpret_cast<PyCFunction>(Sbk_QTextFormatFunc_isEmpty), METH_NOARGS, nullptr},
    {"isFrameFormat", reinterpret_cast<PyCFunction>(Sbk_QTextFormatFunc_isFrameFormat), METH_NOARGS, nullptr},
    {"isImageFormat", reinterpret_cast<PyCFunction>(Sbk_QTextFormatFunc_isImageFormat), METH_NOARGS, nullptr},
    {"isListFormat", reinterpret_cast<PyCFunction>(Sbk_QTextFormatFunc_isListFormat), METH_NOARGS, nullptr},
    {"isTableCellFormat", reinterpret_cast<PyCFunction>(Sbk_QTextFormatFunc_isTableCellFormat), METH_NOARGS, nullptr},
    {"isTableFormat", reinterpret_cast<PyCFunction>(Sbk_QTextFormatFunc_isTableFormat), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QTextFormatFunc_isValid), METH_NOARGS, nullptr},
    {"layoutDirection", reinterpret_cast<PyCFunction>(Sbk_QTextFormatFunc_layoutDirection), METH_NOARGS, nullptr},
    {"lengthProperty", reinterpret_cast<PyCFunction>(Sbk_QTextFormatFunc_lengthProperty), METH_O, nullptr},
    {"lengthVectorProperty", reinterpret_cast<PyCFunction>(Sbk_QTextFormatFunc_lengthVectorProperty), METH_O, nullptr},
    {"merge", reinterpret_cast<PyCFunction>(Sbk_QTextFormatFunc_merge), METH_O, nullptr},
    {"objectIndex", reinterpret_cast<PyCFunction>(Sbk_QTextFormatFunc_objectIndex), METH_NOARGS, nullptr},
    {"objectType", reinterpret_cast<PyCFunction>(Sbk_QTextFormatFunc_objectType), METH_NOARGS, nullptr},
    {"penProperty", reinterpret_cast<PyCFunction>(Sbk_QTextFormatFunc_penProperty), METH_O, nullptr},
    {"properties", reinterpret_cast<PyCFunction>(Sbk_QTextFormatFunc_properties), METH_NOARGS, nullptr},
    {"property", reinterpret_cast<PyCFunction>(Sbk_QTextFormatFunc_property), METH_O, nullptr},
    {"propertyCount", reinterpret_cast<PyCFunction>(Sbk_QTextFormatFunc_propertyCount), METH_NOARGS, nullptr},
    {"setBackground", reinterpret_cast<PyCFunction>(Sbk_QTextFormatFunc_setBackground), METH_O, nullptr},
    {"setForeground", reinterpret_cast<PyCFunction>(Sbk_QTextFormatFunc_setForeground), METH_O, nullptr},
    {"setLayoutDirection", reinterpret_cast<PyCFunction>(Sbk_QTextFormatFunc_setLayoutDirection), METH_O, nullptr},
    {"setObjectIndex", reinterpret_cast<PyCFunction>(Sbk_QTextFormatFunc_setObjectIndex), METH_O, nullptr},
    {"setObjectType", reinterpret_cast<PyCFunction>(Sbk_QTextFormatFunc_setObjectType), METH_O, nullptr},
    {"setProperty", reinterpret_cast<PyCFunction>(Sbk_QTextFormatFunc_setProperty), METH_VARARGS, nullptr},
    {"stringProperty", reinterpret_cast<PyCFunction>(Sbk_QTextFormatFunc_stringProperty), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QTextFormatFunc_swap), METH_O, nullptr},
    {"toBlockFormat", reinterpret_cast<PyCFunction>(Sbk_QTextFormatFunc_toBlockFormat), METH_NOARGS, nullptr},
    {"toCharFormat", reinterpret_cast<PyCFunction>(Sbk_QTextFormatFunc_toCharFormat), METH_NOARGS, nullptr},
    {"toFrameFormat", reinterpret_cast<PyCFunction>(Sbk_QTextFormatFunc_toFrameFormat), METH_NOARGS, nullptr},
    {"toImageFormat", reinterpret_cast<PyCFunction>(Sbk_QTextFormatFunc_toImageFormat), METH_NOARGS, nullptr},
    {"toListFormat", reinterpret_cast<PyCFunction>(Sbk_QTextFormatFunc_toListFormat), METH_NOARGS, nullptr},
    {"toTableCellFormat", reinterpret_cast<PyCFunction>(Sbk_QTextFormatFunc_toTableCellFormat), METH_NOARGS, nullptr},
    {"toTableFormat", reinterpret_cast<PyCFunction>(Sbk_QTextFormatFunc_toTableFormat), METH_NOARGS, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QTextFormatFunc_type), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QTextFormat__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QTextFormat_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), (pyArg)))) {
                // operator!=(const QTextFormat &rhs) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QTextFormat cppArg0_local;
                ::QTextFormat *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), (pyArg)))) {
                // operator==(const QTextFormat &rhs) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QTextFormat cppArg0_local;
                ::QTextFormat *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QTextFormat_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QTextFormat_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QTextFormat__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QTextFormat_Type = nullptr;
static PyTypeObject *Sbk_QTextFormat_TypeF(void)
{
    return _Sbk_QTextFormat_Type;
}

static PyType_Slot Sbk_QTextFormat_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QTextFormat__repr__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QTextFormat_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QTextFormat_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QTextFormat_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QTextFormat_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QTextFormat_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QTextFormat_spec = {
    "2:PySide6.QtGui.QTextFormat",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QTextFormat_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QTextFormat_FormatType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QTextFormat::FormatType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QTextFormat::FormatType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QTextFormat_FormatType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_FormatType_IDX])))
        return Enum_PythonToCpp_QTextFormat_FormatType;
    return {};
}

static PyObject *QTextFormat_FormatType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QTextFormat::FormatType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QTextFormat::FormatType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_FormatType_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QTextFormat_Property(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QTextFormat::Property>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QTextFormat::Property *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QTextFormat_Property_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_Property_IDX])))
        return Enum_PythonToCpp_QTextFormat_Property;
    return {};
}

static PyObject *QTextFormat_Property_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QTextFormat::Property>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QTextFormat::Property *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_Property_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QTextFormat_ObjectTypes(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QTextFormat::ObjectTypes>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QTextFormat::ObjectTypes *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QTextFormat_ObjectTypes_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_ObjectTypes_IDX])))
        return Enum_PythonToCpp_QTextFormat_ObjectTypes;
    return {};
}

static PyObject *QTextFormat_ObjectTypes_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QTextFormat::ObjectTypes>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QTextFormat::ObjectTypes *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_ObjectTypes_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QTextFormat_PageBreakFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QTextFormat::PageBreakFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QTextFormat::PageBreakFlag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QTextFormat_PageBreakFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_PageBreakFlag_IDX])))
        return Enum_PythonToCpp_QTextFormat_PageBreakFlag;
    return {};
}

static PyObject *QTextFormat_PageBreakFlag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QTextFormat::PageBreakFlag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QTextFormat::PageBreakFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_PageBreakFlag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QTextFormat_PageBreakFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QTextFormat::PageBreakFlag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QTextFormat::PageBreakFlag> *>(cppOut) = value;

}

static PyObject *QTextFormat_PageBreakFlag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QTextFormat::PageBreakFlag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_PageBreakFlag_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QTextFormat_PythonToCpp_QTextFormat_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QTextFormat_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QTextFormat_PythonToCpp_QTextFormat_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QTextFormat_TypeF()))
        return QTextFormat_PythonToCpp_QTextFormat_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QTextFormat_PTR_CppToPython_QTextFormat(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QTextFormat_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QTextFormat_COPY_CppToPython_QTextFormat(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QTextFormat *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QTextFormat_TypeF(), new ::QTextFormat(*source), true, true);
}

// Python to C++ copy conversion.
static void QTextFormat_PythonToCpp_QTextFormat_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QTextFormat *>(cppOut) = *reinterpret_cast< ::QTextFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QTextFormat_PythonToCpp_QTextFormat_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QTextFormat_TypeF()))
        return QTextFormat_PythonToCpp_QTextFormat_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QTextFormat_SignatureStrings[] = {
    "2:PySide6.QtGui.QTextFormat(self)",
    "1:PySide6.QtGui.QTextFormat(self,rhs:PySide6.QtGui.QTextFormat)",
    "0:PySide6.QtGui.QTextFormat(self,type:int)",
    "PySide6.QtGui.QTextFormat.background(self)->PySide6.QtGui.QBrush",
    "PySide6.QtGui.QTextFormat.boolProperty(self,propertyId:int)->bool",
    "PySide6.QtGui.QTextFormat.brushProperty(self,propertyId:int)->PySide6.QtGui.QBrush",
    "PySide6.QtGui.QTextFormat.clearBackground(self)",
    "PySide6.QtGui.QTextFormat.clearForeground(self)",
    "PySide6.QtGui.QTextFormat.clearProperty(self,propertyId:int)",
    "PySide6.QtGui.QTextFormat.colorProperty(self,propertyId:int)->PySide6.QtGui.QColor",
    "PySide6.QtGui.QTextFormat.doubleProperty(self,propertyId:int)->qreal",
    "PySide6.QtGui.QTextFormat.foreground(self)->PySide6.QtGui.QBrush",
    "PySide6.QtGui.QTextFormat.hasProperty(self,propertyId:int)->bool",
    "PySide6.QtGui.QTextFormat.intProperty(self,propertyId:int)->int",
    "PySide6.QtGui.QTextFormat.isBlockFormat(self)->bool",
    "PySide6.QtGui.QTextFormat.isCharFormat(self)->bool",
    "PySide6.QtGui.QTextFormat.isEmpty(self)->bool",
    "PySide6.QtGui.QTextFormat.isFrameFormat(self)->bool",
    "PySide6.QtGui.QTextFormat.isImageFormat(self)->bool",
    "PySide6.QtGui.QTextFormat.isListFormat(self)->bool",
    "PySide6.QtGui.QTextFormat.isTableCellFormat(self)->bool",
    "PySide6.QtGui.QTextFormat.isTableFormat(self)->bool",
    "PySide6.QtGui.QTextFormat.isValid(self)->bool",
    "PySide6.QtGui.QTextFormat.layoutDirection(self)->PySide6.QtCore.Qt.LayoutDirection",
    "PySide6.QtGui.QTextFormat.lengthProperty(self,propertyId:int)->PySide6.QtGui.QTextLength",
    "PySide6.QtGui.QTextFormat.lengthVectorProperty(self,propertyId:int)->QList[PySide6.QtGui.QTextLength]",
    "PySide6.QtGui.QTextFormat.merge(self,other:PySide6.QtGui.QTextFormat)",
    "PySide6.QtGui.QTextFormat.objectIndex(self)->int",
    "PySide6.QtGui.QTextFormat.objectType(self)->int",
    "PySide6.QtGui.QTextFormat.penProperty(self,propertyId:int)->PySide6.QtGui.QPen",
    "PySide6.QtGui.QTextFormat.properties(self)->QMap[int, QVariant]",
    "PySide6.QtGui.QTextFormat.property(self,propertyId:int)->QVariant",
    "PySide6.QtGui.QTextFormat.propertyCount(self)->int",
    "PySide6.QtGui.QTextFormat.setBackground(self,brush:typing.Union[PySide6.QtGui.QBrush, PySide6.QtCore.Qt.BrushStyle, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor, PySide6.QtGui.QGradient, PySide6.QtGui.QImage, PySide6.QtGui.QPixmap])",
    "PySide6.QtGui.QTextFormat.setForeground(self,brush:typing.Union[PySide6.QtGui.QBrush, PySide6.QtCore.Qt.BrushStyle, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor, PySide6.QtGui.QGradient, PySide6.QtGui.QImage, PySide6.QtGui.QPixmap])",
    "PySide6.QtGui.QTextFormat.setLayoutDirection(self,direction:PySide6.QtCore.Qt.LayoutDirection)",
    "PySide6.QtGui.QTextFormat.setObjectIndex(self,object:int)",
    "PySide6.QtGui.QTextFormat.setObjectType(self,type:int)",
    "1:PySide6.QtGui.QTextFormat.setProperty(self,propertyId:int,lengths:QList[PySide6.QtGui.QTextLength])",
    "0:PySide6.QtGui.QTextFormat.setProperty(self,propertyId:int,value:QVariant)",
    "PySide6.QtGui.QTextFormat.stringProperty(self,propertyId:int)->QString",
    "PySide6.QtGui.QTextFormat.swap(self,other:PySide6.QtGui.QTextFormat)",
    "PySide6.QtGui.QTextFormat.toBlockFormat(self)->PySide6.QtGui.QTextBlockFormat",
    "PySide6.QtGui.QTextFormat.toCharFormat(self)->PySide6.QtGui.QTextCharFormat",
    "PySide6.QtGui.QTextFormat.toFrameFormat(self)->PySide6.QtGui.QTextFrameFormat",
    "PySide6.QtGui.QTextFormat.toImageFormat(self)->PySide6.QtGui.QTextImageFormat",
    "PySide6.QtGui.QTextFormat.toListFormat(self)->PySide6.QtGui.QTextListFormat",
    "PySide6.QtGui.QTextFormat.toTableCellFormat(self)->PySide6.QtGui.QTextTableCellFormat",
    "PySide6.QtGui.QTextFormat.toTableFormat(self)->PySide6.QtGui.QTextTableFormat",
    "PySide6.QtGui.QTextFormat.type(self)->int",
    "PySide6.QtGui.QTextFormat.__copy__(self)->typing.Self",
    "PySide6.QtGui.QTextFormat.__ne__(self,rhs:PySide6.QtGui.QTextFormat)->bool",
    "PySide6.QtGui.QTextFormat.__eq__(self,rhs:PySide6.QtGui.QTextFormat)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QTextFormat_SignatureByteSize = 614;
static constexpr uint8_t QTextFormat_SignatureBytes[614] = {
    0x78, 0xda, 0xdd, 0x57, 0x4d, 0x8f, 0xda, 0x30, 0x10, 0xbd, 0xef, 0xaf, 0xd8, 0x63, 0x91, 0xb2,
    0xa8, 0xed, 0xa1, 0x87, 0x1c, 0xf6, 0x40, 0xb6, 0x8b, 0x90, 0xa8, 0x0a, 0x82, 0x72, 0x41, 0x28,
    0x32, 0x64, 0x36, 0xb8, 0xeb, 0xc4, 0x59, 0xc7, 0x69, 0xc9, 0xbf, 0xaf, 0xf3, 0x05, 0x69, 0xe2,
    0x8c, 0xe3, 0xee, 0xad, 0x17, 0x20, 0xf1, 0x7b, 0x6f, 0xc6, 0xf6, 0x7c, 0xf1, 0xd9, 0x5d, 0xe5,
    0x1b, 0x1a, 0xc0, 0x97, 0xe9, 0x5a, 0xce, 0x33, 0x3a, 0x5d, 0x6f, 0xe1, 0x22, 0x9f, 0xb9, 0x88,
    0x88, 0xfc, 0x90, 0x02, 0x7b, 0x99, 0xdc, 0x7d, 0x32, 0x20, 0x1c, 0x71, 0x4e, 0x87, 0x21, 0x93,
    0xbb, 0x8f, 0x26, 0xbe, 0xcc, 0x13, 0x70, 0x69, 0xac, 0xa0, 0x83, 0xc0, 0xe9, 0x91, 0x9c, 0x5e,
    0x43, 0xc1, 0xb3, 0x38, 0xa8, 0xbc, 0x7a, 0x78, 0xec, 0x60, 0x67, 0x22, 0x4b, 0xcf, 0x98, 0x00,
    0xe7, 0x6c, 0x25, 0x78, 0x02, 0x42, 0xe6, 0x95, 0xd9, 0xa4, 0x7e, 0x5a, 0x04, 0xa5, 0xf1, 0x87,
    0xc7, 0x02, 0x82, 0x29, 0x14, 0x16, 0x0c, 0x12, 0x96, 0x4e, 0x9d, 0x18, 0x10, 0x31, 0xeb, 0x6c,
    0xcd, 0x84, 0x57, 0xbf, 0xc1, 0x06, 0x8f, 0xba, 0x8c, 0x91, 0x39, 0xe3, 0xc2, 0x6e, 0xbf, 0x5e,
    0x41, 0x41, 0x24, 0x03, 0x9e, 0x1d, 0x19, 0x18, 0x34, 0xdf, 0x04, 0x10, 0xec, 0x1e, 0x5e, 0x3a,
    0xfb, 0xb7, 0x3e, 0xf5, 0x33, 0x49, 0xdf, 0x17, 0x09, 0x0a, 0x64, 0x10, 0x50, 0x9f, 0x18, 0x3f,
    0x9d, 0x31, 0x7e, 0x7a, 0x6d, 0x67, 0x99, 0xd9, 0x66, 0xea, 0x9d, 0xcb, 0xbb, 0xb7, 0xa1, 0x7c,
    0x8d, 0x92, 0xda, 0xc5, 0x31, 0xe8, 0x67, 0x41, 0x22, 0xb0, 0xb4, 0xb0, 0x88, 0x48, 0x68, 0xcb,
    0x59, 0xd2, 0x54, 0x5a, 0x52, 0xb6, 0x44, 0xc5, 0x8d, 0x07, 0x8c, 0xfd, 0x0b, 0xcf, 0x92, 0xb3,
    0x23, 0x8c, 0x06, 0x23, 0xd1, 0x8c, 0xe4, 0x3c, 0x93, 0x4f, 0x54, 0xc0, 0x49, 0x52, 0x1e, 0xf7,
    0x03, 0xd2, 0x53, 0xc1, 0xaa, 0xbe, 0xa6, 0xcb, 0xbf, 0x81, 0x98, 0x24, 0xc4, 0xa1, 0xb4, 0xac,
    0x33, 0x05, 0x7d, 0x59, 0xf2, 0x8c, 0xc2, 0x3b, 0xe5, 0x80, 0x31, 0xad, 0xd7, 0xc5, 0x15, 0xed,
    0x07, 0x8d, 0x1c, 0x10, 0x2b, 0x11, 0x88, 0x10, 0x2a, 0x59, 0x2e, 0xcf, 0x20, 0xb0, 0xce, 0x30,
    0xac, 0xc2, 0x8f, 0x3f, 0x95, 0x9f, 0x8b, 0x38, 0x80, 0x4b, 0x73, 0xa6, 0x78, 0x4a, 0x55, 0x84,
    0xad, 0xea, 0x24, 0xe3, 0xf0, 0x09, 0xc4, 0x76, 0x47, 0xbc, 0x02, 0xec, 0xd2, 0x6a, 0x36, 0x85,
    0xb4, 0x31, 0xbf, 0xfe, 0x46, 0x92, 0xbd, 0x52, 0x72, 0xee, 0xd7, 0x3b, 0x22, 0x28, 0x89, 0xe5,
    0xc1, 0xcc, 0x1f, 0xbc, 0x8f, 0x5a, 0x62, 0x84, 0x82, 0xa7, 0x0a, 0xa3, 0x1c, 0x77, 0x06, 0x29,
    0xc8, 0x4e, 0xef, 0x71, 0xca, 0x1e, 0xe7, 0xaa, 0x86, 0x4c, 0xe3, 0x70, 0xfa, 0x23, 0x56, 0x91,
    0xba, 0xd7, 0x15, 0x57, 0xe7, 0xbe, 0x1f, 0xe1, 0xe5, 0xc2, 0x46, 0xe6, 0x0c, 0x74, 0xab, 0x73,
    0xc6, 0x8f, 0x84, 0x95, 0xfd, 0xa1, 0xbd, 0x7c, 0xeb, 0x1a, 0xbd, 0xb7, 0x73, 0x41, 0x02, 0x0a,
    0xc5, 0x01, 0x76, 0x16, 0xca, 0x92, 0xd3, 0x7b, 0xbb, 0xa2, 0x97, 0x88, 0x24, 0x87, 0x09, 0xbe,
    0xdf, 0x4e, 0xef, 0xfc, 0xef, 0xf7, 0xbb, 0xd4, 0xd4, 0x27, 0x27, 0x68, 0x1e, 0x5d, 0x63, 0x9d,
    0x32, 0xc8, 0x7f, 0xef, 0xa4, 0xa9, 0x53, 0xa5, 0xa1, 0x69, 0xb2, 0xb8, 0x32, 0xaf, 0xf9, 0xda,
    0x9a, 0x01, 0x91, 0x71, 0xb3, 0x20, 0x62, 0x59, 0xeb, 0x54, 0x25, 0x2e, 0x75, 0x4d, 0xf5, 0x0b,
    0x1d, 0x4a, 0x8d, 0x56, 0x7e, 0x11, 0x96, 0x81, 0xdb, 0xe4, 0x24, 0xba, 0x51, 0x29, 0x54, 0x60,
    0x99, 0x8a, 0xed, 0xa6, 0x44, 0x61, 0x32, 0xbf, 0x49, 0xf2, 0xee, 0x92, 0x2a, 0xb9, 0x66, 0xe8,
    0xd0, 0xc0, 0x5b, 0x28, 0x54, 0xad, 0x3f, 0x8e, 0x68, 0xd0, 0x37, 0x10, 0xaa, 0xa5, 0x99, 0x3c,
    0x74, 0xf0, 0x1b, 0x0a, 0x55, 0xd3, 0xcc, 0x24, 0x1a, 0x78, 0x0b, 0x85, 0xaa, 0xf5, 0xa7, 0x15,
    0x5d, 0x5c, 0x5d, 0x41, 0xa8, 0xd6, 0xc0, 0x18, 0xa3, 0xa1, 0x74, 0x90, 0x66, 0xd5, 0x71, 0x8a,
    0x66, 0xb5, 0xd1, 0x1d, 0xd4, 0xf7, 0x4f, 0x3c, 0xc9, 0x7d, 0xbf, 0x41, 0xd7, 0x45, 0x74, 0xa3,
    0x9e, 0x50, 0x56, 0x0c, 0x35, 0xc7, 0xf0, 0xbf, 0xd1, 0x38, 0x7b, 0xf9, 0x3e, 0xbc, 0x59, 0x49,
    0xfd, 0x01, 0xa1, 0xc4, 0x61, 0x11
};
#endif

PyTypeObject *init_QTextFormat(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX].type;

    Shiboken::AutoDecRef Sbk_QTextFormat_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QTextFormat_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QTextFormat",
        "QTextFormat",
        &Sbk_QTextFormat_spec,
        &Shiboken::callCppDestructor< ::QTextFormat >,
        Sbk_QTextFormat_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QTextFormat_TypeF(); // references _Sbk_QTextFormat_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QTextFormat_SignatureStrings);
#else
    InitSignatureBytes(pyType, QTextFormat_SignatureBytes, QTextFormat_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QTextFormat_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QTextFormat_PythonToCpp_QTextFormat_PTR,
        is_QTextFormat_PythonToCpp_QTextFormat_PTR_Convertible,
        QTextFormat_PTR_CppToPython_QTextFormat,
        QTextFormat_COPY_CppToPython_QTextFormat);

    Shiboken::Conversions::registerConverterName(converter, "QTextFormat");
    Shiboken::Conversions::registerConverterName(converter, "QTextFormat*");
    Shiboken::Conversions::registerConverterName(converter, "QTextFormat&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QTextFormat).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QTextFormat_PythonToCpp_QTextFormat_COPY,
        is_QTextFormat_PythonToCpp_QTextFormat_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QTextFormat_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'FormatType'.
    const char *FormatType_Initializer[] = {
        "InvalidFormat",
        "BlockFormat",
        "CharFormat",
        "ListFormat",
        "FrameFormat",
        "UserFormat",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t FormatType_InitializerValues[] = {
        int8_t(QTextFormat::FormatType::InvalidFormat), // -0x01 -1
        int8_t(QTextFormat::FormatType::BlockFormat),   //  0x01  1
        int8_t(QTextFormat::FormatType::CharFormat),    //  0x02  2
        int8_t(QTextFormat::FormatType::ListFormat),    //  0x03  3
        int8_t(QTextFormat::FormatType::FrameFormat),   //  0x05  5
        int8_t(QTextFormat::FormatType::UserFormat)     //  0x64  100
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QTextFormat_TypeF(),
        "2:PySide6.QtGui.QTextFormat.FormatType",
        FormatType_Initializer, FormatType_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_FormatType_IDX].type = EType;
    // Register converter for enum 'QTextFormat::FormatType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QTextFormat_FormatType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QTextFormat_FormatType,
            is_Enum_PythonToCpp_QTextFormat_FormatType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QTextFormat::FormatType");
        Shiboken::Conversions::registerConverterAlias(converter, "FormatType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'FormatType' enum.

    // Initialization of enum 'Property'.
    const char *Property_Initializer[] = {
        "ObjectIndex",
        "CssFloat",
        "LayoutDirection",
        "OutlinePen",
        "BackgroundBrush",
        "ForegroundBrush",
        "BackgroundImageUrl",
        "BlockAlignment",
        "BlockTopMargin",
        "BlockBottomMargin",
        "BlockLeftMargin",
        "BlockRightMargin",
        "TextIndent",
        "TabPositions",
        "BlockIndent",
        "LineHeight",
        "LineHeightType",
        "BlockNonBreakableLines",
        "BlockTrailingHorizontalRulerWidth",
        "HeadingLevel",
        "BlockQuoteLevel",
        "BlockCodeLanguage",
        "BlockCodeFence",
        "BlockMarker",
        "FirstFontProperty",
        "FontCapitalization",
        "FontLetterSpacing",
        "FontWordSpacing",
        "FontStyleHint",
        "FontStyleStrategy",
        "FontKerning",
        "FontHintingPreference",
        "FontFamilies",
        "FontStyleName",
        "FontLetterSpacingType",
        "FontStretch",
        "FontFamily",
        "FontPointSize",
        "FontSizeAdjustment",
        "FontSizeIncrement",
        "FontWeight",
        "FontItalic",
        "FontUnderline",
        "FontOverline",
        "FontStrikeOut",
        "FontFixedPitch",
        "FontPixelSize",
        "LastFontProperty",
        "TextUnderlineColor",
        "TextVerticalAlignment",
        "TextOutline",
        "TextUnderlineStyle",
        "TextToolTip",
        "TextSuperScriptBaseline",
        "TextSubScriptBaseline",
        "TextBaselineOffset",
        "IsAnchor",
        "AnchorHref",
        "AnchorName",
        "OldFontLetterSpacingType",
        "OldFontStretch",
        "OldTextUnderlineColor",
        "OldFontFamily",
        "ObjectType",
        "ListStyle",
        "ListIndent",
        "ListNumberPrefix",
        "ListNumberSuffix",
        "ListStart",
        "FrameBorder",
        "FrameMargin",
        "FramePadding",
        "FrameWidth",
        "FrameHeight",
        "FrameTopMargin",
        "FrameBottomMargin",
        "FrameLeftMargin",
        "FrameRightMargin",
        "FrameBorderBrush",
        "FrameBorderStyle",
        "TableColumns",
        "TableColumnWidthConstraints",
        "TableCellSpacing",
        "TableCellPadding",
        "TableHeaderRowCount",
        "TableBorderCollapse",
        "TableCellRowSpan",
        "TableCellColumnSpan",
        "TableCellTopPadding",
        "TableCellBottomPadding",
        "TableCellLeftPadding",
        "TableCellRightPadding",
        "TableCellTopBorder",
        "TableCellBottomBorder",
        "TableCellLeftBorder",
        "TableCellRightBorder",
        "TableCellTopBorderStyle",
        "TableCellBottomBorderStyle",
        "TableCellLeftBorderStyle",
        "TableCellRightBorderStyle",
        "TableCellTopBorderBrush",
        "TableCellBottomBorderBrush",
        "TableCellLeftBorderBrush",
        "TableCellRightBorderBrush",
        "ImageName",
        "ImageTitle",
        "ImageAltText",
        "ImageWidth",
        "ImageHeight",
        "ImageQuality",
        "ImageMaxWidth",
        "FullWidthSelection",
        "PageBreakPolicy",
        "UserProperty",
        nullptr};
    // "uint32_t" used instead of "unsigned int"
    constexpr uint32_t Property_InitializerValues[] = {
        uint32_t(QTextFormat::Property::ObjectIndex),                       //  0x00000000  0
        uint32_t(QTextFormat::Property::CssFloat),                          //  0x00000800  2048
        uint32_t(QTextFormat::Property::LayoutDirection),                   //  0x00000801  2049
        uint32_t(QTextFormat::Property::OutlinePen),                        //  0x00000810  2064
        uint32_t(QTextFormat::Property::BackgroundBrush),                   //  0x00000820  2080
        uint32_t(QTextFormat::Property::ForegroundBrush),                   //  0x00000821  2081
        uint32_t(QTextFormat::Property::BackgroundImageUrl),                //  0x00000823  2083
        uint32_t(QTextFormat::Property::BlockAlignment),                    //  0x00001010  4112
        uint32_t(QTextFormat::Property::BlockTopMargin),                    //  0x00001030  4144
        uint32_t(QTextFormat::Property::BlockBottomMargin),                 //  0x00001031  4145
        uint32_t(QTextFormat::Property::BlockLeftMargin),                   //  0x00001032  4146
        uint32_t(QTextFormat::Property::BlockRightMargin),                  //  0x00001033  4147
        uint32_t(QTextFormat::Property::TextIndent),                        //  0x00001034  4148
        uint32_t(QTextFormat::Property::TabPositions),                      //  0x00001035  4149
        uint32_t(QTextFormat::Property::BlockIndent),                       //  0x00001040  4160
        uint32_t(QTextFormat::Property::LineHeight),                        //  0x00001048  4168
        uint32_t(QTextFormat::Property::LineHeightType),                    //  0x00001049  4169
        uint32_t(QTextFormat::Property::BlockNonBreakableLines),            //  0x00001050  4176
        uint32_t(QTextFormat::Property::BlockTrailingHorizontalRulerWidth), //  0x00001060  4192
        uint32_t(QTextFormat::Property::HeadingLevel),                      //  0x00001070  4208
        uint32_t(QTextFormat::Property::BlockQuoteLevel),                   //  0x00001080  4224
        uint32_t(QTextFormat::Property::BlockCodeLanguage),                 //  0x00001090  4240
        uint32_t(QTextFormat::Property::BlockCodeFence),                    //  0x00001091  4241
        uint32_t(QTextFormat::Property::BlockMarker),                       //  0x000010a0  4256
        uint32_t(QTextFormat::Property::FirstFontProperty),                 //  0x00001fe0  8160
        uint32_t(QTextFormat::Property::FontCapitalization),                //  0x00001fe0  8160
        uint32_t(QTextFormat::Property::FontLetterSpacing),                 //  0x00001fe1  8161
        uint32_t(QTextFormat::Property::FontWordSpacing),                   //  0x00001fe2  8162
        uint32_t(QTextFormat::Property::FontStyleHint),                     //  0x00001fe3  8163
        uint32_t(QTextFormat::Property::FontStyleStrategy),                 //  0x00001fe4  8164
        uint32_t(QTextFormat::Property::FontKerning),                       //  0x00001fe5  8165
        uint32_t(QTextFormat::Property::FontHintingPreference),             //  0x00001fe6  8166
        uint32_t(QTextFormat::Property::FontFamilies),                      //  0x00001fe7  8167
        uint32_t(QTextFormat::Property::FontStyleName),                     //  0x00001fe8  8168
        uint32_t(QTextFormat::Property::FontLetterSpacingType),             //  0x00001fe9  8169
        uint32_t(QTextFormat::Property::FontStretch),                       //  0x00001fea  8170
        uint32_t(QTextFormat::Property::FontFamily),                        //  0x00002000  8192
        uint32_t(QTextFormat::Property::FontPointSize),                     //  0x00002001  8193
        uint32_t(QTextFormat::Property::FontSizeAdjustment),                //  0x00002002  8194
        uint32_t(QTextFormat::Property::FontSizeIncrement),                 //  0x00002002  8194
        uint32_t(QTextFormat::Property::FontWeight),                        //  0x00002003  8195
        uint32_t(QTextFormat::Property::FontItalic),                        //  0x00002004  8196
        uint32_t(QTextFormat::Property::FontUnderline),                     //  0x00002005  8197
        uint32_t(QTextFormat::Property::FontOverline),                      //  0x00002006  8198
        uint32_t(QTextFormat::Property::FontStrikeOut),                     //  0x00002007  8199
        uint32_t(QTextFormat::Property::FontFixedPitch),                    //  0x00002008  8200
        uint32_t(QTextFormat::Property::FontPixelSize),                     //  0x00002009  8201
        uint32_t(QTextFormat::Property::LastFontProperty),                  //  0x00002009  8201
        uint32_t(QTextFormat::Property::TextUnderlineColor),                //  0x00002020  8224
        uint32_t(QTextFormat::Property::TextVerticalAlignment),             //  0x00002021  8225
        uint32_t(QTextFormat::Property::TextOutline),                       //  0x00002022  8226
        uint32_t(QTextFormat::Property::TextUnderlineStyle),                //  0x00002023  8227
        uint32_t(QTextFormat::Property::TextToolTip),                       //  0x00002024  8228
        uint32_t(QTextFormat::Property::TextSuperScriptBaseline),           //  0x00002025  8229
        uint32_t(QTextFormat::Property::TextSubScriptBaseline),             //  0x00002026  8230
        uint32_t(QTextFormat::Property::TextBaselineOffset),                //  0x00002027  8231
        uint32_t(QTextFormat::Property::IsAnchor),                          //  0x00002030  8240
        uint32_t(QTextFormat::Property::AnchorHref),                        //  0x00002031  8241
        uint32_t(QTextFormat::Property::AnchorName),                        //  0x00002032  8242
        uint32_t(QTextFormat::Property::OldFontLetterSpacingType),          //  0x00002033  8243
        uint32_t(QTextFormat::Property::OldFontStretch),                    //  0x00002034  8244
        uint32_t(QTextFormat::Property::OldTextUnderlineColor),             //  0x00002010  8208
        uint32_t(QTextFormat::Property::OldFontFamily),                     //  0x00002000  8192
        uint32_t(QTextFormat::Property::ObjectType),                        //  0x00002f00  12032
        uint32_t(QTextFormat::Property::ListStyle),                         //  0x00003000  12288
        uint32_t(QTextFormat::Property::ListIndent),                        //  0x00003001  12289
        uint32_t(QTextFormat::Property::ListNumberPrefix),                  //  0x00003002  12290
        uint32_t(QTextFormat::Property::ListNumberSuffix),                  //  0x00003003  12291
        uint32_t(QTextFormat::Property::ListStart),                         //  0x00003004  12292
        uint32_t(QTextFormat::Property::FrameBorder),                       //  0x00004000  16384
        uint32_t(QTextFormat::Property::FrameMargin),                       //  0x00004001  16385
        uint32_t(QTextFormat::Property::FramePadding),                      //  0x00004002  16386
        uint32_t(QTextFormat::Property::FrameWidth),                        //  0x00004003  16387
        uint32_t(QTextFormat::Property::FrameHeight),                       //  0x00004004  16388
        uint32_t(QTextFormat::Property::FrameTopMargin),                    //  0x00004005  16389
        uint32_t(QTextFormat::Property::FrameBottomMargin),                 //  0x00004006  16390
        uint32_t(QTextFormat::Property::FrameLeftMargin),                   //  0x00004007  16391
        uint32_t(QTextFormat::Property::FrameRightMargin),                  //  0x00004008  16392
        uint32_t(QTextFormat::Property::FrameBorderBrush),                  //  0x00004009  16393
        uint32_t(QTextFormat::Property::FrameBorderStyle),                  //  0x00004010  16400
        uint32_t(QTextFormat::Property::TableColumns),                      //  0x00004100  16640
        uint32_t(QTextFormat::Property::TableColumnWidthConstraints),       //  0x00004101  16641
        uint32_t(QTextFormat::Property::TableCellSpacing),                  //  0x00004102  16642
        uint32_t(QTextFormat::Property::TableCellPadding),                  //  0x00004103  16643
        uint32_t(QTextFormat::Property::TableHeaderRowCount),               //  0x00004104  16644
        uint32_t(QTextFormat::Property::TableBorderCollapse),               //  0x00004105  16645
        uint32_t(QTextFormat::Property::TableCellRowSpan),                  //  0x00004810  18448
        uint32_t(QTextFormat::Property::TableCellColumnSpan),               //  0x00004811  18449
        uint32_t(QTextFormat::Property::TableCellTopPadding),               //  0x00004812  18450
        uint32_t(QTextFormat::Property::TableCellBottomPadding),            //  0x00004813  18451
        uint32_t(QTextFormat::Property::TableCellLeftPadding),              //  0x00004814  18452
        uint32_t(QTextFormat::Property::TableCellRightPadding),             //  0x00004815  18453
        uint32_t(QTextFormat::Property::TableCellTopBorder),                //  0x00004816  18454
        uint32_t(QTextFormat::Property::TableCellBottomBorder),             //  0x00004817  18455
        uint32_t(QTextFormat::Property::TableCellLeftBorder),               //  0x00004818  18456
        uint32_t(QTextFormat::Property::TableCellRightBorder),              //  0x00004819  18457
        uint32_t(QTextFormat::Property::TableCellTopBorderStyle),           //  0x0000481a  18458
        uint32_t(QTextFormat::Property::TableCellBottomBorderStyle),        //  0x0000481b  18459
        uint32_t(QTextFormat::Property::TableCellLeftBorderStyle),          //  0x0000481c  18460
        uint32_t(QTextFormat::Property::TableCellRightBorderStyle),         //  0x0000481d  18461
        uint32_t(QTextFormat::Property::TableCellTopBorderBrush),           //  0x0000481e  18462
        uint32_t(QTextFormat::Property::TableCellBottomBorderBrush),        //  0x0000481f  18463
        uint32_t(QTextFormat::Property::TableCellLeftBorderBrush),          //  0x00004820  18464
        uint32_t(QTextFormat::Property::TableCellRightBorderBrush),         //  0x00004821  18465
        uint32_t(QTextFormat::Property::ImageName),                         //  0x00005000  20480
        uint32_t(QTextFormat::Property::ImageTitle),                        //  0x00005001  20481
        uint32_t(QTextFormat::Property::ImageAltText),                      //  0x00005002  20482
        uint32_t(QTextFormat::Property::ImageWidth),                        //  0x00005010  20496
        uint32_t(QTextFormat::Property::ImageHeight),                       //  0x00005011  20497
        uint32_t(QTextFormat::Property::ImageQuality),                      //  0x00005014  20500
        uint32_t(QTextFormat::Property::ImageMaxWidth),                     //  0x00005015  20501
        uint32_t(QTextFormat::Property::FullWidthSelection),                //  0x00006000  24576
        uint32_t(QTextFormat::Property::PageBreakPolicy),                   //  0x00007000  28672
        uint32_t(QTextFormat::Property::UserProperty)                       //  0x00100000  1048576
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QTextFormat_TypeF(),
        "2:PySide6.QtGui.QTextFormat.Property",
        Property_Initializer, Property_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_Property_IDX].type = EType;
    // Register converter for enum 'QTextFormat::Property'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QTextFormat_Property_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QTextFormat_Property,
            is_Enum_PythonToCpp_QTextFormat_Property_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QTextFormat::Property");
        Shiboken::Conversions::registerConverterAlias(converter, "Property");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Property' enum.

    // Initialization of enum 'ObjectTypes'.
    const char *ObjectTypes_Initializer[] = {
        "NoObject",
        "ImageObject",
        "TableObject",
        "TableCellObject",
        "UserObject",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t ObjectTypes_InitializerValues[] = {
        uint16_t(QTextFormat::ObjectTypes::NoObject),        //  0x0000  0
        uint16_t(QTextFormat::ObjectTypes::ImageObject),     //  0x0001  1
        uint16_t(QTextFormat::ObjectTypes::TableObject),     //  0x0002  2
        uint16_t(QTextFormat::ObjectTypes::TableCellObject), //  0x0003  3
        uint16_t(QTextFormat::ObjectTypes::UserObject)       //  0x1000  4096
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QTextFormat_TypeF(),
        "2:PySide6.QtGui.QTextFormat.ObjectTypes",
        ObjectTypes_Initializer, ObjectTypes_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_ObjectTypes_IDX].type = EType;
    // Register converter for enum 'QTextFormat::ObjectTypes'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QTextFormat_ObjectTypes_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QTextFormat_ObjectTypes,
            is_Enum_PythonToCpp_QTextFormat_ObjectTypes_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QTextFormat::ObjectTypes");
        Shiboken::Conversions::registerConverterAlias(converter, "ObjectTypes");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ObjectTypes' enum.

    // Initialization of enum 'PageBreakFlag'.
    const char *PageBreakFlag_Initializer[] = {
        "PageBreak_Auto",
        "PageBreak_AlwaysBefore",
        "PageBreak_AlwaysAfter",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t PageBreakFlag_InitializerValues[] = {
        uint8_t(QTextFormat::PageBreakFlag::PageBreak_Auto),         //  0x00  0
        uint8_t(QTextFormat::PageBreakFlag::PageBreak_AlwaysBefore), //  0x01  1
        uint8_t(QTextFormat::PageBreakFlag::PageBreak_AlwaysAfter)   //  0x10  16
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QTextFormat_TypeF(),
        "2:PySide6.QtGui.QTextFormat.PageBreakFlag",
        PageBreakFlag_Initializer, PageBreakFlag_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_PageBreakFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QTextFormat_PageBreakFlag_IDX].type =
        EType;
    // Register converter for enum 'QTextFormat::PageBreakFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QTextFormat_PageBreakFlag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QTextFormat_PageBreakFlag,
            is_Enum_PythonToCpp_QTextFormat_PageBreakFlag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QTextFormat::PageBreakFlag");
        Shiboken::Conversions::registerConverterAlias(converter, "PageBreakFlag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QTextFormat_PageBreakFlag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QTextFormat_PageBreakFlag,
            is_Enum_PythonToCpp_QTextFormat_PageBreakFlag_Convertible);
        // Register converter for flag 'QFlags<QTextFormat::PageBreakFlag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QTextFormat::PageBreakFlag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QTextFormat::PageBreakFlags");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'PageBreakFlag' enum/flags.

    qRegisterMetaType< ::QTextFormat >("QTextFormat");
    qRegisterMetaType< ::QTextFormat::FormatType >("QTextFormat::FormatType");
    qRegisterMetaType< ::QTextFormat::Property >("QTextFormat::Property");
    qRegisterMetaType< ::QTextFormat::ObjectTypes >("QTextFormat::ObjectTypes");
    qRegisterMetaType< ::QTextFormat::PageBreakFlag >("QTextFormat::PageBreakFlag");

    return pyType;
}
