// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qtextfragment_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtGui/qglyphrun.h>
#include <QtGui/qtextformat.h>
#include <QtGui/qtextobject.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTextFragment_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QTextFragment >()))
        return -1;

    ::QTextFragment *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QTextFragment", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QTextFragment::QTextFragment()
    // 1: QTextFragment::QTextFragment(QTextFragment)
    if (numArgs == 0) {
        overloadId = 0; // QTextFragment()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFragment_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QTextFragment(QTextFragment)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextFragment_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QTextFragment_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QTextFragment()
        {

            // QTextFragment()
            cptr = new ::QTextFragment();
            break;
        }
        case 1: // QTextFragment(const QTextFragment &o)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QTextFragment cppArg0_local;
            ::QTextFragment *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QTextFragment(QTextFragment)
                cptr = new ::QTextFragment(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QTextFragment >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextFragment_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QTextFragmentFunc_charFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFragment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFragment_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // charFormat()const
        QTextCharFormat cppResult = const_cast<const ::QTextFragment *>(cppSelf)->charFormat();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextFragmentFunc_charFormatIndex(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFragment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFragment_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // charFormatIndex()const
        int cppResult = const_cast<const ::QTextFragment *>(cppSelf)->charFormatIndex();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextFragmentFunc_contains(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFragment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFragment_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextFragment::contains(int)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // contains(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "contains", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextFragment_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // contains(int)const
            bool cppResult = const_cast<const ::QTextFragment *>(cppSelf)->contains(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextFragmentFunc_glyphRuns(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFragment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFragment_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "glyphRuns", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextFragment_IDX]);

    if (PyArg_ParseTuple(args, "|OO:glyphRuns", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTextFragment::glyphRuns(int=,int=)const->QList<QGlyphRun>
    if (numArgs == 0) {
        overloadId = 0; // glyphRuns(int,int)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // glyphRuns(int,int)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 0; // glyphRuns(int,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glyphRuns", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextFragment_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_from = Shiboken::String::createStaticString("from");
            if (PyDict_Contains(kwds, key_from) != 0) {
                value = PyDict_GetItem(kwds, key_from);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_from);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "glyphRuns", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextFragment_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "glyphRuns", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextFragment_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_from);
            }
            static PyObject *const key_length = Shiboken::String::createStaticString("length");
            if (PyDict_Contains(kwds, key_length) != 0) {
                value = PyDict_GetItem(kwds, key_length);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_length);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "glyphRuns", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextFragment_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "glyphRuns", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextFragment_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_length);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "glyphRuns", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextFragment_IDX]);
            }
        }
        int cppArg0 = -1;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1 = -1;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glyphRuns(int,int)const
            QList<QGlyphRun> cppResult = const_cast<const ::QTextFragment *>(cppSelf)->glyphRuns(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QGlyphRun_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextFragmentFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFragment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFragment_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QTextFragment *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextFragmentFunc_length(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFragment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFragment_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // length()const
        int cppResult = const_cast<const ::QTextFragment *>(cppSelf)->length();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextFragmentFunc_position(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFragment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFragment_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // position()const
        int cppResult = const_cast<const ::QTextFragment *>(cppSelf)->position();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextFragmentFunc_text(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextFragment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFragment_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // text()const
        QString cppResult = const_cast<const ::QTextFragment *>(cppSelf)->text();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextFragment__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QTextFragment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFragment_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFragment_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QTextFragment_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QTextFragment_methods[] = {
    {"charFormat", reinterpret_cast<PyCFunction>(Sbk_QTextFragmentFunc_charFormat), METH_NOARGS, nullptr},
    {"charFormatIndex", reinterpret_cast<PyCFunction>(Sbk_QTextFragmentFunc_charFormatIndex), METH_NOARGS, nullptr},
    {"contains", reinterpret_cast<PyCFunction>(Sbk_QTextFragmentFunc_contains), METH_O, nullptr},
    {"glyphRuns", reinterpret_cast<PyCFunction>(Sbk_QTextFragmentFunc_glyphRuns), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QTextFragmentFunc_isValid), METH_NOARGS, nullptr},
    {"length", reinterpret_cast<PyCFunction>(Sbk_QTextFragmentFunc_length), METH_NOARGS, nullptr},
    {"position", reinterpret_cast<PyCFunction>(Sbk_QTextFragmentFunc_position), METH_NOARGS, nullptr},
    {"text", reinterpret_cast<PyCFunction>(Sbk_QTextFragmentFunc_text), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QTextFragment__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QTextFragment_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QTextFragment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFragment_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFragment_IDX]), (pyArg)))) {
                // operator!=(const QTextFragment &o) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QTextFragment cppArg0_local;
                ::QTextFragment *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_LT:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFragment_IDX]), (pyArg)))) {
                // operator<(const QTextFragment &o) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QTextFragment cppArg0_local;
                ::QTextFragment *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf < (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFragment_IDX]), (pyArg)))) {
                // operator==(const QTextFragment &o) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QTextFragment cppArg0_local;
                ::QTextFragment *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QTextFragment_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QTextFragment_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QTextFragment_Type = nullptr;
static PyTypeObject *Sbk_QTextFragment_TypeF(void)
{
    return _Sbk_QTextFragment_Type;
}

static PyType_Slot Sbk_QTextFragment_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QTextFragment_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QTextFragment_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QTextFragment_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QTextFragment_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QTextFragment_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QTextFragment_spec = {
    "2:PySide6.QtGui.QTextFragment",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QTextFragment_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QTextFragment_PythonToCpp_QTextFragment_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QTextFragment_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QTextFragment_PythonToCpp_QTextFragment_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QTextFragment_TypeF()))
        return QTextFragment_PythonToCpp_QTextFragment_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QTextFragment_PTR_CppToPython_QTextFragment(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QTextFragment_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QTextFragment_COPY_CppToPython_QTextFragment(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QTextFragment *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QTextFragment_TypeF(), new ::QTextFragment(*source), true, true);
}

// Python to C++ copy conversion.
static void QTextFragment_PythonToCpp_QTextFragment_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QTextFragment *>(cppOut) = *reinterpret_cast< ::QTextFragment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFragment_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QTextFragment_PythonToCpp_QTextFragment_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QTextFragment_TypeF()))
        return QTextFragment_PythonToCpp_QTextFragment_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QTextFragment_SignatureStrings[] = {
    "1:PySide6.QtGui.QTextFragment(self)",
    "0:PySide6.QtGui.QTextFragment(self,o:PySide6.QtGui.QTextFragment)",
    "PySide6.QtGui.QTextFragment.charFormat(self)->PySide6.QtGui.QTextCharFormat",
    "PySide6.QtGui.QTextFragment.charFormatIndex(self)->int",
    "PySide6.QtGui.QTextFragment.contains(self,position:int)->bool",
    "PySide6.QtGui.QTextFragment.glyphRuns(self,from:int=-1,length:int=-1)->QList[PySide6.QtGui.QGlyphRun]",
    "PySide6.QtGui.QTextFragment.isValid(self)->bool",
    "PySide6.QtGui.QTextFragment.length(self)->int",
    "PySide6.QtGui.QTextFragment.position(self)->int",
    "PySide6.QtGui.QTextFragment.text(self)->QString",
    "PySide6.QtGui.QTextFragment.__copy__(self)->typing.Self",
    "PySide6.QtGui.QTextFragment.__ne__(self,o:PySide6.QtGui.QTextFragment)->bool",
    "PySide6.QtGui.QTextFragment.__lt__(self,o:PySide6.QtGui.QTextFragment)->bool",
    "PySide6.QtGui.QTextFragment.__eq__(self,o:PySide6.QtGui.QTextFragment)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QTextFragment_SignatureByteSize = 225;
static constexpr uint8_t QTextFragment_SignatureBytes[225] = {
    0x78, 0xda, 0xad, 0x92, 0xc1, 0x8a, 0xc2, 0x30, 0x10, 0x86, 0xef, 0x3e, 0x89, 0x82, 0x16, 0xbd,
    0x78, 0x10, 0xdc, 0x8b, 0xa0, 0x08, 0x1e, 0xac, 0x15, 0x2f, 0xb2, 0x84, 0xac, 0x8d, 0xed, 0x40,
    0x3a, 0x53, 0x93, 0x11, 0xec, 0xdb, 0x1b, 0xb1, 0xf1, 0x20, 0x92, 0x74, 0xc1, 0xe3, 0x90, 0xef,
    0xfb, 0x27, 0x33, 0xcc, 0x64, 0xb6, 0x6d, 0x32, 0xc8, 0xd5, 0x34, 0x49, 0x79, 0x75, 0x85, 0x24,
    0xdd, 0xab, 0x1b, 0x2f, 0x8d, 0x2c, 0x2a, 0x85, 0xdc, 0xb7, 0x4a, 0x9f, 0x07, 0xbd, 0x71, 0x94,
    0x19, 0x52, 0x08, 0x19, 0xf4, 0x02, 0x8f, 0xc9, 0xa9, 0x94, 0x66, 0x49, 0xa6, 0x92, 0x6d, 0xbb,
    0xd1, 0xcf, 0x07, 0x7a, 0xf1, 0x82, 0x3a, 0x66, 0xad, 0x31, 0x57, 0x37, 0x1f, 0x08, 0x18, 0xd1,
    0x08, 0x59, 0x02, 0xda, 0xe7, 0x2c, 0x35, 0x59, 0x60, 0x20, 0x9c, 0x39, 0xcd, 0xc9, 0x7f, 0x44,
    0x3a, 0x68, 0x17, 0xba, 0xa9, 0xcb, 0xdd, 0xd5, 0xeb, 0x67, 0x43, 0xd5, 0x43, 0x9d, 0x8f, 0x26,
    0x43, 0xad, 0xb0, 0xe0, 0xb2, 0xad, 0x5c, 0x56, 0xba, 0x01, 0xcb, 0xc7, 0xb7, 0xb0, 0x55, 0xeb,
    0xff, 0x06, 0xbb, 0x80, 0x3d, 0x48, 0x0d, 0xb9, 0x1f, 0x29, 0xfa, 0xab, 0x67, 0xeb, 0xae, 0x1b,
    0xf0, 0x33, 0x77, 0xe5, 0xd9, 0x15, 0x9e, 0x4d, 0x33, 0x36, 0x80, 0x45, 0x90, 0x17, 0xe2, 0x44,
    0x75, 0x23, 0x84, 0x77, 0xb8, 0xa9, 0x9d, 0x92, 0x64, 0xae, 0x8a, 0x78, 0xa8, 0x5a, 0x2b, 0x72,
    0x63, 0x1d, 0x56, 0x22, 0x84, 0xe6, 0x2f, 0x86, 0xa9, 0xcb, 0xbf, 0xc2, 0xee, 0xc7, 0xa1, 0x37,
    0xac
};
#endif

PyTypeObject *init_QTextFragment(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QTextFragment_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QTextFragment_IDX].type;

    Shiboken::AutoDecRef Sbk_QTextFragment_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QTextFragment_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QTextFragment",
        "QTextFragment",
        &Sbk_QTextFragment_spec,
        &Shiboken::callCppDestructor< ::QTextFragment >,
        Sbk_QTextFragment_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QTextFragment_TypeF(); // references _Sbk_QTextFragment_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QTextFragment_SignatureStrings);
#else
    InitSignatureBytes(pyType, QTextFragment_SignatureBytes, QTextFragment_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QTextFragment_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QTextFragment_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QTextFragment_PythonToCpp_QTextFragment_PTR,
        is_QTextFragment_PythonToCpp_QTextFragment_PTR_Convertible,
        QTextFragment_PTR_CppToPython_QTextFragment,
        QTextFragment_COPY_CppToPython_QTextFragment);

    Shiboken::Conversions::registerConverterName(converter, "QTextFragment");
    Shiboken::Conversions::registerConverterName(converter, "QTextFragment*");
    Shiboken::Conversions::registerConverterName(converter, "QTextFragment&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QTextFragment).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QTextFragment_PythonToCpp_QTextFragment_COPY,
        is_QTextFragment_PythonToCpp_QTextFragment_COPY_Convertible);

    qRegisterMetaType< ::QTextFragment >("QTextFragment");

    return pyType;
}
