// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qtextinlineobject_wrapper.h"

// Argument includes
#include <QtGui/qtextformat.h>
#include <qnamespace.h>
#include <qrect.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTextInlineObject_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QTextInlineObject >()))
        return -1;

    ::QTextInlineObject *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QTextInlineObject()
        cptr = new ::QTextInlineObject();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QTextInlineObject >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QTextInlineObjectFunc_ascent(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextInlineObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ascent()const
        qreal cppResult = const_cast<const ::QTextInlineObject *>(cppSelf)->ascent();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextInlineObjectFunc_descent(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextInlineObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // descent()const
        qreal cppResult = const_cast<const ::QTextInlineObject *>(cppSelf)->descent();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextInlineObjectFunc_format(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextInlineObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // format()const
        QTextFormat cppResult = const_cast<const ::QTextInlineObject *>(cppSelf)->format();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextInlineObjectFunc_formatIndex(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextInlineObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // formatIndex()const
        int cppResult = const_cast<const ::QTextInlineObject *>(cppSelf)->formatIndex();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextInlineObjectFunc_height(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextInlineObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // height()const
        qreal cppResult = const_cast<const ::QTextInlineObject *>(cppSelf)->height();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextInlineObjectFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextInlineObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QTextInlineObject *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextInlineObjectFunc_rect(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextInlineObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rect()const
        QRectF cppResult = const_cast<const ::QTextInlineObject *>(cppSelf)->rect();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextInlineObjectFunc_setAscent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextInlineObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextInlineObject::setAscent(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setAscent(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAscent", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAscent(qreal)
            cppSelf->setAscent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextInlineObjectFunc_setDescent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextInlineObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextInlineObject::setDescent(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setDescent(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDescent", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDescent(qreal)
            cppSelf->setDescent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextInlineObjectFunc_setWidth(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextInlineObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextInlineObject::setWidth(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setWidth(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setWidth", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setWidth(qreal)
            cppSelf->setWidth(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextInlineObjectFunc_textDirection(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextInlineObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // textDirection()const
        Qt::LayoutDirection cppResult = const_cast<const ::QTextInlineObject *>(cppSelf)->textDirection();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_LayoutDirection_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextInlineObjectFunc_textPosition(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextInlineObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // textPosition()const
        int cppResult = const_cast<const ::QTextInlineObject *>(cppSelf)->textPosition();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextInlineObjectFunc_width(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextInlineObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // width()const
        qreal cppResult = const_cast<const ::QTextInlineObject *>(cppSelf)->width();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextInlineObject__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QTextInlineObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QTextInlineObject_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QTextInlineObject_methods[] = {
    {"ascent", reinterpret_cast<PyCFunction>(Sbk_QTextInlineObjectFunc_ascent), METH_NOARGS, nullptr},
    {"descent", reinterpret_cast<PyCFunction>(Sbk_QTextInlineObjectFunc_descent), METH_NOARGS, nullptr},
    {"format", reinterpret_cast<PyCFunction>(Sbk_QTextInlineObjectFunc_format), METH_NOARGS, nullptr},
    {"formatIndex", reinterpret_cast<PyCFunction>(Sbk_QTextInlineObjectFunc_formatIndex), METH_NOARGS, nullptr},
    {"height", reinterpret_cast<PyCFunction>(Sbk_QTextInlineObjectFunc_height), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QTextInlineObjectFunc_isValid), METH_NOARGS, nullptr},
    {"rect", reinterpret_cast<PyCFunction>(Sbk_QTextInlineObjectFunc_rect), METH_NOARGS, nullptr},
    {"setAscent", reinterpret_cast<PyCFunction>(Sbk_QTextInlineObjectFunc_setAscent), METH_O, nullptr},
    {"setDescent", reinterpret_cast<PyCFunction>(Sbk_QTextInlineObjectFunc_setDescent), METH_O, nullptr},
    {"setWidth", reinterpret_cast<PyCFunction>(Sbk_QTextInlineObjectFunc_setWidth), METH_O, nullptr},
    {"textDirection", reinterpret_cast<PyCFunction>(Sbk_QTextInlineObjectFunc_textDirection), METH_NOARGS, nullptr},
    {"textPosition", reinterpret_cast<PyCFunction>(Sbk_QTextInlineObjectFunc_textPosition), METH_NOARGS, nullptr},
    {"width", reinterpret_cast<PyCFunction>(Sbk_QTextInlineObjectFunc_width), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QTextInlineObject__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QTextInlineObject_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QTextInlineObject_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QTextInlineObject_Type = nullptr;
static PyTypeObject *Sbk_QTextInlineObject_TypeF(void)
{
    return _Sbk_QTextInlineObject_Type;
}

static PyType_Slot Sbk_QTextInlineObject_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QTextInlineObject_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QTextInlineObject_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QTextInlineObject_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QTextInlineObject_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QTextInlineObject_spec = {
    "2:PySide6.QtGui.QTextInlineObject",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QTextInlineObject_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QTextInlineObject_PythonToCpp_QTextInlineObject_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QTextInlineObject_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QTextInlineObject_PythonToCpp_QTextInlineObject_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QTextInlineObject_TypeF()))
        return QTextInlineObject_PythonToCpp_QTextInlineObject_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QTextInlineObject_PTR_CppToPython_QTextInlineObject(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QTextInlineObject_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QTextInlineObject_COPY_CppToPython_QTextInlineObject(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QTextInlineObject *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QTextInlineObject_TypeF(), new ::QTextInlineObject(*source), true, true);
}

// Python to C++ copy conversion.
static void QTextInlineObject_PythonToCpp_QTextInlineObject_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QTextInlineObject *>(cppOut) = *reinterpret_cast< ::QTextInlineObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QTextInlineObject_PythonToCpp_QTextInlineObject_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QTextInlineObject_TypeF()))
        return QTextInlineObject_PythonToCpp_QTextInlineObject_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QTextInlineObject_SignatureStrings[] = {
    "PySide6.QtGui.QTextInlineObject(self)",
    "PySide6.QtGui.QTextInlineObject.ascent(self)->qreal",
    "PySide6.QtGui.QTextInlineObject.descent(self)->qreal",
    "PySide6.QtGui.QTextInlineObject.format(self)->PySide6.QtGui.QTextFormat",
    "PySide6.QtGui.QTextInlineObject.formatIndex(self)->int",
    "PySide6.QtGui.QTextInlineObject.height(self)->qreal",
    "PySide6.QtGui.QTextInlineObject.isValid(self)->bool",
    "PySide6.QtGui.QTextInlineObject.rect(self)->PySide6.QtCore.QRectF",
    "PySide6.QtGui.QTextInlineObject.setAscent(self,a:qreal)",
    "PySide6.QtGui.QTextInlineObject.setDescent(self,d:qreal)",
    "PySide6.QtGui.QTextInlineObject.setWidth(self,w:qreal)",
    "PySide6.QtGui.QTextInlineObject.textDirection(self)->PySide6.QtCore.Qt.LayoutDirection",
    "PySide6.QtGui.QTextInlineObject.textPosition(self)->int",
    "PySide6.QtGui.QTextInlineObject.width(self)->qreal",
    "PySide6.QtGui.QTextInlineObject.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QTextInlineObject_SignatureByteSize = 218;
static constexpr uint8_t QTextInlineObject_SignatureBytes[218] = {
    0x78, 0xda, 0x9d, 0x91, 0xc1, 0x0e, 0x82, 0x30, 0x10, 0x44, 0xef, 0x7c, 0x89, 0x24, 0xd8, 0xa3,
    0x07, 0x0f, 0x26, 0x46, 0xa2, 0x31, 0x31, 0x11, 0xc4, 0xe8, 0x91, 0x14, 0xba, 0xc0, 0x1a, 0x6c,
    0x91, 0x96, 0x08, 0x7f, 0x2f, 0xa2, 0x20, 0x07, 0x95, 0xea, 0xb1, 0xdb, 0x79, 0x93, 0x9d, 0x1d,
    0xa7, 0xf2, 0x90, 0xc1, 0x84, 0xb8, 0x6a, 0x55, 0x20, 0x71, 0xf7, 0x50, 0xaa, 0x35, 0x4f, 0x91,
    0xc3, 0x36, 0x38, 0x41, 0xa8, 0x46, 0x12, 0xd2, 0xc8, 0x34, 0x9c, 0xef, 0x2a, 0x42, 0x65, 0x08,
    0xfc, 0x29, 0x1e, 0xcf, 0x2e, 0x39, 0xd0, 0x74, 0x90, 0x61, 0xf0, 0x07, 0x14, 0x89, 0xfc, 0x4c,
    0x3b, 0xe6, 0x8d, 0x7a, 0xd9, 0x08, 0x34, 0x7d, 0xd6, 0x9c, 0x41, 0xd9, 0x9a, 0x21, 0x1f, 0xc6,
    0x12, 0xc0, 0x38, 0xf9, 0x71, 0x65, 0x94, 0x07, 0x9a, 0x22, 0x6b, 0xa1, 0x40, 0x88, 0x61, 0x26,
    0xef, 0x4e, 0xdf, 0x0f, 0xb9, 0x10, 0x39, 0x10, 0x77, 0x57, 0xff, 0x2d, 0x07, 0x1d, 0x24, 0xa8,
    0xf9, 0xeb, 0xbe, 0x16, 0x9d, 0x36, 0xcb, 0x9a, 0x3a, 0x9c, 0xdd, 0x2b, 0xc6, 0x62, 0x3f, 0x80,
    0x47, 0x64, 0x2a, 0x79, 0x60, 0x57, 0x5d, 0x4c, 0xd5, 0x03, 0x1b, 0xef, 0x79, 0x51, 0xf0, 0x4f,
    0x91, 0x15, 0xd9, 0xd0, 0x4a, 0x14, 0x2f, 0xa1, 0x96, 0xad, 0x23, 0x24, 0xf6, 0x5d, 0x75, 0x0a,
    0xbe, 0x76, 0x11, 0xb4, 0xfb, 0xf5, 0xfd, 0x50, 0x64, 0x95, 0xef, 0xb7, 0x94, 0xaa, 0x32, 0xe4,
    0x31, 0xf1, 0xea, 0x97, 0x71, 0x03, 0x6e, 0x39, 0x35, 0xf4
};
#endif

PyTypeObject *init_QTextInlineObject(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX].type;

    Shiboken::AutoDecRef Sbk_QTextInlineObject_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QTextInlineObject_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QTextInlineObject",
        "QTextInlineObject",
        &Sbk_QTextInlineObject_spec,
        &Shiboken::callCppDestructor< ::QTextInlineObject >,
        Sbk_QTextInlineObject_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QTextInlineObject_TypeF(); // references _Sbk_QTextInlineObject_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QTextInlineObject_SignatureStrings);
#else
    InitSignatureBytes(pyType, QTextInlineObject_SignatureBytes, QTextInlineObject_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QTextInlineObject_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QTextInlineObject_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QTextInlineObject_PythonToCpp_QTextInlineObject_PTR,
        is_QTextInlineObject_PythonToCpp_QTextInlineObject_PTR_Convertible,
        QTextInlineObject_PTR_CppToPython_QTextInlineObject,
        QTextInlineObject_COPY_CppToPython_QTextInlineObject);

    Shiboken::Conversions::registerConverterName(converter, "QTextInlineObject");
    Shiboken::Conversions::registerConverterName(converter, "QTextInlineObject*");
    Shiboken::Conversions::registerConverterName(converter, "QTextInlineObject&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QTextInlineObject).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QTextInlineObject_PythonToCpp_QTextInlineObject_COPY,
        is_QTextInlineObject_PythonToCpp_QTextInlineObject_COPY_Convertible);

    qRegisterMetaType< ::QTextInlineObject >("QTextInlineObject");

    return pyType;
}
