// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qtextitem_wrapper.h"

// Argument includes
#include <QString>
#include <QtGui/qfont.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTextItem_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QTextItem >()))
        return -1;

    ::QTextItem *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QTextItem_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QTextItem()
        cptr = new ::QTextItem();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QTextItem >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QTextItemFunc_ascent(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ascent()const
        qreal cppResult = const_cast<const ::QTextItem *>(cppSelf)->ascent();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextItemFunc_descent(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // descent()const
        qreal cppResult = const_cast<const ::QTextItem *>(cppSelf)->descent();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextItemFunc_font(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // font()const
        QFont cppResult = const_cast<const ::QTextItem *>(cppSelf)->font();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextItemFunc_renderFlags(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // renderFlags()const
        QFlags<QTextItem::RenderFlag> cppResult = const_cast<const ::QTextItem *>(cppSelf)->renderFlags();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QTextItem_RenderFlag_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextItemFunc_text(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // text()const
        QString cppResult = const_cast<const ::QTextItem *>(cppSelf)->text();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextItemFunc_width(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // width()const
        qreal cppResult = const_cast<const ::QTextItem *>(cppSelf)->width();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QTextItem_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QTextItem_EnumFlagInfo[] = {
    "RenderFlag:Flag:RenderFlags",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QTextItem_methods[] = {
    {"ascent", reinterpret_cast<PyCFunction>(Sbk_QTextItemFunc_ascent), METH_NOARGS, nullptr},
    {"descent", reinterpret_cast<PyCFunction>(Sbk_QTextItemFunc_descent), METH_NOARGS, nullptr},
    {"font", reinterpret_cast<PyCFunction>(Sbk_QTextItemFunc_font), METH_NOARGS, nullptr},
    {"renderFlags", reinterpret_cast<PyCFunction>(Sbk_QTextItemFunc_renderFlags), METH_NOARGS, nullptr},
    {"text", reinterpret_cast<PyCFunction>(Sbk_QTextItemFunc_text), METH_NOARGS, nullptr},
    {"width", reinterpret_cast<PyCFunction>(Sbk_QTextItemFunc_width), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QTextItem_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QTextItem_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QTextItem_Type = nullptr;
static PyTypeObject *Sbk_QTextItem_TypeF(void)
{
    return _Sbk_QTextItem_Type;
}

static PyType_Slot Sbk_QTextItem_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QTextItem_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QTextItem_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QTextItem_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QTextItem_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QTextItem_spec = {
    "2:PySide6.QtGui.QTextItem",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QTextItem_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QTextItem_RenderFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QTextItem::RenderFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QTextItem::RenderFlag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QTextItem_RenderFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextItem_RenderFlag_IDX])))
        return Enum_PythonToCpp_QTextItem_RenderFlag;
    return {};
}

static PyObject *QTextItem_RenderFlag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QTextItem::RenderFlag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QTextItem::RenderFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextItem_RenderFlag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QTextItem_RenderFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QTextItem::RenderFlag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QTextItem::RenderFlag> *>(cppOut) = value;

}

static PyObject *QTextItem_RenderFlag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QTextItem::RenderFlag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextItem_RenderFlag_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QTextItem_PythonToCpp_QTextItem_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QTextItem_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QTextItem_PythonToCpp_QTextItem_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QTextItem_TypeF()))
        return QTextItem_PythonToCpp_QTextItem_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QTextItem_PTR_CppToPython_QTextItem(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QTextItem_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QTextItem_SignatureStrings[] = {
    "PySide6.QtGui.QTextItem(self)",
    "PySide6.QtGui.QTextItem.ascent(self)->qreal",
    "PySide6.QtGui.QTextItem.descent(self)->qreal",
    "PySide6.QtGui.QTextItem.font(self)->PySide6.QtGui.QFont",
    "PySide6.QtGui.QTextItem.renderFlags(self)->PySide6.QtGui.QTextItem.RenderFlag",
    "PySide6.QtGui.QTextItem.text(self)->QString",
    "PySide6.QtGui.QTextItem.width(self)->qreal",
    nullptr}; // Sentinel
#else
static constexpr size_t QTextItem_SignatureByteSize = 116;
static constexpr uint8_t QTextItem_SignatureBytes[116] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0x2f, 0xcd, 0xd4,
    0x0b, 0x0c, 0x49, 0xad, 0x28, 0xf1, 0x2c, 0x49, 0xcd, 0xd5, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0xe4,
    0x0a, 0xc0, 0x2e, 0xab, 0x97, 0x58, 0x9c, 0x9c, 0x9a, 0x57, 0x02, 0x51, 0xa4, 0x6b, 0x57, 0x58,
    0x94, 0x9a, 0x98, 0x83, 0x53, 0x6d, 0x4a, 0x2a, 0x09, 0x8a, 0xd3, 0xf2, 0x11, 0x2a, 0xd1, 0xd4,
    0xb8, 0x01, 0xa5, 0x70, 0xea, 0x2b, 0x4a, 0xcd, 0x4b, 0x49, 0x2d, 0x72, 0xcb, 0x49, 0x4c, 0x2f,
    0xc6, 0xa1, 0x1d, 0xae, 0x34, 0x08, 0xae, 0x14, 0xa7, 0x69, 0x25, 0x40, 0x06, 0xcc, 0x98, 0xc0,
    0xe0, 0x92, 0xa2, 0xcc, 0x3c, 0xdc, 0x6a, 0xcb, 0x33, 0x53, 0x4a, 0x32, 0x50, 0x3d, 0x07, 0x00,
    0x7e, 0xb3, 0x77, 0x60
};
#endif

PyTypeObject *init_QTextItem(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QTextItem_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QTextItem_IDX].type;

    Shiboken::AutoDecRef Sbk_QTextItem_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QTextItem_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QTextItem",
        "QTextItem*",
        &Sbk_QTextItem_spec,
        &Shiboken::callCppDestructor< ::QTextItem >,
        Sbk_QTextItem_Type_bases.object(),
        0);
    auto *pyType = Sbk_QTextItem_TypeF(); // references _Sbk_QTextItem_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QTextItem_SignatureStrings);
#else
    InitSignatureBytes(pyType, QTextItem_SignatureBytes, QTextItem_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QTextItem_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QTextItem_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QTextItem_PythonToCpp_QTextItem_PTR,
        is_QTextItem_PythonToCpp_QTextItem_PTR_Convertible,
        QTextItem_PTR_CppToPython_QTextItem);

    Shiboken::Conversions::registerConverterName(converter, "QTextItem");
    Shiboken::Conversions::registerConverterName(converter, "QTextItem*");
    Shiboken::Conversions::registerConverterName(converter, "QTextItem&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QTextItem).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QTextItem_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'RenderFlag'.
    const char *RenderFlag_Initializer[] = {
        "RightToLeft",
        "Overline",
        "Underline",
        "StrikeOut",
        "Dummy",
        nullptr};
    // "uint32_t" used instead of "unsigned int"
    constexpr uint32_t RenderFlag_InitializerValues[] = {
        uint32_t(QTextItem::RenderFlag::RightToLeft), //  0x00000001  1
        uint32_t(QTextItem::RenderFlag::Overline),    //  0x00000010  16
        uint32_t(QTextItem::RenderFlag::Underline),   //  0x00000020  32
        uint32_t(QTextItem::RenderFlag::StrikeOut),   //  0x00000040  64
        uint32_t(QTextItem::RenderFlag::Dummy)        //  0xffffffff  4294967295
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QTextItem_TypeF(),
        "2:PySide6.QtGui.QTextItem.RenderFlag",
        RenderFlag_Initializer, RenderFlag_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QTextItem_RenderFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QTextItem_RenderFlag_IDX].type =
        EType;
    // Register converter for enum 'QTextItem::RenderFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QTextItem_RenderFlag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QTextItem_RenderFlag,
            is_Enum_PythonToCpp_QTextItem_RenderFlag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QTextItem::RenderFlag");
        Shiboken::Conversions::registerConverterAlias(converter, "RenderFlag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QTextItem_RenderFlag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QTextItem_RenderFlag,
            is_Enum_PythonToCpp_QTextItem_RenderFlag_Convertible);
        // Register converter for flag 'QFlags<QTextItem::RenderFlag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QTextItem::RenderFlag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QTextItem::RenderFlags");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'RenderFlag' enum/flags.

    qRegisterMetaType< ::QTextItem *>();
    qRegisterMetaType< ::QTextItem::RenderFlag >("QTextItem::RenderFlag");

    return pyType;
}
