// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qtextlistformat_wrapper.h"

// Argument includes
#include <QList>
#include <QMap>
#include <QString>
#include <QtGui/qbrush.h>
#include <QtGui/qcolor.h>
#include <QtGui/qpen.h>
#include <QtGui/qtextformat.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTextListFormat_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QTextListFormat >()))
        return -1;

    ::QTextListFormat *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QTextListFormat", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QTextListFormat::QTextListFormat()
    // 1: QTextListFormat::QTextListFormat(QTextFormat)
    // 2: QTextListFormat::QTextListFormat(QTextListFormat)
    if (numArgs == 0) {
        overloadId = 0; // QTextListFormat()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextListFormat_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QTextListFormat(QTextListFormat)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QTextListFormat(QTextFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextListFormat_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QTextListFormat_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QTextListFormat()
        {

            // QTextListFormat()
            cptr = new ::QTextListFormat();
            break;
        }
        case 1: // QTextListFormat(const QTextFormat &fmt)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QTextFormat cppArg0_local;
            ::QTextFormat *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QTextListFormat(QTextFormat)
                cptr = new ::QTextListFormat(*cppArg0);
            }
            break;
        }
        case 2: // QTextListFormat(const QTextListFormat &QTextListFormat)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QTextListFormat cppArg0_local;
            ::QTextListFormat *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QTextListFormat(QTextListFormat)
                cptr = new ::QTextListFormat(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QTextListFormat >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextListFormat_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QTextListFormatFunc_indent(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextListFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextListFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // indent()const
        int cppResult = const_cast<const ::QTextListFormat *>(cppSelf)->indent();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextListFormatFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextListFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextListFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QTextListFormat *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextListFormatFunc_numberPrefix(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextListFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextListFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // numberPrefix()const
        QString cppResult = const_cast<const ::QTextListFormat *>(cppSelf)->numberPrefix();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextListFormatFunc_numberSuffix(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextListFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextListFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // numberSuffix()const
        QString cppResult = const_cast<const ::QTextListFormat *>(cppSelf)->numberSuffix();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextListFormatFunc_setIndent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextListFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextListFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextListFormat::setIndent(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setIndent(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setIndent", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextListFormat_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setIndent(int)
            cppSelf->setIndent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextListFormatFunc_setNumberPrefix(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextListFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextListFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextListFormat::setNumberPrefix(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setNumberPrefix(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setNumberPrefix", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextListFormat_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setNumberPrefix(QString)
            cppSelf->setNumberPrefix(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextListFormatFunc_setNumberSuffix(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextListFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextListFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextListFormat::setNumberSuffix(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setNumberSuffix(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setNumberSuffix", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextListFormat_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setNumberSuffix(QString)
            cppSelf->setNumberSuffix(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextListFormatFunc_setStart(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextListFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextListFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextListFormat::setStart(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setStart(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStart", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextListFormat_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStart(int)
            cppSelf->setStart(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextListFormatFunc_setStyle(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextListFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextListFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextListFormat::setStyle(QTextListFormat::Style)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextListFormat_Style_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setStyle(QTextListFormat::Style)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStyle", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextListFormat_IDX]);

    // Call function/method
    {
        ::QTextListFormat::Style cppArg0{QTextListFormat::ListStyleUndefined};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStyle(QTextListFormat::Style)
            cppSelf->setStyle(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextListFormatFunc_start(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextListFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextListFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // start()const
        int cppResult = const_cast<const ::QTextListFormat *>(cppSelf)->start();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextListFormatFunc_style(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextListFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextListFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // style()const
        QTextListFormat::Style cppResult = const_cast<const ::QTextListFormat *>(cppSelf)->style();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextListFormat_Style_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextListFormat__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QTextListFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextListFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextListFormat_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QTextListFormat_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QTextListFormat_EnumFlagInfo[] = {
    "Style:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QTextListFormat_methods[] = {
    {"indent", reinterpret_cast<PyCFunction>(Sbk_QTextListFormatFunc_indent), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QTextListFormatFunc_isValid), METH_NOARGS, nullptr},
    {"numberPrefix", reinterpret_cast<PyCFunction>(Sbk_QTextListFormatFunc_numberPrefix), METH_NOARGS, nullptr},
    {"numberSuffix", reinterpret_cast<PyCFunction>(Sbk_QTextListFormatFunc_numberSuffix), METH_NOARGS, nullptr},
    {"setIndent", reinterpret_cast<PyCFunction>(Sbk_QTextListFormatFunc_setIndent), METH_O, nullptr},
    {"setNumberPrefix", reinterpret_cast<PyCFunction>(Sbk_QTextListFormatFunc_setNumberPrefix), METH_O, nullptr},
    {"setNumberSuffix", reinterpret_cast<PyCFunction>(Sbk_QTextListFormatFunc_setNumberSuffix), METH_O, nullptr},
    {"setStart", reinterpret_cast<PyCFunction>(Sbk_QTextListFormatFunc_setStart), METH_O, nullptr},
    {"setStyle", reinterpret_cast<PyCFunction>(Sbk_QTextListFormatFunc_setStyle), METH_O, nullptr},
    {"start", reinterpret_cast<PyCFunction>(Sbk_QTextListFormatFunc_start), METH_NOARGS, nullptr},
    {"style", reinterpret_cast<PyCFunction>(Sbk_QTextListFormatFunc_style), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QTextListFormat__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QTextListFormat_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QTextListFormat_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QTextListFormat_Type = nullptr;
static PyTypeObject *Sbk_QTextListFormat_TypeF(void)
{
    return _Sbk_QTextListFormat_Type;
}

static PyType_Slot Sbk_QTextListFormat_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QTextListFormat_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QTextListFormat_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QTextListFormat_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QTextListFormat_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QTextListFormat_spec = {
    "2:PySide6.QtGui.QTextListFormat",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QTextListFormat_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QTextListFormat_Style(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QTextListFormat::Style>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QTextListFormat::Style *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QTextListFormat_Style_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextListFormat_Style_IDX])))
        return Enum_PythonToCpp_QTextListFormat_Style;
    return {};
}

static PyObject *QTextListFormat_Style_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QTextListFormat::Style>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QTextListFormat::Style *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextListFormat_Style_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QTextListFormat_PythonToCpp_QTextListFormat_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QTextListFormat_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QTextListFormat_PythonToCpp_QTextListFormat_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QTextListFormat_TypeF()))
        return QTextListFormat_PythonToCpp_QTextListFormat_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QTextListFormat_PTR_CppToPython_QTextListFormat(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QTextListFormat_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QTextListFormat_COPY_CppToPython_QTextListFormat(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QTextListFormat *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QTextListFormat_TypeF(), new ::QTextListFormat(*source), true, true);
}

// Python to C++ copy conversion.
static void QTextListFormat_PythonToCpp_QTextListFormat_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QTextListFormat *>(cppOut) = *reinterpret_cast< ::QTextListFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextListFormat_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QTextListFormat_PythonToCpp_QTextListFormat_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QTextListFormat_TypeF()))
        return QTextListFormat_PythonToCpp_QTextListFormat_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QTextListFormat_SignatureStrings[] = {
    "2:PySide6.QtGui.QTextListFormat(self)",
    "1:PySide6.QtGui.QTextListFormat(self,fmt:PySide6.QtGui.QTextFormat)",
    "0:PySide6.QtGui.QTextListFormat(self,QTextListFormat:PySide6.QtGui.QTextListFormat)",
    "PySide6.QtGui.QTextListFormat.indent(self)->int",
    "PySide6.QtGui.QTextListFormat.isValid(self)->bool",
    "PySide6.QtGui.QTextListFormat.numberPrefix(self)->QString",
    "PySide6.QtGui.QTextListFormat.numberSuffix(self)->QString",
    "PySide6.QtGui.QTextListFormat.setIndent(self,indent:int)",
    "PySide6.QtGui.QTextListFormat.setNumberPrefix(self,numberPrefix:QString)",
    "PySide6.QtGui.QTextListFormat.setNumberSuffix(self,numberSuffix:QString)",
    "PySide6.QtGui.QTextListFormat.setStart(self,indent:int)",
    "PySide6.QtGui.QTextListFormat.setStyle(self,style:PySide6.QtGui.QTextListFormat.Style)",
    "PySide6.QtGui.QTextListFormat.start(self)->int",
    "PySide6.QtGui.QTextListFormat.style(self)->PySide6.QtGui.QTextListFormat.Style",
    "PySide6.QtGui.QTextListFormat.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QTextListFormat_SignatureByteSize = 218;
static constexpr uint8_t QTextListFormat_SignatureBytes[218] = {
    0x78, 0xda, 0x9d, 0x92, 0x5d, 0x0b, 0x82, 0x30, 0x18, 0x85, 0xef, 0xfd, 0x25, 0x09, 0x6b, 0x54,
    0x17, 0x5d, 0x78, 0xd1, 0x65, 0x11, 0x44, 0x28, 0x8b, 0x6e, 0x87, 0xe6, 0x8c, 0x81, 0x4e, 0xd9,
    0x5e, 0xc1, 0xfd, 0xfb, 0x56, 0x7e, 0x24, 0x12, 0x6e, 0x76, 0xb7, 0x8f, 0xf3, 0x9c, 0x9d, 0x33,
    0xde, 0x5d, 0x10, 0x6a, 0xc2, 0x53, 0xb6, 0xc7, 0x11, 0x9c, 0x6a, 0x8e, 0xa3, 0x1b, 0x6b, 0xe0,
    0xc2, 0x15, 0x1c, 0x4b, 0x59, 0xc4, 0xb0, 0x52, 0x2c, 0xcf, 0x7c, 0x6f, 0xeb, 0xa0, 0x42, 0x59,
    0x01, 0xbf, 0x64, 0xad, 0xc4, 0xf7, 0x36, 0x2e, 0x1e, 0x93, 0xc3, 0x79, 0xc4, 0xf7, 0x66, 0xaf,
    0x31, 0x17, 0x29, 0x13, 0x5d, 0x85, 0xf5, 0x81, 0x0b, 0xb0, 0xe9, 0xd5, 0x3d, 0xce, 0x79, 0xda,
    0x03, 0x49, 0x59, 0xe6, 0x16, 0x42, 0xd4, 0x45, 0xc2, 0x64, 0x28, 0x59, 0xc6, 0x9b, 0x1e, 0x8b,
    0x08, 0x48, 0x2e, 0x9e, 0x4e, 0x24, 0xa9, 0xb3, 0xc5, 0xa4, 0x62, 0x70, 0xfe, 0x16, 0x43, 0x6d,
    0xc9, 0xc0, 0xb4, 0xf3, 0xed, 0xe0, 0x75, 0x9a, 0x17, 0x8d, 0x1b, 0x04, 0x5d, 0x00, 0x67, 0xa3,
    0x51, 0x7c, 0x34, 0x2e, 0xb4, 0xc0, 0x88, 0x40, 0x2c, 0xff, 0x69, 0x42, 0x40, 0xe7, 0xac, 0xe5,
    0xd4, 0x7b, 0x39, 0x3f, 0x29, 0xf8, 0x23, 0xb7, 0xda, 0x0e, 0x59, 0x9c, 0xc6, 0x45, 0x0d, 0x11,
    0x8c, 0xdc, 0xe1, 0x79, 0x8b, 0x1d, 0xa5, 0x8f, 0xb2, 0xd2, 0x94, 0xf6, 0x8e, 0xa0, 0x2b, 0xf3,
    0x85, 0x98, 0x98, 0x9d, 0xf7, 0x02, 0xe4, 0x7a, 0x53, 0x3e
};
#endif

PyTypeObject *init_QTextListFormat(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QTextListFormat_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QTextListFormat_IDX].type;

    Shiboken::AutoDecRef Sbk_QTextListFormat_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]))));

    _Sbk_QTextListFormat_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QTextListFormat",
        "QTextListFormat",
        &Sbk_QTextListFormat_spec,
        &Shiboken::callCppDestructor< ::QTextListFormat >,
        Sbk_QTextListFormat_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QTextListFormat_TypeF(); // references _Sbk_QTextListFormat_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QTextListFormat_SignatureStrings);
#else
    InitSignatureBytes(pyType, QTextListFormat_SignatureBytes, QTextListFormat_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QTextListFormat_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QTextListFormat_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QTextListFormat_PythonToCpp_QTextListFormat_PTR,
        is_QTextListFormat_PythonToCpp_QTextListFormat_PTR_Convertible,
        QTextListFormat_PTR_CppToPython_QTextListFormat,
        QTextListFormat_COPY_CppToPython_QTextListFormat);

    Shiboken::Conversions::registerConverterName(converter, "QTextListFormat");
    Shiboken::Conversions::registerConverterName(converter, "QTextListFormat*");
    Shiboken::Conversions::registerConverterName(converter, "QTextListFormat&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QTextListFormat).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QTextListFormat_PythonToCpp_QTextListFormat_COPY,
        is_QTextListFormat_PythonToCpp_QTextListFormat_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QTextListFormat_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Style'.
    const char *Style_Initializer[] = {
        "ListDisc",
        "ListCircle",
        "ListSquare",
        "ListDecimal",
        "ListLowerAlpha",
        "ListUpperAlpha",
        "ListLowerRoman",
        "ListUpperRoman",
        "ListStyleUndefined",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t Style_InitializerValues[] = {
        int8_t(QTextListFormat::Style::ListDisc),          // -0x01 -1
        int8_t(QTextListFormat::Style::ListCircle),        // -0x02 -2
        int8_t(QTextListFormat::Style::ListSquare),        // -0x03 -3
        int8_t(QTextListFormat::Style::ListDecimal),       // -0x04 -4
        int8_t(QTextListFormat::Style::ListLowerAlpha),    // -0x05 -5
        int8_t(QTextListFormat::Style::ListUpperAlpha),    // -0x06 -6
        int8_t(QTextListFormat::Style::ListLowerRoman),    // -0x07 -7
        int8_t(QTextListFormat::Style::ListUpperRoman),    // -0x08 -8
        int8_t(QTextListFormat::Style::ListStyleUndefined) //  0x00  0
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QTextListFormat_TypeF(),
        "2:PySide6.QtGui.QTextListFormat.Style",
        Style_Initializer, Style_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QTextListFormat_Style_IDX].type = EType;
    // Register converter for enum 'QTextListFormat::Style'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QTextListFormat_Style_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QTextListFormat_Style,
            is_Enum_PythonToCpp_QTextListFormat_Style_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QTextListFormat::Style");
        Shiboken::Conversions::registerConverterAlias(converter, "Style");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Style' enum.

    qRegisterMetaType< ::QTextListFormat >("QTextListFormat");
    qRegisterMetaType< ::QTextListFormat::Style >("QTextListFormat::Style");

    return pyType;
}
