// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qtextoption_tab_wrapper.h"

// Argument includes
#include <QtGui/qtextoption.h>
#include <qchar.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTextOption_Tab_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QTextOption::Tab >()))
        return -1;

    ::QTextOption::Tab *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_Tab_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:Tab", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: Tab::Tab()
    // 1: Tab::Tab(QTextOption::Tab)
    // 2: Tab::Tab(qreal,QTextOption::TabType,QChar=)
    if (numArgs == 0) {
        overloadId = 0; // Tab()
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_TabType_IDX])))->converter, (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 2; // Tab(qreal,QTextOption::TabType,QChar)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QChar_IDX], (pyArgs[2])))) {
            overloadId = 2; // Tab(qreal,QTextOption::TabType,QChar)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_Tab_IDX]), (pyArgs[0])))) {
        overloadId = 1; // Tab(QTextOption::Tab)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_Tab_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_Tab_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // Tab()
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_Tab_IDX]);
            }

            // Tab()
            cptr = new ::QTextOption::Tab();
            break;
        }
        case 1: // Tab(const QTextOption::Tab &Tab)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_Tab_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QTextOption::Tab cppArg0_local;
            ::QTextOption::Tab *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // Tab(QTextOption::Tab)
                cptr = new ::QTextOption::Tab(*cppArg0);
            }
            break;
        }
        case 2: // Tab(qreal pos, QTextOption::TabType tabType, QChar delim)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_delim = Shiboken::String::createStaticString("delim");
                if (PyDict_Contains(kwds, key_delim) != 0) {
                    value = PyDict_GetItem(kwds, key_delim);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_delim);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_Tab_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QChar_IDX], (pyArgs[2]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_Tab_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_delim);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_Tab_IDX]);
                }
            }
            qreal cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QTextOption::TabType cppArg1{QTextOption::LeftTab};
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QChar cppArg2 = QChar();
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // Tab(qreal,QTextOption::TabType,QChar)
                cptr = new ::QTextOption::Tab(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QTextOption::Tab >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_Tab_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QTextOption_Tab__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QTextOption::Tab *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_Tab_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_Tab_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QTextOption_Tab_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QTextOption_Tab_methods[] = {
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QTextOption_Tab__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QTextOption_Tab_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QTextOption::Tab *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_Tab_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_Tab_IDX]), (pyArg)))) {
                // operator!=(const QTextOption::Tab &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QTextOption::Tab cppArg0_local;
                ::QTextOption::Tab *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_Tab_IDX]), (pyArg)))) {
                // operator==(const QTextOption::Tab &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QTextOption::Tab cppArg0_local;
                ::QTextOption::Tab *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

static PyObject *Sbk_QTextOption_Tab_get_position(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextOption::Tab *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_Tab_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppSelf->position);
    return pyOut;
}
static int Sbk_QTextOption_Tab_set_position(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QTextOption::Tab *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_Tab_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("position");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("position", "qreal");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->position;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

static PyObject *Sbk_QTextOption_Tab_get_type(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextOption::Tab *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_Tab_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::QTextOption::TabType cppOut_local = cppSelf->type;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_TabType_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QTextOption_Tab_set_type(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QTextOption::Tab *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_Tab_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("type");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_TabType_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("type", "TabType");
        return -1;
    }

    auto cppOut_local = cppSelf->type;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->type = cppOut_local;

    return 0;
}

static PyObject *Sbk_QTextOption_Tab_get_delimiter(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextOption::Tab *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_Tab_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QChar_IDX], &cppSelf->delimiter);
    return pyOut;
}
static int Sbk_QTextOption_Tab_set_delimiter(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QTextOption::Tab *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_Tab_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("delimiter");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QChar_IDX], (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("delimiter", "QChar");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->delimiter;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

// Getters and Setters for Tab
static PyGetSetDef Sbk_QTextOption_Tab_getsetlist[] = {
    {const_cast<char *>("position"), Sbk_QTextOption_Tab_get_position, Sbk_QTextOption_Tab_set_position, nullptr, nullptr},
    {const_cast<char *>("type"), Sbk_QTextOption_Tab_get_type, Sbk_QTextOption_Tab_set_type, nullptr, nullptr},
    {const_cast<char *>("delimiter"), Sbk_QTextOption_Tab_get_delimiter, Sbk_QTextOption_Tab_set_delimiter, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QTextOption_Tab_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QTextOption_Tab_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QTextOption_Tab_Type = nullptr;
static PyTypeObject *Sbk_QTextOption_Tab_TypeF(void)
{
    return _Sbk_QTextOption_Tab_Type;
}

static PyType_Slot Sbk_QTextOption_Tab_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QTextOption_Tab_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QTextOption_Tab_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QTextOption_Tab_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QTextOption_Tab_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QTextOption_Tab_getsetlist)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QTextOption_Tab_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QTextOption_Tab_spec = {
    "2:PySide6.QtGui.QTextOption.Tab",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QTextOption_Tab_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void Tab_PythonToCpp_Tab_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QTextOption_Tab_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_Tab_PythonToCpp_Tab_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QTextOption_Tab_TypeF()))
        return Tab_PythonToCpp_Tab_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *Tab_PTR_CppToPython_Tab(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QTextOption_Tab_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *Tab_COPY_CppToPython_Tab(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QTextOption::Tab *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QTextOption_Tab_TypeF(), new ::QTextOption::Tab(*source), true, true);
}

// Python to C++ copy conversion.
static void Tab_PythonToCpp_Tab_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QTextOption::Tab *>(cppOut) = *reinterpret_cast< ::QTextOption::Tab *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_Tab_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_Tab_PythonToCpp_Tab_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QTextOption_Tab_TypeF()))
        return Tab_PythonToCpp_Tab_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QTextOption_Tab_SignatureStrings[] = {
    "2:PySide6.QtGui.QTextOption.Tab(self)",
    "1:PySide6.QtGui.QTextOption.Tab(self,Tab:PySide6.QtGui.QTextOption.Tab)",
    "0:PySide6.QtGui.QTextOption.Tab(self,pos:qreal,tabType:PySide6.QtGui.QTextOption.TabType,delim:QChar=QChar())",
    "PySide6.QtGui.QTextOption.Tab.__copy__(self)->typing.Self",
    "PySide6.QtGui.QTextOption.Tab.__ne__(self,other:PySide6.QtGui.QTextOption.Tab)->bool",
    "PySide6.QtGui.QTextOption.Tab.__eq__(self,other:PySide6.QtGui.QTextOption.Tab)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QTextOption_Tab_SignatureByteSize = 152;
static constexpr uint8_t QTextOption_Tab_SignatureBytes[152] = {
    0x78, 0xda, 0x33, 0xb2, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0x2f,
    0xcd, 0xd4, 0x0b, 0x0c, 0x49, 0xad, 0x28, 0xf1, 0x2f, 0x28, 0xc9, 0xcc, 0xcf, 0xd3, 0x0b, 0x49,
    0x4c, 0xd2, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0xe4, 0x32, 0x24, 0x42, 0x95, 0x0e, 0x90, 0x81, 0x5f,
    0x99, 0x26, 0x97, 0x01, 0x31, 0xe6, 0x14, 0xe4, 0x17, 0x5b, 0x15, 0x16, 0xa5, 0x26, 0xe6, 0xe8,
    0x94, 0x24, 0x26, 0x85, 0x54, 0x16, 0xa4, 0xe2, 0xd7, 0x04, 0x52, 0xa1, 0x93, 0x92, 0x9a, 0x93,
    0x99, 0x6b, 0x15, 0xe8, 0x9c, 0x91, 0x58, 0x64, 0x0b, 0x26, 0x35, 0x34, 0x35, 0xb9, 0xf0, 0x6a,
    0xd3, 0x8b, 0x8f, 0x4f, 0xce, 0x2f, 0xa8, 0x8c, 0x8f, 0x87, 0x78, 0x51, 0xd7, 0xae, 0xa4, 0xb2,
    0x20, 0x33, 0x2f, 0x5d, 0x2f, 0x18, 0xc8, 0x23, 0xa8, 0x33, 0x2f, 0x15, 0xaa, 0x4f, 0x27, 0xbf,
    0x24, 0x23, 0xb5, 0x88, 0x80, 0xb7, 0x75, 0xed, 0x92, 0xf2, 0xf3, 0x73, 0x08, 0x1a, 0x9a, 0x5a,
    0x48, 0x86, 0xa1, 0x00, 0x8b, 0x81, 0x9d, 0x72
};
#endif

PyTypeObject *init_QTextOption_Tab(PyObject *enclosingClass)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_Tab_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_Tab_IDX].type;

    Shiboken::AutoDecRef Sbk_QTextOption_Tab_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QTextOption_Tab_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "Tab",
        "QTextOption::Tab",
        &Sbk_QTextOption_Tab_spec,
        &Shiboken::callCppDestructor< ::QTextOption::Tab >,
        Sbk_QTextOption_Tab_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass | Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QTextOption_Tab_TypeF(); // references _Sbk_QTextOption_Tab_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QTextOption_Tab_SignatureStrings);
#else
    InitSignatureBytes(pyType, QTextOption_Tab_SignatureBytes, QTextOption_Tab_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QTextOption_Tab_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_Tab_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        Tab_PythonToCpp_Tab_PTR,
        is_Tab_PythonToCpp_Tab_PTR_Convertible,
        Tab_PTR_CppToPython_Tab,
        Tab_COPY_CppToPython_Tab);

    Shiboken::Conversions::registerConverterName(converter, "QTextOption::Tab");
    Shiboken::Conversions::registerConverterName(converter, "QTextOption::Tab*");
    Shiboken::Conversions::registerConverterName(converter, "QTextOption::Tab&");
    Shiboken::Conversions::registerConverterAlias(converter, "Tab");
    Shiboken::Conversions::registerConverterAlias(converter, "Tab*");
    Shiboken::Conversions::registerConverterAlias(converter, "Tab&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QTextOption::Tab).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        Tab_PythonToCpp_Tab_COPY,
        is_Tab_PythonToCpp_Tab_COPY_Convertible);

    qRegisterMetaType< ::QTextOption::Tab >("Tab");
    qRegisterMetaType< ::QTextOption::Tab >("QTextOption::Tab");

    return pyType;
}
