// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qtextoption_wrapper.h"

// inner classes
#include "qtextoption_tab_wrapper.h"

// Argument includes
#include <QList>
#include <QtGui/qtextoption.h>
#include <qnamespace.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTextOption_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QTextOption >()))
        return -1;

    ::QTextOption *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QTextOption", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QTextOption::QTextOption()
    // 1: QTextOption::QTextOption(QFlags<Qt::AlignmentFlag>)
    // 2: QTextOption::QTextOption(QTextOption)
    if (numArgs == 0) {
        overloadId = 0; // QTextOption()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_AlignmentFlag_IDX])))->flagsConverter, (pyArgs[0])))) {
        overloadId = 1; // QTextOption(QFlags<Qt::AlignmentFlag>)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QTextOption(QTextOption)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QTextOption()
        {

            // QTextOption()
            cptr = new ::QTextOption();
            break;
        }
        case 1: // QTextOption(QFlags<Qt::AlignmentFlag> alignment)
        {
            ::QFlags<Qt::AlignmentFlag> cppArg0 = QFlags<Qt::AlignmentFlag>(0);
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QTextOption(QFlags<Qt::AlignmentFlag>)
                cptr = new ::QTextOption(cppArg0);
            }
            break;
        }
        case 2: // QTextOption(const QTextOption &o)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QTextOption cppArg0_local;
            ::QTextOption *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QTextOption(QTextOption)
                cptr = new ::QTextOption(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QTextOption >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QTextOptionFunc_alignment(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextOption *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // alignment()const
        QFlags<Qt::AlignmentFlag> cppResult = const_cast<const ::QTextOption *>(cppSelf)->alignment();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_AlignmentFlag_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextOptionFunc_flags(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextOption *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // flags()const
        QFlags<QTextOption::Flag> cppResult = const_cast<const ::QTextOption *>(cppSelf)->flags();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QTextOption_Flag_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextOptionFunc_setAlignment(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextOption *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextOption::setAlignment(QFlags<Qt::AlignmentFlag>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_AlignmentFlag_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setAlignment(QFlags<Qt::AlignmentFlag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAlignment", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_IDX]);

    // Call function/method
    {
        ::QFlags<Qt::AlignmentFlag> cppArg0 = QFlags<Qt::AlignmentFlag>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAlignment(QFlags<Qt::AlignmentFlag>)
            cppSelf->setAlignment(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextOptionFunc_setFlags(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextOption *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextOption::setFlags(QFlags<QTextOption::Flag>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QTextOption_Flag_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setFlags(QFlags<QTextOption::Flag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFlags", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_IDX]);

    // Call function/method
    {
        ::QFlags<QTextOption::Flag> cppArg0 = QFlags<QTextOption::Flag>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFlags(QFlags<QTextOption::Flag>)
            cppSelf->setFlags(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextOptionFunc_setTabArray(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextOption *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextOption::setTabArray(QList<qreal>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_qreal_IDX], (pyArg)))) {
        overloadId = 0; // setTabArray(QList<qreal>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTabArray", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_IDX]);

    // Call function/method
    {
        ::QList<qreal> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTabArray(QList<qreal>)
            cppSelf->setTabArray(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextOptionFunc_setTabStopDistance(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextOption *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextOption::setTabStopDistance(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setTabStopDistance(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTabStopDistance", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTabStopDistance(qreal)
            cppSelf->setTabStopDistance(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextOptionFunc_setTabs(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextOption *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextOption::setTabs(QList<QTextOption::Tab>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QTextOption_Tab_IDX], (pyArg)))) {
        overloadId = 0; // setTabs(QList<QTextOption::Tab>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTabs", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_IDX]);

    // Call function/method
    {
        ::QList<QTextOption::Tab> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTabs(QList<QTextOption::Tab>)
            cppSelf->setTabs(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextOptionFunc_setTextDirection(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextOption *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextOption::setTextDirection(Qt::LayoutDirection)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_LayoutDirection_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setTextDirection(Qt::LayoutDirection)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTextDirection", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_IDX]);

    // Call function/method
    {
        ::Qt::LayoutDirection cppArg0{Qt::LeftToRight};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTextDirection(Qt::LayoutDirection)
            cppSelf->setTextDirection(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextOptionFunc_setUseDesignMetrics(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextOption *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextOption::setUseDesignMetrics(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setUseDesignMetrics(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUseDesignMetrics", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setUseDesignMetrics(bool)
            cppSelf->setUseDesignMetrics(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextOptionFunc_setWrapMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextOption *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextOption::setWrapMode(QTextOption::WrapMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_WrapMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setWrapMode(QTextOption::WrapMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setWrapMode", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_IDX]);

    // Call function/method
    {
        ::QTextOption::WrapMode cppArg0{QTextOption::NoWrap};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setWrapMode(QTextOption::WrapMode)
            cppSelf->setWrapMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextOptionFunc_tabArray(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextOption *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // tabArray()const
        QList<qreal> cppResult = const_cast<const ::QTextOption *>(cppSelf)->tabArray();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_qreal_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextOptionFunc_tabStopDistance(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextOption *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // tabStopDistance()const
        qreal cppResult = const_cast<const ::QTextOption *>(cppSelf)->tabStopDistance();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextOptionFunc_tabs(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextOption *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // tabs()const
        QList<QTextOption::Tab> cppResult = const_cast<const ::QTextOption *>(cppSelf)->tabs();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QTextOption_Tab_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextOptionFunc_textDirection(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextOption *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // textDirection()const
        Qt::LayoutDirection cppResult = const_cast<const ::QTextOption *>(cppSelf)->textDirection();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_LayoutDirection_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextOptionFunc_useDesignMetrics(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextOption *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // useDesignMetrics()const
        bool cppResult = const_cast<const ::QTextOption *>(cppSelf)->useDesignMetrics();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextOptionFunc_wrapMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextOption *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // wrapMode()const
        QTextOption::WrapMode cppResult = const_cast<const ::QTextOption *>(cppSelf)->wrapMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_WrapMode_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextOption__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QTextOption *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QTextOption_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QTextOption_EnumFlagInfo[] = {
    "Flag:Flag:Flags",
    "TabType:Enum",
    "WrapMode:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QTextOption_methods[] = {
    {"alignment", reinterpret_cast<PyCFunction>(Sbk_QTextOptionFunc_alignment), METH_NOARGS, nullptr},
    {"flags", reinterpret_cast<PyCFunction>(Sbk_QTextOptionFunc_flags), METH_NOARGS, nullptr},
    {"setAlignment", reinterpret_cast<PyCFunction>(Sbk_QTextOptionFunc_setAlignment), METH_O, nullptr},
    {"setFlags", reinterpret_cast<PyCFunction>(Sbk_QTextOptionFunc_setFlags), METH_O, nullptr},
    {"setTabArray", reinterpret_cast<PyCFunction>(Sbk_QTextOptionFunc_setTabArray), METH_O, nullptr},
    {"setTabStopDistance", reinterpret_cast<PyCFunction>(Sbk_QTextOptionFunc_setTabStopDistance), METH_O, nullptr},
    {"setTabs", reinterpret_cast<PyCFunction>(Sbk_QTextOptionFunc_setTabs), METH_O, nullptr},
    {"setTextDirection", reinterpret_cast<PyCFunction>(Sbk_QTextOptionFunc_setTextDirection), METH_O, nullptr},
    {"setUseDesignMetrics", reinterpret_cast<PyCFunction>(Sbk_QTextOptionFunc_setUseDesignMetrics), METH_O, nullptr},
    {"setWrapMode", reinterpret_cast<PyCFunction>(Sbk_QTextOptionFunc_setWrapMode), METH_O, nullptr},
    {"tabArray", reinterpret_cast<PyCFunction>(Sbk_QTextOptionFunc_tabArray), METH_NOARGS, nullptr},
    {"tabStopDistance", reinterpret_cast<PyCFunction>(Sbk_QTextOptionFunc_tabStopDistance), METH_NOARGS, nullptr},
    {"tabs", reinterpret_cast<PyCFunction>(Sbk_QTextOptionFunc_tabs), METH_NOARGS, nullptr},
    {"textDirection", reinterpret_cast<PyCFunction>(Sbk_QTextOptionFunc_textDirection), METH_NOARGS, nullptr},
    {"useDesignMetrics", reinterpret_cast<PyCFunction>(Sbk_QTextOptionFunc_useDesignMetrics), METH_NOARGS, nullptr},
    {"wrapMode", reinterpret_cast<PyCFunction>(Sbk_QTextOptionFunc_wrapMode), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QTextOption__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QTextOption_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QTextOption_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QTextOption_Type = nullptr;
static PyTypeObject *Sbk_QTextOption_TypeF(void)
{
    return _Sbk_QTextOption_Type;
}

static PyType_Slot Sbk_QTextOption_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QTextOption_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QTextOption_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QTextOption_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QTextOption_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QTextOption_spec = {
    "2:PySide6.QtGui.QTextOption",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QTextOption_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QTextOption_TabType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QTextOption::TabType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QTextOption::TabType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QTextOption_TabType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_TabType_IDX])))
        return Enum_PythonToCpp_QTextOption_TabType;
    return {};
}

static PyObject *QTextOption_TabType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QTextOption::TabType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QTextOption::TabType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_TabType_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QTextOption_WrapMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QTextOption::WrapMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QTextOption::WrapMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QTextOption_WrapMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_WrapMode_IDX])))
        return Enum_PythonToCpp_QTextOption_WrapMode;
    return {};
}

static PyObject *QTextOption_WrapMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QTextOption::WrapMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QTextOption::WrapMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_WrapMode_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QTextOption_Flag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QTextOption::Flag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QTextOption::Flag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QTextOption_Flag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_Flag_IDX])))
        return Enum_PythonToCpp_QTextOption_Flag;
    return {};
}

static PyObject *QTextOption_Flag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QTextOption::Flag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QTextOption::Flag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_Flag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QTextOption_Flag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QTextOption::Flag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QTextOption::Flag> *>(cppOut) = value;

}

static PyObject *QTextOption_Flag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QTextOption::Flag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_Flag_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QTextOption_PythonToCpp_QTextOption_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QTextOption_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QTextOption_PythonToCpp_QTextOption_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QTextOption_TypeF()))
        return QTextOption_PythonToCpp_QTextOption_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QTextOption_PTR_CppToPython_QTextOption(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QTextOption_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QTextOption_COPY_CppToPython_QTextOption(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QTextOption *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QTextOption_TypeF(), new ::QTextOption(*source), true, true);
}

// Python to C++ copy conversion.
static void QTextOption_PythonToCpp_QTextOption_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QTextOption *>(cppOut) = *reinterpret_cast< ::QTextOption *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QTextOption_PythonToCpp_QTextOption_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QTextOption_TypeF()))
        return QTextOption_PythonToCpp_QTextOption_COPY;
    return {};
}

// Implicit conversions.
static void PySide6_QtCore_QFlags_Qt_AlignmentFlag__PythonToCpp_QTextOption(PyObject *pyIn, void *cppOut)
{
    ::QFlags<Qt::AlignmentFlag> cppIn = QFlags<Qt::AlignmentFlag>(0);
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_AlignmentFlag_IDX])))->flagsConverter, pyIn, &cppIn);
    *reinterpret_cast<::QTextOption *>(cppOut) = ::QTextOption(cppIn);
}
static PythonToCppFunc is_PySide6_QtCore_QFlags_Qt_AlignmentFlag__PythonToCpp_QTextOption_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_AlignmentFlag_IDX]), pyIn))
        return PySide6_QtCore_QFlags_Qt_AlignmentFlag__PythonToCpp_QTextOption;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QTextOption_SignatureStrings[] = {
    "2:PySide6.QtGui.QTextOption(self)",
    "1:PySide6.QtGui.QTextOption(self,alignment:PySide6.QtCore.Qt.AlignmentFlag)",
    "0:PySide6.QtGui.QTextOption(self,o:PySide6.QtGui.QTextOption)",
    "PySide6.QtGui.QTextOption.alignment(self)->PySide6.QtCore.Qt.AlignmentFlag",
    "PySide6.QtGui.QTextOption.flags(self)->PySide6.QtGui.QTextOption.Flag",
    "PySide6.QtGui.QTextOption.setAlignment(self,alignment:PySide6.QtCore.Qt.AlignmentFlag)",
    "PySide6.QtGui.QTextOption.setFlags(self,flags:PySide6.QtGui.QTextOption.Flag)",
    "PySide6.QtGui.QTextOption.setTabArray(self,tabStops:QList[qreal])",
    "PySide6.QtGui.QTextOption.setTabStopDistance(self,tabStopDistance:qreal)",
    "PySide6.QtGui.QTextOption.setTabs(self,tabStops:QList[PySide6.QtGui.QTextOption.Tab])",
    "PySide6.QtGui.QTextOption.setTextDirection(self,aDirection:PySide6.QtCore.Qt.LayoutDirection)",
    "PySide6.QtGui.QTextOption.setUseDesignMetrics(self,b:bool)",
    "PySide6.QtGui.QTextOption.setWrapMode(self,wrap:PySide6.QtGui.QTextOption.WrapMode)",
    "PySide6.QtGui.QTextOption.tabArray(self)->QList[qreal]",
    "PySide6.QtGui.QTextOption.tabStopDistance(self)->qreal",
    "PySide6.QtGui.QTextOption.tabs(self)->QList[PySide6.QtGui.QTextOption.Tab]",
    "PySide6.QtGui.QTextOption.textDirection(self)->PySide6.QtCore.Qt.LayoutDirection",
    "PySide6.QtGui.QTextOption.useDesignMetrics(self)->bool",
    "PySide6.QtGui.QTextOption.wrapMode(self)->PySide6.QtGui.QTextOption.WrapMode",
    "PySide6.QtGui.QTextOption.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QTextOption_SignatureByteSize = 315;
static constexpr uint8_t QTextOption_SignatureBytes[315] = {
    0x78, 0xda, 0x95, 0x93, 0x41, 0x4f, 0x83, 0x40, 0x10, 0x85, 0xef, 0xfc, 0x12, 0x49, 0x2a, 0x51,
    0x0f, 0x1e, 0x38, 0x98, 0x10, 0x9b, 0x7a, 0x69, 0xa3, 0x84, 0x1a, 0x0f, 0xc6, 0x90, 0x85, 0x4e,
    0xc9, 0x26, 0xc8, 0xe2, 0xee, 0x90, 0xca, 0xbf, 0x77, 0x4a, 0x0b, 0x42, 0x81, 0xd9, 0xf4, 0xb4,
    0x99, 0x9d, 0x79, 0x1f, 0x8f, 0x7d, 0xbb, 0x0f, 0xfe, 0x5b, 0x1d, 0xc9, 0x1d, 0x3c, 0x7a, 0x21,
    0xbe, 0x54, 0xd2, 0x0b, 0xb7, 0xf0, 0x8b, 0xaf, 0x25, 0x4a, 0x55, 0xdc, 0x18, 0xc8, 0xf7, 0xae,
    0x73, 0x6f, 0x99, 0x58, 0x88, 0x5c, 0x66, 0xc5, 0x37, 0x14, 0xd8, 0x1b, 0x7c, 0x56, 0x1a, 0x68,
    0xf1, 0x82, 0xb6, 0xb7, 0xca, 0x45, 0xe6, 0x3a, 0x77, 0x36, 0x96, 0x9a, 0x1f, 0x70, 0x9d, 0xd9,
    0x96, 0xd7, 0x59, 0x38, 0x79, 0xbe, 0x7d, 0xb2, 0x38, 0x61, 0x50, 0x7b, 0x6a, 0x9b, 0x31, 0xe6,
    0x72, 0xcc, 0x42, 0x31, 0x80, 0xc1, 0xc0, 0xd3, 0x35, 0xa7, 0xc4, 0x62, 0x57, 0x9d, 0xbf, 0x45,
    0x63, 0xd5, 0xe7, 0x3d, 0x5a, 0x68, 0x5b, 0x91, 0x04, 0x5a, 0x8b, 0xfa, 0x04, 0x44, 0x91, 0x44,
    0xa8, 0x4a, 0xe3, 0x87, 0x6b, 0x69, 0xf0, 0xf3, 0x47, 0x83, 0xc8, 0xbf, 0xec, 0x84, 0xa3, 0x66,
    0x49, 0x02, 0x51, 0xa4, 0x30, 0x00, 0xb5, 0x9b, 0x7e, 0x43, 0xb2, 0x83, 0xcc, 0xa4, 0x8d, 0x79,
    0x15, 0x49, 0xac, 0xf6, 0xa8, 0x5a, 0x4a, 0x0d, 0x69, 0xef, 0xbe, 0x76, 0xf5, 0x44, 0x14, 0x6b,
    0x51, 0xab, 0xea, 0x5f, 0x61, 0xa1, 0xbf, 0x1b, 0x58, 0x82, 0xa1, 0xf0, 0x36, 0x80, 0x5a, 0xa6,
    0x67, 0xff, 0x89, 0x9f, 0x28, 0x65, 0xfb, 0xdd, 0x0f, 0x2d, 0xca, 0x8d, 0xda, 0x9d, 0x0f, 0xec,
    0x40, 0x15, 0x93, 0x64, 0x3b, 0xcc, 0x31, 0xb1, 0x1f, 0x25, 0xdd, 0xdd, 0x7e, 0x86, 0xbc, 0x6c,
    0x94, 0x1f, 0xa9, 0x1b, 0x1d, 0x2f, 0x33, 0xc3, 0x2f, 0xf1, 0x31, 0x71, 0xa8, 0x51, 0x44, 0x93,
    0x0f, 0xf8, 0x22, 0x19, 0x06, 0x58, 0x4d, 0xa5, 0x42, 0xcc, 0x63, 0x2a, 0x8c, 0xec, 0xd0, 0x4f,
    0x84, 0x7d, 0xfc, 0x6d, 0x1c, 0x0c, 0x2c, 0x8e, 0x53, 0x55, 0xd6, 0x71, 0xdc, 0xc2, 0xb0, 0x2e,
    0x65, 0x91, 0x79, 0x11, 0x55, 0xce, 0x1f, 0xdd, 0xfd, 0xf7, 0xbf
};
#endif

PyTypeObject *init_QTextOption(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_IDX].type;

    Shiboken::AutoDecRef Sbk_QTextOption_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QTextOption_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QTextOption",
        "QTextOption",
        &Sbk_QTextOption_spec,
        &Shiboken::callCppDestructor< ::QTextOption >,
        Sbk_QTextOption_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QTextOption_TypeF(); // references _Sbk_QTextOption_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QTextOption_SignatureStrings);
#else
    InitSignatureBytes(pyType, QTextOption_SignatureBytes, QTextOption_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QTextOption_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QTextOption_PythonToCpp_QTextOption_PTR,
        is_QTextOption_PythonToCpp_QTextOption_PTR_Convertible,
        QTextOption_PTR_CppToPython_QTextOption,
        QTextOption_COPY_CppToPython_QTextOption);

    Shiboken::Conversions::registerConverterName(converter, "QTextOption");
    Shiboken::Conversions::registerConverterName(converter, "QTextOption*");
    Shiboken::Conversions::registerConverterName(converter, "QTextOption&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QTextOption).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QTextOption_PythonToCpp_QTextOption_COPY,
        is_QTextOption_PythonToCpp_QTextOption_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        PySide6_QtCore_QFlags_Qt_AlignmentFlag__PythonToCpp_QTextOption,
        is_PySide6_QtCore_QFlags_Qt_AlignmentFlag__PythonToCpp_QTextOption_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QTextOption_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'TabType'.
    const char *TabType_Initializer[] = {
        "LeftTab",
        "RightTab",
        "CenterTab",
        "DelimiterTab",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t TabType_InitializerValues[] = {
        uint8_t(QTextOption::TabType::LeftTab),     //  0x00  0
        uint8_t(QTextOption::TabType::RightTab),    //  0x01  1
        uint8_t(QTextOption::TabType::CenterTab),   //  0x02  2
        uint8_t(QTextOption::TabType::DelimiterTab) //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QTextOption_TypeF(),
        "2:PySide6.QtGui.QTextOption.TabType",
        TabType_Initializer, TabType_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_TabType_IDX].type = EType;
    // Register converter for enum 'QTextOption::TabType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QTextOption_TabType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QTextOption_TabType,
            is_Enum_PythonToCpp_QTextOption_TabType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QTextOption::TabType");
        Shiboken::Conversions::registerConverterAlias(converter, "TabType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'TabType' enum.

    // Initialization of enum 'WrapMode'.
    const char *WrapMode_Initializer[] = {
        "NoWrap",
        "WordWrap",
        "ManualWrap",
        "WrapAnywhere",
        "WrapAtWordBoundaryOrAnywhere",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t WrapMode_InitializerValues[] = {
        uint8_t(QTextOption::WrapMode::NoWrap),                      //  0x00  0
        uint8_t(QTextOption::WrapMode::WordWrap),                    //  0x01  1
        uint8_t(QTextOption::WrapMode::ManualWrap),                  //  0x02  2
        uint8_t(QTextOption::WrapMode::WrapAnywhere),                //  0x03  3
        uint8_t(QTextOption::WrapMode::WrapAtWordBoundaryOrAnywhere) //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QTextOption_TypeF(),
        "2:PySide6.QtGui.QTextOption.WrapMode",
        WrapMode_Initializer, WrapMode_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_WrapMode_IDX].type = EType;
    // Register converter for enum 'QTextOption::WrapMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QTextOption_WrapMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QTextOption_WrapMode,
            is_Enum_PythonToCpp_QTextOption_WrapMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QTextOption::WrapMode");
        Shiboken::Conversions::registerConverterAlias(converter, "WrapMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'WrapMode' enum.

    // Initialization of enum 'Flag'.
    const char *Flag_Initializer[] = {
        "ShowTabsAndSpaces",
        "ShowLineAndParagraphSeparators",
        "AddSpaceForLineAndParagraphSeparators",
        "SuppressColors",
        "ShowDocumentTerminator",
        "IncludeTrailingSpaces",
        nullptr};
    constexpr unsigned Flag_InitializerValues[] = {
        unsigned(QTextOption::Flag::ShowTabsAndSpaces),                     //  0x1  1
        unsigned(QTextOption::Flag::ShowLineAndParagraphSeparators),        //  0x2  2
        unsigned(QTextOption::Flag::AddSpaceForLineAndParagraphSeparators), //  0x4  4
        unsigned(QTextOption::Flag::SuppressColors),                        //  0x8  8
        unsigned(QTextOption::Flag::ShowDocumentTerminator),                //  0x10  16
        unsigned(QTextOption::Flag::IncludeTrailingSpaces)                  //  0x80000000  2147483648
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QTextOption_TypeF(),
        "2:PySide6.QtGui.QTextOption.Flag",
        Flag_Initializer, Flag_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_Flag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QTextOption_Flag_IDX].type =
        EType;
    // Register converter for enum 'QTextOption::Flag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QTextOption_Flag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QTextOption_Flag,
            is_Enum_PythonToCpp_QTextOption_Flag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QTextOption::Flag");
        Shiboken::Conversions::registerConverterAlias(converter, "Flag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QTextOption_Flag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QTextOption_Flag,
            is_Enum_PythonToCpp_QTextOption_Flag_Convertible);
        // Register converter for flag 'QFlags<QTextOption::Flag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QTextOption::Flag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QTextOption::Flags");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'Flag' enum/flags.

    qRegisterMetaType< ::QTextOption >("QTextOption");
    qRegisterMetaType< ::QTextOption::TabType >("QTextOption::TabType");
    qRegisterMetaType< ::QTextOption::WrapMode >("QTextOption::WrapMode");
    qRegisterMetaType< ::QTextOption::Flag >("QTextOption::Flag");

    return pyType;
}
