// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qtexttablecell_wrapper.h"

// Extra includes
#include <QTextCursor>

// Argument includes
#include <QTextFrame>
#include <QtGui/qtextcursor.h>
#include <QtGui/qtextformat.h>
#include <QtGui/qtexttable.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTextTableCell_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QTextTableCell >()))
        return -1;

    ::QTextTableCell *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QTextTableCell", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QTextTableCell::QTextTableCell()
    // 1: QTextTableCell::QTextTableCell(QTextTableCell)
    if (numArgs == 0) {
        overloadId = 0; // QTextTableCell()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextTableCell_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QTextTableCell(QTextTableCell)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextTableCell_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QTextTableCell_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QTextTableCell()
        {

            // QTextTableCell()
            cptr = new ::QTextTableCell();
            break;
        }
        case 1: // QTextTableCell(const QTextTableCell &o)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QTextTableCell cppArg0_local;
            ::QTextTableCell *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QTextTableCell(QTextTableCell)
                cptr = new ::QTextTableCell(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QTextTableCell >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextTableCell_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QTextTableCellFunc_begin(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextTableCell *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextTableCell_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // begin()const
        QTextFrame::iterator cppResult = const_cast<const ::QTextTableCell *>(cppSelf)->begin();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFrame_iterator_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextTableCellFunc_column(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextTableCell *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextTableCell_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // column()const
        int cppResult = const_cast<const ::QTextTableCell *>(cppSelf)->column();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextTableCellFunc_columnSpan(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextTableCell *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextTableCell_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // columnSpan()const
        int cppResult = const_cast<const ::QTextTableCell *>(cppSelf)->columnSpan();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextTableCellFunc_end(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextTableCell *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextTableCell_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // end()const
        QTextFrame::iterator cppResult = const_cast<const ::QTextTableCell *>(cppSelf)->end();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFrame_iterator_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextTableCellFunc_firstCursorPosition(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextTableCell *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextTableCell_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // firstCursorPosition()const
        QTextCursor cppResult = const_cast<const ::QTextTableCell *>(cppSelf)->firstCursorPosition();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextTableCellFunc_firstPosition(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextTableCell *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextTableCell_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // firstPosition()const
        int cppResult = const_cast<const ::QTextTableCell *>(cppSelf)->firstPosition();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextTableCellFunc_format(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextTableCell *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextTableCell_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // format()const
        QTextCharFormat cppResult = const_cast<const ::QTextTableCell *>(cppSelf)->format();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextTableCellFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextTableCell *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextTableCell_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QTextTableCell *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextTableCellFunc_lastCursorPosition(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextTableCell *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextTableCell_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lastCursorPosition()const
        QTextCursor cppResult = const_cast<const ::QTextTableCell *>(cppSelf)->lastCursorPosition();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextTableCellFunc_lastPosition(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextTableCell *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextTableCell_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lastPosition()const
        int cppResult = const_cast<const ::QTextTableCell *>(cppSelf)->lastPosition();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextTableCellFunc_row(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextTableCell *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextTableCell_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // row()const
        int cppResult = const_cast<const ::QTextTableCell *>(cppSelf)->row();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextTableCellFunc_rowSpan(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextTableCell *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextTableCell_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rowSpan()const
        int cppResult = const_cast<const ::QTextTableCell *>(cppSelf)->rowSpan();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextTableCellFunc_setFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextTableCell *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextTableCell_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextTableCell::setFormat(QTextCharFormat)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), (pyArg)))) {
        overloadId = 0; // setFormat(QTextCharFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFormat", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextTableCell_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTextCharFormat cppArg0_local;
        ::QTextCharFormat *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setFormat(QTextCharFormat)
            cppSelf->setFormat(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextTableCellFunc_tableCellFormatIndex(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextTableCell *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextTableCell_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // tableCellFormatIndex()const
        int cppResult = const_cast<const ::QTextTableCell *>(cppSelf)->tableCellFormatIndex();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextTableCell__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QTextTableCell *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextTableCell_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextTableCell_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QTextTableCell_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QTextTableCell_methods[] = {
    {"begin", reinterpret_cast<PyCFunction>(Sbk_QTextTableCellFunc_begin), METH_NOARGS, nullptr},
    {"column", reinterpret_cast<PyCFunction>(Sbk_QTextTableCellFunc_column), METH_NOARGS, nullptr},
    {"columnSpan", reinterpret_cast<PyCFunction>(Sbk_QTextTableCellFunc_columnSpan), METH_NOARGS, nullptr},
    {"end", reinterpret_cast<PyCFunction>(Sbk_QTextTableCellFunc_end), METH_NOARGS, nullptr},
    {"firstCursorPosition", reinterpret_cast<PyCFunction>(Sbk_QTextTableCellFunc_firstCursorPosition), METH_NOARGS, nullptr},
    {"firstPosition", reinterpret_cast<PyCFunction>(Sbk_QTextTableCellFunc_firstPosition), METH_NOARGS, nullptr},
    {"format", reinterpret_cast<PyCFunction>(Sbk_QTextTableCellFunc_format), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QTextTableCellFunc_isValid), METH_NOARGS, nullptr},
    {"lastCursorPosition", reinterpret_cast<PyCFunction>(Sbk_QTextTableCellFunc_lastCursorPosition), METH_NOARGS, nullptr},
    {"lastPosition", reinterpret_cast<PyCFunction>(Sbk_QTextTableCellFunc_lastPosition), METH_NOARGS, nullptr},
    {"row", reinterpret_cast<PyCFunction>(Sbk_QTextTableCellFunc_row), METH_NOARGS, nullptr},
    {"rowSpan", reinterpret_cast<PyCFunction>(Sbk_QTextTableCellFunc_rowSpan), METH_NOARGS, nullptr},
    {"setFormat", reinterpret_cast<PyCFunction>(Sbk_QTextTableCellFunc_setFormat), METH_O, nullptr},
    {"tableCellFormatIndex", reinterpret_cast<PyCFunction>(Sbk_QTextTableCellFunc_tableCellFormatIndex), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QTextTableCell__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QTextTableCell_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QTextTableCell *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextTableCell_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextTableCell_IDX]), (pyArg)))) {
                // operator!=(const QTextTableCell &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QTextTableCell cppArg0_local;
                ::QTextTableCell *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextTableCell_IDX]), (pyArg)))) {
                // operator==(const QTextTableCell &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QTextTableCell cppArg0_local;
                ::QTextTableCell *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QTextTableCell_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QTextTableCell_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QTextTableCell_Type = nullptr;
static PyTypeObject *Sbk_QTextTableCell_TypeF(void)
{
    return _Sbk_QTextTableCell_Type;
}

static PyType_Slot Sbk_QTextTableCell_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QTextTableCell_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QTextTableCell_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QTextTableCell_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QTextTableCell_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QTextTableCell_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QTextTableCell_spec = {
    "2:PySide6.QtGui.QTextTableCell",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QTextTableCell_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QTextTableCell_PythonToCpp_QTextTableCell_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QTextTableCell_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QTextTableCell_PythonToCpp_QTextTableCell_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QTextTableCell_TypeF()))
        return QTextTableCell_PythonToCpp_QTextTableCell_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QTextTableCell_PTR_CppToPython_QTextTableCell(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QTextTableCell_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QTextTableCell_COPY_CppToPython_QTextTableCell(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QTextTableCell *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QTextTableCell_TypeF(), new ::QTextTableCell(*source), true, true);
}

// Python to C++ copy conversion.
static void QTextTableCell_PythonToCpp_QTextTableCell_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QTextTableCell *>(cppOut) = *reinterpret_cast< ::QTextTableCell *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextTableCell_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QTextTableCell_PythonToCpp_QTextTableCell_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QTextTableCell_TypeF()))
        return QTextTableCell_PythonToCpp_QTextTableCell_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QTextTableCell_SignatureStrings[] = {
    "1:PySide6.QtGui.QTextTableCell(self)",
    "0:PySide6.QtGui.QTextTableCell(self,o:PySide6.QtGui.QTextTableCell)",
    "PySide6.QtGui.QTextTableCell.begin(self)->PySide6.QtGui.QTextFrame.iterator",
    "PySide6.QtGui.QTextTableCell.column(self)->int",
    "PySide6.QtGui.QTextTableCell.columnSpan(self)->int",
    "PySide6.QtGui.QTextTableCell.end(self)->PySide6.QtGui.QTextFrame.iterator",
    "PySide6.QtGui.QTextTableCell.firstCursorPosition(self)->PySide6.QtGui.QTextCursor",
    "PySide6.QtGui.QTextTableCell.firstPosition(self)->int",
    "PySide6.QtGui.QTextTableCell.format(self)->PySide6.QtGui.QTextCharFormat",
    "PySide6.QtGui.QTextTableCell.isValid(self)->bool",
    "PySide6.QtGui.QTextTableCell.lastCursorPosition(self)->PySide6.QtGui.QTextCursor",
    "PySide6.QtGui.QTextTableCell.lastPosition(self)->int",
    "PySide6.QtGui.QTextTableCell.row(self)->int",
    "PySide6.QtGui.QTextTableCell.rowSpan(self)->int",
    "PySide6.QtGui.QTextTableCell.setFormat(self,format:PySide6.QtGui.QTextCharFormat)",
    "PySide6.QtGui.QTextTableCell.tableCellFormatIndex(self)->int",
    "PySide6.QtGui.QTextTableCell.__copy__(self)->typing.Self",
    "PySide6.QtGui.QTextTableCell.__ne__(self,other:PySide6.QtGui.QTextTableCell)->bool",
    "PySide6.QtGui.QTextTableCell.__eq__(self,other:PySide6.QtGui.QTextTableCell)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QTextTableCell_SignatureByteSize = 243;
static constexpr uint8_t QTextTableCell_SignatureBytes[243] = {
    0x78, 0xda, 0xad, 0x93, 0x41, 0x6b, 0xc3, 0x30, 0x0c, 0x85, 0xef, 0xfd, 0x25, 0x2b, 0x64, 0x66,
    0xbd, 0xf4, 0xd0, 0xc3, 0x2e, 0x85, 0x8c, 0xdd, 0x5a, 0x52, 0x76, 0x35, 0x4e, 0xa3, 0xb4, 0x02,
    0xc7, 0x4a, 0x65, 0x85, 0x35, 0xff, 0xbe, 0xdd, 0xb2, 0x76, 0x30, 0x86, 0xe2, 0x40, 0x6f, 0x36,
    0xfe, 0xde, 0xb3, 0xf4, 0x6c, 0x2d, 0x56, 0x9b, 0xbe, 0xc0, 0x0a, 0x96, 0x66, 0x2b, 0x6f, 0x1d,
    0x9a, 0xed, 0x0e, 0xce, 0xb2, 0x73, 0xa5, 0x87, 0x35, 0x78, 0xff, 0x14, 0xc1, 0xd7, 0xf3, 0xd9,
    0xcb, 0x38, 0x94, 0x91, 0xca, 0xcc, 0x67, 0xda, 0xa9, 0x29, 0xe1, 0x80, 0x61, 0xb8, 0xec, 0xf9,
    0xf5, 0x1f, 0x32, 0x67, 0xd7, 0x80, 0x41, 0x01, 0x76, 0x42, 0xac, 0x7b, 0xed, 0xc9, 0x77, 0xcd,
    0xdd, 0x0c, 0x83, 0xa4, 0xe0, 0x45, 0xeb, 0xd2, 0x25, 0x10, 0xaa, 0x07, 0xd5, 0x5a, 0x23, 0x47,
    0x59, 0x77, 0x1c, 0x89, 0x37, 0x14, 0x51, 0x90, 0xb4, 0x14, 0x06, 0x30, 0xc1, 0xf1, 0xaf, 0xd7,
    0x68, 0x47, 0x35, 0x71, 0xe3, 0x44, 0xbb, 0xfa, 0xe8, 0x38, 0xff, 0x86, 0x74, 0x23, 0x8c, 0x1f,
    0xce, 0xe3, 0x3d, 0x9e, 0x92, 0xc8, 0xeb, 0x02, 0xef, 0x1e, 0x1c, 0xc0, 0x97, 0xe1, 0xe4, 0xfe,
    0x99, 0x3e, 0xa7, 0xb0, 0x93, 0x7e, 0x4b, 0x04, 0xc9, 0x7f, 0xe3, 0xcd, 0x86, 0xa8, 0x57, 0x6a,
    0xc6, 0x23, 0xd3, 0x22, 0xb7, 0xd5, 0x40, 0xbf, 0x87, 0x0a, 0xce, 0xc9, 0xe5, 0x58, 0xbb, 0xa7,
    0xb6, 0xb7, 0xf6, 0x26, 0x90, 0xbe, 0xc5, 0x70, 0x30, 0xc5, 0x75, 0x37, 0x26, 0x0c, 0xf0, 0x23,
    0xcb, 0x48, 0x8e, 0xc0, 0xfa, 0xc0, 0xa7, 0x3c, 0xbe, 0xb5, 0x70, 0x9a, 0x6e, 0x79, 0x01, 0xb3,
    0xb0, 0xac, 0xf9
};
#endif

PyTypeObject *init_QTextTableCell(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QTextTableCell_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QTextTableCell_IDX].type;

    Shiboken::AutoDecRef Sbk_QTextTableCell_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QTextTableCell_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QTextTableCell",
        "QTextTableCell",
        &Sbk_QTextTableCell_spec,
        &Shiboken::callCppDestructor< ::QTextTableCell >,
        Sbk_QTextTableCell_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QTextTableCell_TypeF(); // references _Sbk_QTextTableCell_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QTextTableCell_SignatureStrings);
#else
    InitSignatureBytes(pyType, QTextTableCell_SignatureBytes, QTextTableCell_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QTextTableCell_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QTextTableCell_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QTextTableCell_PythonToCpp_QTextTableCell_PTR,
        is_QTextTableCell_PythonToCpp_QTextTableCell_PTR_Convertible,
        QTextTableCell_PTR_CppToPython_QTextTableCell,
        QTextTableCell_COPY_CppToPython_QTextTableCell);

    Shiboken::Conversions::registerConverterName(converter, "QTextTableCell");
    Shiboken::Conversions::registerConverterName(converter, "QTextTableCell*");
    Shiboken::Conversions::registerConverterName(converter, "QTextTableCell&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QTextTableCell).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QTextTableCell_PythonToCpp_QTextTableCell_COPY,
        is_QTextTableCell_PythonToCpp_QTextTableCell_COPY_Convertible);


    return pyType;
}
