// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qtransform_wrapper.h"

// Argument includes
#include <QtGui/qpainterpath.h>
#include <QtGui/qpolygon.h>
#include <QtGui/qregion.h>
#include <QtGui/qtransform.h>
#include <qdatastream.h>
#include <qline.h>
#include <qnamespace.h>
#include <qpoint.h>
#include <qrect.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTransform_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QTransform >()))
        return -1;

    ::QTransform *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[9];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3 || numArgs == 4 || numArgs == 5 || numArgs == 7 || numArgs == 8)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]);

    if (PyArg_UnpackTuple(args, "QTransform", 0, 9, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7]), &(pyArgs[8])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QTransform::QTransform()
    // 1: QTransform::QTransform(QTransform)
    // 2: QTransform::QTransform(qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal)
    // 3: QTransform::QTransform(qreal,qreal,qreal,qreal,qreal,qreal)
    if (numArgs == 0) {
        overloadId = 0; // QTransform()
    } else if (numArgs >= 6
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[5])))) {
        if (numArgs == 6) {
            overloadId = 3; // QTransform(qreal,qreal,qreal,qreal,qreal,qreal)
        } else if (numArgs == 9
            && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[6])))
            && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[7])))
            && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[8])))) {
            overloadId = 2; // QTransform(qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QTransform(QTransform)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QTransform()
        {

            // QTransform()
            cptr = new ::QTransform();
            break;
        }
        case 1: // QTransform(const QTransform &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QTransform cppArg0_local;
            ::QTransform *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QTransform(QTransform)
                cptr = new ::QTransform(*cppArg0);
            }
            break;
        }
        case 2: // QTransform(qreal h11, qreal h12, qreal h13, qreal h21, qreal h22, qreal h23, qreal h31, qreal h32, qreal h33)
        {
            qreal cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            qreal cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            qreal cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            qreal cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            qreal cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);
            qreal cppArg6;
            pythonToCpp[6](pyArgs[6], &cppArg6);
            qreal cppArg7;
            pythonToCpp[7](pyArgs[7], &cppArg7);
            qreal cppArg8;
            pythonToCpp[8](pyArgs[8], &cppArg8);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QTransform(qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal)
                cptr = new ::QTransform(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8);
            }
            break;
        }
        case 3: // QTransform(qreal h11, qreal h12, qreal h21, qreal h22, qreal dx, qreal dy)
        {
            qreal cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            qreal cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            qreal cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            qreal cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            qreal cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QTransform(qreal,qreal,qreal,qreal,qreal,qreal)
                cptr = new ::QTransform(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QTransform >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QTransformFunc___reduce__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // __reduce__()
        // Begin code injection
        // TEMPLATE - reduce_code - START
        pyResult = Py_BuildValue("(N(ddddddddd))", PyObject_Type(self), cppSelf->m11(), cppSelf->m12(), cppSelf->m13(), cppSelf->m21(), cppSelf->m22(), cppSelf->m23(), cppSelf->m31(), cppSelf->m32(), cppSelf->m33());
        // TEMPLATE - reduce_code - END
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTransformFunc___repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // __repr__()
        // Begin code injection
        // TEMPLATE - repr_code - START
        QString format = QString::asprintf("%s(%f, %f, %f, %f, %f, %f, %f, %f, %f)",
            Py_TYPE(self)->tp_name, cppSelf->m11(), cppSelf->m12(), cppSelf->m13(), cppSelf->m21(), cppSelf->m22(), cppSelf->m23(), cppSelf->m31(), cppSelf->m32(), cppSelf->m33());
        pyResult = Shiboken::String::fromCString(qPrintable(format));
        // TEMPLATE - repr_code - END
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTransformFunc_adjoint(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // adjoint()const
        QTransform cppResult = const_cast<const ::QTransform *>(cppSelf)->adjoint();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTransformFunc_determinant(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // determinant()const
        qreal cppResult = const_cast<const ::QTransform *>(cppSelf)->determinant();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTransformFunc_dx(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // dx()const
        qreal cppResult = const_cast<const ::QTransform *>(cppSelf)->dx();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTransformFunc_dy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // dy()const
        qreal cppResult = const_cast<const ::QTransform *>(cppSelf)->dy();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTransformFunc_fromScale(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "fromScale", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTransform::fromScale(qreal,qreal)->QTransform
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))) {
        overloadId = 0; // fromScale(qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fromScale", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qreal cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromScale(qreal,qreal)
            QTransform cppResult = ::QTransform::fromScale(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTransformFunc_fromTranslate(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "fromTranslate", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTransform::fromTranslate(qreal,qreal)->QTransform
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))) {
        overloadId = 0; // fromTranslate(qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fromTranslate", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qreal cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromTranslate(qreal,qreal)
            QTransform cppResult = ::QTransform::fromTranslate(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTransformFunc_inverted(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        bool* removed_cppArg0 = nullptr;
        SBK_UNUSED(removed_cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // inverted(bool*)const
            // Begin code injection
            // TEMPLATE - fix_bool* - START
            bool ok_;
            ::QTransform retval_ = cppSelf->inverted(&ok_);
            // TEMPLATE - tuple_retval_ok - START
            pyResult = PyTuple_New(2);
            PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), &retval_));
            PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &ok_));
            // TEMPLATE - tuple_retval_ok - END
            // TEMPLATE - fix_bool* - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTransformFunc_isAffine(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isAffine()const
        bool cppResult = const_cast<const ::QTransform *>(cppSelf)->isAffine();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTransformFunc_isIdentity(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isIdentity()const
        bool cppResult = const_cast<const ::QTransform *>(cppSelf)->isIdentity();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTransformFunc_isInvertible(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isInvertible()const
        bool cppResult = const_cast<const ::QTransform *>(cppSelf)->isInvertible();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTransformFunc_isRotating(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isRotating()const
        bool cppResult = const_cast<const ::QTransform *>(cppSelf)->isRotating();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTransformFunc_isScaling(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isScaling()const
        bool cppResult = const_cast<const ::QTransform *>(cppSelf)->isScaling();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTransformFunc_isTranslating(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isTranslating()const
        bool cppResult = const_cast<const ::QTransform *>(cppSelf)->isTranslating();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTransformFunc_m11(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // m11()const
        qreal cppResult = const_cast<const ::QTransform *>(cppSelf)->m11();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTransformFunc_m12(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // m12()const
        qreal cppResult = const_cast<const ::QTransform *>(cppSelf)->m12();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTransformFunc_m13(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // m13()const
        qreal cppResult = const_cast<const ::QTransform *>(cppSelf)->m13();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTransformFunc_m21(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // m21()const
        qreal cppResult = const_cast<const ::QTransform *>(cppSelf)->m21();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTransformFunc_m22(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // m22()const
        qreal cppResult = const_cast<const ::QTransform *>(cppSelf)->m22();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTransformFunc_m23(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // m23()const
        qreal cppResult = const_cast<const ::QTransform *>(cppSelf)->m23();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTransformFunc_m31(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // m31()const
        qreal cppResult = const_cast<const ::QTransform *>(cppSelf)->m31();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTransformFunc_m32(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // m32()const
        qreal cppResult = const_cast<const ::QTransform *>(cppSelf)->m32();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTransformFunc_m33(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // m33()const
        qreal cppResult = const_cast<const ::QTransform *>(cppSelf)->m33();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTransformFunc_map(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "map", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTransform::map(QLine)const->QLine
    // 1: QTransform::map(QLineF)const->QLineF
    // 2: QTransform::map(QPainterPath)const->QPainterPath
    // 3: QTransform::map(QPoint)const->QPoint
    // 4: QTransform::map(QPointF)const->QPointF
    // 5: QTransform::map(QPolygon)const->QPolygon
    // 6: QTransform::map(QPolygonF)const->QPolygonF
    // 7: QTransform::map(QRegion)const->QRegion
    // 8: QTransform::map(qreal,qreal,qreal*,qreal*)const
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))) {
        overloadId = 8; // map(qreal,qreal,qreal*,qreal*)const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPolygon_IDX]), (pyArgs[0])))) {
        overloadId = 5; // map(QPolygon)const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRegion_IDX]), (pyArgs[0])))) {
        overloadId = 7; // map(QRegion)const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPolygonF_IDX]), (pyArgs[0])))) {
        overloadId = 6; // map(QPolygonF)const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[0])))) {
        overloadId = 3; // map(QPoint)const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[0])))) {
        overloadId = 4; // map(QPointF)const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_IDX]), (pyArgs[0])))) {
        overloadId = 2; // map(QPainterPath)const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLine_IDX]), (pyArgs[0])))) {
        overloadId = 0; // map(QLine)const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), (pyArgs[0])))) {
        overloadId = 1; // map(QLineF)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "map", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // map(const QLine &l) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QLine cppArg0_local;
            ::QLine *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // map(QLine)const
                QLine cppResult = const_cast<const ::QTransform *>(cppSelf)->map(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLine_IDX]), &cppResult);
            }
            break;
        }
        case 1: // map(const QLineF &l) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QLineF cppArg0_local;
            ::QLineF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // map(QLineF)const
                QLineF cppResult = const_cast<const ::QTransform *>(cppSelf)->map(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), &cppResult);
            }
            break;
        }
        case 2: // map(const QPainterPath &p) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPainterPath cppArg0_local;
            ::QPainterPath *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // map(QPainterPath)const
                QPainterPath cppResult = const_cast<const ::QTransform *>(cppSelf)->map(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_IDX]), &cppResult);
            }
            break;
        }
        case 3: // map(const QPoint &p) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPoint cppArg0_local;
            ::QPoint *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // map(QPoint)const
                QPoint cppResult = const_cast<const ::QTransform *>(cppSelf)->map(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), &cppResult);
            }
            break;
        }
        case 4: // map(const QPointF &p) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPointF cppArg0_local;
            ::QPointF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // map(QPointF)const
                QPointF cppResult = const_cast<const ::QTransform *>(cppSelf)->map(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
            }
            break;
        }
        case 5: // map(const QPolygon &a) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPolygon cppArg0_local;
            ::QPolygon *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // map(QPolygon)const
                QPolygon cppResult = const_cast<const ::QTransform *>(cppSelf)->map(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPolygon_IDX]), &cppResult);
            }
            break;
        }
        case 6: // map(const QPolygonF &a) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPolygonF cppArg0_local;
            ::QPolygonF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // map(QPolygonF)const
                QPolygonF cppResult = const_cast<const ::QTransform *>(cppSelf)->map(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPolygonF_IDX]), &cppResult);
            }
            break;
        }
        case 7: // map(const QRegion &r) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRegion cppArg0_local;
            ::QRegion *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // map(QRegion)const
                QRegion cppResult = const_cast<const ::QTransform *>(cppSelf)->map(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRegion_IDX]), &cppResult);
            }
            break;
        }
        case 8: // map(qreal x, qreal y, qreal *tx, qreal *ty) const
        {
            qreal cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // map(qreal,qreal,qreal*,qreal*)const
                // Begin code injection
                // TEMPLATE - fix_args,number*,number* - START
                qreal a, b;
                cppSelf->map(cppArg0, cppArg1, &a, &b);
                pyResult = PyTuple_New(2);
                PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &a));
                PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &b));
                // TEMPLATE - fix_args,number*,number* - END
                // End of code injection

            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTransformFunc_mapRect(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTransform::mapRect(QRect)const->QRect
    // 1: QTransform::mapRect(QRectF)const->QRectF
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArg)))) {
        overloadId = 0; // mapRect(QRect)const
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArg)))) {
        overloadId = 1; // mapRect(QRectF)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mapRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // mapRect(const QRect &arg__1) const
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QRect cppArg0_local;
            ::QRect *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // mapRect(QRect)const
                QRect cppResult = const_cast<const ::QTransform *>(cppSelf)->mapRect(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &cppResult);
            }
            break;
        }
        case 1: // mapRect(const QRectF &arg__1) const
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QRectF cppArg0_local;
            ::QRectF *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // mapRect(QRectF)const
                QRectF cppResult = const_cast<const ::QTransform *>(cppSelf)->mapRect(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTransformFunc_mapToPolygon(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTransform::mapToPolygon(QRect)const->QPolygon
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArg)))) {
        overloadId = 0; // mapToPolygon(QRect)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mapToPolygon", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRect cppArg0_local;
        ::QRect *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // mapToPolygon(QRect)const
            QPolygon cppResult = const_cast<const ::QTransform *>(cppSelf)->mapToPolygon(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPolygon_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTransformFunc_quadToQuad(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "quadToQuad", 2, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTransform::quadToQuad(QPolygonF&,QPolygonF&)->PyObject*
    // 1: static QTransform::quadToQuad(QPolygonF,QPolygonF,QTransform&)->bool
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPolygonF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPolygonF_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // quadToQuad(QPolygonF&,QPolygonF&)
        } else if (numArgs == 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), (pyArgs[2])))) {
            overloadId = 1; // quadToQuad(QPolygonF,QPolygonF,QTransform&)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "quadToQuad", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // quadToQuad(QPolygonF &one, QPolygonF &two)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPolygonF cppArg0_local;
            ::QPolygonF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            SBK_UNUSED(cppArg0)
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QPolygonF cppArg1_local;
            ::QPolygonF *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            SBK_UNUSED(cppArg1)

            if (Shiboken::Errors::occurred() == nullptr) {
                // quadToQuad(QPolygonF&,QPolygonF&)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtgui.cpp (qtransform-quadtoquad)]
                QTransform _result;
                if (QTransform::quadToQuad((*cppArg0), (*cppArg1), _result)) {
                    pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), &_result);
                } else {
                    Py_INCREF(Py_None);
                    pyResult = Py_None;
                }
                // END of custom code block [file: ../glue/qtgui.cpp (qtransform-quadtoquad)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 1: // quadToQuad(const QPolygonF &one, const QPolygonF &two, QTransform &result)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPolygonF cppArg0_local;
            ::QPolygonF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QPolygonF cppArg1_local;
            ::QPolygonF *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QTransform cppArg2_local;
            ::QTransform *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);


            if (Shiboken::Errors::occurred() == nullptr) {
                // quadToQuad(QPolygonF,QPolygonF,QTransform&)
                bool cppResult = ::QTransform::quadToQuad(*cppArg0, *cppArg1, *cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTransformFunc_quadToSquare(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "quadToSquare", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTransform::quadToSquare(QPolygonF&)->PyObject*
    // 1: static QTransform::quadToSquare(QPolygonF,QTransform&)->bool
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPolygonF_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // quadToSquare(QPolygonF&)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), (pyArgs[1])))) {
            overloadId = 1; // quadToSquare(QPolygonF,QTransform&)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "quadToSquare", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // quadToSquare(QPolygonF &arg__1)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPolygonF cppArg0_local;
            ::QPolygonF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            SBK_UNUSED(cppArg0)

            if (Shiboken::Errors::occurred() == nullptr) {
                // quadToSquare(QPolygonF&)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtgui.cpp (qtransform-quadtosquare)]
                QTransform _result;
                if (QTransform::quadToSquare((*cppArg0), _result)) {
                    pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), &_result);
                } else {
                    Py_INCREF(Py_None);
                    pyResult = Py_None;
                }
                // END of custom code block [file: ../glue/qtgui.cpp (qtransform-quadtosquare)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 1: // quadToSquare(const QPolygonF &quad, QTransform &result)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPolygonF cppArg0_local;
            ::QPolygonF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QTransform cppArg1_local;
            ::QTransform *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // quadToSquare(QPolygonF,QTransform&)
                bool cppResult = ::QTransform::quadToSquare(*cppArg0, *cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTransformFunc_reset(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // reset()
        cppSelf->reset();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTransformFunc_rotate(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "rotate", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:rotate", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTransform::rotate(qreal,Qt::Axis=)->QTransform&
    // 1: QTransform::rotate(qreal,Qt::Axis,qreal)->QTransform&
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // rotate(qreal,Qt::Axis)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_Axis_IDX])))->converter, (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // rotate(qreal,Qt::Axis)
            } else if (numArgs == 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[2])))) {
                overloadId = 1; // rotate(qreal,Qt::Axis,qreal)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "rotate", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // rotate(qreal a, Qt::Axis axis)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_axis = Shiboken::String::createStaticString("axis");
                if (PyDict_Contains(kwds, key_axis) != 0) {
                    value = PyDict_GetItem(kwds, key_axis);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_axis);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "rotate", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_Axis_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "rotate", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_axis);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "rotate", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]);
                }
            }
            qreal cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::Qt::Axis cppArg1(Qt::ZAxis);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // rotate(qreal,Qt::Axis)
                QTransform & cppResult = cppSelf->rotate(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), &cppResult);
            }
            break;
        }
        case 1: // rotate(qreal a, Qt::Axis axis, qreal distanceToPlane)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "rotate", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]);
            }
            qreal cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::Qt::Axis cppArg1{Qt::XAxis};
            pythonToCpp[1](pyArgs[1], &cppArg1);
            qreal cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // rotate(qreal,Qt::Axis,qreal)
                QTransform & cppResult = cppSelf->rotate(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTransformFunc_rotateRadians(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "rotateRadians", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:rotateRadians", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTransform::rotateRadians(qreal,Qt::Axis=)->QTransform&
    // 1: QTransform::rotateRadians(qreal,Qt::Axis,qreal)->QTransform&
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // rotateRadians(qreal,Qt::Axis)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_Axis_IDX])))->converter, (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // rotateRadians(qreal,Qt::Axis)
            } else if (numArgs == 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[2])))) {
                overloadId = 1; // rotateRadians(qreal,Qt::Axis,qreal)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "rotateRadians", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // rotateRadians(qreal a, Qt::Axis axis)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_axis = Shiboken::String::createStaticString("axis");
                if (PyDict_Contains(kwds, key_axis) != 0) {
                    value = PyDict_GetItem(kwds, key_axis);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_axis);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "rotateRadians", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_Axis_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "rotateRadians", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_axis);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "rotateRadians", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]);
                }
            }
            qreal cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::Qt::Axis cppArg1(Qt::ZAxis);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // rotateRadians(qreal,Qt::Axis)
                QTransform & cppResult = cppSelf->rotateRadians(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), &cppResult);
            }
            break;
        }
        case 1: // rotateRadians(qreal a, Qt::Axis axis, qreal distanceToPlane)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "rotateRadians", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]);
            }
            qreal cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::Qt::Axis cppArg1{Qt::XAxis};
            pythonToCpp[1](pyArgs[1], &cppArg1);
            qreal cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // rotateRadians(qreal,Qt::Axis,qreal)
                QTransform & cppResult = cppSelf->rotateRadians(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTransformFunc_scale(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "scale", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTransform::scale(qreal,qreal)->QTransform&
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))) {
        overloadId = 0; // scale(qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "scale", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qreal cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // scale(qreal,qreal)
            QTransform & cppResult = cppSelf->scale(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTransformFunc_setMatrix(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[9];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setMatrix", 9, 9, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7]), &(pyArgs[8])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTransform::setMatrix(qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal)
    if (numArgs == 9
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[5])))
        && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[6])))
        && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[7])))
        && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[8])))) {
        overloadId = 0; // setMatrix(qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setMatrix", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qreal cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        qreal cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        qreal cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        qreal cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);
        qreal cppArg5;
        pythonToCpp[5](pyArgs[5], &cppArg5);
        qreal cppArg6;
        pythonToCpp[6](pyArgs[6], &cppArg6);
        qreal cppArg7;
        pythonToCpp[7](pyArgs[7], &cppArg7);
        qreal cppArg8;
        pythonToCpp[8](pyArgs[8], &cppArg8);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMatrix(qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal)
            cppSelf->setMatrix(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTransformFunc_shear(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "shear", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTransform::shear(qreal,qreal)->QTransform&
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))) {
        overloadId = 0; // shear(qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "shear", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qreal cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // shear(qreal,qreal)
            QTransform & cppResult = cppSelf->shear(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTransformFunc_squareToQuad(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "squareToQuad", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTransform::squareToQuad(QPolygonF&)->PyObject*
    // 1: static QTransform::squareToQuad(QPolygonF,QTransform&)->bool
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPolygonF_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // squareToQuad(QPolygonF&)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), (pyArgs[1])))) {
            overloadId = 1; // squareToQuad(QPolygonF,QTransform&)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "squareToQuad", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // squareToQuad(QPolygonF &arg__1)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPolygonF cppArg0_local;
            ::QPolygonF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            SBK_UNUSED(cppArg0)

            if (Shiboken::Errors::occurred() == nullptr) {
                // squareToQuad(QPolygonF&)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtgui.cpp (qtransform-squaretoquad)]
                QTransform _result;
                if (QTransform::squareToQuad((*cppArg0), _result)) {
                    pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), &_result);
                } else {
                    Py_INCREF(Py_None);
                    pyResult = Py_None;
                }
                // END of custom code block [file: ../glue/qtgui.cpp (qtransform-squaretoquad)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 1: // squareToQuad(const QPolygonF &square, QTransform &result)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPolygonF cppArg0_local;
            ::QPolygonF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QTransform cppArg1_local;
            ::QTransform *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // squareToQuad(QPolygonF,QTransform&)
                bool cppResult = ::QTransform::squareToQuad(*cppArg0, *cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTransformFunc_translate(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "translate", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTransform::translate(qreal,qreal)->QTransform&
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))) {
        overloadId = 0; // translate(qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "translate", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qreal cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // translate(qreal,qreal)
            QTransform & cppResult = cppSelf->translate(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTransformFunc_transposed(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // transposed()const
        QTransform cppResult = const_cast<const ::QTransform *>(cppSelf)->transposed();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTransformFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        QTransform::TransformationType cppResult = const_cast<const ::QTransform *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_TransformationType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTransform__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QTransform_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QTransform_EnumFlagInfo[] = {
    "TransformationType:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QTransform_methods[] = {
    {"__reduce__", reinterpret_cast<PyCFunction>(Sbk_QTransformFunc___reduce__), METH_NOARGS, nullptr},
    {"adjoint", reinterpret_cast<PyCFunction>(Sbk_QTransformFunc_adjoint), METH_NOARGS, nullptr},
    {"determinant", reinterpret_cast<PyCFunction>(Sbk_QTransformFunc_determinant), METH_NOARGS, nullptr},
    {"dx", reinterpret_cast<PyCFunction>(Sbk_QTransformFunc_dx), METH_NOARGS, nullptr},
    {"dy", reinterpret_cast<PyCFunction>(Sbk_QTransformFunc_dy), METH_NOARGS, nullptr},
    {"fromScale", reinterpret_cast<PyCFunction>(Sbk_QTransformFunc_fromScale), METH_VARARGS|METH_STATIC, nullptr},
    {"fromTranslate", reinterpret_cast<PyCFunction>(Sbk_QTransformFunc_fromTranslate), METH_VARARGS|METH_STATIC, nullptr},
    {"inverted", reinterpret_cast<PyCFunction>(Sbk_QTransformFunc_inverted), METH_NOARGS, nullptr},
    {"isAffine", reinterpret_cast<PyCFunction>(Sbk_QTransformFunc_isAffine), METH_NOARGS, nullptr},
    {"isIdentity", reinterpret_cast<PyCFunction>(Sbk_QTransformFunc_isIdentity), METH_NOARGS, nullptr},
    {"isInvertible", reinterpret_cast<PyCFunction>(Sbk_QTransformFunc_isInvertible), METH_NOARGS, nullptr},
    {"isRotating", reinterpret_cast<PyCFunction>(Sbk_QTransformFunc_isRotating), METH_NOARGS, nullptr},
    {"isScaling", reinterpret_cast<PyCFunction>(Sbk_QTransformFunc_isScaling), METH_NOARGS, nullptr},
    {"isTranslating", reinterpret_cast<PyCFunction>(Sbk_QTransformFunc_isTranslating), METH_NOARGS, nullptr},
    {"m11", reinterpret_cast<PyCFunction>(Sbk_QTransformFunc_m11), METH_NOARGS, nullptr},
    {"m12", reinterpret_cast<PyCFunction>(Sbk_QTransformFunc_m12), METH_NOARGS, nullptr},
    {"m13", reinterpret_cast<PyCFunction>(Sbk_QTransformFunc_m13), METH_NOARGS, nullptr},
    {"m21", reinterpret_cast<PyCFunction>(Sbk_QTransformFunc_m21), METH_NOARGS, nullptr},
    {"m22", reinterpret_cast<PyCFunction>(Sbk_QTransformFunc_m22), METH_NOARGS, nullptr},
    {"m23", reinterpret_cast<PyCFunction>(Sbk_QTransformFunc_m23), METH_NOARGS, nullptr},
    {"m31", reinterpret_cast<PyCFunction>(Sbk_QTransformFunc_m31), METH_NOARGS, nullptr},
    {"m32", reinterpret_cast<PyCFunction>(Sbk_QTransformFunc_m32), METH_NOARGS, nullptr},
    {"m33", reinterpret_cast<PyCFunction>(Sbk_QTransformFunc_m33), METH_NOARGS, nullptr},
    {"map", reinterpret_cast<PyCFunction>(Sbk_QTransformFunc_map), METH_VARARGS, nullptr},
    {"mapRect", reinterpret_cast<PyCFunction>(Sbk_QTransformFunc_mapRect), METH_O, nullptr},
    {"mapToPolygon", reinterpret_cast<PyCFunction>(Sbk_QTransformFunc_mapToPolygon), METH_O, nullptr},
    {"quadToQuad", reinterpret_cast<PyCFunction>(Sbk_QTransformFunc_quadToQuad), METH_VARARGS|METH_STATIC, nullptr},
    {"quadToSquare", reinterpret_cast<PyCFunction>(Sbk_QTransformFunc_quadToSquare), METH_VARARGS|METH_STATIC, nullptr},
    {"reset", reinterpret_cast<PyCFunction>(Sbk_QTransformFunc_reset), METH_NOARGS, nullptr},
    {"rotate", reinterpret_cast<PyCFunction>(Sbk_QTransformFunc_rotate), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"rotateRadians", reinterpret_cast<PyCFunction>(Sbk_QTransformFunc_rotateRadians), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"scale", reinterpret_cast<PyCFunction>(Sbk_QTransformFunc_scale), METH_VARARGS, nullptr},
    {"setMatrix", reinterpret_cast<PyCFunction>(Sbk_QTransformFunc_setMatrix), METH_VARARGS, nullptr},
    {"shear", reinterpret_cast<PyCFunction>(Sbk_QTransformFunc_shear), METH_VARARGS, nullptr},
    {"squareToQuad", reinterpret_cast<PyCFunction>(Sbk_QTransformFunc_squareToQuad), METH_VARARGS|METH_STATIC, nullptr},
    {"translate", reinterpret_cast<PyCFunction>(Sbk_QTransformFunc_translate), METH_VARARGS, nullptr},
    {"transposed", reinterpret_cast<PyCFunction>(Sbk_QTransformFunc_transposed), METH_NOARGS, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QTransformFunc_type), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QTransform__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QTransformFunc___mul__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTransform::operator*(QLine)->QLine
    // 1: QTransform::operator*(QLineF)->QLineF
    // 2: QTransform::operator*(QPoint)->QPoint
    // 3: QTransform::operator*(QPointF)->QPointF
    // 4: QTransform::operator*(QTransform)const->QTransform
    // 5: QTransform::operator*(qreal)->QTransform
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 5; // operator*(QTransform,qreal)
    } else if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), (pyArg)))) {
        overloadId = 4; // operator*(QTransform)const
    } else if (isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArg)))) {
        overloadId = 2; // operator*(QPoint,QTransform)
    } else if (isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArg)))) {
        overloadId = 3; // operator*(QPointF,QTransform)
    } else if (isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLine_IDX]), (pyArg)))) {
        overloadId = 0; // operator*(QLine,QTransform)
    } else if (isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), (pyArg)))) {
        overloadId = 1; // operator*(QLineF,QTransform)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator*", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // operator*(const QLine &l)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QLine cppArg0_local;
            ::QLine *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // operator*(QLine,QTransform) [reverse operator]
                QLine cppResult = (*cppArg0) * (*cppSelf);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLine_IDX]), &cppResult);
            }
            break;
        }
        case 1: // operator*(const QLineF &l)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QLineF cppArg0_local;
            ::QLineF *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // operator*(QLineF,QTransform) [reverse operator]
                QLineF cppResult = (*cppArg0) * (*cppSelf);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), &cppResult);
            }
            break;
        }
        case 2: // operator*(const QPoint &p)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QPoint cppArg0_local;
            ::QPoint *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // operator*(QPoint,QTransform) [reverse operator]
                QPoint cppResult = (*cppArg0) * (*cppSelf);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), &cppResult);
            }
            break;
        }
        case 3: // operator*(const QPointF &p)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QPointF cppArg0_local;
            ::QPointF *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // operator*(QPointF,QTransform) [reverse operator]
                QPointF cppResult = (*cppArg0) * (*cppSelf);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
            }
            break;
        }
        case 4: // operator*(const QTransform &o) const
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QTransform cppArg0_local;
            ::QTransform *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // operator*(QTransform)const
                QTransform cppResult = (*cppSelf) * (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), &cppResult);
            }
            break;
        }
        case 5: // operator*(qreal n)
        {
            qreal cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator*(QTransform,qreal)
                QTransform cppResult = (*cppSelf) * cppArg0;
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTransformFunc___imul__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTransform::operator*=(QTransform)->QTransform&
    // 1: QTransform::operator*=(qreal)->QTransform&
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 1; // operator*=(qreal)
    } else if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), (pyArg)))) {
        overloadId = 0; // operator*=(QTransform)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator*=", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // operator*=(const QTransform &arg__1)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QTransform cppArg0_local;
            ::QTransform *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // operator*=(QTransform)
                (*cppSelf) *= (*cppArg0);
            }
            break;
        }
        case 1: // operator*=(qreal div)
        {
            qreal cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator*=(qreal)
                (*cppSelf) *= cppArg0;
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_INCREF(self);
    return self;
}

static PyObject *Sbk_QTransformFunc___add__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTransform::operator+(qreal)->QTransform
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // operator+(QTransform,qreal)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator+", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // operator+(QTransform,qreal)
            QTransform cppResult = (*cppSelf) + cppArg0;
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTransformFunc___iadd__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTransform::operator+=(qreal)->QTransform&
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // operator+=(qreal)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator+=", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // operator+=(qreal)
            (*cppSelf) += cppArg0;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_INCREF(self);
    return self;
}

static PyObject *Sbk_QTransformFunc___sub__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTransform::operator-(qreal)->QTransform
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // operator-(QTransform,qreal)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator-", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // operator-(QTransform,qreal)
            QTransform cppResult = (*cppSelf) - cppArg0;
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTransformFunc___isub__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTransform::operator-=(qreal)->QTransform&
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // operator-=(qreal)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator-=", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // operator-=(qreal)
            (*cppSelf) -= cppArg0;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_INCREF(self);
    return self;
}

static PyObject *Sbk_QTransformFunc___div__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTransform::operator/(qreal)->QTransform
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // operator/(QTransform,qreal)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator/", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // operator/(QTransform,qreal)
            QTransform cppResult = (*cppSelf) / cppArg0;
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTransformFunc___lshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rlshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QTransform::operator<<(QDataStream&)->QDataStream&
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // operator<<(QDataStream&,QTransform)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator<<", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator<<(QDataStream&,QTransform) [reverse operator]
                QDataStream & cppResult = (*cppArg0) << (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTransformFunc___rshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rrshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QTransform::operator>>(QDataStream&)->QDataStream&
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // operator>>(QDataStream&,QTransform&)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator>>", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator>>(QDataStream&,QTransform&) [reverse operator]
                QDataStream & cppResult = (*cppArg0) >> (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

// Rich comparison
static PyObject * Sbk_QTransform_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), (pyArg)))) {
                // operator!=(const QTransform &arg__1) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QTransform cppArg0_local;
                ::QTransform *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), (pyArg)))) {
                // operator==(const QTransform &arg__1) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QTransform cppArg0_local;
                ::QTransform *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static Py_hash_t Sbk_QTransform_HashFunc(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return Py_hash_t(qHash(*cppSelf));
}

static int Sbk_QTransform_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QTransform_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QTransform_Type = nullptr;
static PyTypeObject *Sbk_QTransform_TypeF(void)
{
    return _Sbk_QTransform_Type;
}

static PyType_Slot Sbk_QTransform_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QTransformFunc___repr__)},
    {Py_tp_hash,        reinterpret_cast<void *>(&Sbk_QTransform_HashFunc)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QTransform_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QTransform_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QTransform_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QTransform_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QTransform_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_inplace_add, reinterpret_cast<void *>(Sbk_QTransformFunc___iadd__)},
    {Py_nb_subtract,    reinterpret_cast<void *>(Sbk_QTransformFunc___sub__)},
    {Py_nb_inplace_multiply,reinterpret_cast<void *>(Sbk_QTransformFunc___imul__)},
    {Py_nb_multiply,    reinterpret_cast<void *>(Sbk_QTransformFunc___mul__)},
    {Py_nb_inplace_subtract,reinterpret_cast<void *>(Sbk_QTransformFunc___isub__)},
    {Py_nb_lshift,      reinterpret_cast<void *>(Sbk_QTransformFunc___lshift__)},
    {Py_nb_rshift,      reinterpret_cast<void *>(Sbk_QTransformFunc___rshift__)},
    {Py_nb_true_divide, reinterpret_cast<void *>(Sbk_QTransformFunc___div__)},
    {Py_nb_add,         reinterpret_cast<void *>(Sbk_QTransformFunc___add__)},
    {0, nullptr}
};
static PyType_Spec Sbk_QTransform_spec = {
    "2:PySide6.QtGui.QTransform",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QTransform_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QTransform_TransformationType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QTransform::TransformationType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QTransform::TransformationType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QTransform_TransformationType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_TransformationType_IDX])))
        return Enum_PythonToCpp_QTransform_TransformationType;
    return {};
}

static PyObject *QTransform_TransformationType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QTransform::TransformationType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QTransform::TransformationType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_TransformationType_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QTransform_PythonToCpp_QTransform_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QTransform_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QTransform_PythonToCpp_QTransform_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QTransform_TypeF()))
        return QTransform_PythonToCpp_QTransform_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QTransform_PTR_CppToPython_QTransform(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QTransform_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QTransform_COPY_CppToPython_QTransform(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QTransform *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QTransform_TypeF(), new ::QTransform(*source), true, true);
}

// Python to C++ copy conversion.
static void QTransform_PythonToCpp_QTransform_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QTransform *>(cppOut) = *reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QTransform_PythonToCpp_QTransform_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QTransform_TypeF()))
        return QTransform_PythonToCpp_QTransform_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QTransform_SignatureStrings[] = {
    "3:PySide6.QtGui.QTransform(self)",
    "2:PySide6.QtGui.QTransform(self,other:PySide6.QtGui.QTransform)",
    "1:PySide6.QtGui.QTransform(self,h11:qreal,h12:qreal,h13:qreal,h21:qreal,h22:qreal,h23:qreal,h31:qreal,h32:qreal,h33:qreal)",
    "0:PySide6.QtGui.QTransform(self,h11:qreal,h12:qreal,h21:qreal,h22:qreal,dx:qreal,dy:qreal)",
    "PySide6.QtGui.QTransform.__reduce__(self)->str",
    "PySide6.QtGui.QTransform.__repr__(self)->str",
    "PySide6.QtGui.QTransform.adjoint(self)->PySide6.QtGui.QTransform",
    "PySide6.QtGui.QTransform.determinant(self)->qreal",
    "PySide6.QtGui.QTransform.dx(self)->qreal",
    "PySide6.QtGui.QTransform.dy(self)->qreal",
    "PySide6.QtGui.QTransform.fromScale(dx:qreal,dy:qreal)->PySide6.QtGui.QTransform",
    "PySide6.QtGui.QTransform.fromTranslate(dx:qreal,dy:qreal)->PySide6.QtGui.QTransform",
    "PySide6.QtGui.QTransform.inverted(self)->Tuple[PySide6.QtGui.QTransform, bool]",
    "PySide6.QtGui.QTransform.isAffine(self)->bool",
    "PySide6.QtGui.QTransform.isIdentity(self)->bool",
    "PySide6.QtGui.QTransform.isInvertible(self)->bool",
    "PySide6.QtGui.QTransform.isRotating(self)->bool",
    "PySide6.QtGui.QTransform.isScaling(self)->bool",
    "PySide6.QtGui.QTransform.isTranslating(self)->bool",
    "PySide6.QtGui.QTransform.m11(self)->qreal",
    "PySide6.QtGui.QTransform.m12(self)->qreal",
    "PySide6.QtGui.QTransform.m13(self)->qreal",
    "PySide6.QtGui.QTransform.m21(self)->qreal",
    "PySide6.QtGui.QTransform.m22(self)->qreal",
    "PySide6.QtGui.QTransform.m23(self)->qreal",
    "PySide6.QtGui.QTransform.m31(self)->qreal",
    "PySide6.QtGui.QTransform.m32(self)->qreal",
    "PySide6.QtGui.QTransform.m33(self)->qreal",
    "8:PySide6.QtGui.QTransform.map(self,l:PySide6.QtCore.QLine)->PySide6.QtCore.QLine",
    "7:PySide6.QtGui.QTransform.map(self,l:typing.Union[PySide6.QtCore.QLineF, PySide6.QtCore.QLine])->PySide6.QtCore.QLineF",
    "6:PySide6.QtGui.QTransform.map(self,p:PySide6.QtGui.QPainterPath)->PySide6.QtGui.QPainterPath",
    "5:PySide6.QtGui.QTransform.map(self,p:PySide6.QtCore.QPoint)->PySide6.QtCore.QPoint",
    "4:PySide6.QtGui.QTransform.map(self,p:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element])->PySide6.QtCore.QPointF",
    "3:PySide6.QtGui.QTransform.map(self,a:typing.Union[PySide6.QtGui.QPolygon, QList[PySide6.QtCore.QPoint], PySide6.QtCore.QRect])->PySide6.QtGui.QPolygon",
    "2:PySide6.QtGui.QTransform.map(self,a:typing.Union[PySide6.QtGui.QPolygonF, QList[PySide6.QtCore.QPointF], PySide6.QtGui.QPolygon, PySide6.QtCore.QRectF])->PySide6.QtGui.QPolygonF",
    "1:PySide6.QtGui.QTransform.map(self,r:typing.Union[PySide6.QtGui.QRegion, PySide6.QtGui.QBitmap, PySide6.QtGui.QPolygon, PySide6.QtCore.QRect])->PySide6.QtGui.QRegion",
    "0:PySide6.QtGui.QTransform.map(self,x:qreal,y:qreal)->PyObject",
    "1:PySide6.QtGui.QTransform.mapRect(self,arg__1:PySide6.QtCore.QRect)->PySide6.QtCore.QRect",
    "0:PySide6.QtGui.QTransform.mapRect(self,arg__1:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect])->PySide6.QtCore.QRectF",
    "PySide6.QtGui.QTransform.mapToPolygon(self,r:PySide6.QtCore.QRect)->PySide6.QtGui.QPolygon",
    "1:PySide6.QtGui.QTransform.quadToQuad(one:typing.Union[PySide6.QtGui.QPolygonF, QList[PySide6.QtCore.QPointF], PySide6.QtGui.QPolygon, PySide6.QtCore.QRectF],two:typing.Union[PySide6.QtGui.QPolygonF, QList[PySide6.QtCore.QPointF], PySide6.QtGui.QPolygon, PySide6.QtCore.QRectF])->PyObject",
    "0:PySide6.QtGui.QTransform.quadToQuad(one:typing.Union[PySide6.QtGui.QPolygonF, QList[PySide6.QtCore.QPointF], PySide6.QtGui.QPolygon, PySide6.QtCore.QRectF],two:typing.Union[PySide6.QtGui.QPolygonF, QList[PySide6.QtCore.QPointF], PySide6.QtGui.QPolygon, PySide6.QtCore.QRectF],result:PySide6.QtGui.QTransform)->bool",
    "1:PySide6.QtGui.QTransform.quadToSquare(arg__1:typing.Union[PySide6.QtGui.QPolygonF, QList[PySide6.QtCore.QPointF], PySide6.QtGui.QPolygon, PySide6.QtCore.QRectF])->PyObject",
    "0:PySide6.QtGui.QTransform.quadToSquare(quad:typing.Union[PySide6.QtGui.QPolygonF, QList[PySide6.QtCore.QPointF], PySide6.QtGui.QPolygon, PySide6.QtCore.QRectF],result:PySide6.QtGui.QTransform)->bool",
    "PySide6.QtGui.QTransform.reset(self)",
    "1:PySide6.QtGui.QTransform.rotate(self,a:qreal,axis:PySide6.QtCore.Qt.Axis=Qt.ZAxis)->PySide6.QtGui.QTransform",
    "0:PySide6.QtGui.QTransform.rotate(self,a:qreal,axis:PySide6.QtCore.Qt.Axis,distanceToPlane:qreal)->PySide6.QtGui.QTransform",
    "1:PySide6.QtGui.QTransform.rotateRadians(self,a:qreal,axis:PySide6.QtCore.Qt.Axis=Qt.ZAxis)->PySide6.QtGui.QTransform",
    "0:PySide6.QtGui.QTransform.rotateRadians(self,a:qreal,axis:PySide6.QtCore.Qt.Axis,distanceToPlane:qreal)->PySide6.QtGui.QTransform",
    "PySide6.QtGui.QTransform.scale(self,sx:qreal,sy:qreal)->PySide6.QtGui.QTransform",
    "PySide6.QtGui.QTransform.setMatrix(self,m11:qreal,m12:qreal,m13:qreal,m21:qreal,m22:qreal,m23:qreal,m31:qreal,m32:qreal,m33:qreal)",
    "PySide6.QtGui.QTransform.shear(self,sh:qreal,sv:qreal)->PySide6.QtGui.QTransform",
    "1:PySide6.QtGui.QTransform.squareToQuad(arg__1:typing.Union[PySide6.QtGui.QPolygonF, QList[PySide6.QtCore.QPointF], PySide6.QtGui.QPolygon, PySide6.QtCore.QRectF])->PyObject",
    "0:PySide6.QtGui.QTransform.squareToQuad(square:typing.Union[PySide6.QtGui.QPolygonF, QList[PySide6.QtCore.QPointF], PySide6.QtGui.QPolygon, PySide6.QtCore.QRectF],result:PySide6.QtGui.QTransform)->bool",
    "PySide6.QtGui.QTransform.translate(self,dx:qreal,dy:qreal)->PySide6.QtGui.QTransform",
    "PySide6.QtGui.QTransform.transposed(self)->PySide6.QtGui.QTransform",
    "PySide6.QtGui.QTransform.type(self)->PySide6.QtGui.QTransform.TransformationType",
    "PySide6.QtGui.QTransform.__copy__(self)->typing.Self",
    "5:PySide6.QtGui.QTransform.__mul__(self,l:PySide6.QtCore.QLine)->PySide6.QtCore.QLine",
    "4:PySide6.QtGui.QTransform.__mul__(self,l:typing.Union[PySide6.QtCore.QLineF, PySide6.QtCore.QLine])->PySide6.QtCore.QLineF",
    "3:PySide6.QtGui.QTransform.__mul__(self,p:PySide6.QtCore.QPoint)->PySide6.QtCore.QPoint",
    "2:PySide6.QtGui.QTransform.__mul__(self,p:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element])->PySide6.QtCore.QPointF",
    "1:PySide6.QtGui.QTransform.__mul__(self,o:PySide6.QtGui.QTransform)->PySide6.QtGui.QTransform",
    "0:PySide6.QtGui.QTransform.__mul__(self,n:qreal)->PySide6.QtGui.QTransform",
    "1:PySide6.QtGui.QTransform.__imul__(self,arg__1:PySide6.QtGui.QTransform)->PySide6.QtGui.QTransform",
    "0:PySide6.QtGui.QTransform.__imul__(self,div:qreal)->PySide6.QtGui.QTransform",
    "PySide6.QtGui.QTransform.__add__(self,n:qreal)->PySide6.QtGui.QTransform",
    "PySide6.QtGui.QTransform.__iadd__(self,div:qreal)->PySide6.QtGui.QTransform",
    "PySide6.QtGui.QTransform.__sub__(self,n:qreal)->PySide6.QtGui.QTransform",
    "PySide6.QtGui.QTransform.__isub__(self,div:qreal)->PySide6.QtGui.QTransform",
    "PySide6.QtGui.QTransform.__div__(self,n:qreal)->PySide6.QtGui.QTransform",
    "PySide6.QtGui.QTransform.__lshift__(self,arg__1:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "PySide6.QtGui.QTransform.__rshift__(self,arg__1:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "PySide6.QtGui.QTransform.__ne__(self,arg__1:PySide6.QtGui.QTransform)->bool",
    "PySide6.QtGui.QTransform.__eq__(self,arg__1:PySide6.QtGui.QTransform)->bool",
    "PySide6.QtGui.QTransform.__hash__(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t QTransform_SignatureByteSize = 930;
static constexpr uint8_t QTransform_SignatureBytes[930] = {
    0x78, 0xda, 0xed, 0x59, 0x5b, 0x6f, 0x9b, 0x30, 0x14, 0x7e, 0xe7, 0x57, 0xf4, 0x31, 0x95, 0x32,
    0x54, 0xa0, 0xbb, 0x28, 0xd2, 0x26, 0x75, 0x97, 0x4c, 0x93, 0x36, 0x2d, 0xb7, 0xbd, 0xac, 0x8a,
    0x90, 0x13, 0x9c, 0xe0, 0x0a, 0x63, 0x6a, 0x3b, 0x5d, 0xf9, 0xf7, 0x33, 0x37, 0x43, 0x12, 0x30,
    0x26, 0x41, 0x6d, 0x27, 0xed, 0xa5, 0x01, 0xfb, 0xf8, 0x3b, 0xdf, 0x39, 0x3e, 0x3e, 0xe6, 0x9c,
    0x3a, 0xa3, 0x49, 0x3c, 0x47, 0x1e, 0x7c, 0x63, 0x4e, 0xf9, 0xd7, 0x1d, 0x32, 0xa7, 0x0b, 0x0a,
    0x42, 0xb6, 0x21, 0x14, 0x0f, 0x18, 0x0c, 0x36, 0x97, 0x86, 0xad, 0x16, 0x18, 0x12, 0xee, 0x43,
    0xda, 0x28, 0x73, 0x69, 0x58, 0x2d, 0xeb, 0x7d, 0xcb, 0x1a, 0xdd, 0x53, 0x08, 0x02, 0xf1, 0x64,
    0xcb, 0x27, 0xa7, 0x78, 0xb2, 0xe5, 0xac, 0x2d, 0x67, 0x6d, 0x39, 0xeb, 0xc8, 0x59, 0x47, 0xce,
    0x3a, 0xf9, 0xec, 0xa5, 0x71, 0x75, 0x8a, 0xea, 0x1a, 0x85, 0xde, 0x63, 0xf1, 0x10, 0x17, 0xd0,
    0x4d, 0xc0, 0xa6, 0xeb, 0x52, 0xe8, 0xed, 0xd6, 0xd0, 0x75, 0x33, 0xff, 0xbd, 0xfa, 0xc0, 0x38,
    0x55, 0x8b, 0x47, 0x54, 0x53, 0x18, 0x78, 0x77, 0x04, 0x85, 0xbc, 0x90, 0x6d, 0x92, 0x6b, 0x06,
    0xf0, 0x20, 0x87, 0x14, 0xa3, 0x10, 0x94, 0x20, 0xa9, 0x3d, 0x8a, 0x15, 0x8f, 0xba, 0x82, 0xb1,
    0xa6, 0xe0, 0x86, 0x12, 0x3c, 0x5f, 0x83, 0x00, 0x0e, 0x8e, 0xdd, 0x7a, 0x8a, 0x4d, 0x09, 0x5e,
    0xfa, 0x16, 0x00, 0xde, 0x17, 0x26, 0x0a, 0x1f, 0x20, 0xe5, 0xd0, 0x2b, 0x4c, 0x5a, 0xec, 0xa2,
    0x00, 0xde, 0x36, 0x89, 0x0f, 0x2f, 0x56, 0x84, 0x04, 0x4b, 0x05, 0x1c, 0xbb, 0xd9, 0x6c, 0x50,
    0x08, 0x0b, 0xb8, 0x44, 0x5c, 0x25, 0xfd, 0xcd, 0x83, 0x21, 0x47, 0x3c, 0xd6, 0x96, 0x4f, 0xe9,
    0xa2, 0x55, 0xa0, 0xad, 0x61, 0x46, 0x38, 0xe0, 0x28, 0xdc, 0xea, 0xca, 0x27, 0x1b, 0xd6, 0x41,
    0xbc, 0xd8, 0x0f, 0xed, 0x25, 0xd8, 0xb2, 0x34, 0xc3, 0x07, 0x5b, 0xb6, 0xb6, 0xa4, 0xa3, 0x2b,
    0x69, 0x6b, 0x6b, 0xb7, 0xb5, 0xb5, 0xdb, 0xda, 0xda, 0x1d, 0x6d, 0xed, 0x8e, 0xb6, 0x76, 0xe7,
    0x40, 0xfb, 0xbb, 0x51, 0xb3, 0x2c, 0x88, 0xb2, 0x74, 0x18, 0x54, 0x64, 0x3e, 0x11, 0x0a, 0xcd,
    0xe9, 0x77, 0x11, 0xb4, 0x7b, 0x07, 0xa8, 0x1c, 0x36, 0xde, 0x6a, 0x21, 0xf2, 0x38, 0x12, 0x41,
    0x60, 0xfe, 0x0a, 0x11, 0x09, 0x6f, 0xeb, 0x70, 0xc6, 0xc3, 0x8b, 0xba, 0xe1, 0x65, 0x83, 0xda,
    0xb1, 0xf1, 0x46, 0x43, 0x6f, 0x74, 0x28, 0x33, 0x01, 0x22, 0x6f, 0x42, 0x3a, 0x01, 0xdc, 0x3f,
    0x4e, 0x08, 0x95, 0x49, 0xe3, 0x75, 0x47, 0xf4, 0x8c, 0xd9, 0x24, 0x49, 0xcb, 0x35, 0x8c, 0xd3,
    0x71, 0xe3, 0x5a, 0x0b, 0x53, 0xe9, 0xa9, 0x14, 0xa8, 0xc6, 0x55, 0xe9, 0x78, 0x75, 0xf8, 0xd0,
    0x20, 0xf3, 0x4b, 0x00, 0xb1, 0xc8, 0x26, 0xcb, 0x26, 0x76, 0x63, 0xc3, 0xd1, 0xa0, 0x07, 0x9a,
    0xe8, 0x65, 0xfa, 0x48, 0x10, 0x6f, 0x49, 0x38, 0xbc, 0x10, 0x5b, 0xc4, 0x78, 0x3d, 0xf9, 0xe5,
    0x31, 0xf9, 0x19, 0x5c, 0x1f, 0xf0, 0xaa, 0xa2, 0x29, 0x3e, 0x3c, 0x3a, 0xf2, 0x1a, 0x2b, 0x89,
    0x8d, 0x97, 0xc7, 0xfe, 0x2b, 0xec, 0xa9, 0x63, 0x3c, 0x6e, 0xa6, 0x3c, 0x56, 0x7c, 0xec, 0x94,
    0x9c, 0xa9, 0x92, 0xf3, 0x0c, 0x6e, 0xd1, 0xbe, 0xea, 0x74, 0xf8, 0x23, 0xe2, 0x02, 0xa0, 0x1b,
    0xd3, 0x1a, 0xa2, 0x19, 0xba, 0xe2, 0xc3, 0xa8, 0xa4, 0x59, 0x5c, 0xa4, 0xd5, 0x7b, 0xf4, 0xe7,
    0xea, 0x4e, 0xe0, 0xb6, 0x58, 0x99, 0xa8, 0xce, 0x77, 0x87, 0x6e, 0x5d, 0xd7, 0x1a, 0xd5, 0x71,
    0xab, 0x09, 0xc7, 0x64, 0xb8, 0x85, 0xd9, 0x11, 0xb4, 0xf2, 0xd0, 0xa4, 0xbb, 0xa5, 0xe3, 0x9a,
    0x8a, 0xb8, 0xa1, 0x52, 0xbf, 0x20, 0xb9, 0xbf, 0x8b, 0x8d, 0x6c, 0xb5, 0x6c, 0x2f, 0xa0, 0x15,
    0x6e, 0xbb, 0xdf, 0x01, 0x6f, 0x41, 0xa6, 0xe2, 0xef, 0x80, 0x84, 0xf0, 0x39, 0x82, 0x7a, 0xc8,
    0xff, 0x90, 0x67, 0x3b, 0x4c, 0x79, 0x5c, 0x5d, 0xfd, 0x77, 0x50, 0x8d, 0x5e, 0x0a, 0xd9, 0x2e,
    0xe0, 0xcd, 0x15, 0x56, 0xfe, 0x6d, 0xd5, 0x1a, 0x5d, 0x73, 0xf1, 0x43, 0xe1, 0x40, 0x7d, 0x72,
    0x5e, 0xcc, 0x56, 0xe7, 0x6c, 0x93, 0x97, 0x97, 0xec, 0xf5, 0x46, 0x2b, 0xc4, 0x7a, 0x98, 0x17,
    0x59, 0xaa, 0xad, 0xa1, 0xc9, 0x87, 0x38, 0x2c, 0x2e, 0xb3, 0x2c, 0xe3, 0x82, 0x47, 0xc4, 0x8e,
    0x52, 0x0b, 0x37, 0x6f, 0xc4, 0xf0, 0x7b, 0xf1, 0xfb, 0x3b, 0x79, 0x50, 0x95, 0x35, 0x57, 0xbd,
    0xa9, 0x1b, 0x7a, 0xc2, 0xa5, 0x20, 0x5c, 0x43, 0x91, 0xf9, 0x02, 0x20, 0xce, 0x5d, 0x6b, 0x49,
    0xd5, 0x6a, 0xea, 0x0c, 0x78, 0x48, 0x8c, 0x3c, 0xb1, 0xc5, 0x5d, 0xb5, 0x76, 0x37, 0xbc, 0x91,
    0x00, 0x4b, 0x6b, 0xdd, 0x54, 0x31, 0x2b, 0xee, 0x54, 0x76, 0x4e, 0x71, 0x2a, 0xe2, 0xea, 0x07,
    0xe0, 0x14, 0x65, 0x95, 0xf9, 0x10, 0xcb, 0x26, 0x06, 0x96, 0x4d, 0x0c, 0x2c, 0xfb, 0x27, 0x58,
    0xb6, 0x33, 0xb0, 0x6c, 0x67, 0x60, 0xd9, 0x3f, 0xc1, 0xb2, 0x7f, 0x82, 0x65, 0xff, 0x04, 0x97,
    0xfd, 0x93, 0x66, 0x0a, 0x3e, 0x04, 0x34, 0xb7, 0xc9, 0x2f, 0x6c, 0x7a, 0x38, 0x2b, 0x3a, 0x58,
    0x7a, 0xde, 0xf3, 0x14, 0xff, 0xe2, 0x73, 0xd4, 0x1e, 0xdb, 0xec, 0xe5, 0x9f, 0xcc, 0x52, 0x5c,
    0x36, 0x4e, 0xd2, 0xcd, 0xec, 0xa7, 0x7b, 0x92, 0x82, 0x46, 0x84, 0x95, 0xfd, 0x93, 0x13, 0x30,
    0xe2, 0x08, 0xb6, 0xad, 0x36, 0xe5, 0x13, 0xe0, 0xc2, 0xe7, 0x0b, 0xb1, 0x44, 0xd5, 0x68, 0x5b,
    0x93, 0x28, 0x2e, 0x1b, 0x6d, 0xf9, 0x6e, 0xcd, 0xc5, 0x9b, 0xaa, 0xe8, 0x73, 0x5d, 0xbc, 0x0b,
    0xf2, 0x55, 0x1d, 0x0b, 0xe4, 0x6b, 0x6d, 0xd4, 0xfe, 0x8b, 0x64, 0x47, 0x53, 0x77, 0xd7, 0x52,
    0xd6, 0xd6, 0xc6, 0x7d, 0xb6, 0x72, 0xd6, 0xd2, 0xa4, 0x48, 0x54, 0xa7, 0xe6, 0x94, 0x9b, 0x66,
    0x0f, 0x3d, 0x3c, 0x2b, 0x19, 0xba, 0x2e, 0xaa, 0x60, 0x1d, 0x95, 0x51, 0x3d, 0xd1, 0xad, 0xea,
    0xf0, 0xd0, 0xc3, 0x19, 0x27, 0xde, 0x75, 0x81, 0xe7, 0x75, 0x30, 0x5d, 0x45, 0xaa, 0x82, 0x74,
    0x2e, 0x29, 0xb6, 0x5b, 0xf5, 0x44, 0xaa, 0x82, 0x74, 0x2e, 0x29, 0xb1, 0xbe, 0x1f, 0x52, 0x01,
    0xf3, 0xd1, 0x86, 0x37, 0x06, 0x49, 0x76, 0x28, 0x3e, 0x03, 0x0e, 0xe6, 0x5c, 0x68, 0xc1, 0x35,
    0x27, 0xa6, 0x9c, 0x54, 0xfe, 0x83, 0xe2, 0x89, 0xf4, 0x84, 0x50, 0x3f, 0xe0, 0xd5, 0xb7, 0x9a,
    0xeb, 0xc2, 0xfb, 0xfe, 0xb0, 0x7c, 0xc0, 0xfc, 0xf2, 0xde, 0x48, 0xb2, 0xe0, 0x5f, 0xbf, 0x02,
    0x93, 0x00
};
#endif

PyTypeObject *init_QTransform(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX].type;

    Shiboken::AutoDecRef Sbk_QTransform_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QTransform_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QTransform",
        "QTransform",
        &Sbk_QTransform_spec,
        &Shiboken::callCppDestructor< ::QTransform >,
        Sbk_QTransform_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QTransform_TypeF(); // references _Sbk_QTransform_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QTransform_SignatureStrings);
#else
    InitSignatureBytes(pyType, QTransform_SignatureBytes, QTransform_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QTransform_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QTransform_PythonToCpp_QTransform_PTR,
        is_QTransform_PythonToCpp_QTransform_PTR_Convertible,
        QTransform_PTR_CppToPython_QTransform,
        QTransform_COPY_CppToPython_QTransform);

    Shiboken::Conversions::registerConverterName(converter, "QTransform");
    Shiboken::Conversions::registerConverterName(converter, "QTransform*");
    Shiboken::Conversions::registerConverterName(converter, "QTransform&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QTransform).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QTransform_PythonToCpp_QTransform_COPY,
        is_QTransform_PythonToCpp_QTransform_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QTransform_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'TransformationType'.
    const char *TransformationType_Initializer[] = {
        "TxNone",
        "TxTranslate",
        "TxScale",
        "TxRotate",
        "TxShear",
        "TxProject",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t TransformationType_InitializerValues[] = {
        uint8_t(QTransform::TransformationType::TxNone),      //  0x00  0
        uint8_t(QTransform::TransformationType::TxTranslate), //  0x01  1
        uint8_t(QTransform::TransformationType::TxScale),     //  0x02  2
        uint8_t(QTransform::TransformationType::TxRotate),    //  0x04  4
        uint8_t(QTransform::TransformationType::TxShear),     //  0x08  8
        uint8_t(QTransform::TransformationType::TxProject)    //  0x10  16
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QTransform_TypeF(),
        "2:PySide6.QtGui.QTransform.TransformationType",
        TransformationType_Initializer, TransformationType_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QTransform_TransformationType_IDX].type = EType;
    // Register converter for enum 'QTransform::TransformationType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QTransform_TransformationType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QTransform_TransformationType,
            is_Enum_PythonToCpp_QTransform_TransformationType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QTransform::TransformationType");
        Shiboken::Conversions::registerConverterAlias(converter, "TransformationType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'TransformationType' enum.

    qRegisterMetaType< ::QTransform >("QTransform");
    qRegisterMetaType< ::QTransform::TransformationType >("QTransform::TransformationType");

    return pyType;
}
