// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qvector4d_wrapper.h"

// Extra includes
#include <QMatrix4x4>

// Argument includes
#include <QtGui/qmatrix4x4.h>
#include <QtGui/qvectornd.h>
#include <qdatastream.h>
#include <qpoint.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QVector4D_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QVector4D >()))
        return -1;

    ::QVector4D *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QVector4D", 0, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QVector4D::QVector4D()
    // 1: QVector4D::QVector4D(QPoint)
    // 2: QVector4D::QVector4D(QPointF)
    // 3: QVector4D::QVector4D(QVector2D)
    // 4: QVector4D::QVector4D(QVector2D,float,float)
    // 5: QVector4D::QVector4D(QVector3D)
    // 6: QVector4D::QVector4D(QVector3D,float)
    // 7: QVector4D::QVector4D(float,float,float,float)
    if (numArgs == 0) {
        overloadId = 0; // QVector4D()
    } else if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[3])))) {
        overloadId = 7; // QVector4D(float,float,float,float)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 5; // QVector4D(QVector3D)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))) {
            overloadId = 6; // QVector4D(QVector3D,float)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector2D_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 3; // QVector4D(QVector2D)
        } else if (numArgs == 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))) {
            overloadId = 4; // QVector4D(QVector2D,float,float)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QVector4D(QPoint)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QVector4D(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QVector4D()
        {

            // QVector4D()
            cptr = new ::QVector4D();
            break;
        }
        case 1: // QVector4D(QPoint point)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPoint cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QVector4D(QPoint)
                cptr = new ::QVector4D(cppArg0);
            }
            break;
        }
        case 2: // QVector4D(QPointF point)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPointF cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QVector4D(QPointF)
                cptr = new ::QVector4D(cppArg0);
            }
            break;
        }
        case 3: // QVector4D(QVector2D vector)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QVector2D cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QVector4D(QVector2D)
                cptr = new ::QVector4D(cppArg0);
            }
            break;
        }
        case 4: // QVector4D(QVector2D vector, float zpos, float wpos)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QVector2D cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            float cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QVector4D(QVector2D,float,float)
                cptr = new ::QVector4D(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
        case 5: // QVector4D(QVector3D vector)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QVector3D cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QVector4D(QVector3D)
                cptr = new ::QVector4D(cppArg0);
            }
            break;
        }
        case 6: // QVector4D(QVector3D vector, float wpos)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QVector3D cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QVector4D(QVector3D,float)
                cptr = new ::QVector4D(cppArg0, cppArg1);
            }
            break;
        }
        case 7: // QVector4D(float xpos, float ypos, float zpos, float wpos)
        {
            float cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            float cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            float cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QVector4D(float,float,float,float)
                cptr = new ::QVector4D(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QVector4D >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QVector4DFunc___reduce__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVector4D *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // __reduce__()
        // Begin code injection
        // TEMPLATE - reduce_code - START
        pyResult = Py_BuildValue("(N(dddd))", PyObject_Type(self), cppSelf->x(), cppSelf->y(), cppSelf->z(), cppSelf->w());
        // TEMPLATE - reduce_code - END
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVector4DFunc___repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVector4D *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // __repr__()
        // Begin code injection
        // TEMPLATE - repr_code - START
        QString format = QString::asprintf("%s(%f, %f, %f, %f)",
            Py_TYPE(self)->tp_name, cppSelf->x(), cppSelf->y(), cppSelf->z(), cppSelf->w());
        pyResult = Shiboken::String::fromCString(qPrintable(format));
        // TEMPLATE - repr_code - END
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVector4DFunc_dotProduct(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "dotProduct", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QVector4D::dotProduct(QVector4D,QVector4D)->float
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), (pyArgs[1])))) {
        overloadId = 0; // dotProduct(QVector4D,QVector4D)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "dotProduct", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QVector4D cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QVector4D cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // dotProduct(QVector4D,QVector4D)
            float cppResult = ::QVector4D::dotProduct(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVector4DFunc_isNull(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVector4D *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isNull()const
        bool cppResult = const_cast<const ::QVector4D *>(cppSelf)->isNull();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVector4DFunc_length(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVector4D *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // length()const
        float cppResult = const_cast<const ::QVector4D *>(cppSelf)->length();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVector4DFunc_lengthSquared(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVector4D *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lengthSquared()const
        float cppResult = const_cast<const ::QVector4D *>(cppSelf)->lengthSquared();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVector4DFunc_normalize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVector4D *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // normalize()
        cppSelf->normalize();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QVector4DFunc_normalized(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVector4D *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // normalized()const
        QVector4D cppResult = const_cast<const ::QVector4D *>(cppSelf)->normalized();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVector4DFunc_setW(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVector4D *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QVector4D::setW(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setW(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setW", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setW(float)
            cppSelf->setW(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QVector4DFunc_setX(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVector4D *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QVector4D::setX(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setX(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setX", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setX(float)
            cppSelf->setX(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QVector4DFunc_setY(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVector4D *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QVector4D::setY(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setY(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setY", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setY(float)
            cppSelf->setY(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QVector4DFunc_setZ(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVector4D *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QVector4D::setZ(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setZ(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setZ", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setZ(float)
            cppSelf->setZ(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QVector4DFunc_toPoint(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVector4D *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toPoint()const
        QPoint cppResult = const_cast<const ::QVector4D *>(cppSelf)->toPoint();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVector4DFunc_toPointF(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVector4D *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toPointF()const
        QPointF cppResult = const_cast<const ::QVector4D *>(cppSelf)->toPointF();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVector4DFunc_toTuple(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVector4D *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toTuple()
        // Begin code injection
        // TEMPLATE - to_tuple - START
        pyResult = Py_BuildValue("dddd", cppSelf->x(), cppSelf->y(), cppSelf->z(), cppSelf->w());
        // TEMPLATE - to_tuple - END
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVector4DFunc_toVector2D(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVector4D *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toVector2D()const
        QVector2D cppResult = const_cast<const ::QVector4D *>(cppSelf)->toVector2D();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector2D_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVector4DFunc_toVector2DAffine(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVector4D *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toVector2DAffine()const
        QVector2D cppResult = const_cast<const ::QVector4D *>(cppSelf)->toVector2DAffine();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector2D_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVector4DFunc_toVector3D(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVector4D *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toVector3D()const
        QVector3D cppResult = const_cast<const ::QVector4D *>(cppSelf)->toVector3D();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVector4DFunc_toVector3DAffine(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVector4D *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toVector3DAffine()const
        QVector3D cppResult = const_cast<const ::QVector4D *>(cppSelf)->toVector3DAffine();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVector4DFunc_w(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVector4D *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // w()const
        float cppResult = const_cast<const ::QVector4D *>(cppSelf)->w();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVector4DFunc_x(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVector4D *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // x()const
        float cppResult = const_cast<const ::QVector4D *>(cppSelf)->x();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVector4DFunc_y(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVector4D *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // y()const
        float cppResult = const_cast<const ::QVector4D *>(cppSelf)->y();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVector4DFunc_z(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVector4D *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // z()const
        float cppResult = const_cast<const ::QVector4D *>(cppSelf)->z();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVector4D__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QVector4D *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QVector4D_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QVector4D_methods[] = {
    {"__reduce__", reinterpret_cast<PyCFunction>(Sbk_QVector4DFunc___reduce__), METH_NOARGS, nullptr},
    {"dotProduct", reinterpret_cast<PyCFunction>(Sbk_QVector4DFunc_dotProduct), METH_VARARGS|METH_STATIC, nullptr},
    {"isNull", reinterpret_cast<PyCFunction>(Sbk_QVector4DFunc_isNull), METH_NOARGS, nullptr},
    {"length", reinterpret_cast<PyCFunction>(Sbk_QVector4DFunc_length), METH_NOARGS, nullptr},
    {"lengthSquared", reinterpret_cast<PyCFunction>(Sbk_QVector4DFunc_lengthSquared), METH_NOARGS, nullptr},
    {"normalize", reinterpret_cast<PyCFunction>(Sbk_QVector4DFunc_normalize), METH_NOARGS, nullptr},
    {"normalized", reinterpret_cast<PyCFunction>(Sbk_QVector4DFunc_normalized), METH_NOARGS, nullptr},
    {"setW", reinterpret_cast<PyCFunction>(Sbk_QVector4DFunc_setW), METH_O, nullptr},
    {"setX", reinterpret_cast<PyCFunction>(Sbk_QVector4DFunc_setX), METH_O, nullptr},
    {"setY", reinterpret_cast<PyCFunction>(Sbk_QVector4DFunc_setY), METH_O, nullptr},
    {"setZ", reinterpret_cast<PyCFunction>(Sbk_QVector4DFunc_setZ), METH_O, nullptr},
    {"toPoint", reinterpret_cast<PyCFunction>(Sbk_QVector4DFunc_toPoint), METH_NOARGS, nullptr},
    {"toPointF", reinterpret_cast<PyCFunction>(Sbk_QVector4DFunc_toPointF), METH_NOARGS, nullptr},
    {"toTuple", reinterpret_cast<PyCFunction>(Sbk_QVector4DFunc_toTuple), METH_NOARGS, nullptr},
    {"toVector2D", reinterpret_cast<PyCFunction>(Sbk_QVector4DFunc_toVector2D), METH_NOARGS, nullptr},
    {"toVector2DAffine", reinterpret_cast<PyCFunction>(Sbk_QVector4DFunc_toVector2DAffine), METH_NOARGS, nullptr},
    {"toVector3D", reinterpret_cast<PyCFunction>(Sbk_QVector4DFunc_toVector3D), METH_NOARGS, nullptr},
    {"toVector3DAffine", reinterpret_cast<PyCFunction>(Sbk_QVector4DFunc_toVector3DAffine), METH_NOARGS, nullptr},
    {"w", reinterpret_cast<PyCFunction>(Sbk_QVector4DFunc_w), METH_NOARGS, nullptr},
    {"x", reinterpret_cast<PyCFunction>(Sbk_QVector4DFunc_x), METH_NOARGS, nullptr},
    {"y", reinterpret_cast<PyCFunction>(Sbk_QVector4DFunc_y), METH_NOARGS, nullptr},
    {"z", reinterpret_cast<PyCFunction>(Sbk_QVector4DFunc_z), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QVector4D__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QVector4D___nb_bool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QVector4D *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return !cppSelf->isNull() ? 1 : 0;
}

static PyObject *Sbk_QVector4DFunc___mul__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVector4D *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QVector4D::operator*(QVector4D)->QVector4D
    // 1: QVector4D::operator*(QMatrix4x4)->QVector4D
    // 2: QVector4D::operator*(QMatrix4x4)->QVector4D
    // 3: QVector4D::operator*(float)->QVector4D
    // 4: QVector4D::operator*(float)->QVector4D
    if (isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 4; // operator*(float,QVector4D)
    } else if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 3; // operator*(QVector4D,float)
    } else if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), (pyArg)))) {
        overloadId = 2; // operator*(QVector4D,QMatrix4x4)
    } else if (isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), (pyArg)))) {
        overloadId = 1; // operator*(QMatrix4x4,QVector4D)
    } else if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), (pyArg)))) {
        overloadId = 0; // operator*(QVector4D,QVector4D)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator*", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // operator*(QVector4D v2)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QVector4D cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator*(QVector4D,QVector4D)
                QVector4D cppResult = (*cppSelf) * cppArg0;
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), &cppResult);
            }
            break;
        }
        case 1: // operator*(const QMatrix4x4 &matrix)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QMatrix4x4 cppArg0_local;
            ::QMatrix4x4 *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // operator*(QMatrix4x4,QVector4D) [reverse operator]
                QVector4D cppResult = (*cppArg0) * (*cppSelf);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), &cppResult);
            }
            break;
        }
        case 2: // operator*(const QMatrix4x4 &matrix)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QMatrix4x4 cppArg0_local;
            ::QMatrix4x4 *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // operator*(QVector4D,QMatrix4x4)
                QVector4D cppResult = (*cppSelf) * (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), &cppResult);
            }
            break;
        }
        case 3: // operator*(float factor)
        {
            float cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator*(QVector4D,float)
                QVector4D cppResult = (*cppSelf) * cppArg0;
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), &cppResult);
            }
            break;
        }
        case 4: // operator*(float factor)
        {
            float cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator*(float,QVector4D) [reverse operator]
                QVector4D cppResult = cppArg0 * (*cppSelf);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVector4DFunc___imul__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVector4D *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QVector4D::operator*=(QVector4D)->QVector4D&
    // 1: QVector4D::operator*=(float)->QVector4D&
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 1; // operator*=(float)
    } else if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), (pyArg)))) {
        overloadId = 0; // operator*=(QVector4D)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator*=", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // operator*=(QVector4D vector)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QVector4D cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator*=(QVector4D)
                (*cppSelf) *= cppArg0;
            }
            break;
        }
        case 1: // operator*=(float factor)
        {
            float cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator*=(float)
                (*cppSelf) *= cppArg0;
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_INCREF(self);
    return self;
}

static PyObject *Sbk_QVector4DFunc___add__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVector4D *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QVector4D::operator+(QVector4D)->QVector4D
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), (pyArg)))) {
        overloadId = 0; // operator+(QVector4D,QVector4D)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator+", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QVector4D cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // operator+(QVector4D,QVector4D)
            QVector4D cppResult = (*cppSelf) + cppArg0;
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVector4DFunc___iadd__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVector4D *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QVector4D::operator+=(QVector4D)->QVector4D&
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), (pyArg)))) {
        overloadId = 0; // operator+=(QVector4D)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator+=", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QVector4D cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // operator+=(QVector4D)
            (*cppSelf) += cppArg0;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_INCREF(self);
    return self;
}

static PyObject *Sbk_QVector4DFunc___neg__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVector4D *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // operator-(QVector4D)
        QVector4D cppResult = - (*cppSelf);
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVector4DFunc___sub__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVector4D *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QVector4D::operator-(QVector4D)->QVector4D
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), (pyArg)))) {
        overloadId = 0; // operator-(QVector4D,QVector4D)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator-", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QVector4D cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // operator-(QVector4D,QVector4D)
            QVector4D cppResult = (*cppSelf) - cppArg0;
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVector4DFunc___isub__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVector4D *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QVector4D::operator-=(QVector4D)->QVector4D&
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), (pyArg)))) {
        overloadId = 0; // operator-=(QVector4D)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator-=", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QVector4D cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // operator-=(QVector4D)
            (*cppSelf) -= cppArg0;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_INCREF(self);
    return self;
}

static PyObject *Sbk_QVector4DFunc___div__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVector4D *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QVector4D::operator/(QVector4D)->QVector4D
    // 1: QVector4D::operator/(float)->QVector4D
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 1; // operator/(QVector4D,float)
    } else if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), (pyArg)))) {
        overloadId = 0; // operator/(QVector4D,QVector4D)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator/", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // operator/(QVector4D divisor)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QVector4D cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator/(QVector4D,QVector4D)
                QVector4D cppResult = (*cppSelf) / cppArg0;
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), &cppResult);
            }
            break;
        }
        case 1: // operator/(float divisor)
        {
            float cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator/(QVector4D,float)
                QVector4D cppResult = (*cppSelf) / cppArg0;
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVector4DFunc___lshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVector4D *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rlshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QVector4D::operator<<(QDataStream&)->QDataStream&
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // operator<<(QDataStream&,QVector4D)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator<<", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator<<(QDataStream&,QVector4D) [reverse operator]
                QDataStream & cppResult = (*cppArg0) << (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVector4DFunc___rshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVector4D *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rrshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QVector4D::operator>>(QDataStream&)->QDataStream&
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // operator>>(QDataStream&,QVector4D&)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator>>", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator>>(QDataStream&,QVector4D&) [reverse operator]
                QDataStream & cppResult = (*cppArg0) >> (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

// Rich comparison
static PyObject * Sbk_QVector4D_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QVector4D *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), (pyArg)))) {
                // operator!=(QVector4D v2)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QVector4D cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf != (cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), (pyArg)))) {
                // operator==(QVector4D v2)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QVector4D cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf == (cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QVector4D_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QVector4D_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QVector4D_Type = nullptr;
static PyTypeObject *Sbk_QVector4D_TypeF(void)
{
    return _Sbk_QVector4D_Type;
}

static PyType_Slot Sbk_QVector4D_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QVector4DFunc___repr__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QVector4D_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QVector4D_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QVector4D_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QVector4D_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QVector4D_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_inplace_add, reinterpret_cast<void *>(Sbk_QVector4DFunc___iadd__)},
    {Py_nb_subtract,    reinterpret_cast<void *>(Sbk_QVector4DFunc___sub__)},
    {Py_nb_inplace_multiply,reinterpret_cast<void *>(Sbk_QVector4DFunc___imul__)},
    {Py_nb_multiply,    reinterpret_cast<void *>(Sbk_QVector4DFunc___mul__)},
    {Py_nb_negative,    reinterpret_cast<void *>(Sbk_QVector4DFunc___neg__)},
    {Py_nb_bool,        reinterpret_cast<void *>(Sbk_QVector4D___nb_bool)},
    {Py_nb_inplace_subtract,reinterpret_cast<void *>(Sbk_QVector4DFunc___isub__)},
    {Py_nb_lshift,      reinterpret_cast<void *>(Sbk_QVector4DFunc___lshift__)},
    {Py_nb_rshift,      reinterpret_cast<void *>(Sbk_QVector4DFunc___rshift__)},
    {Py_nb_true_divide, reinterpret_cast<void *>(Sbk_QVector4DFunc___div__)},
    {Py_nb_add,         reinterpret_cast<void *>(Sbk_QVector4DFunc___add__)},
    {0, nullptr}
};
static PyType_Spec Sbk_QVector4D_spec = {
    "2:PySide6.QtGui.QVector4D",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QVector4D_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QVector4D_PythonToCpp_QVector4D_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QVector4D_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QVector4D_PythonToCpp_QVector4D_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QVector4D_TypeF()))
        return QVector4D_PythonToCpp_QVector4D_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QVector4D_PTR_CppToPython_QVector4D(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QVector4D_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QVector4D_COPY_CppToPython_QVector4D(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QVector4D *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QVector4D_TypeF(), new ::QVector4D(*source), true, true);
}

// Python to C++ copy conversion.
static void QVector4D_PythonToCpp_QVector4D_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QVector4D *>(cppOut) = *reinterpret_cast< ::QVector4D *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QVector4D_PythonToCpp_QVector4D_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QVector4D_TypeF()))
        return QVector4D_PythonToCpp_QVector4D_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QVector4D_SignatureStrings[] = {
    "7:PySide6.QtGui.QVector4D(self)",
    "6:PySide6.QtGui.QVector4D(self,point:PySide6.QtCore.QPoint)",
    "5:PySide6.QtGui.QVector4D(self,point:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element])",
    "4:PySide6.QtGui.QVector4D(self,vector:PySide6.QtGui.QVector2D)",
    "3:PySide6.QtGui.QVector4D(self,vector:PySide6.QtGui.QVector2D,zpos:float,wpos:float)",
    "2:PySide6.QtGui.QVector4D(self,vector:PySide6.QtGui.QVector3D)",
    "1:PySide6.QtGui.QVector4D(self,vector:PySide6.QtGui.QVector3D,wpos:float)",
    "0:PySide6.QtGui.QVector4D(self,xpos:float,ypos:float,zpos:float,wpos:float)",
    "PySide6.QtGui.QVector4D.__reduce__(self)->str",
    "PySide6.QtGui.QVector4D.__repr__(self)->str",
    "PySide6.QtGui.QVector4D.dotProduct(v1:PySide6.QtGui.QVector4D,v2:PySide6.QtGui.QVector4D)->float",
    "PySide6.QtGui.QVector4D.isNull(self)->bool",
    "PySide6.QtGui.QVector4D.length(self)->float",
    "PySide6.QtGui.QVector4D.lengthSquared(self)->float",
    "PySide6.QtGui.QVector4D.normalize(self)",
    "PySide6.QtGui.QVector4D.normalized(self)->PySide6.QtGui.QVector4D",
    "PySide6.QtGui.QVector4D.setW(self,w:float)",
    "PySide6.QtGui.QVector4D.setX(self,x:float)",
    "PySide6.QtGui.QVector4D.setY(self,y:float)",
    "PySide6.QtGui.QVector4D.setZ(self,z:float)",
    "PySide6.QtGui.QVector4D.toPoint(self)->PySide6.QtCore.QPoint",
    "PySide6.QtGui.QVector4D.toPointF(self)->PySide6.QtCore.QPointF",
    "PySide6.QtGui.QVector4D.toTuple(self)->PyObject",
    "PySide6.QtGui.QVector4D.toVector2D(self)->PySide6.QtGui.QVector2D",
    "PySide6.QtGui.QVector4D.toVector2DAffine(self)->PySide6.QtGui.QVector2D",
    "PySide6.QtGui.QVector4D.toVector3D(self)->PySide6.QtGui.QVector3D",
    "PySide6.QtGui.QVector4D.toVector3DAffine(self)->PySide6.QtGui.QVector3D",
    "PySide6.QtGui.QVector4D.w(self)->float",
    "PySide6.QtGui.QVector4D.x(self)->float",
    "PySide6.QtGui.QVector4D.y(self)->float",
    "PySide6.QtGui.QVector4D.z(self)->float",
    "PySide6.QtGui.QVector4D.__copy__(self)->typing.Self",
    "4:PySide6.QtGui.QVector4D.__mul__(self,v2:PySide6.QtGui.QVector4D)->PySide6.QtGui.QVector4D",
    "3:PySide6.QtGui.QVector4D.__mul__(self,matrix:typing.Union[PySide6.QtGui.QMatrix4x4, PySide6.QtGui.QTransform])->PySide6.QtGui.QVector4D",
    "2:PySide6.QtGui.QVector4D.__mul__(self,matrix:typing.Union[PySide6.QtGui.QMatrix4x4, PySide6.QtGui.QTransform])->PySide6.QtGui.QVector4D",
    "1:PySide6.QtGui.QVector4D.__mul__(self,factor:float)->PySide6.QtGui.QVector4D",
    "0:PySide6.QtGui.QVector4D.__mul__(self,factor:float)->PySide6.QtGui.QVector4D",
    "1:PySide6.QtGui.QVector4D.__imul__(self,vector:PySide6.QtGui.QVector4D)->PySide6.QtGui.QVector4D",
    "0:PySide6.QtGui.QVector4D.__imul__(self,factor:float)->PySide6.QtGui.QVector4D",
    "PySide6.QtGui.QVector4D.__add__(self,v2:PySide6.QtGui.QVector4D)->PySide6.QtGui.QVector4D",
    "PySide6.QtGui.QVector4D.__iadd__(self,vector:PySide6.QtGui.QVector4D)->PySide6.QtGui.QVector4D",
    "PySide6.QtGui.QVector4D.__neg__(self)->PySide6.QtGui.QVector4D",
    "PySide6.QtGui.QVector4D.__sub__(self,v2:PySide6.QtGui.QVector4D)->PySide6.QtGui.QVector4D",
    "PySide6.QtGui.QVector4D.__isub__(self,vector:PySide6.QtGui.QVector4D)->PySide6.QtGui.QVector4D",
    "1:PySide6.QtGui.QVector4D.__div__(self,divisor:PySide6.QtGui.QVector4D)->PySide6.QtGui.QVector4D",
    "0:PySide6.QtGui.QVector4D.__div__(self,divisor:float)->PySide6.QtGui.QVector4D",
    "PySide6.QtGui.QVector4D.__lshift__(self,arg__1:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "PySide6.QtGui.QVector4D.__rshift__(self,arg__1:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "PySide6.QtGui.QVector4D.__ne__(self,v2:PySide6.QtGui.QVector4D)->bool",
    "PySide6.QtGui.QVector4D.__eq__(self,v2:PySide6.QtGui.QVector4D)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QVector4D_SignatureByteSize = 545;
static constexpr uint8_t QVector4D_SignatureBytes[545] = {
    0x78, 0xda, 0xcd, 0x97, 0x4d, 0x8f, 0x9b, 0x30, 0x10, 0x86, 0xef, 0xfc, 0x8a, 0x1e, 0x17, 0x89,
    0xa2, 0x24, 0xa4, 0x5b, 0x69, 0x0f, 0x95, 0xaa, 0xa6, 0xe9, 0xa9, 0x2d, 0x51, 0xb6, 0xdf, 0x5a,
    0x21, 0x27, 0x0c, 0x89, 0x2b, 0x63, 0xb3, 0xc6, 0x24, 0x21, 0xbf, 0x7e, 0x5d, 0x08, 0x0b, 0x55,
    0xf0, 0xc4, 0x4d, 0xb6, 0x55, 0x6f, 0x60, 0xde, 0x79, 0xfc, 0xda, 0x1e, 0x66, 0xe0, 0xe5, 0x4d,
    0x58, 0xce, 0x69, 0x0c, 0xd7, 0xfe, 0x4c, 0xbd, 0x2b, 0xa8, 0x3f, 0xfb, 0x0c, 0x4b, 0x25, 0xe4,
    0x78, 0x72, 0x95, 0x03, 0x4b, 0x5c, 0xe7, 0x1a, 0x7d, 0xee, 0x65, 0x82, 0x72, 0xd5, 0x91, 0xbc,
    0x11, 0x12, 0xfc, 0x59, 0xf8, 0x6b, 0xd4, 0x75, 0x5e, 0xd8, 0xc4, 0xaa, 0x32, 0xa3, 0x7c, 0xe5,
    0x7f, 0xe2, 0x54, 0xf0, 0x1f, 0xbd, 0xa0, 0xa9, 0xf7, 0xac, 0x77, 0xbc, 0x3b, 0x5c, 0xe1, 0x43,
    0xa2, 0x47, 0x41, 0x86, 0x44, 0xad, 0xfd, 0xb7, 0x0c, 0x52, 0xe0, 0xea, 0xce, 0x75, 0xc6, 0xb8,
    0x8b, 0x4d, 0x75, 0xd7, 0xaf, 0x19, 0x4d, 0x5c, 0x27, 0xb8, 0x24, 0xdc, 0xdb, 0x67, 0x22, 0xbf,
    0x49, 0x98, 0x20, 0xca, 0xdb, 0x3e, 0x5e, 0xba, 0xce, 0xe8, 0x7c, 0x68, 0xa0, 0x3d, 0x0d, 0x2f,
    0x09, 0xff, 0xcd, 0xc8, 0x00, 0x27, 0xed, 0x5a, 0xfb, 0x65, 0x7b, 0x69, 0x58, 0x94, 0x81, 0xe4,
    0x47, 0x91, 0x84, 0xb8, 0x58, 0x42, 0x14, 0xd5, 0x39, 0xf5, 0xfc, 0x55, 0xae, 0x24, 0xaa, 0xce,
    0xa4, 0x9d, 0x36, 0x16, 0x2a, 0x94, 0x42, 0xb3, 0xd5, 0xd5, 0xc6, 0xb8, 0x27, 0xde, 0xc6, 0xb8,
    0xdb, 0x1a, 0x5f, 0x79, 0x37, 0x4e, 0x40, 0xf3, 0x0f, 0x05, 0x63, 0x8d, 0x95, 0x85, 0x10, 0xcc,
    0x28, 0x65, 0xc0, 0x57, 0x6a, 0xdd, 0x48, 0x71, 0x6c, 0xad, 0x9d, 0xdf, 0x17, 0x44, 0xef, 0x8c,
    0x5d, 0x08, 0x17, 0x32, 0x25, 0x8c, 0xee, 0xe1, 0xf0, 0x5e, 0x9e, 0xd4, 0x3d, 0x72, 0x0d, 0x4a,
    0x23, 0x21, 0x07, 0xf5, 0xa5, 0x3e, 0xfd, 0xed, 0xa9, 0x93, 0xd5, 0xd2, 0xaf, 0x87, 0x44, 0xb1,
    0x90, 0x7e, 0xab, 0xa5, 0xa5, 0x85, 0xf4, 0x7b, 0x2d, 0xdd, 0x9f, 0x92, 0x2a, 0x51, 0x55, 0x82,
    0xe3, 0xa5, 0x76, 0xca, 0xc4, 0xa9, 0xe0, 0x29, 0x1a, 0x3d, 0x45, 0xc2, 0x6f, 0x8b, 0x8c, 0x41,
    0x1b, 0xfd, 0x71, 0xf1, 0x53, 0x3f, 0x43, 0xf4, 0x4d, 0x55, 0x40, 0x4f, 0x66, 0x34, 0xb1, 0x20,
    0xbc, 0x4e, 0x12, 0xca, 0xe1, 0x52, 0x4e, 0x80, 0x3b, 0x09, 0x6c, 0x08, 0x16, 0x4e, 0x10, 0xce,
    0xd6, 0x2e, 0xf9, 0x77, 0x76, 0xb2, 0xd2, 0x4e, 0xb6, 0xb7, 0x93, 0x45, 0xd1, 0x52, 0x64, 0x65,
    0x5b, 0x88, 0x0e, 0x8d, 0x6a, 0xae, 0xef, 0xcc, 0x3d, 0x45, 0x47, 0xa5, 0x05, 0x3b, 0x04, 0xe1,
    0x95, 0xc7, 0xf4, 0x5e, 0x06, 0x76, 0xec, 0x94, 0x28, 0x49, 0x77, 0xa6, 0xf6, 0x59, 0x05, 0xbe,
    0xaf, 0x24, 0xe3, 0xdd, 0xf8, 0xa8, 0x53, 0xde, 0x4a, 0xc2, 0xf3, 0x44, 0x97, 0x8a, 0x3b, 0xc4,
    0xc8, 0xe8, 0x7f, 0x31, 0x32, 0xb4, 0x33, 0x92, 0x90, 0xaa, 0xed, 0xd5, 0x25, 0xc3, 0x4c, 0x1b,
    0x3c, 0x29, 0x0d, 0xf3, 0x46, 0xbb, 0xa9, 0x80, 0xf4, 0x64, 0x34, 0x1d, 0x06, 0x96, 0x13, 0x58,
    0xfa, 0x35, 0xc3, 0x48, 0x1c, 0x5f, 0x94, 0xb7, 0x88, 0xcd, 0x2e, 0xfa, 0xdc, 0x7d, 0x30, 0xe3,
    0x39, 0xac, 0xda, 0xb7, 0xf4, 0xcf, 0xc3, 0xf3, 0x62, 0xf1, 0xb7, 0xd6, 0xdd, 0x45, 0x9f, 0xbb,
    0x6e, 0x2c, 0xc1, 0x62, 0xba, 0x69, 0xf8, 0xfa, 0x92, 0xe6, 0x4f, 0x9e, 0x60, 0x3d, 0x13, 0x9c,
    0x9f, 0x60, 0x2c, 0x5f, 0xd3, 0x44, 0x35, 0x3c, 0x22, 0xf5, 0xa9, 0x0d, 0x8f, 0x7e, 0x1d, 0x26,
    0x44, 0x91, 0xb9, 0x92, 0x40, 0xd2, 0x9e, 0x8e, 0xdc, 0x3e, 0xc4, 0x3e, 0x1f, 0xff, 0xcd, 0x34,
    0x1c, 0xac, 0xb2, 0x06, 0xfd, 0x66, 0x8c, 0x22, 0xb8, 0xb7, 0xa7, 0x3c, 0x00, 0x48, 0x71, 0xb6,
    0xe0
};
#endif

PyTypeObject *init_QVector4D(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX].type;

    Shiboken::AutoDecRef Sbk_QVector4D_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QVector4D_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QVector4D",
        "QVector4D",
        &Sbk_QVector4D_spec,
        &Shiboken::callCppDestructor< ::QVector4D >,
        Sbk_QVector4D_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QVector4D_TypeF(); // references _Sbk_QVector4D_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QVector4D_SignatureStrings);
#else
    InitSignatureBytes(pyType, QVector4D_SignatureBytes, QVector4D_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QVector4D_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QVector4D_PythonToCpp_QVector4D_PTR,
        is_QVector4D_PythonToCpp_QVector4D_PTR_Convertible,
        QVector4D_PTR_CppToPython_QVector4D,
        QVector4D_COPY_CppToPython_QVector4D);

    Shiboken::Conversions::registerConverterName(converter, "QVector4D");
    Shiboken::Conversions::registerConverterName(converter, "QVector4D*");
    Shiboken::Conversions::registerConverterName(converter, "QVector4D&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QVector4D).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QVector4D_PythonToCpp_QVector4D_COPY,
        is_QVector4D_PythonToCpp_QVector4D_COPY_Convertible);

    qRegisterMetaType< ::QVector4D >("QVector4D");

    return pyType;
}
