// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qwheelevent_wrapper.h"

// Argument includes
#include <QtGui/qevent.h>
#include <QtGui/qpointingdevice.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QWheelEventWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QWheelEventWrapper::QWheelEventWrapper(const ::QPointF & pos, const ::QPointF & globalPos, ::QPoint pixelDelta, ::QPoint angleDelta, ::QFlags<Qt::MouseButton> buttons, ::QFlags<Qt::KeyboardModifier> modifiers, ::Qt::ScrollPhase phase, bool inverted, ::Qt::MouseEventSource source, const ::QPointingDevice * device) : QWheelEvent(pos, globalPos, pixelDelta, angleDelta, buttons, modifiers, phase, inverted, source, device)
{
}

::QWheelEvent * QWheelEventWrapper::clone() const
{
    if (m_PyMethodCache[0])
        return this->::QWheelEvent::clone();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "clone";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QWheelEvent::clone();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWheelEvent", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QWheelEvent", funcName, Shiboken::SbkType< QWheelEvent >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QWheelEvent *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QWheelEventWrapper::isBeginEvent() const
{
    if (m_PyMethodCache[1])
        return this->::QWheelEvent::isBeginEvent();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "isBeginEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QWheelEvent::isBeginEvent();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWheelEvent", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QWheelEvent", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QWheelEventWrapper::isEndEvent() const
{
    if (m_PyMethodCache[2])
        return this->::QWheelEvent::isEndEvent();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "isEndEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QWheelEvent::isEndEvent();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWheelEvent", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QWheelEvent", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QWheelEventWrapper::isUpdateEvent() const
{
    if (m_PyMethodCache[3])
        return this->::QWheelEvent::isUpdateEvent();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "isUpdateEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QWheelEvent::isUpdateEvent();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWheelEvent", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QWheelEvent", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QWheelEventWrapper::setAccepted(bool accepted)
{
    if (m_PyMethodCache[4]) {
        return this->::QPointerEvent::setAccepted(accepted);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setAccepted";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QPointerEvent::setAccepted(accepted);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &accepted)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &accepted)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWheelEvent", funcName);
        return;
    }
}

void QWheelEventWrapper::setTimestamp(quint64 timestamp)
{
    if (m_PyMethodCache[5]) {
        return this->::QPointerEvent::setTimestamp(timestamp);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setTimestamp";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QPointerEvent::setTimestamp(timestamp);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &timestamp)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(K)",
        timestamp
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWheelEvent", funcName);
        return;
    }
}

QWheelEventWrapper::~QWheelEventWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QWheelEvent_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QWheelEvent >()))
        return -1;

    QWheelEventWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[10];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 10));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX]);
    if (numArgs == 2 || numArgs == 3 || numArgs == 4 || numArgs == 5 || numArgs == 6 || numArgs == 7)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOOOOOOO:QWheelEvent", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7]), &(pyArgs[8]), &(pyArgs[9])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QWheelEvent::QWheelEvent(QPointF,QPointF,QPoint,QPoint,QFlags<Qt::MouseButton>,QFlags<Qt::KeyboardModifier>,Qt::ScrollPhase,bool,Qt::MouseEventSource=,const QPointingDevice*=)
    // 1: QWheelEvent::QWheelEvent(QWheelEvent)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QWheelEvent(QWheelEvent)
    } else if (numArgs >= 8
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_MouseButton_IDX])))->flagsConverter, (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[5])))
        && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ScrollPhase_IDX])))->converter, (pyArgs[6])))
        && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[7])))) {
        if (numArgs == 8) {
            overloadId = 0; // QWheelEvent(QPointF,QPointF,QPoint,QPoint,QFlags<Qt::MouseButton>,QFlags<Qt::KeyboardModifier>,Qt::ScrollPhase,bool,Qt::MouseEventSource,const QPointingDevice*)
        } else if (numArgs >= 9
            && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_MouseEventSource_IDX])))->converter, (pyArgs[8])))) {
            if (numArgs == 9) {
                overloadId = 0; // QWheelEvent(QPointF,QPointF,QPoint,QPoint,QFlags<Qt::MouseButton>,QFlags<Qt::KeyboardModifier>,Qt::ScrollPhase,bool,Qt::MouseEventSource,const QPointingDevice*)
            } else if (numArgs >= 10
                && (pythonToCpp[9] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPointingDevice_IDX]), (pyArgs[9])))) {
                overloadId = 0; // QWheelEvent(QPointF,QPointF,QPoint,QPoint,QFlags<Qt::MouseButton>,QFlags<Qt::KeyboardModifier>,Qt::ScrollPhase,bool,Qt::MouseEventSource,const QPointingDevice*)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QWheelEvent(const QPointF &pos, const QPointF &globalPos, QPoint pixelDelta, QPoint angleDelta, QFlags<Qt::MouseButton> buttons, QFlags<Qt::KeyboardModifier> modifiers, Qt::ScrollPhase phase, bool inverted, Qt::MouseEventSource source, const QPointingDevice *device)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_source = Shiboken::String::createStaticString("source");
                if (PyDict_Contains(kwds, key_source) != 0) {
                    value = PyDict_GetItem(kwds, key_source);
                    if (value != nullptr && pyArgs[8] != nullptr ) {
                        errInfo.reset(key_source);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[8] = value;
                        if (!(pythonToCpp[8] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_MouseEventSource_IDX])))->converter, (pyArgs[8]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_source);
                }
                static PyObject *const key_device = Shiboken::String::createStaticString("device");
                if (PyDict_Contains(kwds, key_device) != 0) {
                    value = PyDict_GetItem(kwds, key_device);
                    if (value != nullptr && pyArgs[9] != nullptr ) {
                        errInfo.reset(key_device);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[9] = value;
                        if (!(pythonToCpp[9] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPointingDevice_IDX]), (pyArgs[9]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_device);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPointF cppArg0_local;
            ::QPointF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QPointF cppArg1_local;
            ::QPointF *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return -1;
            ::QPoint cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return -1;
            ::QPoint cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            ::QFlags<Qt::MouseButton> cppArg4 = QFlags<Qt::MouseButton>(0);
            pythonToCpp[4](pyArgs[4], &cppArg4);
            ::QFlags<Qt::KeyboardModifier> cppArg5 = QFlags<Qt::KeyboardModifier>(0);
            pythonToCpp[5](pyArgs[5], &cppArg5);
            ::Qt::ScrollPhase cppArg6{Qt::NoScrollPhase};
            pythonToCpp[6](pyArgs[6], &cppArg6);
            bool cppArg7;
            pythonToCpp[7](pyArgs[7], &cppArg7);
            ::Qt::MouseEventSource cppArg8(Qt::MouseEventNotSynthesized);
            if (pythonToCpp[8])
                pythonToCpp[8](pyArgs[8], &cppArg8);
            if (!Shiboken::Object::isValid(pyArgs[9]))
                return -1;
            ::QPointingDevice *cppArg9 = const_cast<::QPointingDevice *>(QPointingDevice::primaryPointingDevice());
            if (pythonToCpp[9])
                pythonToCpp[9](pyArgs[9], &cppArg9);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QWheelEvent(QPointF,QPointF,QPoint,QPoint,QFlags<Qt::MouseButton>,QFlags<Qt::KeyboardModifier>,Qt::ScrollPhase,bool,Qt::MouseEventSource,const QPointingDevice*)
                cptr = new QWheelEventWrapper(*cppArg0, *cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8, cppArg9);
            }
            break;
        }
        case 1: // QWheelEvent(const QWheelEvent &arg__1)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QWheelEvent *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QWheelEvent(QWheelEvent)
                cptr = new QWheelEventWrapper(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QWheelEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QWheelEventFunc___repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWheelEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // __repr__()
        // Begin code injection
        // TEMPLATE - repr_qdebug_gui - START
        // TEMPLATE - repr_qdebug - START
        QString result;
        QDebug(&result).nospace() << "<PySide6.QtGui." << cppSelf << '>';
        pyResult = Shiboken::String::fromCString(qPrintable(result));
        // TEMPLATE - repr_qdebug - END
        // TEMPLATE - repr_qdebug_gui - END
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWheelEventFunc_angleDelta(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWheelEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // angleDelta()const
        QPoint cppResult = const_cast<const ::QWheelEvent *>(cppSelf)->angleDelta();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWheelEventFunc_clone(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWheelEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clone()const
        QWheelEvent * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QWheelEvent *>(cppSelf)->::QWheelEvent::clone()
            : const_cast<const ::QWheelEvent *>(cppSelf)->clone();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWheelEventFunc_hasPixelDelta(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWheelEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hasPixelDelta()const
        bool cppResult = const_cast<const ::QWheelEvent *>(cppSelf)->hasPixelDelta();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWheelEventFunc_inverted(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWheelEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // inverted()const
        bool cppResult = const_cast<const ::QWheelEvent *>(cppSelf)->inverted();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWheelEventFunc_isBeginEvent(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWheelEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isBeginEvent()const
        bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QWheelEvent *>(cppSelf)->::QWheelEvent::isBeginEvent()
            : const_cast<const ::QWheelEvent *>(cppSelf)->isBeginEvent();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWheelEventFunc_isEndEvent(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWheelEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isEndEvent()const
        bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QWheelEvent *>(cppSelf)->::QWheelEvent::isEndEvent()
            : const_cast<const ::QWheelEvent *>(cppSelf)->isEndEvent();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWheelEventFunc_isInverted(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWheelEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isInverted()const
        bool cppResult = const_cast<const ::QWheelEvent *>(cppSelf)->isInverted();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWheelEventFunc_isUpdateEvent(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWheelEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isUpdateEvent()const
        bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QWheelEvent *>(cppSelf)->::QWheelEvent::isUpdateEvent()
            : const_cast<const ::QWheelEvent *>(cppSelf)->isUpdateEvent();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWheelEventFunc_phase(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWheelEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // phase()const
        Qt::ScrollPhase cppResult = const_cast<const ::QWheelEvent *>(cppSelf)->phase();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ScrollPhase_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWheelEventFunc_pixelDelta(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWheelEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pixelDelta()const
        QPoint cppResult = const_cast<const ::QWheelEvent *>(cppSelf)->pixelDelta();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWheelEventFunc_source(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWheelEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // source()const
        Qt::MouseEventSource cppResult = const_cast<const ::QWheelEvent *>(cppSelf)->source();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_MouseEventSource_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QWheelEvent_PropertyStrings[] = {
    "angleDelta:",
    "device:pointingDevice",
    "inverted:",
    "phase:",
    "pixelDelta:",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QWheelEvent_methods[] = {
    {"angleDelta", reinterpret_cast<PyCFunction>(Sbk_QWheelEventFunc_angleDelta), METH_NOARGS, nullptr},
    {"clone", reinterpret_cast<PyCFunction>(Sbk_QWheelEventFunc_clone), METH_NOARGS, nullptr},
    {"hasPixelDelta", reinterpret_cast<PyCFunction>(Sbk_QWheelEventFunc_hasPixelDelta), METH_NOARGS, nullptr},
    {"inverted", reinterpret_cast<PyCFunction>(Sbk_QWheelEventFunc_inverted), METH_NOARGS, nullptr},
    {"isBeginEvent", reinterpret_cast<PyCFunction>(Sbk_QWheelEventFunc_isBeginEvent), METH_NOARGS, nullptr},
    {"isEndEvent", reinterpret_cast<PyCFunction>(Sbk_QWheelEventFunc_isEndEvent), METH_NOARGS, nullptr},
    {"isInverted", reinterpret_cast<PyCFunction>(Sbk_QWheelEventFunc_isInverted), METH_NOARGS, nullptr},
    {"isUpdateEvent", reinterpret_cast<PyCFunction>(Sbk_QWheelEventFunc_isUpdateEvent), METH_NOARGS, nullptr},
    {"phase", reinterpret_cast<PyCFunction>(Sbk_QWheelEventFunc_phase), METH_NOARGS, nullptr},
    {"pixelDelta", reinterpret_cast<PyCFunction>(Sbk_QWheelEventFunc_pixelDelta), METH_NOARGS, nullptr},
    {"source", reinterpret_cast<PyCFunction>(Sbk_QWheelEventFunc_source), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QWheelEvent_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QWheelEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QWheelEventWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QWheelEvent_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QWheelEvent_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QWheelEvent_Type = nullptr;
static PyTypeObject *Sbk_QWheelEvent_TypeF(void)
{
    return _Sbk_QWheelEvent_Type;
}

static PyType_Slot Sbk_QWheelEvent_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QWheelEventFunc___repr__)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QWheelEvent_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QWheelEvent_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QWheelEvent_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QWheelEvent_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QWheelEvent_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QWheelEvent_spec = {
    "2:PySide6.QtGui.QWheelEvent",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QWheelEvent_slots
};

} //extern "C"

static void *Sbk_QWheelEvent_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if ( reinterpret_cast< ::QEvent *>(cptr)->type() == QEvent::Wheel)
        return cptr;
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QWheelEvent_PythonToCpp_QWheelEvent_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QWheelEvent_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QWheelEvent_PythonToCpp_QWheelEvent_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QWheelEvent_TypeF()))
        return QWheelEvent_PythonToCpp_QWheelEvent_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QWheelEvent_PTR_CppToPython_QWheelEvent(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QWheelEvent *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QWheelEvent_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QWheelEvent_SignatureStrings[] = {
    "1:PySide6.QtGui.QWheelEvent(self,pos:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],globalPos:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],pixelDelta:PySide6.QtCore.QPoint,angleDelta:PySide6.QtCore.QPoint,buttons:PySide6.QtCore.Qt.MouseButton,modifiers:PySide6.QtCore.Qt.KeyboardModifier,phase:PySide6.QtCore.Qt.ScrollPhase,inverted:bool,source:PySide6.QtCore.Qt.MouseEventSource=Qt.MouseEventNotSynthesized,device:PySide6.QtGui.QPointingDevice=QPointingDevice.primaryPointingDevice(),*:KeywordOnly=None,device:QPointingDevice=None,pixelDelta:QPoint=None,angleDelta:QPoint=None,phase:Qt.ScrollPhase=None,inverted:bool=None)",
    "0:PySide6.QtGui.QWheelEvent(self,arg__1:PySide6.QtGui.QWheelEvent,*:KeywordOnly=None,device:QPointingDevice=None,pixelDelta:QPoint=None,angleDelta:QPoint=None,phase:Qt.ScrollPhase=None,inverted:bool=None)",
    "PySide6.QtGui.QWheelEvent.__repr__(self)->str",
    "PySide6.QtGui.QWheelEvent.angleDelta(self)->PySide6.QtCore.QPoint",
    "PySide6.QtGui.QWheelEvent.clone(self)->PySide6.QtGui.QWheelEvent",
    "PySide6.QtGui.QWheelEvent.hasPixelDelta(self)->bool",
    "PySide6.QtGui.QWheelEvent.inverted(self)->bool",
    "PySide6.QtGui.QWheelEvent.isBeginEvent(self)->bool",
    "PySide6.QtGui.QWheelEvent.isEndEvent(self)->bool",
    "PySide6.QtGui.QWheelEvent.isInverted(self)->bool",
    "PySide6.QtGui.QWheelEvent.isUpdateEvent(self)->bool",
    "PySide6.QtGui.QWheelEvent.phase(self)->PySide6.QtCore.Qt.ScrollPhase",
    "PySide6.QtGui.QWheelEvent.pixelDelta(self)->PySide6.QtCore.QPoint",
    "PySide6.QtGui.QWheelEvent.source(self)->PySide6.QtCore.Qt.MouseEventSource",
    nullptr}; // Sentinel
#else
static constexpr size_t QWheelEvent_SignatureByteSize = 396;
static constexpr uint8_t QWheelEvent_SignatureBytes[396] = {
    0x78, 0xda, 0xcd, 0x54, 0xc1, 0x4e, 0x83, 0x40, 0x10, 0xbd, 0xf7, 0x2b, 0x3c, 0xb6, 0x66, 0xdd,
    0xd8, 0x8b, 0x07, 0x92, 0x7a, 0xa8, 0xad, 0xc6, 0x98, 0x56, 0x1a, 0xd2, 0x78, 0x30, 0x86, 0x2c,
    0xdd, 0x29, 0x6c, 0xb2, 0xdd, 0x25, 0xbb, 0x4b, 0x15, 0xbf, 0x5e, 0xba, 0x88, 0x05, 0x0a, 0x58,
    0x2e, 0xc6, 0x23, 0xef, 0xbd, 0x79, 0x3b, 0xf3, 0x66, 0xc2, 0xd8, 0x71, 0x53, 0x8f, 0x51, 0xb8,
    0xc1, 0x2b, 0xf3, 0x90, 0x30, 0xbc, 0x7a, 0x89, 0x00, 0xf8, 0x7c, 0x0f, 0xc2, 0x0c, 0x35, 0xf0,
    0x2d, 0x8a, 0xa5, 0x76, 0x4c, 0x1a, 0x33, 0x11, 0xe2, 0xb5, 0x60, 0x52, 0xbc, 0x1e, 0xf5, 0x77,
    0x52, 0x01, 0x5e, 0xb9, 0x92, 0x09, 0x73, 0x8f, 0x2e, 0x1a, 0xf1, 0x32, 0x6c, 0xed, 0x5d, 0x92,
    0xa1, 0xa0, 0x5c, 0x62, 0x22, 0x3c, 0xe7, 0xb0, 0xcb, 0xde, 0x79, 0x43, 0x21, 0x97, 0x01, 0xe1,
    0xee, 0x1f, 0xbc, 0x14, 0xb3, 0x0f, 0xe0, 0x33, 0xe0, 0x86, 0x38, 0xcd, 0x2e, 0x44, 0x84, 0x1c,
    0xba, 0x04, 0x41, 0x62, 0x8c, 0x14, 0xfa, 0x84, 0x35, 0x78, 0x21, 0x13, 0x0d, 0x53, 0x4b, 0xa3,
    0x9d, 0xa4, 0x6c, 0xcb, 0x40, 0x35, 0xe9, 0x9e, 0x20, 0x0d, 0x24, 0x51, 0x74, 0xf1, 0xad, 0x41,
    0x71, 0x44, 0x34, 0x34, 0x08, 0xbd, 0x8d, 0x92, 0x9c, 0xbb, 0x07, 0x16, 0x31, 0xb1, 0x07, 0x65,
    0x80, 0x3a, 0x81, 0x94, 0x1c, 0x69, 0x99, 0xa8, 0x0d, 0xb4, 0xf5, 0x60, 0xb7, 0xe7, 0x59, 0xc9,
    0xa4, 0x82, 0x2d, 0xa5, 0xf1, 0x52, 0x61, 0x22, 0xd0, 0xec, 0x13, 0x28, 0xa2, 0xb0, 0x67, 0x15,
    0x97, 0x3c, 0xb7, 0xc3, 0x98, 0xd9, 0x12, 0x66, 0x96, 0x9d, 0xd4, 0xbe, 0x71, 0xac, 0xd8, 0x8e,
    0xa8, 0xb4, 0x8a, 0x0e, 0x47, 0xe8, 0xd2, 0xc9, 0xe6, 0x7a, 0x97, 0x8a, 0x3e, 0x0b, 0x9e, 0x4e,
    0x96, 0x52, 0x40, 0xe1, 0x5f, 0x77, 0xb4, 0x5c, 0x69, 0x11, 0x39, 0x9f, 0xc3, 0xa5, 0xf8, 0xcb,
    0x70, 0x9e, 0x50, 0x35, 0x92, 0x9c, 0xa9, 0xe4, 0x62, 0xa1, 0xd1, 0xe0, 0xfa, 0xb7, 0x9b, 0x26,
    0x2a, 0xf4, 0xfd, 0x71, 0xbb, 0xea, 0x3f, 0x0d, 0xd3, 0xda, 0x24, 0xf6, 0x7d, 0x05, 0xb1, 0xf2,
    0x7d, 0x3b, 0xd3, 0xe8, 0xea, 0x56, 0x1b, 0xd5, 0xa1, 0x3e, 0x36, 0x53, 0xe8, 0x1b, 0xef, 0xbb,
    0xc3, 0x61, 0xc3, 0xb3, 0x86, 0x4e, 0x8b, 0x6b, 0xb2, 0x0e, 0x83, 0x6c, 0x50, 0xf7, 0x27, 0xa9,
    0xc2, 0xe8, 0x30, 0x6a, 0x47, 0x4d, 0x11, 0xc9, 0xb9, 0x72, 0x3d, 0x85, 0x90, 0x89, 0xe3, 0xae,
    0xcf, 0x29, 0x99, 0x0b, 0xda, 0xaf, 0xe0, 0xb1, 0x6f, 0x53, 0xeb, 0x98, 0x12, 0x03, 0x7d, 0x1e,
    0xb1, 0x47, 0xd2, 0xb6, 0xa9, 0xca, 0xe9, 0x74, 0x99, 0x9c, 0xa4, 0xdd, 0x77, 0xe7, 0xf9, 0x8f,
    0xa6, 0xbd, 0x8f, 0xfa, 0xff, 0x66, 0xf0, 0x05, 0x49, 0x93, 0x46, 0xf3
};
#endif

PyTypeObject *init_QWheelEvent(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX].type;

    Shiboken::AutoDecRef Sbk_QWheelEvent_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSinglePointEvent_IDX]))));

    _Sbk_QWheelEvent_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QWheelEvent",
        "QWheelEvent*",
        &Sbk_QWheelEvent_spec,
        &Shiboken::callCppDestructor< QWheelEvent >,
        Sbk_QWheelEvent_Type_bases.object(),
        0);
    auto *pyType = Sbk_QWheelEvent_TypeF(); // references _Sbk_QWheelEvent_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QWheelEvent_SignatureStrings);
#else
    InitSignatureBytes(pyType, QWheelEvent_SignatureBytes, QWheelEvent_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QWheelEvent_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QWheelEvent_PythonToCpp_QWheelEvent_PTR,
        is_QWheelEvent_PythonToCpp_QWheelEvent_PTR_Convertible,
        QWheelEvent_PTR_CppToPython_QWheelEvent);

    Shiboken::Conversions::registerConverterName(converter, "QWheelEvent");
    Shiboken::Conversions::registerConverterName(converter, "QWheelEvent*");
    Shiboken::Conversions::registerConverterName(converter, "QWheelEvent&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QWheelEvent).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QWheelEventWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QWheelEvent_TypeF(), &Sbk_QWheelEvent_typeDiscovery);


    return pyType;
}
