// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qthelp_python.h"

// main header
#include "qhelpfilterdata_wrapper.h"

// Argument includes
#include <QList>
#include <QStringList>
#include <QtHelp/qhelpfilterdata.h>
#include <qversionnumber.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QHelpFilterData_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QHelpFilterData >()))
        return -1;

    ::QHelpFilterData *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QHelpFilterData", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QHelpFilterData::QHelpFilterData()
    // 1: QHelpFilterData::QHelpFilterData(QHelpFilterData)
    if (numArgs == 0) {
        overloadId = 0; // QHelpFilterData()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtHelpTypeStructs[SBK_QHelpFilterData_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QHelpFilterData(QHelpFilterData)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtHelpTypeStructs[SBK_QHelpFilterData_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtHelpTypeStructs[SBK_QHelpFilterData_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QHelpFilterData()
        {

            // QHelpFilterData()
            cptr = new ::QHelpFilterData();
            break;
        }
        case 1: // QHelpFilterData(const QHelpFilterData &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QHelpFilterData cppArg0_local;
            ::QHelpFilterData *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QHelpFilterData(QHelpFilterData)
                cptr = new ::QHelpFilterData(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QHelpFilterData >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtHelpTypeStructs[SBK_QHelpFilterData_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QHelpFilterDataFunc_components(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHelpFilterData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHelpTypeStructs[SBK_QHelpFilterData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // components()const
        QStringList cppResult = const_cast<const ::QHelpFilterData *>(cppSelf)->components();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHelpFilterDataFunc_setComponents(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHelpFilterData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHelpTypeStructs[SBK_QHelpFilterData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHelpFilterData::setComponents(QStringList)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // setComponents(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setComponents", errInfo, SbkPySide6_QtHelpTypeStructs[SBK_QHelpFilterData_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setComponents(QStringList)
            cppSelf->setComponents(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHelpFilterDataFunc_setVersions(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHelpFilterData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHelpTypeStructs[SBK_QHelpFilterData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHelpFilterData::setVersions(QList<QVersionNumber>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtHelpTypeConverters[SBK_QtHelp_QList_QVersionNumber_IDX], (pyArg)))) {
        overloadId = 0; // setVersions(QList<QVersionNumber>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setVersions", errInfo, SbkPySide6_QtHelpTypeStructs[SBK_QHelpFilterData_IDX]);

    // Call function/method
    {
        ::QList<QVersionNumber> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setVersions(QList<QVersionNumber>)
            cppSelf->setVersions(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHelpFilterDataFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHelpFilterData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHelpTypeStructs[SBK_QHelpFilterData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHelpFilterData::swap(QHelpFilterData&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtHelpTypeStructs[SBK_QHelpFilterData_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QHelpFilterData&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtHelpTypeStructs[SBK_QHelpFilterData_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QHelpFilterData cppArg0_local;
        ::QHelpFilterData *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QHelpFilterData&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHelpFilterDataFunc_versions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHelpFilterData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHelpTypeStructs[SBK_QHelpFilterData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // versions()const
        QList<QVersionNumber> cppResult = const_cast<const ::QHelpFilterData *>(cppSelf)->versions();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtHelpTypeConverters[SBK_QtHelp_QList_QVersionNumber_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHelpFilterData__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QHelpFilterData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHelpTypeStructs[SBK_QHelpFilterData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtHelpTypeStructs[SBK_QHelpFilterData_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QHelpFilterData_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QHelpFilterData_methods[] = {
    {"components", reinterpret_cast<PyCFunction>(Sbk_QHelpFilterDataFunc_components), METH_NOARGS, nullptr},
    {"setComponents", reinterpret_cast<PyCFunction>(Sbk_QHelpFilterDataFunc_setComponents), METH_O, nullptr},
    {"setVersions", reinterpret_cast<PyCFunction>(Sbk_QHelpFilterDataFunc_setVersions), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QHelpFilterDataFunc_swap), METH_O, nullptr},
    {"versions", reinterpret_cast<PyCFunction>(Sbk_QHelpFilterDataFunc_versions), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QHelpFilterData__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QHelpFilterData_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QHelpFilterData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHelpTypeStructs[SBK_QHelpFilterData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtHelpTypeStructs[SBK_QHelpFilterData_IDX]), (pyArg)))) {
                // operator==(const QHelpFilterData &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QHelpFilterData cppArg0_local;
                ::QHelpFilterData *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QHelpFilterData_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QHelpFilterData_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QHelpFilterData_Type = nullptr;
static PyTypeObject *Sbk_QHelpFilterData_TypeF(void)
{
    return _Sbk_QHelpFilterData_Type;
}

static PyType_Slot Sbk_QHelpFilterData_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QHelpFilterData_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QHelpFilterData_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QHelpFilterData_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QHelpFilterData_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QHelpFilterData_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QHelpFilterData_spec = {
    "2:PySide6.QtHelp.QHelpFilterData",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_GC,
    Sbk_QHelpFilterData_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QHelpFilterData_PythonToCpp_QHelpFilterData_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QHelpFilterData_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QHelpFilterData_PythonToCpp_QHelpFilterData_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QHelpFilterData_TypeF()))
        return QHelpFilterData_PythonToCpp_QHelpFilterData_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QHelpFilterData_PTR_CppToPython_QHelpFilterData(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QHelpFilterData_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QHelpFilterData_COPY_CppToPython_QHelpFilterData(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QHelpFilterData *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QHelpFilterData_TypeF(), new ::QHelpFilterData(*source), true, true);
}

// Python to C++ copy conversion.
static void QHelpFilterData_PythonToCpp_QHelpFilterData_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QHelpFilterData *>(cppOut) = *reinterpret_cast< ::QHelpFilterData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHelpTypeStructs[SBK_QHelpFilterData_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QHelpFilterData_PythonToCpp_QHelpFilterData_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QHelpFilterData_TypeF()))
        return QHelpFilterData_PythonToCpp_QHelpFilterData_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QHelpFilterData_SignatureStrings[] = {
    "1:PySide6.QtHelp.QHelpFilterData(self)",
    "0:PySide6.QtHelp.QHelpFilterData(self,other:PySide6.QtHelp.QHelpFilterData)",
    "PySide6.QtHelp.QHelpFilterData.components(self)->QStringList",
    "PySide6.QtHelp.QHelpFilterData.setComponents(self,components:QStringList)",
    "PySide6.QtHelp.QHelpFilterData.setVersions(self,versions:QList[PySide6.QtCore.QVersionNumber])",
    "PySide6.QtHelp.QHelpFilterData.swap(self,other:PySide6.QtHelp.QHelpFilterData)",
    "PySide6.QtHelp.QHelpFilterData.versions(self)->QList[PySide6.QtCore.QVersionNumber]",
    "PySide6.QtHelp.QHelpFilterData.__copy__(self)->typing.Self",
    "PySide6.QtHelp.QHelpFilterData.__eq__(self,other:PySide6.QtHelp.QHelpFilterData)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QHelpFilterData_SignatureByteSize = 190;
static constexpr uint8_t QHelpFilterData_SignatureBytes[190] = {
    0x78, 0xda, 0xad, 0x90, 0xb1, 0x0a, 0xc2, 0x30, 0x14, 0x45, 0xf7, 0x7e, 0x89, 0x85, 0x36, 0xe8,
    0xe2, 0xd0, 0xa1, 0x4b, 0x45, 0x1c, 0x44, 0x0c, 0x05, 0x17, 0x91, 0xd0, 0xd6, 0xa7, 0x06, 0xd2,
    0x24, 0x26, 0xcf, 0x4a, 0xff, 0xde, 0x16, 0x23, 0xad, 0x8b, 0xe9, 0xe0, 0x12, 0x78, 0xe4, 0x9e,
    0x93, 0x97, 0xbb, 0x48, 0xf6, 0x6d, 0xce, 0xcf, 0xb0, 0x24, 0x14, 0x37, 0x20, 0x34, 0xa1, 0xfd,
    0xb9, 0xe6, 0x02, 0xc1, 0xac, 0x0a, 0x2c, 0x66, 0x16, 0xc4, 0x25, 0x0c, 0xe6, 0x53, 0x62, 0x91,
    0xc2, 0x1b, 0x18, 0x4f, 0x32, 0x0c, 0x7e, 0xdf, 0x93, 0x4a, 0xd5, 0x5a, 0x49, 0x90, 0x68, 0xdf,
    0x6f, 0xc7, 0x29, 0xcd, 0xd1, 0x70, 0x79, 0xdd, 0x72, 0x8b, 0x3e, 0xd8, 0x02, 0x66, 0xdf, 0x7c,
    0x34, 0xf8, 0x92, 0x91, 0x28, 0x9c, 0x60, 0x3a, 0x80, 0xb1, 0x5c, 0x49, 0xe7, 0x69, 0xdc, 0x94,
    0xd0, 0x9e, 0x3f, 0x0e, 0x78, 0xa6, 0x0c, 0x10, 0xea, 0xc2, 0xbb, 0x47, 0x5d, 0x82, 0x39, 0xf9,
    0xf5, 0xcf, 0x42, 0xff, 0xb1, 0xb4, 0x66, 0xbc, 0x6a, 0x5f, 0xd9, 0x84, 0x1d, 0x7d, 0x4e, 0xc6,
    0x2a, 0xa5, 0x5b, 0xc6, 0x3e, 0x4e, 0x6c, 0x75, 0x57, 0x1e, 0xc9, 0xbb, 0xc9, 0x8f, 0xc2, 0xdd,
    0x81, 0xd3, 0xfe, 0x17, 0xa7, 0xa5, 0x52, 0x22, 0x78, 0x01, 0x83, 0x14, 0xeb, 0xbb
};
#endif

PyTypeObject *init_QHelpFilterData(PyObject *module)
{
    if (SbkPySide6_QtHelpTypeStructs[SBK_QHelpFilterData_IDX].type != nullptr)
        return SbkPySide6_QtHelpTypeStructs[SBK_QHelpFilterData_IDX].type;

    Shiboken::AutoDecRef Sbk_QHelpFilterData_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QHelpFilterData_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QHelpFilterData",
        "QHelpFilterData",
        &Sbk_QHelpFilterData_spec,
        &Shiboken::callCppDestructor< ::QHelpFilterData >,
        Sbk_QHelpFilterData_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QHelpFilterData_TypeF(); // references _Sbk_QHelpFilterData_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QHelpFilterData_SignatureStrings);
#else
    InitSignatureBytes(pyType, QHelpFilterData_SignatureBytes, QHelpFilterData_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QHelpFilterData_PropertyStrings);
    SbkPySide6_QtHelpTypeStructs[SBK_QHelpFilterData_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QHelpFilterData_PythonToCpp_QHelpFilterData_PTR,
        is_QHelpFilterData_PythonToCpp_QHelpFilterData_PTR_Convertible,
        QHelpFilterData_PTR_CppToPython_QHelpFilterData,
        QHelpFilterData_COPY_CppToPython_QHelpFilterData);

    Shiboken::Conversions::registerConverterName(converter, "QHelpFilterData");
    Shiboken::Conversions::registerConverterName(converter, "QHelpFilterData*");
    Shiboken::Conversions::registerConverterName(converter, "QHelpFilterData&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QHelpFilterData).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QHelpFilterData_PythonToCpp_QHelpFilterData_COPY,
        is_QHelpFilterData_PythonToCpp_QHelpFilterData_COPY_Convertible);

    qRegisterMetaType< ::QHelpFilterData >("QHelpFilterData");

    return pyType;
}
