// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qthelp_python.h"

// main header
#include "qhelpindexmodel_wrapper.h"

// Argument includes
#include <QHash>
#include <QList>
#include <QMap>
#include <QString>
#include <QStringList>
#include <QtHelp/qhelpenginecore.h>
#include <qabstractitemmodel.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qmimedata.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qsize.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QHelpIndexModelFunc_createIndex(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHelpIndexModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHelpTypeStructs[SBK_QHelpIndexModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHelpIndexModel::createIndex(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // createIndex(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "createIndex", errInfo, SbkPySide6_QtHelpTypeStructs[SBK_QHelpIndexModel_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createIndex(QString)
            cppSelf->createIndex(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHelpIndexModelFunc_createIndexForCurrentFilter(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHelpIndexModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHelpTypeStructs[SBK_QHelpIndexModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // createIndexForCurrentFilter()
        cppSelf->createIndexForCurrentFilter();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHelpIndexModelFunc_filter(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHelpIndexModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHelpTypeStructs[SBK_QHelpIndexModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "filter", errInfo, SbkPySide6_QtHelpTypeStructs[SBK_QHelpIndexModel_IDX]);

    if (PyArg_ParseTuple(args, "|OO:filter", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QHelpIndexModel::filter(QString,const QString&=)->QModelIndex
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // filter(QString,QString)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 0; // filter(QString,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "filter", errInfo, SbkPySide6_QtHelpTypeStructs[SBK_QHelpIndexModel_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_wildcard = Shiboken::String::createStaticString("wildcard");
            if (PyDict_Contains(kwds, key_wildcard) != 0) {
                value = PyDict_GetItem(kwds, key_wildcard);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_wildcard);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "filter", errInfo, SbkPySide6_QtHelpTypeStructs[SBK_QHelpIndexModel_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "filter", errInfo, SbkPySide6_QtHelpTypeStructs[SBK_QHelpIndexModel_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_wildcard);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "filter", errInfo, SbkPySide6_QtHelpTypeStructs[SBK_QHelpIndexModel_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1{};
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // filter(QString,QString)
            QModelIndex cppResult = cppSelf->filter(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHelpIndexModelFunc_helpEngine(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHelpIndexModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHelpTypeStructs[SBK_QHelpIndexModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // helpEngine()const
        QHelpEngineCore * cppResult = const_cast<const ::QHelpIndexModel *>(cppSelf)->helpEngine();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtHelpTypeStructs[SBK_QHelpEngineCore_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHelpIndexModelFunc_isCreatingIndex(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHelpIndexModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHelpTypeStructs[SBK_QHelpIndexModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isCreatingIndex()const
        bool cppResult = const_cast<const ::QHelpIndexModel *>(cppSelf)->isCreatingIndex();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QHelpIndexModel_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QHelpIndexModel_methods[] = {
    {"createIndex", reinterpret_cast<PyCFunction>(Sbk_QHelpIndexModelFunc_createIndex), METH_O, nullptr},
    {"createIndexForCurrentFilter", reinterpret_cast<PyCFunction>(Sbk_QHelpIndexModelFunc_createIndexForCurrentFilter), METH_NOARGS, nullptr},
    {"filter", reinterpret_cast<PyCFunction>(Sbk_QHelpIndexModelFunc_filter), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"helpEngine", reinterpret_cast<PyCFunction>(Sbk_QHelpIndexModelFunc_helpEngine), METH_NOARGS, nullptr},
    {"isCreatingIndex", reinterpret_cast<PyCFunction>(Sbk_QHelpIndexModelFunc_isCreatingIndex), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QHelpIndexModel_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QHelpIndexModel_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QHelpIndexModel_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QHelpIndexModel_Type = nullptr;
static PyTypeObject *Sbk_QHelpIndexModel_TypeF(void)
{
    return _Sbk_QHelpIndexModel_Type;
}

static PyType_Slot Sbk_QHelpIndexModel_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(SbkDeallocWrapperWithPrivateDtor)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QHelpIndexModel_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QHelpIndexModel_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QHelpIndexModel_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QHelpIndexModel_methods)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QHelpIndexModel_spec = {
    "2:PySide6.QtHelp.QHelpIndexModel",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QHelpIndexModel_slots
};

} //extern "C"

static void *Sbk_QHelpIndexModel_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QHelpIndexModel *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QHelpIndexModel_PythonToCpp_QHelpIndexModel_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QHelpIndexModel_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QHelpIndexModel_PythonToCpp_QHelpIndexModel_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QHelpIndexModel_TypeF()))
        return QHelpIndexModel_PythonToCpp_QHelpIndexModel_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QHelpIndexModel_PTR_CppToPython_QHelpIndexModel(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QHelpIndexModel *>(const_cast<void *>(cppIn)), Sbk_QHelpIndexModel_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QHelpIndexModel_SignatureStrings[] = {
    "PySide6.QtHelp.QHelpIndexModel.createIndex(self,customFilterName:QString)",
    "PySide6.QtHelp.QHelpIndexModel.createIndexForCurrentFilter(self)",
    "PySide6.QtHelp.QHelpIndexModel.filter(self,filter:QString,wildcard:QString={})->PySide6.QtCore.QModelIndex",
    "PySide6.QtHelp.QHelpIndexModel.helpEngine(self)->PySide6.QtHelp.QHelpEngineCore",
    "PySide6.QtHelp.QHelpIndexModel.isCreatingIndex(self)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QHelpIndexModel_SignatureByteSize = 170;
static constexpr uint8_t QHelpIndexModel_SignatureBytes[170] = {
    0x78, 0xda, 0x8d, 0xd0, 0xc1, 0x0a, 0xc2, 0x30, 0x0c, 0x00, 0xd0, 0xfb, 0xbe, 0xc4, 0xc1, 0xec,
    0xd1, 0x83, 0xa0, 0x97, 0xe2, 0xd0, 0x83, 0xb2, 0xb2, 0x2f, 0xa8, 0x6d, 0x36, 0x03, 0x5d, 0x2b,
    0x59, 0x87, 0x8a, 0xf8, 0xef, 0x6e, 0x2d, 0xa3, 0xde, 0xe6, 0xa5, 0xb4, 0x21, 0x79, 0x49, 0x5a,
    0xbd, 0x6a, 0xd4, 0xb0, 0x61, 0xc2, 0x1f, 0xc1, 0xdc, 0x99, 0x98, 0xce, 0x93, 0xd5, 0xf0, 0x3c,
    0x3b, 0x0d, 0x86, 0x29, 0x02, 0xe9, 0x21, 0x04, 0x56, 0x3d, 0x98, 0xa6, 0x50, 0x43, 0xef, 0x5d,
    0x57, 0xa2, 0xf1, 0x40, 0x17, 0xd9, 0xc1, 0x56, 0xd4, 0x9e, 0xd0, 0xb6, 0x79, 0x56, 0xfd, 0x2d,
    0x95, 0x8e, 0xf8, 0x40, 0x04, 0xd6, 0x47, 0x27, 0xc8, 0x8b, 0x40, 0x93, 0x72, 0x8b, 0x78, 0x9f,
    0x7b, 0x17, 0x0f, 0x34, 0x5a, 0x49, 0xd2, 0x73, 0x60, 0xf7, 0xfe, 0xe4, 0xeb, 0x7d, 0xf2, 0xb8,
    0x23, 0x60, 0x22, 0x30, 0x01, 0x5c, 0x6a, 0x75, 0x1b, 0x9f, 0x07, 0xdb, 0xa2, 0x85, 0x38, 0xda,
    0xaf, 0x95, 0x0a, 0x62, 0xc6, 0x64, 0x2f, 0x79, 0xd8, 0xf3, 0x69, 0xfb, 0x71, 0xb2, 0xf4, 0x93,
    0x23, 0x7a, 0x75, 0xce, 0x64, 0x5f, 0x3d, 0xd5, 0x8b, 0xd0
};
#endif

PyTypeObject *init_QHelpIndexModel(PyObject *module)
{
    if (SbkPySide6_QtHelpTypeStructs[SBK_QHelpIndexModel_IDX].type != nullptr)
        return SbkPySide6_QtHelpTypeStructs[SBK_QHelpIndexModel_IDX].type;

    Shiboken::AutoDecRef Sbk_QHelpIndexModel_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStringListModel_IDX]))));

    _Sbk_QHelpIndexModel_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QHelpIndexModel",
        "QHelpIndexModel*",
        &Sbk_QHelpIndexModel_spec,
        nullptr,
        Sbk_QHelpIndexModel_Type_bases.object(),
        0);
    auto *pyType = Sbk_QHelpIndexModel_TypeF(); // references _Sbk_QHelpIndexModel_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QHelpIndexModel_SignatureStrings);
#else
    InitSignatureBytes(pyType, QHelpIndexModel_SignatureBytes, QHelpIndexModel_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QHelpIndexModel_PropertyStrings);
    SbkPySide6_QtHelpTypeStructs[SBK_QHelpIndexModel_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QHelpIndexModel_PythonToCpp_QHelpIndexModel_PTR,
        is_QHelpIndexModel_PythonToCpp_QHelpIndexModel_PTR_Convertible,
        QHelpIndexModel_PTR_CppToPython_QHelpIndexModel);

    Shiboken::Conversions::registerConverterName(converter, "QHelpIndexModel");
    Shiboken::Conversions::registerConverterName(converter, "QHelpIndexModel*");
    Shiboken::Conversions::registerConverterName(converter, "QHelpIndexModel&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QHelpIndexModel).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QHelpIndexModel_TypeF(), &Sbk_QHelpIndexModel_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::QHelpIndexModel::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QHelpIndexModel::staticMetaObject, sizeof(::QHelpIndexModel));

    return pyType;
}
