// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qthelp_python.h"

// main header
#include "qhelpsearchresult_wrapper.h"

// Argument includes
#include <QString>
#include <QtHelp/qhelpsearchresult.h>
#include <qurl.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QHelpSearchResult_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QHelpSearchResult >()))
        return -1;

    ::QHelpSearchResult *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 2)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtHelpTypeStructs[SBK_QHelpSearchResult_IDX]);

    if (PyArg_UnpackTuple(args, "QHelpSearchResult", 0, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QHelpSearchResult::QHelpSearchResult()
    // 1: QHelpSearchResult::QHelpSearchResult(QHelpSearchResult)
    // 2: QHelpSearchResult::QHelpSearchResult(QUrl,QString,QString)
    if (numArgs == 0) {
        overloadId = 0; // QHelpSearchResult()
    } else if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
        overloadId = 2; // QHelpSearchResult(QUrl,QString,QString)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtHelpTypeStructs[SBK_QHelpSearchResult_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QHelpSearchResult(QHelpSearchResult)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtHelpTypeStructs[SBK_QHelpSearchResult_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtHelpTypeStructs[SBK_QHelpSearchResult_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QHelpSearchResult()
        {

            // QHelpSearchResult()
            cptr = new ::QHelpSearchResult();
            break;
        }
        case 1: // QHelpSearchResult(const QHelpSearchResult &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QHelpSearchResult *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QHelpSearchResult(QHelpSearchResult)
                cptr = new ::QHelpSearchResult(*cppArg0);
            }
            break;
        }
        case 2: // QHelpSearchResult(const QUrl &url, const QString &title, const QString &snippet)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QUrl cppArg0_local;
            ::QUrl *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QHelpSearchResult(QUrl,QString,QString)
                cptr = new ::QHelpSearchResult(*cppArg0, cppArg1, cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QHelpSearchResult >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtHelpTypeStructs[SBK_QHelpSearchResult_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QHelpSearchResultFunc_snippet(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHelpSearchResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHelpTypeStructs[SBK_QHelpSearchResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // snippet()const
        QString cppResult = const_cast<const ::QHelpSearchResult *>(cppSelf)->snippet();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHelpSearchResultFunc_title(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHelpSearchResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHelpTypeStructs[SBK_QHelpSearchResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // title()const
        QString cppResult = const_cast<const ::QHelpSearchResult *>(cppSelf)->title();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHelpSearchResultFunc_url(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHelpSearchResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHelpTypeStructs[SBK_QHelpSearchResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // url()const
        QUrl cppResult = const_cast<const ::QHelpSearchResult *>(cppSelf)->url();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QHelpSearchResult_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QHelpSearchResult_methods[] = {
    {"snippet", reinterpret_cast<PyCFunction>(Sbk_QHelpSearchResultFunc_snippet), METH_NOARGS, nullptr},
    {"title", reinterpret_cast<PyCFunction>(Sbk_QHelpSearchResultFunc_title), METH_NOARGS, nullptr},
    {"url", reinterpret_cast<PyCFunction>(Sbk_QHelpSearchResultFunc_url), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QHelpSearchResult_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QHelpSearchResult_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QHelpSearchResult_Type = nullptr;
static PyTypeObject *Sbk_QHelpSearchResult_TypeF(void)
{
    return _Sbk_QHelpSearchResult_Type;
}

static PyType_Slot Sbk_QHelpSearchResult_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QHelpSearchResult_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QHelpSearchResult_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QHelpSearchResult_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QHelpSearchResult_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QHelpSearchResult_spec = {
    "2:PySide6.QtHelp.QHelpSearchResult",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QHelpSearchResult_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QHelpSearchResult_PythonToCpp_QHelpSearchResult_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QHelpSearchResult_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QHelpSearchResult_PythonToCpp_QHelpSearchResult_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QHelpSearchResult_TypeF()))
        return QHelpSearchResult_PythonToCpp_QHelpSearchResult_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QHelpSearchResult_PTR_CppToPython_QHelpSearchResult(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QHelpSearchResult_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QHelpSearchResult_SignatureStrings[] = {
    "2:PySide6.QtHelp.QHelpSearchResult(self)",
    "1:PySide6.QtHelp.QHelpSearchResult(self,other:PySide6.QtHelp.QHelpSearchResult)",
    "0:PySide6.QtHelp.QHelpSearchResult(self,url:typing.Union[PySide6.QtCore.QUrl, QString],title:QString,snippet:QString)",
    "PySide6.QtHelp.QHelpSearchResult.snippet(self)->QString",
    "PySide6.QtHelp.QHelpSearchResult.title(self)->QString",
    "PySide6.QtHelp.QHelpSearchResult.url(self)->PySide6.QtCore.QUrl",
    nullptr}; // Sentinel
#else
static constexpr size_t QHelpSearchResult_SignatureByteSize = 147;
static constexpr uint8_t QHelpSearchResult_SignatureBytes[147] = {
    0x78, 0xda, 0x33, 0xb2, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0xf1, 0x48,
    0xcd, 0x29, 0xd0, 0x0b, 0x04, 0x91, 0xc1, 0xa9, 0x89, 0x45, 0xc9, 0x19, 0x41, 0xa9, 0xc5, 0xa5,
    0x39, 0x25, 0x1a, 0xc5, 0xa9, 0x39, 0x69, 0x9a, 0x5c, 0x86, 0xc4, 0x29, 0xd4, 0xc9, 0x2f, 0xc9,
    0x48, 0x2d, 0x22, 0xa8, 0x56, 0x93, 0xcb, 0x80, 0x48, 0xf3, 0x4a, 0x8b, 0x72, 0xac, 0x4a, 0x2a,
    0x0b, 0x32, 0xf3, 0xd2, 0xf5, 0x42, 0xf3, 0x32, 0xf3, 0xf3, 0xa2, 0x11, 0xda, 0x9c, 0xf3, 0x8b,
    0x52, 0xf5, 0x02, 0x43, 0x8b, 0x72, 0x74, 0x14, 0x02, 0x83, 0x4b, 0x8a, 0x80, 0x4a, 0x62, 0x75,
    0x4a, 0x32, 0x4b, 0x72, 0x52, 0xad, 0xa0, 0x5c, 0x9d, 0xe2, 0xbc, 0xcc, 0x82, 0x82, 0xd4, 0x12,
    0x18, 0x5f, 0x93, 0x8b, 0x90, 0x9d, 0x7a, 0x50, 0x1d, 0x10, 0x4f, 0xeb, 0xda, 0x41, 0x35, 0x12,
    0xd6, 0x07, 0xb6, 0x97, 0x64, 0x5d, 0x40, 0xcf, 0xc1, 0xf4, 0x60, 0xf1, 0x16, 0x17, 0x00, 0xbd,
    0x8a, 0x94, 0x02
};
#endif

PyTypeObject *init_QHelpSearchResult(PyObject *module)
{
    if (SbkPySide6_QtHelpTypeStructs[SBK_QHelpSearchResult_IDX].type != nullptr)
        return SbkPySide6_QtHelpTypeStructs[SBK_QHelpSearchResult_IDX].type;

    Shiboken::AutoDecRef Sbk_QHelpSearchResult_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QHelpSearchResult_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QHelpSearchResult",
        "QHelpSearchResult*",
        &Sbk_QHelpSearchResult_spec,
        &Shiboken::callCppDestructor< ::QHelpSearchResult >,
        Sbk_QHelpSearchResult_Type_bases.object(),
        0);
    auto *pyType = Sbk_QHelpSearchResult_TypeF(); // references _Sbk_QHelpSearchResult_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QHelpSearchResult_SignatureStrings);
#else
    InitSignatureBytes(pyType, QHelpSearchResult_SignatureBytes, QHelpSearchResult_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QHelpSearchResult_PropertyStrings);
    SbkPySide6_QtHelpTypeStructs[SBK_QHelpSearchResult_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QHelpSearchResult_PythonToCpp_QHelpSearchResult_PTR,
        is_QHelpSearchResult_PythonToCpp_QHelpSearchResult_PTR_Convertible,
        QHelpSearchResult_PTR_CppToPython_QHelpSearchResult);

    Shiboken::Conversions::registerConverterName(converter, "QHelpSearchResult");
    Shiboken::Conversions::registerConverterName(converter, "QHelpSearchResult*");
    Shiboken::Conversions::registerConverterName(converter, "QHelpSearchResult&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QHelpSearchResult).name());

    qRegisterMetaType< ::QHelpSearchResult *>();

    return pyType;
}
