// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qthttpserver_python.h"

// main header
#include "qabstracthttpserver_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QtHttpServer/qhttpserverrequest.h>
#include <QtHttpServer/qhttpserverresponder.h>
#include <QtNetwork/qhttp2configuration.h>
#include <QtNetwork/qlocalserver.h>
#include <QtNetwork/qtcpserver.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QAbstractHttpServer_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QAbstractHttpServer_IDX]);
    SBK_UNUSED(sbkSelf)
    SBK_UNUSED(type)
    SBK_UNUSED(myType)
    Shiboken::Errors::setInstantiateAbstractClassDisabledWrapper("QAbstractHttpServer");
    return -1;
}

static PyObject *Sbk_QAbstractHttpServerFunc_bind(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractHttpServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QAbstractHttpServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractHttpServer::bind(QLocalServer*)->bool
    // 1: QAbstractHttpServer::bind(QTcpServer*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QTcpServer_IDX]), (pyArg)))) {
        overloadId = 1; // bind(QTcpServer*)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QLocalServer_IDX]), (pyArg)))) {
        overloadId = 0; // bind(QLocalServer*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "bind", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QAbstractHttpServer_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // bind(QLocalServer *server)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QLocalServer *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // bind(QLocalServer*)
                bool cppResult = cppSelf->bind(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // bind(QTcpServer *server)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QTcpServer *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // bind(QTcpServer*)
                bool cppResult = cppSelf->bind(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractHttpServerFunc_http2Configuration(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractHttpServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QAbstractHttpServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // http2Configuration()const
        QHttp2Configuration cppResult = const_cast<const ::QAbstractHttpServer *>(cppSelf)->http2Configuration();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractHttpServerFunc_localServers(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractHttpServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QAbstractHttpServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // localServers()const
        QList<QLocalServer*> cppResult = const_cast<const ::QAbstractHttpServer *>(cppSelf)->localServers();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtHttpServerTypeConverters[SBK_QtHttpServer_QList_QLocalServerPTR_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractHttpServerFunc_serverPorts(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractHttpServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QAbstractHttpServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // serverPorts()const
        QList<quint16> cppResult = const_cast<const ::QAbstractHttpServer *>(cppSelf)->serverPorts();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtHttpServerTypeConverters[SBK_QtHttpServer_QList_quint16_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractHttpServerFunc_servers(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractHttpServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QAbstractHttpServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // servers()const
        QList<QTcpServer*> cppResult = const_cast<const ::QAbstractHttpServer *>(cppSelf)->servers();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtHttpServerTypeConverters[SBK_QtHttpServer_QList_QTcpServerPTR_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractHttpServerFunc_setHttp2Configuration(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractHttpServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QAbstractHttpServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractHttpServer::setHttp2Configuration(QHttp2Configuration)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]), (pyArg)))) {
        overloadId = 0; // setHttp2Configuration(QHttp2Configuration)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHttp2Configuration", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QAbstractHttpServer_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QHttp2Configuration cppArg0_local;
        ::QHttp2Configuration *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setHttp2Configuration(QHttp2Configuration)
            cppSelf->setHttp2Configuration(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QAbstractHttpServer_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QAbstractHttpServer_methods[] = {
    {"bind", reinterpret_cast<PyCFunction>(Sbk_QAbstractHttpServerFunc_bind), METH_O, nullptr},
    {"http2Configuration", reinterpret_cast<PyCFunction>(Sbk_QAbstractHttpServerFunc_http2Configuration), METH_NOARGS, nullptr},
    {"localServers", reinterpret_cast<PyCFunction>(Sbk_QAbstractHttpServerFunc_localServers), METH_NOARGS, nullptr},
    {"serverPorts", reinterpret_cast<PyCFunction>(Sbk_QAbstractHttpServerFunc_serverPorts), METH_NOARGS, nullptr},
    {"servers", reinterpret_cast<PyCFunction>(Sbk_QAbstractHttpServerFunc_servers), METH_NOARGS, nullptr},
    {"setHttp2Configuration", reinterpret_cast<PyCFunction>(Sbk_QAbstractHttpServerFunc_setHttp2Configuration), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QAbstractHttpServer_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QAbstractHttpServer_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QAbstractHttpServer_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QAbstractHttpServer_Type = nullptr;
static PyTypeObject *Sbk_QAbstractHttpServer_TypeF(void)
{
    return _Sbk_QAbstractHttpServer_Type;
}

static PyType_Slot Sbk_QAbstractHttpServer_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QAbstractHttpServer_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QAbstractHttpServer_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QAbstractHttpServer_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QAbstractHttpServer_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QAbstractHttpServer_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QAbstractHttpServer_spec = {
    "2:PySide6.QtHttpServer.QAbstractHttpServer",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QAbstractHttpServer_slots
};

} //extern "C"

static void *Sbk_QAbstractHttpServer_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QAbstractHttpServer *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAbstractHttpServer_PythonToCpp_QAbstractHttpServer_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QAbstractHttpServer_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAbstractHttpServer_PythonToCpp_QAbstractHttpServer_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QAbstractHttpServer_TypeF()))
        return QAbstractHttpServer_PythonToCpp_QAbstractHttpServer_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAbstractHttpServer_PTR_CppToPython_QAbstractHttpServer(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QAbstractHttpServer *>(const_cast<void *>(cppIn)), Sbk_QAbstractHttpServer_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QAbstractHttpServer_SignatureStrings[] = {
    "PySide6.QtHttpServer.QAbstractHttpServer(self,parent:PySide6.QtCore.QObject=nullptr)",
    "1:PySide6.QtHttpServer.QAbstractHttpServer.bind(self,server:PySide6.QtNetwork.QLocalServer)->bool",
    "0:PySide6.QtHttpServer.QAbstractHttpServer.bind(self,server:PySide6.QtNetwork.QTcpServer)->bool",
    "PySide6.QtHttpServer.QAbstractHttpServer.http2Configuration(self)->PySide6.QtNetwork.QHttp2Configuration",
    "PySide6.QtHttpServer.QAbstractHttpServer.localServers(self)->QList[PySide6.QtNetwork.QLocalServer]",
    "PySide6.QtHttpServer.QAbstractHttpServer.serverPorts(self)->QList[quint16]",
    "PySide6.QtHttpServer.QAbstractHttpServer.servers(self)->QList[PySide6.QtNetwork.QTcpServer]",
    "PySide6.QtHttpServer.QAbstractHttpServer.setHttp2Configuration(self,configuration:PySide6.QtNetwork.QHttp2Configuration)",
    nullptr}; // Sentinel
#else
static constexpr size_t QAbstractHttpServer_SignatureByteSize = 210;
static constexpr uint8_t QAbstractHttpServer_SignatureBytes[210] = {
    0x78, 0xda, 0xad, 0x91, 0x3d, 0x0b, 0xc2, 0x30, 0x10, 0x86, 0xf7, 0xfe, 0x12, 0x0b, 0x1a, 0xd4,
    0xa1, 0x83, 0xa0, 0x20, 0x5d, 0x3a, 0x14, 0x6d, 0xa8, 0x9b, 0x38, 0xb4, 0x31, 0xd5, 0x68, 0x48,
    0xe2, 0xe5, 0xaa, 0xf8, 0xef, 0x2d, 0x2d, 0x6a, 0xfc, 0x40, 0x2b, 0xb8, 0x85, 0x97, 0xbb, 0xe7,
    0x09, 0xef, 0x25, 0xe7, 0x54, 0xac, 0x79, 0x40, 0x28, 0x46, 0x88, 0x26, 0xe5, 0x70, 0xe4, 0x40,
    0xe8, 0x34, 0xb7, 0x08, 0x19, 0x73, 0xb2, 0x8e, 0xe5, 0xb2, 0xe8, 0x9a, 0x0c, 0xb8, 0xc2, 0x51,
    0x72, 0x5b, 0x0a, 0x35, 0x70, 0x42, 0xe7, 0xf9, 0x8e, 0x33, 0x1c, 0xab, 0x52, 0x4a, 0x83, 0xe0,
    0x7b, 0x03, 0x67, 0xe2, 0x33, 0x96, 0xe4, 0x42, 0xad, 0x1b, 0xb6, 0xad, 0x03, 0x67, 0x73, 0xc6,
    0xf1, 0xa4, 0x61, 0x4f, 0x68, 0xac, 0x59, 0x26, 0x9b, 0x79, 0xbf, 0x37, 0xc9, 0xb5, 0x96, 0x5e,
    0xff, 0xbf, 0x86, 0x05, 0x33, 0x8f, 0xfc, 0xd6, 0xf4, 0x6d, 0xf5, 0x1c, 0x86, 0x5a, 0x15, 0x62,
    0x53, 0x42, 0x86, 0x42, 0xab, 0xda, 0x55, 0x71, 0xde, 0x68, 0xa2, 0x97, 0xe1, 0xf6, 0x22, 0x79,
    0x2f, 0xc1, 0x5e, 0x15, 0x34, 0x16, 0x16, 0x97, 0x9f, 0x1b, 0x5b, 0xb5, 0x57, 0x34, 0xfd, 0x24,
    0x1a, 0xf0, 0xc9, 0x70, 0x28, 0x85, 0xc2, 0x41, 0xf0, 0x33, 0xea, 0xfb, 0x47, 0x6f, 0xc5, 0xff,
    0xc4, 0xc6, 0xe8, 0x7d, 0xeb, 0x5d, 0xe6, 0x46, 0xa3, 0x56, 0x17, 0xf0, 0xbd, 0x0b, 0x6e, 0x5b,
    0x1e, 0x98
};
#endif

PyTypeObject *init_QAbstractHttpServer(PyObject *module)
{
    if (SbkPySide6_QtHttpServerTypeStructs[SBK_QAbstractHttpServer_IDX].type != nullptr)
        return SbkPySide6_QtHttpServerTypeStructs[SBK_QAbstractHttpServer_IDX].type;

    Shiboken::AutoDecRef Sbk_QAbstractHttpServer_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QAbstractHttpServer_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QAbstractHttpServer",
        "QAbstractHttpServer*",
        &Sbk_QAbstractHttpServer_spec,
        &Shiboken::callCppDestructor< ::QAbstractHttpServer >,
        Sbk_QAbstractHttpServer_Type_bases.object(),
        0);
    auto *pyType = Sbk_QAbstractHttpServer_TypeF(); // references _Sbk_QAbstractHttpServer_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QAbstractHttpServer_SignatureStrings);
#else
    InitSignatureBytes(pyType, QAbstractHttpServer_SignatureBytes, QAbstractHttpServer_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QAbstractHttpServer_PropertyStrings);
    SbkPySide6_QtHttpServerTypeStructs[SBK_QAbstractHttpServer_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAbstractHttpServer_PythonToCpp_QAbstractHttpServer_PTR,
        is_QAbstractHttpServer_PythonToCpp_QAbstractHttpServer_PTR_Convertible,
        QAbstractHttpServer_PTR_CppToPython_QAbstractHttpServer);

    Shiboken::Conversions::registerConverterName(converter, "QAbstractHttpServer");
    Shiboken::Conversions::registerConverterName(converter, "QAbstractHttpServer*");
    Shiboken::Conversions::registerConverterName(converter, "QAbstractHttpServer&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QAbstractHttpServer).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QAbstractHttpServer_TypeF(), &Sbk_QAbstractHttpServer_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QAbstractHttpServer::staticMetaObject, sizeof(::QAbstractHttpServer));

    return pyType;
}
