// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qthttpserver_python.h"

// main header
#include "qfuturehttpserverresponse_wrapper.h"

// Argument includes
#include <QString>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QFutureHttpServerResponse_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QFutureHttpServerResponse >()))
        return -1;

    ::QFutureHttpServerResponse *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QFutureHttpServerResponse", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QFutureHttpServerResponse::QFutureHttpServerResponse()
    // 1: QFutureHttpServerResponse::QFutureHttpServerResponse(QFutureHttpServerResponse)
    if (numArgs == 0) {
        overloadId = 0; // QFutureHttpServerResponse()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QFutureHttpServerResponse_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QFutureHttpServerResponse(QFutureHttpServerResponse)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QFutureHttpServerResponse_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtHttpServerTypeStructs[SBK_QFutureHttpServerResponse_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QFutureHttpServerResponse()
        {

            // QFutureHttpServerResponse()
            cptr = new ::QFutureHttpServerResponse();
            break;
        }
        case 1: // QFutureHttpServerResponse(const QFutureHttpServerResponse &QFutureHttpServerResponse)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QFutureHttpServerResponse cppArg0_local;
            ::QFutureHttpServerResponse *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QFutureHttpServerResponse(QFutureHttpServerResponse)
                cptr = new ::QFutureHttpServerResponse(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QFutureHttpServerResponse >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QFutureHttpServerResponse_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QFutureHttpServerResponseFunc_cancel(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureHttpServerResponse *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QFutureHttpServerResponse_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cancel()
        cppSelf->cancel();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFutureHttpServerResponseFunc_isCanceled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureHttpServerResponse *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QFutureHttpServerResponse_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isCanceled()const
        bool cppResult = const_cast<const ::QFutureHttpServerResponse *>(cppSelf)->isCanceled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureHttpServerResponseFunc_isFinished(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureHttpServerResponse *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QFutureHttpServerResponse_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isFinished()const
        bool cppResult = const_cast<const ::QFutureHttpServerResponse *>(cppSelf)->isFinished();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureHttpServerResponseFunc_isPaused(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureHttpServerResponse *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QFutureHttpServerResponse_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QFutureHttpServerResponse", "isPaused() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // isPaused()const
        bool cppResult = const_cast<const ::QFutureHttpServerResponse *>(cppSelf)->isPaused();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureHttpServerResponseFunc_isRunning(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureHttpServerResponse *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QFutureHttpServerResponse_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isRunning()const
        bool cppResult = const_cast<const ::QFutureHttpServerResponse *>(cppSelf)->isRunning();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureHttpServerResponseFunc_isStarted(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureHttpServerResponse *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QFutureHttpServerResponse_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isStarted()const
        bool cppResult = const_cast<const ::QFutureHttpServerResponse *>(cppSelf)->isStarted();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureHttpServerResponseFunc_isSuspended(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureHttpServerResponse *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QFutureHttpServerResponse_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isSuspended()const
        bool cppResult = const_cast<const ::QFutureHttpServerResponse *>(cppSelf)->isSuspended();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureHttpServerResponseFunc_isSuspending(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureHttpServerResponse *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QFutureHttpServerResponse_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isSuspending()const
        bool cppResult = const_cast<const ::QFutureHttpServerResponse *>(cppSelf)->isSuspending();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureHttpServerResponseFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureHttpServerResponse *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QFutureHttpServerResponse_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QFutureHttpServerResponse *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureHttpServerResponseFunc_pause(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureHttpServerResponse *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QFutureHttpServerResponse_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QFutureHttpServerResponse", "pause()");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // pause()
        cppSelf->pause();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFutureHttpServerResponseFunc_progressMaximum(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureHttpServerResponse *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QFutureHttpServerResponse_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // progressMaximum()const
        int cppResult = const_cast<const ::QFutureHttpServerResponse *>(cppSelf)->progressMaximum();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureHttpServerResponseFunc_progressMinimum(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureHttpServerResponse *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QFutureHttpServerResponse_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // progressMinimum()const
        int cppResult = const_cast<const ::QFutureHttpServerResponse *>(cppSelf)->progressMinimum();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureHttpServerResponseFunc_progressText(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureHttpServerResponse *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QFutureHttpServerResponse_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // progressText()const
        QString cppResult = const_cast<const ::QFutureHttpServerResponse *>(cppSelf)->progressText();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureHttpServerResponseFunc_progressValue(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureHttpServerResponse *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QFutureHttpServerResponse_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // progressValue()const
        int cppResult = const_cast<const ::QFutureHttpServerResponse *>(cppSelf)->progressValue();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureHttpServerResponseFunc_resultCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureHttpServerResponse *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QFutureHttpServerResponse_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // resultCount()const
        int cppResult = const_cast<const ::QFutureHttpServerResponse *>(cppSelf)->resultCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureHttpServerResponseFunc_resume(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureHttpServerResponse *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QFutureHttpServerResponse_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // resume()
        cppSelf->resume();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFutureHttpServerResponseFunc_setPaused(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureHttpServerResponse *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QFutureHttpServerResponse_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFutureHttpServerResponse::setPaused(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setPaused(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPaused", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QFutureHttpServerResponse_IDX]);

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QFutureHttpServerResponse", "setPaused(bool paused)");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPaused(bool)
            cppSelf->setPaused(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFutureHttpServerResponseFunc_setSuspended(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureHttpServerResponse *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QFutureHttpServerResponse_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFutureHttpServerResponse::setSuspended(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setSuspended(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSuspended", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QFutureHttpServerResponse_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSuspended(bool)
            cppSelf->setSuspended(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFutureHttpServerResponseFunc_suspend(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureHttpServerResponse *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QFutureHttpServerResponse_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // suspend()
        cppSelf->suspend();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFutureHttpServerResponseFunc_togglePaused(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureHttpServerResponse *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QFutureHttpServerResponse_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QFutureHttpServerResponse", "togglePaused()");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // togglePaused()
        cppSelf->togglePaused();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFutureHttpServerResponseFunc_toggleSuspended(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureHttpServerResponse *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QFutureHttpServerResponse_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toggleSuspended()
        cppSelf->toggleSuspended();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFutureHttpServerResponseFunc_waitForFinished(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureHttpServerResponse *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QFutureHttpServerResponse_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // waitForFinished()
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        cppSelf->waitForFinished();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFutureHttpServerResponse__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QFutureHttpServerResponse *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QFutureHttpServerResponse_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QFutureHttpServerResponse_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QFutureHttpServerResponse_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QFutureHttpServerResponse_methods[] = {
    {"cancel", reinterpret_cast<PyCFunction>(Sbk_QFutureHttpServerResponseFunc_cancel), METH_NOARGS, nullptr},
    {"isCanceled", reinterpret_cast<PyCFunction>(Sbk_QFutureHttpServerResponseFunc_isCanceled), METH_NOARGS, nullptr},
    {"isFinished", reinterpret_cast<PyCFunction>(Sbk_QFutureHttpServerResponseFunc_isFinished), METH_NOARGS, nullptr},
    {"isPaused", reinterpret_cast<PyCFunction>(Sbk_QFutureHttpServerResponseFunc_isPaused), METH_NOARGS, nullptr},
    {"isRunning", reinterpret_cast<PyCFunction>(Sbk_QFutureHttpServerResponseFunc_isRunning), METH_NOARGS, nullptr},
    {"isStarted", reinterpret_cast<PyCFunction>(Sbk_QFutureHttpServerResponseFunc_isStarted), METH_NOARGS, nullptr},
    {"isSuspended", reinterpret_cast<PyCFunction>(Sbk_QFutureHttpServerResponseFunc_isSuspended), METH_NOARGS, nullptr},
    {"isSuspending", reinterpret_cast<PyCFunction>(Sbk_QFutureHttpServerResponseFunc_isSuspending), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QFutureHttpServerResponseFunc_isValid), METH_NOARGS, nullptr},
    {"pause", reinterpret_cast<PyCFunction>(Sbk_QFutureHttpServerResponseFunc_pause), METH_NOARGS, nullptr},
    {"progressMaximum", reinterpret_cast<PyCFunction>(Sbk_QFutureHttpServerResponseFunc_progressMaximum), METH_NOARGS, nullptr},
    {"progressMinimum", reinterpret_cast<PyCFunction>(Sbk_QFutureHttpServerResponseFunc_progressMinimum), METH_NOARGS, nullptr},
    {"progressText", reinterpret_cast<PyCFunction>(Sbk_QFutureHttpServerResponseFunc_progressText), METH_NOARGS, nullptr},
    {"progressValue", reinterpret_cast<PyCFunction>(Sbk_QFutureHttpServerResponseFunc_progressValue), METH_NOARGS, nullptr},
    {"resultCount", reinterpret_cast<PyCFunction>(Sbk_QFutureHttpServerResponseFunc_resultCount), METH_NOARGS, nullptr},
    {"resume", reinterpret_cast<PyCFunction>(Sbk_QFutureHttpServerResponseFunc_resume), METH_NOARGS, nullptr},
    {"setPaused", reinterpret_cast<PyCFunction>(Sbk_QFutureHttpServerResponseFunc_setPaused), METH_O, nullptr},
    {"setSuspended", reinterpret_cast<PyCFunction>(Sbk_QFutureHttpServerResponseFunc_setSuspended), METH_O, nullptr},
    {"suspend", reinterpret_cast<PyCFunction>(Sbk_QFutureHttpServerResponseFunc_suspend), METH_NOARGS, nullptr},
    {"togglePaused", reinterpret_cast<PyCFunction>(Sbk_QFutureHttpServerResponseFunc_togglePaused), METH_NOARGS, nullptr},
    {"toggleSuspended", reinterpret_cast<PyCFunction>(Sbk_QFutureHttpServerResponseFunc_toggleSuspended), METH_NOARGS, nullptr},
    {"waitForFinished", reinterpret_cast<PyCFunction>(Sbk_QFutureHttpServerResponseFunc_waitForFinished), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QFutureHttpServerResponse__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QFutureHttpServerResponse_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QFutureHttpServerResponse_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QFutureHttpServerResponse_Type = nullptr;
static PyTypeObject *Sbk_QFutureHttpServerResponse_TypeF(void)
{
    return _Sbk_QFutureHttpServerResponse_Type;
}

static PyType_Slot Sbk_QFutureHttpServerResponse_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QFutureHttpServerResponse_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QFutureHttpServerResponse_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QFutureHttpServerResponse_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QFutureHttpServerResponse_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QFutureHttpServerResponse_spec = {
    "2:PySide6.QtHttpServer.QFutureHttpServerResponse",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QFutureHttpServerResponse_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QFutureHttpServerResponse_PythonToCpp_QFutureHttpServerResponse_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QFutureHttpServerResponse_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QFutureHttpServerResponse_PythonToCpp_QFutureHttpServerResponse_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QFutureHttpServerResponse_TypeF()))
        return QFutureHttpServerResponse_PythonToCpp_QFutureHttpServerResponse_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QFutureHttpServerResponse_PTR_CppToPython_QFutureHttpServerResponse(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QFutureHttpServerResponse_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QFutureHttpServerResponse_COPY_CppToPython_QFutureHttpServerResponse(const void *cppIn)
{
    auto *source = reinterpret_cast<const QFutureHttpServerResponse *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QFutureHttpServerResponse_TypeF(), new ::QFutureHttpServerResponse(*source), true, true);
}

// Python to C++ copy conversion.
static void QFutureHttpServerResponse_PythonToCpp_QFutureHttpServerResponse_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<QFutureHttpServerResponse *>(cppOut) = *reinterpret_cast< ::QFutureHttpServerResponse *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QFutureHttpServerResponse_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QFutureHttpServerResponse_PythonToCpp_QFutureHttpServerResponse_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QFutureHttpServerResponse_TypeF()))
        return QFutureHttpServerResponse_PythonToCpp_QFutureHttpServerResponse_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QFutureHttpServerResponse_SignatureStrings[] = {
    "1:PySide6.QtHttpServer.QFutureHttpServerResponse(self)",
    "0:PySide6.QtHttpServer.QFutureHttpServerResponse(self,QFutureHttpServerResponse:PySide6.QtHttpServer.QFutureHttpServerResponse)",
    "PySide6.QtHttpServer.QFutureHttpServerResponse.cancel(self)",
    "PySide6.QtHttpServer.QFutureHttpServerResponse.isCanceled(self)->bool",
    "PySide6.QtHttpServer.QFutureHttpServerResponse.isFinished(self)->bool",
    "PySide6.QtHttpServer.QFutureHttpServerResponse.isPaused(self)->bool",
    "PySide6.QtHttpServer.QFutureHttpServerResponse.isRunning(self)->bool",
    "PySide6.QtHttpServer.QFutureHttpServerResponse.isStarted(self)->bool",
    "PySide6.QtHttpServer.QFutureHttpServerResponse.isSuspended(self)->bool",
    "PySide6.QtHttpServer.QFutureHttpServerResponse.isSuspending(self)->bool",
    "PySide6.QtHttpServer.QFutureHttpServerResponse.isValid(self)->bool",
    "PySide6.QtHttpServer.QFutureHttpServerResponse.pause(self)",
    "PySide6.QtHttpServer.QFutureHttpServerResponse.progressMaximum(self)->int",
    "PySide6.QtHttpServer.QFutureHttpServerResponse.progressMinimum(self)->int",
    "PySide6.QtHttpServer.QFutureHttpServerResponse.progressText(self)->QString",
    "PySide6.QtHttpServer.QFutureHttpServerResponse.progressValue(self)->int",
    "PySide6.QtHttpServer.QFutureHttpServerResponse.resultCount(self)->int",
    "PySide6.QtHttpServer.QFutureHttpServerResponse.resume(self)",
    "PySide6.QtHttpServer.QFutureHttpServerResponse.setPaused(self,paused:bool)",
    "PySide6.QtHttpServer.QFutureHttpServerResponse.setSuspended(self,suspend:bool)",
    "PySide6.QtHttpServer.QFutureHttpServerResponse.suspend(self)",
    "PySide6.QtHttpServer.QFutureHttpServerResponse.togglePaused(self)",
    "PySide6.QtHttpServer.QFutureHttpServerResponse.toggleSuspended(self)",
    "PySide6.QtHttpServer.QFutureHttpServerResponse.waitForFinished(self)",
    "PySide6.QtHttpServer.QFutureHttpServerResponse.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QFutureHttpServerResponse_SignatureByteSize = 274;
static constexpr uint8_t QFutureHttpServerResponse_SignatureBytes[274] = {
    0x78, 0xda, 0xad, 0x94, 0x3f, 0x4f, 0xc3, 0x30, 0x10, 0xc5, 0xf7, 0x7c, 0x12, 0x2a, 0x85, 0x08,
    0x16, 0x86, 0x0e, 0x2c, 0x95, 0x22, 0x16, 0xa4, 0xa6, 0xae, 0x58, 0x23, 0x93, 0x1c, 0xc1, 0x92,
    0x63, 0x5b, 0xbe, 0xbb, 0xd2, 0x7c, 0x7b, 0xdc, 0x86, 0x88, 0x16, 0x89, 0xc1, 0x76, 0x47, 0xff,
    0x79, 0x3f, 0xbd, 0xf3, 0xbd, 0xf3, 0xe3, 0x7a, 0x3b, 0x09, 0xd5, 0xc3, 0x53, 0xd5, 0xd0, 0x0b,
    0x91, 0x13, 0xe0, 0x0f, 0xe0, 0xab, 0xa6, 0x66, 0x62, 0x0f, 0xbf, 0x3b, 0x3b, 0x40, 0x67, 0x0d,
    0xc2, 0x1d, 0x82, 0xfe, 0x58, 0x15, 0x0f, 0x29, 0xb2, 0xf2, 0xdf, 0xe3, 0x48, 0xda, 0xaa, 0x88,
    0xbb, 0x5f, 0x75, 0xd2, 0x74, 0xa0, 0x7f, 0xbc, 0x47, 0x6a, 0x15, 0x6e, 0xce, 0x6a, 0xe8, 0x67,
    0xfd, 0xfd, 0xf3, 0xbb, 0xb5, 0x3a, 0x9e, 0x52, 0x2b, 0xa3, 0xf0, 0x33, 0x97, 0xb2, 0x95, 0x8c,
    0xb9, 0x8c, 0x1d, 0x1b, 0xa3, 0xcc, 0x90, 0x07, 0x11, 0x24, 0x3d, 0xe5, 0x3a, 0x11, 0x8c, 0x0e,
    0x4c, 0x7f, 0x23, 0x4c, 0x76, 0x4d, 0x6f, 0x52, 0xab, 0x2c, 0x2b, 0xee, 0xd4, 0x9d, 0xb4, 0x98,
    0x39, 0x6f, 0x07, 0x0f, 0x88, 0xaf, 0xf2, 0xa8, 0x46, 0x1e, 0x17, 0x17, 0xca, 0x50, 0x32, 0x29,
    0x04, 0xee, 0x36, 0xa4, 0x3d, 0x1c, 0x69, 0xc1, 0x34, 0x82, 0x7c, 0x78, 0xe8, 0x54, 0x54, 0x78,
    0x62, 0x86, 0x0c, 0x4b, 0x81, 0xc1, 0x9a, 0x36, 0x96, 0x0d, 0x65, 0x52, 0xc6, 0xc4, 0x46, 0x21,
    0xd0, 0xc5, 0x10, 0x96, 0xe7, 0x96, 0xf7, 0xeb, 0x53, 0x5a, 0x52, 0x50, 0xd7, 0x13, 0x50, 0xe2,
    0xbc, 0x4c, 0xc4, 0xcd, 0xe2, 0xb4, 0xb2, 0xc8, 0x0e, 0x83, 0x86, 0xcb, 0xef, 0x25, 0x8d, 0xf0,
    0x67, 0xa4, 0x63, 0x21, 0x5f, 0x52, 0x51, 0x6d, 0xfd, 0xf5, 0x67, 0x19, 0x0b, 0x69, 0xdb, 0xce,
    0xba, 0xa9, 0x6d, 0x97, 0x84, 0xd0, 0xe4, 0x42, 0x64, 0x2b, 0x11, 0x56, 0xc5, 0x37, 0x4d, 0xb5,
    0x9f, 0x50
};
#endif

PyTypeObject *init_QFutureHttpServerResponse(PyObject *module)
{
    if (SbkPySide6_QtHttpServerTypeStructs[SBK_QFutureHttpServerResponse_IDX].type != nullptr)
        return SbkPySide6_QtHttpServerTypeStructs[SBK_QFutureHttpServerResponse_IDX].type;

    Shiboken::AutoDecRef Sbk_QFutureHttpServerResponse_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QFutureHttpServerResponse_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QFutureHttpServerResponse",
        "QFutureHttpServerResponse",
        &Sbk_QFutureHttpServerResponse_spec,
        &Shiboken::callCppDestructor< ::QFutureHttpServerResponse >,
        Sbk_QFutureHttpServerResponse_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QFutureHttpServerResponse_TypeF(); // references _Sbk_QFutureHttpServerResponse_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QFutureHttpServerResponse_SignatureStrings);
#else
    InitSignatureBytes(pyType, QFutureHttpServerResponse_SignatureBytes, QFutureHttpServerResponse_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QFutureHttpServerResponse_PropertyStrings);
    SbkPySide6_QtHttpServerTypeStructs[SBK_QFutureHttpServerResponse_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QFutureHttpServerResponse_PythonToCpp_QFutureHttpServerResponse_PTR,
        is_QFutureHttpServerResponse_PythonToCpp_QFutureHttpServerResponse_PTR_Convertible,
        QFutureHttpServerResponse_PTR_CppToPython_QFutureHttpServerResponse,
        QFutureHttpServerResponse_COPY_CppToPython_QFutureHttpServerResponse);

    Shiboken::Conversions::registerConverterName(converter, "QFutureHttpServerResponse");
    Shiboken::Conversions::registerConverterName(converter, "QFutureHttpServerResponse*");
    Shiboken::Conversions::registerConverterName(converter, "QFutureHttpServerResponse&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QFutureHttpServerResponse).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QFutureHttpServerResponse_PythonToCpp_QFutureHttpServerResponse_COPY,
        is_QFutureHttpServerResponse_PythonToCpp_QFutureHttpServerResponse_COPY_Convertible);

    qRegisterMetaType< ::QFutureHttpServerResponse >("QFutureHttpServerResponse");

    return pyType;
}
