// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qthttpserver_python.h"

// main header
#include "qhttpserverrequest_wrapper.h"

// Argument includes
#include <QtHttpServer/qhttpserverrequest.h>
#include <QtNetwork/qhostaddress.h>
#include <QtNetwork/qhttpheaders.h>
#include <QtNetwork/qsslconfiguration.h>
#include <qbytearray.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qurl.h>
#include <qurlquery.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QHttpServerRequestFunc_body(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpServerRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // body()const
        QByteArray cppResult = const_cast<const ::QHttpServerRequest *>(cppSelf)->body();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttpServerRequestFunc_headers(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpServerRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // headers()
        QHttpHeaders cppResult = cppSelf->headers();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttpServerRequestFunc_localAddress(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpServerRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // localAddress()const
        QHostAddress cppResult = const_cast<const ::QHttpServerRequest *>(cppSelf)->localAddress();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttpServerRequestFunc_localPort(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpServerRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // localPort()const
        quint16 cppResult = const_cast<const ::QHttpServerRequest *>(cppSelf)->localPort();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttpServerRequestFunc_method(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpServerRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // method()const
        QHttpServerRequest::Method cppResult = const_cast<const ::QHttpServerRequest *>(cppSelf)->method();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRequest_Method_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttpServerRequestFunc_query(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpServerRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // query()const
        QUrlQuery cppResult = const_cast<const ::QHttpServerRequest *>(cppSelf)->query();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttpServerRequestFunc_remoteAddress(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpServerRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // remoteAddress()const
        QHostAddress cppResult = const_cast<const ::QHttpServerRequest *>(cppSelf)->remoteAddress();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttpServerRequestFunc_remotePort(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpServerRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // remotePort()const
        quint16 cppResult = const_cast<const ::QHttpServerRequest *>(cppSelf)->remotePort();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttpServerRequestFunc_sslConfiguration(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpServerRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sslConfiguration()const
        QSslConfiguration cppResult = const_cast<const ::QHttpServerRequest *>(cppSelf)->sslConfiguration();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslConfiguration_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttpServerRequestFunc_url(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpServerRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // url()const
        QUrl cppResult = const_cast<const ::QHttpServerRequest *>(cppSelf)->url();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttpServerRequestFunc_value(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpServerRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHttpServerRequest::value(QByteArray)const->QByteArray
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // value(QByteArray)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "value", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRequest_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // value(QByteArray)const
            QByteArray cppResult = const_cast<const ::QHttpServerRequest *>(cppSelf)->value(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QHttpServerRequest_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QHttpServerRequest_EnumFlagInfo[] = {
    "Method:Flag:Methods",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QHttpServerRequest_methods[] = {
    {"body", reinterpret_cast<PyCFunction>(Sbk_QHttpServerRequestFunc_body), METH_NOARGS, nullptr},
    {"headers", reinterpret_cast<PyCFunction>(Sbk_QHttpServerRequestFunc_headers), METH_NOARGS, nullptr},
    {"localAddress", reinterpret_cast<PyCFunction>(Sbk_QHttpServerRequestFunc_localAddress), METH_NOARGS, nullptr},
    {"localPort", reinterpret_cast<PyCFunction>(Sbk_QHttpServerRequestFunc_localPort), METH_NOARGS, nullptr},
    {"method", reinterpret_cast<PyCFunction>(Sbk_QHttpServerRequestFunc_method), METH_NOARGS, nullptr},
    {"query", reinterpret_cast<PyCFunction>(Sbk_QHttpServerRequestFunc_query), METH_NOARGS, nullptr},
    {"remoteAddress", reinterpret_cast<PyCFunction>(Sbk_QHttpServerRequestFunc_remoteAddress), METH_NOARGS, nullptr},
    {"remotePort", reinterpret_cast<PyCFunction>(Sbk_QHttpServerRequestFunc_remotePort), METH_NOARGS, nullptr},
    {"sslConfiguration", reinterpret_cast<PyCFunction>(Sbk_QHttpServerRequestFunc_sslConfiguration), METH_NOARGS, nullptr},
    {"url", reinterpret_cast<PyCFunction>(Sbk_QHttpServerRequestFunc_url), METH_NOARGS, nullptr},
    {"value", reinterpret_cast<PyCFunction>(Sbk_QHttpServerRequestFunc_value), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QHttpServerRequest_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QHttpServerRequest_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QHttpServerRequest_Type = nullptr;
static PyTypeObject *Sbk_QHttpServerRequest_TypeF(void)
{
    return _Sbk_QHttpServerRequest_Type;
}

static PyType_Slot Sbk_QHttpServerRequest_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QHttpServerRequest_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QHttpServerRequest_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QHttpServerRequest_methods)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QHttpServerRequest_spec = {
    "2:PySide6.QtHttpServer.QHttpServerRequest",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_GC,
    Sbk_QHttpServerRequest_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QHttpServerRequest_Method(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QHttpServerRequest::Method>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QHttpServerRequest::Method *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QHttpServerRequest_Method_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRequest_Method_IDX])))
        return Enum_PythonToCpp_QHttpServerRequest_Method;
    return {};
}

static PyObject *QHttpServerRequest_Method_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QHttpServerRequest::Method>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QHttpServerRequest::Method *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRequest_Method_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QHttpServerRequest_Method(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QHttpServerRequest::Method>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QHttpServerRequest::Method> *>(cppOut) = value;

}

static PyObject *QHttpServerRequest_Method_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QHttpServerRequest::Method> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRequest_Method_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QHttpServerRequest_PythonToCpp_QHttpServerRequest_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QHttpServerRequest_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QHttpServerRequest_PythonToCpp_QHttpServerRequest_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QHttpServerRequest_TypeF()))
        return QHttpServerRequest_PythonToCpp_QHttpServerRequest_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QHttpServerRequest_PTR_CppToPython_QHttpServerRequest(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QHttpServerRequest_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QHttpServerRequest_SignatureStrings[] = {
    "PySide6.QtHttpServer.QHttpServerRequest.body(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtHttpServer.QHttpServerRequest.headers(self)->PySide6.QtNetwork.QHttpHeaders",
    "PySide6.QtHttpServer.QHttpServerRequest.localAddress(self)->PySide6.QtNetwork.QHostAddress",
    "PySide6.QtHttpServer.QHttpServerRequest.localPort(self)->quint16",
    "PySide6.QtHttpServer.QHttpServerRequest.method(self)->PySide6.QtHttpServer.QHttpServerRequest.Method",
    "PySide6.QtHttpServer.QHttpServerRequest.query(self)->PySide6.QtCore.QUrlQuery",
    "PySide6.QtHttpServer.QHttpServerRequest.remoteAddress(self)->PySide6.QtNetwork.QHostAddress",
    "PySide6.QtHttpServer.QHttpServerRequest.remotePort(self)->quint16",
    "PySide6.QtHttpServer.QHttpServerRequest.sslConfiguration(self)->PySide6.QtNetwork.QSslConfiguration",
    "PySide6.QtHttpServer.QHttpServerRequest.url(self)->PySide6.QtCore.QUrl",
    "PySide6.QtHttpServer.QHttpServerRequest.value(self,key:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtCore.QByteArray",
    nullptr}; // Sentinel
#else
static constexpr size_t QHttpServerRequest_SignatureByteSize = 235;
static constexpr uint8_t QHttpServerRequest_SignatureBytes[235] = {
    0x78, 0xda, 0xb5, 0x93, 0x3f, 0x8b, 0x02, 0x31, 0x10, 0xc5, 0x7b, 0x3f, 0xc5, 0x95, 0x7a, 0x78,
    0x01, 0x1b, 0x8b, 0x2b, 0x04, 0xb5, 0xb1, 0x51, 0x76, 0x5d, 0xac, 0x0e, 0x8b, 0x68, 0x46, 0x37,
    0x18, 0x33, 0x3a, 0x99, 0x78, 0xe4, 0xdb, 0xdf, 0xea, 0xfa, 0x07, 0x14, 0x43, 0x0e, 0xb1, 0x09,
    0x03, 0x79, 0xef, 0x37, 0xc3, 0x1b, 0x26, 0x0b, 0x85, 0x56, 0xd0, 0x15, 0x39, 0x8f, 0x98, 0x77,
    0x05, 0xd0, 0x01, 0x48, 0xe4, 0xb7, 0x7a, 0x0a, 0x7b, 0x0f, 0x8e, 0xc5, 0x02, 0x55, 0x68, 0x3a,
    0x30, 0xab, 0xd6, 0x57, 0x2f, 0xbb, 0x7a, 0x86, 0x48, 0x20, 0xf2, 0x41, 0x60, 0xe8, 0x13, 0xc9,
    0xd0, 0xc8, 0x12, 0x69, 0x25, 0x48, 0x05, 0xe4, 0x1e, 0x81, 0x13, 0xe0, 0x5f, 0xa4, 0x4d, 0xed,
    0x19, 0xd5, 0xaa, 0x64, 0xaa, 0xc1, 0xa5, 0x34, 0x7d, 0xa5, 0x08, 0x5c, 0x14, 0x8d, 0x8e, 0xcf,
    0xaa, 0xff, 0xa1, 0x33, 0x24, 0xbe, 0x70, 0xf7, 0x5e, 0x5b, 0xee, 0x74, 0x93, 0x01, 0x5b, 0xe0,
    0x12, 0xd5, 0xe3, 0x54, 0x71, 0xd7, 0xf8, 0xe4, 0x4a, 0x6e, 0x52, 0xbd, 0xf4, 0x74, 0x4b, 0x33,
    0x32, 0xf9, 0xf1, 0x3f, 0x99, 0x46, 0xb0, 0xc5, 0x6a, 0xb1, 0x6f, 0xc9, 0xb3, 0x66, 0xbf, 0x12,
    0xa8, 0x73, 0x66, 0x88, 0x76, 0xa5, 0xd7, 0x9e, 0x24, 0x6b, 0xb4, 0x91, 0x01, 0x8b, 0x3b, 0x69,
    0x72, 0x0f, 0x4f, 0x26, 0x92, 0x66, 0x32, 0xe6, 0x20, 0x8d, 0x87, 0x13, 0xa8, 0xbd, 0x81, 0xf0,
    0xcd, 0x61, 0xa7, 0xed, 0x5a, 0xcc, 0x6c, 0x35, 0xca, 0xcf, 0xd3, 0x5b, 0x6a, 0x7f, 0x2c, 0x4b,
    0x49, 0x9f, 0xf3, 0xe8, 0xbd, 0xfd, 0x01, 0x45, 0xfc, 0x61, 0xbf
};
#endif

PyTypeObject *init_QHttpServerRequest(PyObject *module)
{
    if (SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRequest_IDX].type != nullptr)
        return SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRequest_IDX].type;

    Shiboken::AutoDecRef Sbk_QHttpServerRequest_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QHttpServerRequest_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QHttpServerRequest",
        "QHttpServerRequest*",
        &Sbk_QHttpServerRequest_spec,
        &Shiboken::callCppDestructor< ::QHttpServerRequest >,
        Sbk_QHttpServerRequest_Type_bases.object(),
        0);
    auto *pyType = Sbk_QHttpServerRequest_TypeF(); // references _Sbk_QHttpServerRequest_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QHttpServerRequest_SignatureStrings);
#else
    InitSignatureBytes(pyType, QHttpServerRequest_SignatureBytes, QHttpServerRequest_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QHttpServerRequest_PropertyStrings);
    SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRequest_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QHttpServerRequest_PythonToCpp_QHttpServerRequest_PTR,
        is_QHttpServerRequest_PythonToCpp_QHttpServerRequest_PTR_Convertible,
        QHttpServerRequest_PTR_CppToPython_QHttpServerRequest);

    Shiboken::Conversions::registerConverterName(converter, "QHttpServerRequest");
    Shiboken::Conversions::registerConverterName(converter, "QHttpServerRequest*");
    Shiboken::Conversions::registerConverterName(converter, "QHttpServerRequest&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QHttpServerRequest).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QHttpServerRequest_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Method'.
    const char *Method_Initializer[] = {
        "Unknown",
        "Get",
        "Put",
        "Delete",
        "Post",
        "Head",
        "Options",
        "Patch",
        "Connect",
        "Trace",
        "AnyKnown",
        nullptr};
    // "int16_t" used instead of "int"
    constexpr int16_t Method_InitializerValues[] = {
        int16_t(QHttpServerRequest::Method::Unknown), //  0x0000  0
        int16_t(QHttpServerRequest::Method::Get),     //  0x0001  1
        int16_t(QHttpServerRequest::Method::Put),     //  0x0002  2
        int16_t(QHttpServerRequest::Method::Delete),  //  0x0004  4
        int16_t(QHttpServerRequest::Method::Post),    //  0x0008  8
        int16_t(QHttpServerRequest::Method::Head),    //  0x0010  16
        int16_t(QHttpServerRequest::Method::Options), //  0x0020  32
        int16_t(QHttpServerRequest::Method::Patch),   //  0x0040  64
        int16_t(QHttpServerRequest::Method::Connect), //  0x0080  128
        int16_t(QHttpServerRequest::Method::Trace),   //  0x0100  256
        int16_t(QHttpServerRequest::Method::AnyKnown) //  0x01ff  511
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QHttpServerRequest_TypeF(),
        "2:PySide6.QtHttpServer.QHttpServerRequest.Method",
        Method_Initializer, Method_InitializerValues);
    SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRequest_Method_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtHttpServerTypeStructs[SBK_QFlags_QHttpServerRequest_Method_IDX].type =
        EType;
    // Register converter for enum 'QHttpServerRequest::Method'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QHttpServerRequest_Method_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QHttpServerRequest_Method,
            is_Enum_PythonToCpp_QHttpServerRequest_Method_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QHttpServerRequest::Method");
        Shiboken::Conversions::registerConverterAlias(converter, "Method");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QHttpServerRequest_Method_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QHttpServerRequest_Method,
            is_Enum_PythonToCpp_QHttpServerRequest_Method_Convertible);
        // Register converter for flag 'QFlags<QHttpServerRequest::Method>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QHttpServerRequest::Method>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QHttpServerRequest::Methods");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'Method' enum/flags.

    qRegisterMetaType< ::QHttpServerRequest *>();
    qRegisterMetaType< ::QHttpServerRequest::Method >("QHttpServerRequest::Method");

    return pyType;
}
