// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qthttpserver_python.h"

// main header
#include "qhttpserverresponder_wrapper.h"

// Argument includes
#include <QList>
#include <QtHttpServer/qhttpserverresponder.h>
#include <QtHttpServer/qhttpserverresponse.h>
#include <QtNetwork/qhttpheaders.h>
#include <qbytearray.h>
#include <qiodevice.h>
#include <qjsondocument.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QHttpServerResponderFunc_sendResponse(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpServerResponder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHttpServerResponder::sendResponse(QHttpServerResponse)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponse_IDX]), (pyArg)))) {
        overloadId = 0; // sendResponse(QHttpServerResponse)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "sendResponse", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QHttpServerResponse *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // sendResponse(QHttpServerResponse)
            cppSelf->sendResponse(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHttpServerResponderFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpServerResponder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHttpServerResponder::swap(QHttpServerResponder&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QHttpServerResponder&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QHttpServerResponder *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QHttpServerResponder&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHttpServerResponderFunc_write(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpServerResponder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "write", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:write", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QHttpServerResponder::write(QHttpServerResponder::StatusCode=)
    // 1: QHttpServerResponder::write(QIODevice*,QByteArray,QHttpServerResponder::StatusCode=)
    // 2: QHttpServerResponder::write(QIODevice*,QHttpHeaders,QHttpServerResponder::StatusCode=)
    // 3: QHttpServerResponder::write(QByteArray,QByteArray,QHttpServerResponder::StatusCode=)
    // 4: QHttpServerResponder::write(QByteArray,QHttpHeaders,QHttpServerResponder::StatusCode=)
    // 5: QHttpServerResponder::write(QHttpHeaders,QHttpServerResponder::StatusCode=)
    // 6: QHttpServerResponder::write(QJsonDocument,QHttpServerResponder::StatusCode=)
    // 7: QHttpServerResponder::write(QJsonDocument,QHttpHeaders,QHttpServerResponder::StatusCode=)
    if (numArgs == 0) {
        overloadId = 0; // write(QHttpServerResponder::StatusCode)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 6; // write(QJsonDocument,QHttpServerResponder::StatusCode)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 7; // write(QJsonDocument,QHttpHeaders,QHttpServerResponder::StatusCode)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))->converter, (pyArgs[2])))) {
                overloadId = 7; // write(QJsonDocument,QHttpHeaders,QHttpServerResponder::StatusCode)
            }
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 6; // write(QJsonDocument,QHttpServerResponder::StatusCode)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 5; // write(QHttpHeaders,QHttpServerResponder::StatusCode)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 5; // write(QHttpHeaders,QHttpServerResponder::StatusCode)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 4; // write(QByteArray,QHttpHeaders,QHttpServerResponder::StatusCode)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))->converter, (pyArgs[2])))) {
                overloadId = 4; // write(QByteArray,QHttpHeaders,QHttpServerResponder::StatusCode)
            }
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 3; // write(QByteArray,QByteArray,QHttpServerResponder::StatusCode)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))->converter, (pyArgs[2])))) {
                overloadId = 3; // write(QByteArray,QByteArray,QHttpServerResponder::StatusCode)
            }
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), (pyArgs[0])))) {
        if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 2; // write(QIODevice*,QHttpHeaders,QHttpServerResponder::StatusCode)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))->converter, (pyArgs[2])))) {
                overloadId = 2; // write(QIODevice*,QHttpHeaders,QHttpServerResponder::StatusCode)
            }
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 1; // write(QIODevice*,QByteArray,QHttpServerResponder::StatusCode)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))->converter, (pyArgs[2])))) {
                overloadId = 1; // write(QIODevice*,QByteArray,QHttpServerResponder::StatusCode)
            }
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // write(QHttpServerResponder::StatusCode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "write", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // write(QHttpServerResponder::StatusCode status)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_status = Shiboken::String::createStaticString("status");
                if (PyDict_Contains(kwds, key_status) != 0) {
                    value = PyDict_GetItem(kwds, key_status);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_status);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "write", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))->converter, (pyArgs[0]))))
                            return Shiboken::returnWrongArguments(args, "write", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_status);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "write", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]);
                }
            }
            ::QHttpServerResponder::StatusCode cppArg0(QHttpServerResponder::StatusCode::Ok);
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // write(QHttpServerResponder::StatusCode)
                cppSelf->write(cppArg0);
            }
            break;
        }
        case 1: // write(QIODevice *data, const QByteArray &mimeType, QHttpServerResponder::StatusCode status)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_status = Shiboken::String::createStaticString("status");
                if (PyDict_Contains(kwds, key_status) != 0) {
                    value = PyDict_GetItem(kwds, key_status);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_status);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "write", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))->converter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "write", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_status);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "write", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QIODevice *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QByteArray cppArg1_local;
            ::QByteArray *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            ::QHttpServerResponder::StatusCode cppArg2(QHttpServerResponder::StatusCode::Ok);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // write(QIODevice*,QByteArray,QHttpServerResponder::StatusCode)
                cppSelf->write(cppArg0, *cppArg1, cppArg2);
            }
            break;
        }
        case 2: // write(QIODevice *data, const QHttpHeaders &headers, QHttpServerResponder::StatusCode status)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_status = Shiboken::String::createStaticString("status");
                if (PyDict_Contains(kwds, key_status) != 0) {
                    value = PyDict_GetItem(kwds, key_status);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_status);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "write", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))->converter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "write", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_status);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "write", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QIODevice *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QHttpHeaders cppArg1_local;
            ::QHttpHeaders *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            ::QHttpServerResponder::StatusCode cppArg2(QHttpServerResponder::StatusCode::Ok);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // write(QIODevice*,QHttpHeaders,QHttpServerResponder::StatusCode)
                cppSelf->write(cppArg0, *cppArg1, cppArg2);
            }
            break;
        }
        case 3: // write(const QByteArray &data, const QByteArray &mimeType, QHttpServerResponder::StatusCode status)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_status = Shiboken::String::createStaticString("status");
                if (PyDict_Contains(kwds, key_status) != 0) {
                    value = PyDict_GetItem(kwds, key_status);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_status);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "write", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))->converter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "write", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_status);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "write", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QByteArray cppArg1_local;
            ::QByteArray *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            ::QHttpServerResponder::StatusCode cppArg2(QHttpServerResponder::StatusCode::Ok);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // write(QByteArray,QByteArray,QHttpServerResponder::StatusCode)
                cppSelf->write(*cppArg0, *cppArg1, cppArg2);
            }
            break;
        }
        case 4: // write(const QByteArray &data, const QHttpHeaders &headers, QHttpServerResponder::StatusCode status)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_status = Shiboken::String::createStaticString("status");
                if (PyDict_Contains(kwds, key_status) != 0) {
                    value = PyDict_GetItem(kwds, key_status);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_status);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "write", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))->converter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "write", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_status);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "write", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QHttpHeaders cppArg1_local;
            ::QHttpHeaders *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            ::QHttpServerResponder::StatusCode cppArg2(QHttpServerResponder::StatusCode::Ok);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // write(QByteArray,QHttpHeaders,QHttpServerResponder::StatusCode)
                cppSelf->write(*cppArg0, *cppArg1, cppArg2);
            }
            break;
        }
        case 5: // write(const QHttpHeaders &headers, QHttpServerResponder::StatusCode status)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_status = Shiboken::String::createStaticString("status");
                if (PyDict_Contains(kwds, key_status) != 0) {
                    value = PyDict_GetItem(kwds, key_status);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_status);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "write", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "write", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_status);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "write", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QHttpHeaders cppArg0_local;
            ::QHttpHeaders *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QHttpServerResponder::StatusCode cppArg1(QHttpServerResponder::StatusCode::Ok);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // write(QHttpHeaders,QHttpServerResponder::StatusCode)
                cppSelf->write(*cppArg0, cppArg1);
            }
            break;
        }
        case 6: // write(const QJsonDocument &document, QHttpServerResponder::StatusCode status)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_status = Shiboken::String::createStaticString("status");
                if (PyDict_Contains(kwds, key_status) != 0) {
                    value = PyDict_GetItem(kwds, key_status);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_status);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "write", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "write", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_status);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "write", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QJsonDocument cppArg0_local;
            ::QJsonDocument *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QHttpServerResponder::StatusCode cppArg1(QHttpServerResponder::StatusCode::Ok);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // write(QJsonDocument,QHttpServerResponder::StatusCode)
                cppSelf->write(*cppArg0, cppArg1);
            }
            break;
        }
        case 7: // write(const QJsonDocument &document, const QHttpHeaders &headers, QHttpServerResponder::StatusCode status)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_status = Shiboken::String::createStaticString("status");
                if (PyDict_Contains(kwds, key_status) != 0) {
                    value = PyDict_GetItem(kwds, key_status);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_status);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "write", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))->converter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "write", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_status);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "write", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QJsonDocument cppArg0_local;
            ::QJsonDocument *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QHttpHeaders cppArg1_local;
            ::QHttpHeaders *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            ::QHttpServerResponder::StatusCode cppArg2(QHttpServerResponder::StatusCode::Ok);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // write(QJsonDocument,QHttpHeaders,QHttpServerResponder::StatusCode)
                cppSelf->write(*cppArg0, *cppArg1, cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHttpServerResponderFunc_writeBeginChunked(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpServerResponder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "writeBeginChunked", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:writeBeginChunked", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QHttpServerResponder::writeBeginChunked(QByteArray,QHttpServerResponder::StatusCode=)
    // 1: QHttpServerResponder::writeBeginChunked(QHttpHeaders,QHttpServerResponder::StatusCode=)
    // 2: QHttpServerResponder::writeBeginChunked(QHttpHeaders,QList<QHttpHeaders::WellKnownHeader>,QHttpServerResponder::StatusCode=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // writeBeginChunked(QHttpHeaders,QHttpServerResponder::StatusCode)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtHttpServerTypeConverters[SBK_QtHttpServer_QList_QHttpHeaders_WellKnownHeader_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 2; // writeBeginChunked(QHttpHeaders,QList<QHttpHeaders::WellKnownHeader>,QHttpServerResponder::StatusCode)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))->converter, (pyArgs[2])))) {
                overloadId = 2; // writeBeginChunked(QHttpHeaders,QList<QHttpHeaders::WellKnownHeader>,QHttpServerResponder::StatusCode)
            }
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 1; // writeBeginChunked(QHttpHeaders,QHttpServerResponder::StatusCode)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // writeBeginChunked(QByteArray,QHttpServerResponder::StatusCode)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // writeBeginChunked(QByteArray,QHttpServerResponder::StatusCode)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "writeBeginChunked", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // writeBeginChunked(const QByteArray &mimeType, QHttpServerResponder::StatusCode status)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_status = Shiboken::String::createStaticString("status");
                if (PyDict_Contains(kwds, key_status) != 0) {
                    value = PyDict_GetItem(kwds, key_status);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_status);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "writeBeginChunked", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "writeBeginChunked", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_status);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "writeBeginChunked", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QHttpServerResponder::StatusCode cppArg1(QHttpServerResponder::StatusCode::Ok);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // writeBeginChunked(QByteArray,QHttpServerResponder::StatusCode)
                cppSelf->writeBeginChunked(*cppArg0, cppArg1);
            }
            break;
        }
        case 1: // writeBeginChunked(const QHttpHeaders &headers, QHttpServerResponder::StatusCode status)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_status = Shiboken::String::createStaticString("status");
                if (PyDict_Contains(kwds, key_status) != 0) {
                    value = PyDict_GetItem(kwds, key_status);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_status);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "writeBeginChunked", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "writeBeginChunked", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_status);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "writeBeginChunked", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QHttpHeaders cppArg0_local;
            ::QHttpHeaders *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QHttpServerResponder::StatusCode cppArg1(QHttpServerResponder::StatusCode::Ok);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // writeBeginChunked(QHttpHeaders,QHttpServerResponder::StatusCode)
                cppSelf->writeBeginChunked(*cppArg0, cppArg1);
            }
            break;
        }
        case 2: // writeBeginChunked(const QHttpHeaders &headers, QList<QHttpHeaders::WellKnownHeader> trailerNames, QHttpServerResponder::StatusCode status)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_status = Shiboken::String::createStaticString("status");
                if (PyDict_Contains(kwds, key_status) != 0) {
                    value = PyDict_GetItem(kwds, key_status);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_status);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "writeBeginChunked", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))->converter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "writeBeginChunked", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_status);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "writeBeginChunked", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QHttpHeaders cppArg0_local;
            ::QHttpHeaders *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QList<QHttpHeaders::WellKnownHeader> cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QHttpServerResponder::StatusCode cppArg2(QHttpServerResponder::StatusCode::Ok);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // writeBeginChunked(QHttpHeaders,QList<QHttpHeaders::WellKnownHeader>,QHttpServerResponder::StatusCode)
                cppSelf->writeBeginChunked(*cppArg0, cppArg1, cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHttpServerResponderFunc_writeChunk(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpServerResponder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHttpServerResponder::writeChunk(QByteArray)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // writeChunk(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "writeChunk", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // writeChunk(QByteArray)
            cppSelf->writeChunk(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHttpServerResponderFunc_writeEndChunked(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpServerResponder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "writeEndChunked", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QHttpServerResponder::writeEndChunked(QByteArray)
    // 1: QHttpServerResponder::writeEndChunked(QByteArray,QHttpHeaders)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // writeEndChunked(QByteArray)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_IDX]), (pyArgs[1])))) {
            overloadId = 1; // writeEndChunked(QByteArray,QHttpHeaders)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "writeEndChunked", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // writeEndChunked(const QByteArray &data)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // writeEndChunked(QByteArray)
                cppSelf->writeEndChunked(*cppArg0);
            }
            break;
        }
        case 1: // writeEndChunked(const QByteArray &data, const QHttpHeaders &trailers)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QHttpHeaders cppArg1_local;
            ::QHttpHeaders *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // writeEndChunked(QByteArray,QHttpHeaders)
                cppSelf->writeEndChunked(*cppArg0, *cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QHttpServerResponder_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QHttpServerResponder_EnumFlagInfo[] = {
    "StatusCode:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QHttpServerResponder_methods[] = {
    {"sendResponse", reinterpret_cast<PyCFunction>(Sbk_QHttpServerResponderFunc_sendResponse), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QHttpServerResponderFunc_swap), METH_O, nullptr},
    {"write", reinterpret_cast<PyCFunction>(Sbk_QHttpServerResponderFunc_write), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"writeBeginChunked", reinterpret_cast<PyCFunction>(Sbk_QHttpServerResponderFunc_writeBeginChunked), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"writeChunk", reinterpret_cast<PyCFunction>(Sbk_QHttpServerResponderFunc_writeChunk), METH_O, nullptr},
    {"writeEndChunked", reinterpret_cast<PyCFunction>(Sbk_QHttpServerResponderFunc_writeEndChunked), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QHttpServerResponder_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QHttpServerResponder_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QHttpServerResponder_Type = nullptr;
static PyTypeObject *Sbk_QHttpServerResponder_TypeF(void)
{
    return _Sbk_QHttpServerResponder_Type;
}

static PyType_Slot Sbk_QHttpServerResponder_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QHttpServerResponder_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QHttpServerResponder_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QHttpServerResponder_methods)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QHttpServerResponder_spec = {
    "2:PySide6.QtHttpServer.QHttpServerResponder",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_GC,
    Sbk_QHttpServerResponder_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QHttpServerResponder_StatusCode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QHttpServerResponder::StatusCode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QHttpServerResponder::StatusCode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QHttpServerResponder_StatusCode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))
        return Enum_PythonToCpp_QHttpServerResponder_StatusCode;
    return {};
}

static PyObject *QHttpServerResponder_StatusCode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QHttpServerResponder::StatusCode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QHttpServerResponder::StatusCode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QHttpServerResponder_PythonToCpp_QHttpServerResponder_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QHttpServerResponder_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QHttpServerResponder_PythonToCpp_QHttpServerResponder_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QHttpServerResponder_TypeF()))
        return QHttpServerResponder_PythonToCpp_QHttpServerResponder_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QHttpServerResponder_PTR_CppToPython_QHttpServerResponder(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QHttpServerResponder_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QHttpServerResponder_SignatureStrings[] = {
    "PySide6.QtHttpServer.QHttpServerResponder.sendResponse(self,response:PySide6.QtHttpServer.QHttpServerResponse)",
    "PySide6.QtHttpServer.QHttpServerResponder.swap(self,other:PySide6.QtHttpServer.QHttpServerResponder)",
    "7:PySide6.QtHttpServer.QHttpServerResponder.write(self,status:PySide6.QtHttpServer.QHttpServerResponder.StatusCode=QHttpServerResponder.StatusCode.Ok)",
    "6:PySide6.QtHttpServer.QHttpServerResponder.write(self,data:PySide6.QtCore.QIODevice,mimeType:typing.Union[PySide6.QtCore.QByteArray, char*],status:PySide6.QtHttpServer.QHttpServerResponder.StatusCode=QHttpServerResponder.StatusCode.Ok)",
    "5:PySide6.QtHttpServer.QHttpServerResponder.write(self,data:PySide6.QtCore.QIODevice,headers:PySide6.QtNetwork.QHttpHeaders,status:PySide6.QtHttpServer.QHttpServerResponder.StatusCode=QHttpServerResponder.StatusCode.Ok)",
    "4:PySide6.QtHttpServer.QHttpServerResponder.write(self,data:typing.Union[PySide6.QtCore.QByteArray, char*],mimeType:typing.Union[PySide6.QtCore.QByteArray, char*],status:PySide6.QtHttpServer.QHttpServerResponder.StatusCode=QHttpServerResponder.StatusCode.Ok)",
    "3:PySide6.QtHttpServer.QHttpServerResponder.write(self,data:typing.Union[PySide6.QtCore.QByteArray, char*],headers:PySide6.QtNetwork.QHttpHeaders,status:PySide6.QtHttpServer.QHttpServerResponder.StatusCode=QHttpServerResponder.StatusCode.Ok)",
    "2:PySide6.QtHttpServer.QHttpServerResponder.write(self,headers:PySide6.QtNetwork.QHttpHeaders,status:PySide6.QtHttpServer.QHttpServerResponder.StatusCode=QHttpServerResponder.StatusCode.Ok)",
    "1:PySide6.QtHttpServer.QHttpServerResponder.write(self,document:PySide6.QtCore.QJsonDocument,status:PySide6.QtHttpServer.QHttpServerResponder.StatusCode=QHttpServerResponder.StatusCode.Ok)",
    "0:PySide6.QtHttpServer.QHttpServerResponder.write(self,document:PySide6.QtCore.QJsonDocument,headers:PySide6.QtNetwork.QHttpHeaders,status:PySide6.QtHttpServer.QHttpServerResponder.StatusCode=QHttpServerResponder.StatusCode.Ok)",
    "2:PySide6.QtHttpServer.QHttpServerResponder.writeBeginChunked(self,mimeType:typing.Union[PySide6.QtCore.QByteArray, char*],status:PySide6.QtHttpServer.QHttpServerResponder.StatusCode=QHttpServerResponder.StatusCode.Ok)",
    "1:PySide6.QtHttpServer.QHttpServerResponder.writeBeginChunked(self,headers:PySide6.QtNetwork.QHttpHeaders,status:PySide6.QtHttpServer.QHttpServerResponder.StatusCode=QHttpServerResponder.StatusCode.Ok)",
    "0:PySide6.QtHttpServer.QHttpServerResponder.writeBeginChunked(self,headers:PySide6.QtNetwork.QHttpHeaders,trailerNames:QList[PySide6.QtNetwork.QHttpHeaders.WellKnownHeader],status:PySide6.QtHttpServer.QHttpServerResponder.StatusCode=QHttpServerResponder.StatusCode.Ok)",
    "PySide6.QtHttpServer.QHttpServerResponder.writeChunk(self,data:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "1:PySide6.QtHttpServer.QHttpServerResponder.writeEndChunked(self,data:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "0:PySide6.QtHttpServer.QHttpServerResponder.writeEndChunked(self,data:typing.Union[PySide6.QtCore.QByteArray, char*],trailers:PySide6.QtNetwork.QHttpHeaders)",
    nullptr}; // Sentinel
#else
static constexpr size_t QHttpServerResponder_SignatureByteSize = 339;
static constexpr uint8_t QHttpServerResponder_SignatureBytes[339] = {
    0x78, 0xda, 0xd5, 0x55, 0x4d, 0x4f, 0x83, 0x40, 0x10, 0xbd, 0xf3, 0x2b, 0x3c, 0x8a, 0x21, 0x1b,
    0xea, 0x47, 0x4d, 0x48, 0x3c, 0x58, 0x6a, 0x52, 0x3f, 0xd2, 0x82, 0x68, 0x3c, 0x34, 0x1e, 0x36,
    0xec, 0x58, 0x36, 0xc0, 0x2e, 0xd9, 0x9d, 0x96, 0xf0, 0xef, 0x6d, 0x0a, 0xc6, 0xaa, 0x89, 0x05,
    0x1a, 0x2a, 0xde, 0xd8, 0x9d, 0x79, 0x3b, 0xef, 0xcd, 0x9b, 0x65, 0xbd, 0x22, 0xe0, 0x0c, 0x86,
    0xc4, 0xc7, 0x09, 0x62, 0x16, 0x80, 0x5a, 0x81, 0x22, 0xfe, 0xe7, 0xf7, 0x23, 0xe8, 0x4c, 0x0a,
    0xb6, 0xde, 0xd4, 0x20, 0x58, 0xb9, 0xd2, 0x70, 0xac, 0x21, 0x79, 0xb3, 0x54, 0xb5, 0x72, 0xbc,
    0x5a, 0x87, 0x68, 0x30, 0x0d, 0xaf, 0x7e, 0xb9, 0x9c, 0x66, 0x65, 0x19, 0x89, 0x11, 0x28, 0xa7,
    0x36, 0xd2, 0x34, 0x2e, 0xeb, 0x27, 0x93, 0x5c, 0x71, 0xac, 0xe4, 0x68, 0xa4, 0xb8, 0xd4, 0x0d,
    0xb0, 0xc1, 0x06, 0xe0, 0x4a, 0x06, 0x57, 0x3b, 0xe2, 0x64, 0x16, 0x9b, 0xc6, 0xb0, 0x1d, 0x2d,
    0x46, 0x91, 0x6e, 0x21, 0x5d, 0xa9, 0x80, 0xf8, 0xb7, 0xb3, 0x31, 0xac, 0x78, 0x08, 0x56, 0xca,
    0x53, 0x78, 0x2a, 0x32, 0x70, 0xb0, 0xc8, 0xb8, 0x58, 0x90, 0x67, 0xc1, 0xa5, 0x98, 0x7f, 0x4f,
    0x1f, 0x15, 0x08, 0xd7, 0x4a, 0xd1, 0xc2, 0x3a, 0x0a, 0x23, 0xaa, 0x4e, 0x5e, 0x3b, 0x17, 0x7b,
    0xd1, 0x85, 0xd8, 0x08, 0xe8, 0x3a, 0x7f, 0x9b, 0xf5, 0x14, 0x30, 0x97, 0x2a, 0x2e, 0xcf, 0x9d,
    0x94, 0xe1, 0xce, 0xb5, 0x9d, 0xef, 0xa1, 0xad, 0xa1, 0x4d, 0x7d, 0xb5, 0xf7, 0xec, 0x70, 0x2d,
    0xe8, 0x89, 0xe9, 0xa7, 0xed, 0x14, 0xf7, 0x84, 0xfd, 0xa0, 0xa5, 0x5f, 0x32, 0x5c, 0xa6, 0x20,
    0xf0, 0xc7, 0x95, 0xbc, 0xd3, 0x52, 0x8c, 0xab, 0x60, 0xe7, 0xe4, 0xed, 0x2e, 0xc9, 0xff, 0xd7,
    0xf1, 0x1a, 0xc1, 0x82, 0x0b, 0x37, 0x5a, 0x8a, 0x18, 0x58, 0xa9, 0xb7, 0xaf, 0xff, 0x8a, 0xc1,
    0xfe, 0xd2, 0x7a, 0x62, 0x92, 0x7d, 0x30, 0x25, 0xa8, 0x28, 0x4f, 0x40, 0x4d, 0x69, 0x0a, 0xda,
    0xf1, 0x1f, 0xb8, 0xc6, 0xf9, 0xef, 0x08, 0xf2, 0x02, 0x49, 0x72, 0x2f, 0x64, 0x2e, 0xca, 0x8d,
    0xee, 0x6d, 0x6d, 0xd8, 0x8a, 0x4d, 0x17, 0x5a, 0xbf, 0x02, 0x2d, 0xa6, 0xe8, 0x46, 0xb0, 0x2f,
    0x9d, 0x6f, 0x55, 0xd5, 0xfe, 0x83, 0xaa, 0x1f, 0xe6, 0xef, 0x1a, 0x12, 0xd3, 0x78, 0x07, 0x5e,
    0x8e, 0x64, 0xb0
};
#endif

PyTypeObject *init_QHttpServerResponder(PyObject *module)
{
    if (SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX].type != nullptr)
        return SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX].type;

    Shiboken::AutoDecRef Sbk_QHttpServerResponder_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QHttpServerResponder_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QHttpServerResponder",
        "QHttpServerResponder*",
        &Sbk_QHttpServerResponder_spec,
        &Shiboken::callCppDestructor< ::QHttpServerResponder >,
        Sbk_QHttpServerResponder_Type_bases.object(),
        0);
    auto *pyType = Sbk_QHttpServerResponder_TypeF(); // references _Sbk_QHttpServerResponder_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QHttpServerResponder_SignatureStrings);
#else
    InitSignatureBytes(pyType, QHttpServerResponder_SignatureBytes, QHttpServerResponder_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QHttpServerResponder_PropertyStrings);
    SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QHttpServerResponder_PythonToCpp_QHttpServerResponder_PTR,
        is_QHttpServerResponder_PythonToCpp_QHttpServerResponder_PTR_Convertible,
        QHttpServerResponder_PTR_CppToPython_QHttpServerResponder);

    Shiboken::Conversions::registerConverterName(converter, "QHttpServerResponder");
    Shiboken::Conversions::registerConverterName(converter, "QHttpServerResponder*");
    Shiboken::Conversions::registerConverterName(converter, "QHttpServerResponder&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QHttpServerResponder).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QHttpServerResponder_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'StatusCode'.
    const char *StatusCode_Initializer[] = {
        "Continue",
        "SwitchingProtocols",
        "Processing",
        "Ok",
        "Created",
        "Accepted",
        "NonAuthoritativeInformation",
        "NoContent",
        "ResetContent",
        "PartialContent",
        "MultiStatus",
        "AlreadyReported",
        "IMUsed",
        "MultipleChoices",
        "MovedPermanently",
        "Found",
        "SeeOther",
        "NotModified",
        "UseProxy",
        "TemporaryRedirect",
        "PermanentRedirect",
        "BadRequest",
        "Unauthorized",
        "PaymentRequired",
        "Forbidden",
        "NotFound",
        "MethodNotAllowed",
        "NotAcceptable",
        "ProxyAuthenticationRequired",
        "RequestTimeout",
        "Conflict",
        "Gone",
        "LengthRequired",
        "PreconditionFailed",
        "PayloadTooLarge",
        "UriTooLong",
        "UnsupportedMediaType",
        "RequestRangeNotSatisfiable",
        "ExpectationFailed",
        "ImATeapot",
        "MisdirectedRequest",
        "UnprocessableEntity",
        "Locked",
        "FailedDependency",
        "UpgradeRequired",
        "PreconditionRequired",
        "TooManyRequests",
        "RequestHeaderFieldsTooLarge",
        "UnavailableForLegalReasons",
        "InternalServerError",
        "NotImplemented",
        "BadGateway",
        "ServiceUnavailable",
        "GatewayTimeout",
        "HttpVersionNotSupported",
        "VariantAlsoNegotiates",
        "InsufficientStorage",
        "LoopDetected",
        "NotExtended",
        "NetworkAuthenticationRequired",
        "NetworkConnectTimeoutError",
        nullptr};
    // "int16_t" used instead of "int"
    constexpr int16_t StatusCode_InitializerValues[] = {
        int16_t(QHttpServerResponder::StatusCode::Continue),                      //  0x0064  100
        int16_t(QHttpServerResponder::StatusCode::SwitchingProtocols),            //  0x0065  101
        int16_t(QHttpServerResponder::StatusCode::Processing),                    //  0x0066  102
        int16_t(QHttpServerResponder::StatusCode::Ok),                            //  0x00c8  200
        int16_t(QHttpServerResponder::StatusCode::Created),                       //  0x00c9  201
        int16_t(QHttpServerResponder::StatusCode::Accepted),                      //  0x00ca  202
        int16_t(QHttpServerResponder::StatusCode::NonAuthoritativeInformation),   //  0x00cb  203
        int16_t(QHttpServerResponder::StatusCode::NoContent),                     //  0x00cc  204
        int16_t(QHttpServerResponder::StatusCode::ResetContent),                  //  0x00cd  205
        int16_t(QHttpServerResponder::StatusCode::PartialContent),                //  0x00ce  206
        int16_t(QHttpServerResponder::StatusCode::MultiStatus),                   //  0x00cf  207
        int16_t(QHttpServerResponder::StatusCode::AlreadyReported),               //  0x00d0  208
        int16_t(QHttpServerResponder::StatusCode::IMUsed),                        //  0x00e2  226
        int16_t(QHttpServerResponder::StatusCode::MultipleChoices),               //  0x012c  300
        int16_t(QHttpServerResponder::StatusCode::MovedPermanently),              //  0x012d  301
        int16_t(QHttpServerResponder::StatusCode::Found),                         //  0x012e  302
        int16_t(QHttpServerResponder::StatusCode::SeeOther),                      //  0x012f  303
        int16_t(QHttpServerResponder::StatusCode::NotModified),                   //  0x0130  304
        int16_t(QHttpServerResponder::StatusCode::UseProxy),                      //  0x0131  305
        int16_t(QHttpServerResponder::StatusCode::TemporaryRedirect),             //  0x0133  307
        int16_t(QHttpServerResponder::StatusCode::PermanentRedirect),             //  0x0134  308
        int16_t(QHttpServerResponder::StatusCode::BadRequest),                    //  0x0190  400
        int16_t(QHttpServerResponder::StatusCode::Unauthorized),                  //  0x0191  401
        int16_t(QHttpServerResponder::StatusCode::PaymentRequired),               //  0x0192  402
        int16_t(QHttpServerResponder::StatusCode::Forbidden),                     //  0x0193  403
        int16_t(QHttpServerResponder::StatusCode::NotFound),                      //  0x0194  404
        int16_t(QHttpServerResponder::StatusCode::MethodNotAllowed),              //  0x0195  405
        int16_t(QHttpServerResponder::StatusCode::NotAcceptable),                 //  0x0196  406
        int16_t(QHttpServerResponder::StatusCode::ProxyAuthenticationRequired),   //  0x0197  407
        int16_t(QHttpServerResponder::StatusCode::RequestTimeout),                //  0x0198  408
        int16_t(QHttpServerResponder::StatusCode::Conflict),                      //  0x0199  409
        int16_t(QHttpServerResponder::StatusCode::Gone),                          //  0x019a  410
        int16_t(QHttpServerResponder::StatusCode::LengthRequired),                //  0x019b  411
        int16_t(QHttpServerResponder::StatusCode::PreconditionFailed),            //  0x019c  412
        int16_t(QHttpServerResponder::StatusCode::PayloadTooLarge),               //  0x019d  413
        int16_t(QHttpServerResponder::StatusCode::UriTooLong),                    //  0x019e  414
        int16_t(QHttpServerResponder::StatusCode::UnsupportedMediaType),          //  0x019f  415
        int16_t(QHttpServerResponder::StatusCode::RequestRangeNotSatisfiable),    //  0x01a0  416
        int16_t(QHttpServerResponder::StatusCode::ExpectationFailed),             //  0x01a1  417
        int16_t(QHttpServerResponder::StatusCode::ImATeapot),                     //  0x01a2  418
        int16_t(QHttpServerResponder::StatusCode::MisdirectedRequest),            //  0x01a5  421
        int16_t(QHttpServerResponder::StatusCode::UnprocessableEntity),           //  0x01a6  422
        int16_t(QHttpServerResponder::StatusCode::Locked),                        //  0x01a7  423
        int16_t(QHttpServerResponder::StatusCode::FailedDependency),              //  0x01a8  424
        int16_t(QHttpServerResponder::StatusCode::UpgradeRequired),               //  0x01aa  426
        int16_t(QHttpServerResponder::StatusCode::PreconditionRequired),          //  0x01ac  428
        int16_t(QHttpServerResponder::StatusCode::TooManyRequests),               //  0x01ad  429
        int16_t(QHttpServerResponder::StatusCode::RequestHeaderFieldsTooLarge),   //  0x01af  431
        int16_t(QHttpServerResponder::StatusCode::UnavailableForLegalReasons),    //  0x01c3  451
        int16_t(QHttpServerResponder::StatusCode::InternalServerError),           //  0x01f4  500
        int16_t(QHttpServerResponder::StatusCode::NotImplemented),                //  0x01f5  501
        int16_t(QHttpServerResponder::StatusCode::BadGateway),                    //  0x01f6  502
        int16_t(QHttpServerResponder::StatusCode::ServiceUnavailable),            //  0x01f7  503
        int16_t(QHttpServerResponder::StatusCode::GatewayTimeout),                //  0x01f8  504
        int16_t(QHttpServerResponder::StatusCode::HttpVersionNotSupported),       //  0x01f9  505
        int16_t(QHttpServerResponder::StatusCode::VariantAlsoNegotiates),         //  0x01fa  506
        int16_t(QHttpServerResponder::StatusCode::InsufficientStorage),           //  0x01fb  507
        int16_t(QHttpServerResponder::StatusCode::LoopDetected),                  //  0x01fc  508
        int16_t(QHttpServerResponder::StatusCode::NotExtended),                   //  0x01fe  510
        int16_t(QHttpServerResponder::StatusCode::NetworkAuthenticationRequired), //  0x01ff  511
        int16_t(QHttpServerResponder::StatusCode::NetworkConnectTimeoutError)     //  0x0257  599
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QHttpServerResponder_TypeF(),
        "2:PySide6.QtHttpServer.QHttpServerResponder.StatusCode",
        StatusCode_Initializer, StatusCode_InitializerValues);
    SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX].type = EType;
    // Register converter for enum 'QHttpServerResponder::StatusCode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QHttpServerResponder_StatusCode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QHttpServerResponder_StatusCode,
            is_Enum_PythonToCpp_QHttpServerResponder_StatusCode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QHttpServerResponder::StatusCode");
        Shiboken::Conversions::registerConverterAlias(converter, "StatusCode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'StatusCode' enum.

    qRegisterMetaType< ::QHttpServerResponder *>();
    qRegisterMetaType< ::QHttpServerResponder::StatusCode >("QHttpServerResponder::StatusCode");

    return pyType;
}
