// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qthttpserver_python.h"

// main header
#include "qhttpserverresponse_wrapper.h"

// Argument includes
#include <QString>
#include <QtHttpServer/qhttpserverresponder.h>
#include <QtHttpServer/qhttpserverresponse.h>
#include <QtNetwork/qhttpheaders.h>
#include <qbytearray.h>
#include <qjsonarray.h>
#include <qjsonobject.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QHttpServerResponse_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QHttpServerResponse >()))
        return -1;

    ::QHttpServerResponse *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponse_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:QHttpServerResponse", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QHttpServerResponse::QHttpServerResponse(QHttpServerResponder::StatusCode)
    // 1: QHttpServerResponse::QHttpServerResponse(QByteArray,QHttpServerResponder::StatusCode=)
    // 2: QHttpServerResponse::QHttpServerResponse(QByteArray,QByteArray,QHttpServerResponder::StatusCode=)
    // 3: QHttpServerResponse::QHttpServerResponse(QJsonArray,QHttpServerResponder::StatusCode=)
    // 4: QHttpServerResponse::QHttpServerResponse(QJsonObject,QHttpServerResponder::StatusCode=)
    // 5: QHttpServerResponse::QHttpServerResponse(QString,QHttpServerResponder::StatusCode=)
    // 6: QHttpServerResponse::QHttpServerResponse(const char*,QHttpServerResponder::StatusCode=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QJsonObject_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 4; // QHttpServerResponse(QJsonObject,QHttpServerResponder::StatusCode)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 4; // QHttpServerResponse(QJsonObject,QHttpServerResponder::StatusCode)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonArray_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 3; // QHttpServerResponse(QJsonArray,QHttpServerResponder::StatusCode)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 3; // QHttpServerResponse(QJsonArray,QHttpServerResponder::StatusCode)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // QHttpServerResponse(QHttpServerResponder::StatusCode)
    } else if (numArgs >= 1
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 6; // QHttpServerResponse(const char*,QHttpServerResponder::StatusCode)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 6; // QHttpServerResponse(const char*,QHttpServerResponder::StatusCode)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 5; // QHttpServerResponse(QString,QHttpServerResponder::StatusCode)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 5; // QHttpServerResponse(QString,QHttpServerResponder::StatusCode)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QHttpServerResponse(QByteArray,QHttpServerResponder::StatusCode)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 2; // QHttpServerResponse(QByteArray,QByteArray,QHttpServerResponder::StatusCode)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))->converter, (pyArgs[2])))) {
                overloadId = 2; // QHttpServerResponse(QByteArray,QByteArray,QHttpServerResponder::StatusCode)
            }
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 1; // QHttpServerResponse(QByteArray,QHttpServerResponder::StatusCode)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponse_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponse_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QHttpServerResponse(QHttpServerResponder::StatusCode statusCode)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponse_IDX]);
            }
            ::QHttpServerResponder::StatusCode cppArg0 = static_cast< ::QHttpServerResponder::StatusCode>(0);
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QHttpServerResponse(QHttpServerResponder::StatusCode)
                cptr = new ::QHttpServerResponse(cppArg0);
            }
            break;
        }
        case 1: // QHttpServerResponse(const QByteArray &data, QHttpServerResponder::StatusCode status)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_status = Shiboken::String::createStaticString("status");
                if (PyDict_Contains(kwds, key_status) != 0) {
                    value = PyDict_GetItem(kwds, key_status);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_status);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponse_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponse_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_status);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponse_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QHttpServerResponder::StatusCode cppArg1(QHttpServerResponder::StatusCode::Ok);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QHttpServerResponse(QByteArray,QHttpServerResponder::StatusCode)
                cptr = new ::QHttpServerResponse(*cppArg0, cppArg1);
            }
            break;
        }
        case 2: // QHttpServerResponse(const QByteArray &mimeType, const QByteArray &data, QHttpServerResponder::StatusCode status)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_status = Shiboken::String::createStaticString("status");
                if (PyDict_Contains(kwds, key_status) != 0) {
                    value = PyDict_GetItem(kwds, key_status);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_status);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponse_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))->converter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponse_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_status);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponse_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QByteArray cppArg1_local;
            ::QByteArray *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            ::QHttpServerResponder::StatusCode cppArg2(QHttpServerResponder::StatusCode::Ok);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QHttpServerResponse(QByteArray,QByteArray,QHttpServerResponder::StatusCode)
                cptr = new ::QHttpServerResponse(*cppArg0, *cppArg1, cppArg2);
            }
            break;
        }
        case 3: // QHttpServerResponse(const QJsonArray &data, QHttpServerResponder::StatusCode status)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_status = Shiboken::String::createStaticString("status");
                if (PyDict_Contains(kwds, key_status) != 0) {
                    value = PyDict_GetItem(kwds, key_status);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_status);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponse_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponse_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_status);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponse_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QJsonArray cppArg0_local;
            ::QJsonArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QHttpServerResponder::StatusCode cppArg1(QHttpServerResponder::StatusCode::Ok);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QHttpServerResponse(QJsonArray,QHttpServerResponder::StatusCode)
                cptr = new ::QHttpServerResponse(*cppArg0, cppArg1);
            }
            break;
        }
        case 4: // QHttpServerResponse(const QJsonObject &data, QHttpServerResponder::StatusCode status)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_status = Shiboken::String::createStaticString("status");
                if (PyDict_Contains(kwds, key_status) != 0) {
                    value = PyDict_GetItem(kwds, key_status);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_status);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponse_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponse_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_status);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponse_IDX]);
                }
            }
            ::QJsonObject cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QHttpServerResponder::StatusCode cppArg1(QHttpServerResponder::StatusCode::Ok);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QHttpServerResponse(QJsonObject,QHttpServerResponder::StatusCode)
                cptr = new ::QHttpServerResponse(cppArg0, cppArg1);
            }
            break;
        }
        case 5: // QHttpServerResponse(const QString &data, QHttpServerResponder::StatusCode status)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_status = Shiboken::String::createStaticString("status");
                if (PyDict_Contains(kwds, key_status) != 0) {
                    value = PyDict_GetItem(kwds, key_status);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_status);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponse_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponse_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_status);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponse_IDX]);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QHttpServerResponder::StatusCode cppArg1(QHttpServerResponder::StatusCode::Ok);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QHttpServerResponse(QString,QHttpServerResponder::StatusCode)
                cptr = new ::QHttpServerResponse(cppArg0, cppArg1);
            }
            break;
        }
        case 6: // QHttpServerResponse(const char *data, QHttpServerResponder::StatusCode status)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_status = Shiboken::String::createStaticString("status");
                if (PyDict_Contains(kwds, key_status) != 0) {
                    value = PyDict_GetItem(kwds, key_status);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_status);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponse_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponse_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_status);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponse_IDX]);
                }
            }
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QHttpServerResponder::StatusCode cppArg1(QHttpServerResponder::StatusCode::Ok);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QHttpServerResponse(const char*,QHttpServerResponder::StatusCode)
                cptr = new ::QHttpServerResponse(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QHttpServerResponse >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponse_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QHttpServerResponseFunc_data(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpServerResponse *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponse_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // data()const
        QByteArray cppResult = const_cast<const ::QHttpServerResponse *>(cppSelf)->data();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttpServerResponseFunc_fromFile(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QHttpServerResponse::fromFile(QString)->QHttpServerResponse
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // fromFile(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fromFile", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponse_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromFile(QString)
            QHttpServerResponse* cppResult = new QHttpServerResponse(::QHttpServerResponse::fromFile(cppArg0));
            pyResult = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponse_IDX]), cppResult, true, true);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttpServerResponseFunc_headers(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpServerResponse *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponse_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // headers()const
        QHttpHeaders cppResult = const_cast<const ::QHttpServerResponse *>(cppSelf)->headers();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttpServerResponseFunc_mimeType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpServerResponse *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponse_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // mimeType()const
        QByteArray cppResult = const_cast<const ::QHttpServerResponse *>(cppSelf)->mimeType();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttpServerResponseFunc_setHeaders(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpServerResponse *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponse_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHttpServerResponse::setHeaders(QHttpHeaders)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_IDX]), (pyArg)))) {
        overloadId = 0; // setHeaders(QHttpHeaders)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHeaders", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponse_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QHttpHeaders cppArg0_local;
        ::QHttpHeaders *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setHeaders(QHttpHeaders)
            cppSelf->setHeaders(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHttpServerResponseFunc_statusCode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpServerResponse *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponse_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // statusCode()const
        QHttpServerResponder::StatusCode cppResult = const_cast<const ::QHttpServerResponse *>(cppSelf)->statusCode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttpServerResponseFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpServerResponse *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponse_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHttpServerResponse::swap(QHttpServerResponse&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponse_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QHttpServerResponse&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponse_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QHttpServerResponse *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QHttpServerResponse&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QHttpServerResponse_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QHttpServerResponse_methods[] = {
    {"data", reinterpret_cast<PyCFunction>(Sbk_QHttpServerResponseFunc_data), METH_NOARGS, nullptr},
    {"fromFile", reinterpret_cast<PyCFunction>(Sbk_QHttpServerResponseFunc_fromFile), METH_O|METH_STATIC, nullptr},
    {"headers", reinterpret_cast<PyCFunction>(Sbk_QHttpServerResponseFunc_headers), METH_NOARGS, nullptr},
    {"mimeType", reinterpret_cast<PyCFunction>(Sbk_QHttpServerResponseFunc_mimeType), METH_NOARGS, nullptr},
    {"setHeaders", reinterpret_cast<PyCFunction>(Sbk_QHttpServerResponseFunc_setHeaders), METH_O, nullptr},
    {"statusCode", reinterpret_cast<PyCFunction>(Sbk_QHttpServerResponseFunc_statusCode), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QHttpServerResponseFunc_swap), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QHttpServerResponse_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QHttpServerResponse_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QHttpServerResponse_Type = nullptr;
static PyTypeObject *Sbk_QHttpServerResponse_TypeF(void)
{
    return _Sbk_QHttpServerResponse_Type;
}

static PyType_Slot Sbk_QHttpServerResponse_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QHttpServerResponse_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QHttpServerResponse_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QHttpServerResponse_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QHttpServerResponse_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QHttpServerResponse_spec = {
    "2:PySide6.QtHttpServer.QHttpServerResponse",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_GC,
    Sbk_QHttpServerResponse_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QHttpServerResponse_PythonToCpp_QHttpServerResponse_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QHttpServerResponse_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QHttpServerResponse_PythonToCpp_QHttpServerResponse_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QHttpServerResponse_TypeF()))
        return QHttpServerResponse_PythonToCpp_QHttpServerResponse_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QHttpServerResponse_PTR_CppToPython_QHttpServerResponse(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QHttpServerResponse_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QHttpServerResponse_SignatureStrings[] = {
    "6:PySide6.QtHttpServer.QHttpServerResponse(self,statusCode:PySide6.QtHttpServer.QHttpServerResponder.StatusCode)",
    "5:PySide6.QtHttpServer.QHttpServerResponse(self,data:typing.Union[PySide6.QtCore.QByteArray, char*],status:PySide6.QtHttpServer.QHttpServerResponder.StatusCode=QHttpServerResponder.StatusCode.Ok)",
    "4:PySide6.QtHttpServer.QHttpServerResponse(self,mimeType:typing.Union[PySide6.QtCore.QByteArray, char*],data:typing.Union[PySide6.QtCore.QByteArray, char*],status:PySide6.QtHttpServer.QHttpServerResponder.StatusCode=QHttpServerResponder.StatusCode.Ok)",
    "3:PySide6.QtHttpServer.QHttpServerResponse(self,data:PySide6.QtCore.QJsonArray,status:PySide6.QtHttpServer.QHttpServerResponder.StatusCode=QHttpServerResponder.StatusCode.Ok)",
    "2:PySide6.QtHttpServer.QHttpServerResponse(self,data:QJsonObject,status:PySide6.QtHttpServer.QHttpServerResponder.StatusCode=QHttpServerResponder.StatusCode.Ok)",
    "1:PySide6.QtHttpServer.QHttpServerResponse(self,data:QString,status:PySide6.QtHttpServer.QHttpServerResponder.StatusCode=QHttpServerResponder.StatusCode.Ok)",
    "0:PySide6.QtHttpServer.QHttpServerResponse(self,data:char*,status:PySide6.QtHttpServer.QHttpServerResponder.StatusCode=QHttpServerResponder.StatusCode.Ok)",
    "PySide6.QtHttpServer.QHttpServerResponse.data(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtHttpServer.QHttpServerResponse.fromFile(fileName:QString)->PySide6.QtHttpServer.QHttpServerResponse",
    "PySide6.QtHttpServer.QHttpServerResponse.headers(self)->PySide6.QtNetwork.QHttpHeaders",
    "PySide6.QtHttpServer.QHttpServerResponse.mimeType(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtHttpServer.QHttpServerResponse.setHeaders(self,newHeaders:PySide6.QtNetwork.QHttpHeaders)",
    "PySide6.QtHttpServer.QHttpServerResponse.statusCode(self)->PySide6.QtHttpServer.QHttpServerResponder.StatusCode",
    "PySide6.QtHttpServer.QHttpServerResponse.swap(self,other:PySide6.QtHttpServer.QHttpServerResponse)",
    nullptr}; // Sentinel
#else
static constexpr size_t QHttpServerResponse_SignatureByteSize = 298;
static constexpr uint8_t QHttpServerResponse_SignatureBytes[298] = {
    0x78, 0xda, 0xcd, 0x95, 0x4d, 0x4f, 0xc3, 0x30, 0x0c, 0x86, 0xef, 0xfd, 0x15, 0x1c, 0x57, 0x54,
    0x22, 0x3e, 0x77, 0xa8, 0x04, 0x12, 0x4c, 0x42, 0x15, 0x87, 0x8d, 0x52, 0x38, 0x21, 0x0e, 0x61,
    0x75, 0x69, 0xd8, 0x9a, 0x44, 0x89, 0xa1, 0xca, 0xbf, 0xa7, 0xb4, 0x1b, 0x05, 0x26, 0x46, 0x12,
    0x51, 0x89, 0x4b, 0x94, 0x2f, 0xdb, 0xcf, 0x1b, 0x3b, 0xc9, 0x38, 0xbe, 0x36, 0x19, 0xcb, 0x61,
    0x4c, 0x52, 0x4c, 0x10, 0x65, 0x06, 0xea, 0x15, 0x14, 0x49, 0xfb, 0xfe, 0x0d, 0x68, 0x29, 0xb8,
    0x86, 0x91, 0x86, 0x65, 0x11, 0x69, 0xa4, 0xf8, 0xa2, 0x27, 0x22, 0x07, 0x4b, 0xc3, 0xbc, 0x99,
    0xcc, 0x3e, 0x8c, 0xc2, 0xe0, 0xc4, 0x31, 0x60, 0x4e, 0x91, 0xc6, 0x68, 0x24, 0xe3, 0x4f, 0xe4,
    0x8e, 0x33, 0xc1, 0xef, 0x7b, 0xfb, 0x89, 0x50, 0x40, 0xd2, 0x0b, 0x83, 0x70, 0xae, 0x14, 0x35,
    0xd1, 0xce, 0xbc, 0xa4, 0x6a, 0xf7, 0x61, 0x05, 0xe9, 0x05, 0x78, 0xfa, 0xcb, 0x3a, 0x99, 0x2d,
    0xc2, 0xe0, 0xd8, 0x51, 0x43, 0xc5, 0x2a, 0xb8, 0x35, 0x12, 0x5c, 0x75, 0xfc, 0x47, 0xed, 0x47,
    0x3e, 0xf9, 0xfb, 0x8e, 0x7d, 0xa5, 0x05, 0xef, 0xb0, 0x87, 0xc6, 0x3d, 0xf4, 0xc1, 0x6d, 0xf9,
    0x66, 0x8f, 0xcf, 0x30, 0xc7, 0xc1, 0x01, 0x0f, 0xbc, 0x00, 0x33, 0x54, 0x4d, 0x51, 0x0c, 0x0e,
    0xb7, 0xef, 0x03, 0xd7, 0x16, 0xe2, 0xe0, 0x68, 0xb6, 0x60, 0xe4, 0x9d, 0xa9, 0xa5, 0x0b, 0xf7,
    0xce, 0x7e, 0xbc, 0x3e, 0xf6, 0xee, 0x0a, 0x25, 0xaa, 0x4b, 0xb6, 0x84, 0x51, 0xd1, 0x34, 0x53,
    0x5a, 0xc1, 0x3a, 0x19, 0x5f, 0xdc, 0x6f, 0x77, 0x62, 0x1f, 0xad, 0x04, 0xda, 0x68, 0xd7, 0x9b,
    0xfc, 0x53, 0xc0, 0x5a, 0xa8, 0x45, 0x67, 0x94, 0x74, 0xbb, 0xec, 0xdd, 0xae, 0x1f, 0xa4, 0x3f,
    0x3c, 0x17, 0x0d, 0x98, 0x7c, 0x82, 0x8d, 0x38, 0xd4, 0xab, 0x71, 0xbc, 0x9d, 0xda, 0x21, 0x95,
    0xfd, 0xe7, 0xb3, 0x09, 0x6e, 0x5f, 0x5e, 0x0e, 0xf1, 0x6a, 0x2a, 0x3b, 0x35, 0x02, 0x4b, 0x50,
    0xd6, 0x97, 0x21, 0x0c, 0xde, 0x00, 0x94, 0x02, 0xbd, 0xd3
};
#endif

PyTypeObject *init_QHttpServerResponse(PyObject *module)
{
    if (SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponse_IDX].type != nullptr)
        return SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponse_IDX].type;

    Shiboken::AutoDecRef Sbk_QHttpServerResponse_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QHttpServerResponse_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QHttpServerResponse",
        "QHttpServerResponse*",
        &Sbk_QHttpServerResponse_spec,
        &Shiboken::callCppDestructor< ::QHttpServerResponse >,
        Sbk_QHttpServerResponse_Type_bases.object(),
        0);
    auto *pyType = Sbk_QHttpServerResponse_TypeF(); // references _Sbk_QHttpServerResponse_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QHttpServerResponse_SignatureStrings);
#else
    InitSignatureBytes(pyType, QHttpServerResponse_SignatureBytes, QHttpServerResponse_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QHttpServerResponse_PropertyStrings);
    SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponse_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QHttpServerResponse_PythonToCpp_QHttpServerResponse_PTR,
        is_QHttpServerResponse_PythonToCpp_QHttpServerResponse_PTR_Convertible,
        QHttpServerResponse_PTR_CppToPython_QHttpServerResponse);

    Shiboken::Conversions::registerConverterName(converter, "QHttpServerResponse");
    Shiboken::Conversions::registerConverterName(converter, "QHttpServerResponse*");
    Shiboken::Conversions::registerConverterName(converter, "QHttpServerResponse&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QHttpServerResponse).name());

    qRegisterMetaType< ::QHttpServerResponse *>();

    return pyType;
}
