// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qthttpserver_python.h"

// main header
#include "qhttpserverrouter_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QHash>
#include <QString>
#include <QtHttpServer/qabstracthttpserver.h>
#include <QtHttpServer/qhttpserverrequest.h>
#include <QtHttpServer/qhttpserverresponder.h>
#include <qmetatype.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QHttpServerRouter_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QHttpServerRouter >()))
        return -1;

    ::QHttpServerRouter *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QHttpServerRouter", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QHttpServerRouter::QHttpServerRouter(QAbstractHttpServer*)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QAbstractHttpServer_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QHttpServerRouter(QAbstractHttpServer*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRouter_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRouter_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QAbstractHttpServer *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QHttpServerRouter(QAbstractHttpServer*)
            cptr = new ::QHttpServerRouter(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QHttpServerRouter >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRouter_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QHttpServerRouterFunc_addConverter(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpServerRouter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRouter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "addConverter", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QHttpServerRouter::addConverter(QMetaType,QAnyStringView)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // addConverter(QMetaType,QAnyStringView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addConverter", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRouter_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QMetaType cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addConverter(QMetaType,QAnyStringView)
            cppSelf->addConverter(cppArg0, QAnyStringView(cppArg1));
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHttpServerRouterFunc_clearConverters(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpServerRouter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRouter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clearConverters()
        cppSelf->clearConverters();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHttpServerRouterFunc_converters(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpServerRouter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRouter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // converters()
        QHash<QMetaType,QString> cppResult = cppSelf->converters();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtHttpServerTypeConverters[SBK_QtHttpServer_QHash_QMetaType_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttpServerRouterFunc_handleRequest(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpServerRouter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRouter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "handleRequest", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QHttpServerRouter::handleRequest(QHttpServerRequest,QHttpServerResponder&)const->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRequest_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]), (pyArgs[1])))) {
        overloadId = 0; // handleRequest(QHttpServerRequest,QHttpServerResponder&)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "handleRequest", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRouter_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QHttpServerRequest *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QHttpServerResponder *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // handleRequest(QHttpServerRequest,QHttpServerResponder&)const
            bool cppResult = const_cast<const ::QHttpServerRouter *>(cppSelf)->handleRequest(*cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttpServerRouterFunc_removeConverter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpServerRouter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRouter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHttpServerRouter::removeConverter(QMetaType)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), (pyArg)))) {
        overloadId = 0; // removeConverter(QMetaType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeConverter", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRouter_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMetaType cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeConverter(QMetaType)
            cppSelf->removeConverter(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QHttpServerRouter_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QHttpServerRouter_methods[] = {
    {"addConverter", reinterpret_cast<PyCFunction>(Sbk_QHttpServerRouterFunc_addConverter), METH_VARARGS, nullptr},
    {"clearConverters", reinterpret_cast<PyCFunction>(Sbk_QHttpServerRouterFunc_clearConverters), METH_NOARGS, nullptr},
    {"converters", reinterpret_cast<PyCFunction>(Sbk_QHttpServerRouterFunc_converters), METH_NOARGS, nullptr},
    {"handleRequest", reinterpret_cast<PyCFunction>(Sbk_QHttpServerRouterFunc_handleRequest), METH_VARARGS, nullptr},
    {"removeConverter", reinterpret_cast<PyCFunction>(Sbk_QHttpServerRouterFunc_removeConverter), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QHttpServerRouter_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QHttpServerRouter_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QHttpServerRouter_Type = nullptr;
static PyTypeObject *Sbk_QHttpServerRouter_TypeF(void)
{
    return _Sbk_QHttpServerRouter_Type;
}

static PyType_Slot Sbk_QHttpServerRouter_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QHttpServerRouter_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QHttpServerRouter_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QHttpServerRouter_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QHttpServerRouter_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QHttpServerRouter_spec = {
    "2:PySide6.QtHttpServer.QHttpServerRouter",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QHttpServerRouter_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QHttpServerRouter_PythonToCpp_QHttpServerRouter_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QHttpServerRouter_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QHttpServerRouter_PythonToCpp_QHttpServerRouter_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QHttpServerRouter_TypeF()))
        return QHttpServerRouter_PythonToCpp_QHttpServerRouter_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QHttpServerRouter_PTR_CppToPython_QHttpServerRouter(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QHttpServerRouter_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QHttpServerRouter_SignatureStrings[] = {
    "PySide6.QtHttpServer.QHttpServerRouter(self,server:PySide6.QtHttpServer.QAbstractHttpServer)",
    "PySide6.QtHttpServer.QHttpServerRouter.addConverter(self,metaType:typing.Union[PySide6.QtCore.QMetaType, PySide6.QtCore.QMetaType.Type],regexp:QString)",
    "PySide6.QtHttpServer.QHttpServerRouter.clearConverters(self)",
    "PySide6.QtHttpServer.QHttpServerRouter.converters(self)->QHash[PySide6.QtCore.QMetaType, QString]",
    "PySide6.QtHttpServer.QHttpServerRouter.handleRequest(self,request:PySide6.QtHttpServer.QHttpServerRequest,responder:PySide6.QtHttpServer.QHttpServerResponder)->bool",
    "PySide6.QtHttpServer.QHttpServerRouter.removeConverter(self,metaType:typing.Union[PySide6.QtCore.QMetaType, PySide6.QtCore.QMetaType.Type])",
    nullptr}; // Sentinel
#else
static constexpr size_t QHttpServerRouter_SignatureByteSize = 211;
static constexpr uint8_t QHttpServerRouter_SignatureBytes[211] = {
    0x78, 0xda, 0xb5, 0x51, 0xb1, 0x0e, 0x82, 0x30, 0x10, 0xdd, 0xf9, 0x0a, 0x47, 0x4d, 0xb0, 0xa3,
    0x03, 0x83, 0x89, 0x61, 0x71, 0x31, 0xa1, 0xa0, 0x93, 0x61, 0xa8, 0xf4, 0x04, 0x12, 0x68, 0xeb,
    0xf5, 0x24, 0xf2, 0xf7, 0xa2, 0x10, 0x35, 0x46, 0xb4, 0x8b, 0xcb, 0xa5, 0x77, 0x7d, 0xef, 0xdd,
    0xbb, 0xbb, 0xa8, 0x4d, 0x4a, 0x09, 0x0b, 0xc6, 0x69, 0x4d, 0x64, 0x12, 0xc0, 0x06, 0x90, 0xf1,
    0xe7, 0x3b, 0xd6, 0x67, 0x02, 0x9c, 0x5a, 0xa8, 0x8e, 0xbe, 0xbd, 0x57, 0x82, 0xe8, 0x23, 0x65,
    0x75, 0xb0, 0x84, 0x22, 0x7b, 0xa9, 0xcd, 0xbc, 0xc8, 0x49, 0x9c, 0x09, 0x29, 0x43, 0xad, 0xba,
    0xfc, 0xd1, 0xa9, 0x06, 0x12, 0xdb, 0xd6, 0x40, 0x40, 0xad, 0x29, 0x55, 0xce, 0x76, 0xaa, 0xd4,
    0x6a, 0xff, 0x94, 0x0b, 0x35, 0x02, 0xe3, 0x9b, 0x01, 0xe5, 0x4f, 0xc6, 0x7e, 0xd8, 0x2d, 0xa4,
    0x3e, 0x42, 0x0e, 0x17, 0x13, 0xf0, 0x84, 0xb0, 0x53, 0x73, 0xf6, 0x95, 0x55, 0x20, 0xf0, 0xe1,
    0xcc, 0xde, 0xad, 0xb9, 0x93, 0xdf, 0x78, 0xf3, 0x25, 0x5f, 0x0b, 0x5b, 0x7c, 0x19, 0x62, 0xb0,
    0x97, 0xba, 0x76, 0x28, 0x84, 0x92, 0x15, 0xc4, 0x70, 0x3a, 0x83, 0xa5, 0x7e, 0x6f, 0xd8, 0x27,
    0xc1, 0x4f, 0x85, 0x1e, 0xd7, 0xe1, 0xad, 0xd1, 0x4a, 0x8e, 0x1e, 0xf5, 0x95, 0x31, 0x20, 0xbb,
    0x41, 0x0e, 0x5a, 0x57, 0xae, 0x26, 0x11, 0x6a, 0xdd, 0xc0, 0x5f, 0xcf, 0x3b, 0xf3, 0xae, 0xc8,
    0xbf, 0x08, 0x98
};
#endif

PyTypeObject *init_QHttpServerRouter(PyObject *module)
{
    if (SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRouter_IDX].type != nullptr)
        return SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRouter_IDX].type;

    Shiboken::AutoDecRef Sbk_QHttpServerRouter_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QHttpServerRouter_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QHttpServerRouter",
        "QHttpServerRouter*",
        &Sbk_QHttpServerRouter_spec,
        &Shiboken::callCppDestructor< ::QHttpServerRouter >,
        Sbk_QHttpServerRouter_Type_bases.object(),
        0);
    auto *pyType = Sbk_QHttpServerRouter_TypeF(); // references _Sbk_QHttpServerRouter_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QHttpServerRouter_SignatureStrings);
#else
    InitSignatureBytes(pyType, QHttpServerRouter_SignatureBytes, QHttpServerRouter_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QHttpServerRouter_PropertyStrings);
    SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRouter_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QHttpServerRouter_PythonToCpp_QHttpServerRouter_PTR,
        is_QHttpServerRouter_PythonToCpp_QHttpServerRouter_PTR_Convertible,
        QHttpServerRouter_PTR_CppToPython_QHttpServerRouter);

    Shiboken::Conversions::registerConverterName(converter, "QHttpServerRouter");
    Shiboken::Conversions::registerConverterName(converter, "QHttpServerRouter*");
    Shiboken::Conversions::registerConverterName(converter, "QHttpServerRouter&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QHttpServerRouter).name());

    qRegisterMetaType< ::QHttpServerRouter *>();

    return pyType;
}
