// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qthttpserver_python.h"

// main header
#include "qhttpserverrouterrule_wrapper.h"

// Argument includes
#include <QtHttpServer/qhttpserverrequest.h>
#include <QtHttpServer/qhttpserverresponder.h>
#include <qobject.h>
#include <qregularexpression.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QHttpServerRouterRuleWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

bool QHttpServerRouterRuleWrapper::matches(const ::QHttpServerRequest & request, ::QRegularExpressionMatch * match) const
{
    if (m_PyMethodCache[0])
        return this->::QHttpServerRouterRule::matches(request, match);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "matches";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QHttpServerRouterRule::matches(request, match);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRequest_IDX]), &request),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpressionMatch_IDX]), match)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRequest_IDX]), &request),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpressionMatch_IDX]), match)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QHttpServerRouterRule", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QHttpServerRouterRule", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QHttpServerRouterRuleWrapper::~QHttpServerRouterRuleWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QHttpServerRouterRuleFunc_contextObject(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpServerRouterRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRouterRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // contextObject()const
        const QObject * cppResult = const_cast<const ::QHttpServerRouterRule *>(cppSelf)->contextObject();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttpServerRouterRuleFunc_exec(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpServerRouterRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRouterRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    pcm.setBlocking();
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "exec", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QHttpServerRouterRule::exec(QHttpServerRequest,QHttpServerResponder&)const->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRequest_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]), (pyArgs[1])))) {
        overloadId = 0; // exec(QHttpServerRequest,QHttpServerResponder&)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "exec", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRouterRule_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QHttpServerRequest *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QHttpServerResponder *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // exec(QHttpServerRequest,QHttpServerResponder&)const
            bool cppResult = const_cast<const ::QHttpServerRouterRule *>(cppSelf)->exec(*cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttpServerRouterRuleFunc_hasValidMethods(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpServerRouterRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRouterRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hasValidMethods()const
        bool cppResult = const_cast<const ::QHttpServerRouterRule *>(cppSelf)->hasValidMethods();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttpServerRouterRuleFunc_matches(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpServerRouterRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRouterRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "matches", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QHttpServerRouterRule::matches(QHttpServerRequest,QRegularExpressionMatch*)const->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRequest_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpressionMatch_IDX]), (pyArgs[1])))) {
        overloadId = 0; // matches(QHttpServerRequest,QRegularExpressionMatch*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "matches", errInfo, SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRouterRule_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QHttpServerRequest *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QRegularExpressionMatch *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // matches(QHttpServerRequest,QRegularExpressionMatch*)const
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QHttpServerRouterRule *>(cppSelf)->::QHttpServerRouterRule::matches(*cppArg0, cppArg1)
                : const_cast<const ::QHttpServerRouterRule *>(cppSelf)->matches(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QHttpServerRouterRule_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QHttpServerRouterRule_methods[] = {
    {"contextObject", reinterpret_cast<PyCFunction>(Sbk_QHttpServerRouterRuleFunc_contextObject), METH_NOARGS, nullptr},
    {"exec", reinterpret_cast<PyCFunction>(Sbk_QHttpServerRouterRuleFunc_exec), METH_VARARGS, nullptr},
    {"hasValidMethods", reinterpret_cast<PyCFunction>(Sbk_QHttpServerRouterRuleFunc_hasValidMethods), METH_NOARGS, nullptr},
    {"matches", reinterpret_cast<PyCFunction>(Sbk_QHttpServerRouterRuleFunc_matches), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QHttpServerRouterRule_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QHttpServerRouterRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRouterRule_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QHttpServerRouterRuleWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QHttpServerRouterRule_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QHttpServerRouterRule_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QHttpServerRouterRule_Type = nullptr;
static PyTypeObject *Sbk_QHttpServerRouterRule_TypeF(void)
{
    return _Sbk_QHttpServerRouterRule_Type;
}

static PyType_Slot Sbk_QHttpServerRouterRule_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QHttpServerRouterRule_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QHttpServerRouterRule_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QHttpServerRouterRule_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QHttpServerRouterRule_methods)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QHttpServerRouterRule_spec = {
    "2:PySide6.QtHttpServer.QHttpServerRouterRule",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QHttpServerRouterRule_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QHttpServerRouterRule_PythonToCpp_QHttpServerRouterRule_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QHttpServerRouterRule_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QHttpServerRouterRule_PythonToCpp_QHttpServerRouterRule_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QHttpServerRouterRule_TypeF()))
        return QHttpServerRouterRule_PythonToCpp_QHttpServerRouterRule_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QHttpServerRouterRule_PTR_CppToPython_QHttpServerRouterRule(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QHttpServerRouterRule *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QHttpServerRouterRule_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QHttpServerRouterRule_SignatureStrings[] = {
    "PySide6.QtHttpServer.QHttpServerRouterRule.contextObject(self)->PySide6.QtCore.QObject",
    "PySide6.QtHttpServer.QHttpServerRouterRule.exec(self,request:PySide6.QtHttpServer.QHttpServerRequest,responder:PySide6.QtHttpServer.QHttpServerResponder)->bool",
    "PySide6.QtHttpServer.QHttpServerRouterRule.hasValidMethods(self)->bool",
    "PySide6.QtHttpServer.QHttpServerRouterRule.matches(self,request:PySide6.QtHttpServer.QHttpServerRequest,match:PySide6.QtCore.QRegularExpressionMatch)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QHttpServerRouterRule_SignatureByteSize = 170;
static constexpr uint8_t QHttpServerRouterRule_SignatureBytes[170] = {
    0x78, 0xda, 0x9d, 0x90, 0xbd, 0x0a, 0xc2, 0x40, 0x10, 0x84, 0x7b, 0x9f, 0x44, 0x41, 0xaf, 0xb4,
    0x48, 0x61, 0x23, 0x82, 0x4d, 0x30, 0x3f, 0x60, 0x7f, 0xb9, 0x1b, 0x4d, 0xe4, 0xcc, 0xc6, 0xbb,
    0x3d, 0x89, 0x6f, 0xef, 0x99, 0x18, 0x05, 0x1b, 0x8d, 0xcd, 0xb2, 0xb0, 0xdf, 0x0c, 0x33, 0x9b,
    0xdc, 0xf2, 0x4a, 0x63, 0x29, 0x52, 0xde, 0x32, 0x37, 0x39, 0xec, 0x15, 0x56, 0xa4, 0xef, 0x3d,
    0x23, 0xcf, 0x61, 0x7a, 0x03, 0xa1, 0xa8, 0x66, 0xb4, 0xbc, 0x2b, 0x4e, 0x50, 0x3c, 0x75, 0x30,
    0x87, 0xd9, 0x62, 0x95, 0xbc, 0xf4, 0x6b, 0xb2, 0x10, 0x69, 0x7f, 0x9d, 0x24, 0xbf, 0xdb, 0xa2,
    0x85, 0xea, 0xdc, 0xe6, 0x16, 0x17, 0x0f, 0xc7, 0xd1, 0x57, 0x71, 0xcf, 0x05, 0xde, 0x35, 0x54,
    0x6b, 0xd8, 0x1f, 0x14, 0x4f, 0x32, 0x24, 0x2e, 0x88, 0xcc, 0x98, 0x7c, 0xa5, 0x74, 0x7b, 0x69,
    0x2a, 0x1d, 0x83, 0x4b, 0xd2, 0x6e, 0x28, 0x3e, 0xd6, 0xe6, 0x2c, 0x59, 0x95, 0x70, 0xff, 0x35,
    0xed, 0xc4, 0xd1, 0xe7, 0xaf, 0x33, 0x1c, 0xbd, 0x91, 0x76, 0xd3, 0x36, 0xe1, 0x13, 0xae, 0xa2,
    0x3a, 0x7e, 0x60, 0x43, 0xb6, 0x3b, 0x47, 0xf9, 0xb2, 0x14
};
#endif

PyTypeObject *init_QHttpServerRouterRule(PyObject *module)
{
    if (SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRouterRule_IDX].type != nullptr)
        return SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRouterRule_IDX].type;

    Shiboken::AutoDecRef Sbk_QHttpServerRouterRule_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QHttpServerRouterRule_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QHttpServerRouterRule",
        "QHttpServerRouterRule*",
        &Sbk_QHttpServerRouterRule_spec,
        &Shiboken::callCppDestructor< QHttpServerRouterRule >,
        Sbk_QHttpServerRouterRule_Type_bases.object(),
        0);
    auto *pyType = Sbk_QHttpServerRouterRule_TypeF(); // references _Sbk_QHttpServerRouterRule_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QHttpServerRouterRule_SignatureStrings);
#else
    InitSignatureBytes(pyType, QHttpServerRouterRule_SignatureBytes, QHttpServerRouterRule_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QHttpServerRouterRule_PropertyStrings);
    SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRouterRule_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QHttpServerRouterRule_PythonToCpp_QHttpServerRouterRule_PTR,
        is_QHttpServerRouterRule_PythonToCpp_QHttpServerRouterRule_PTR_Convertible,
        QHttpServerRouterRule_PTR_CppToPython_QHttpServerRouterRule);

    Shiboken::Conversions::registerConverterName(converter, "QHttpServerRouterRule");
    Shiboken::Conversions::registerConverterName(converter, "QHttpServerRouterRule*");
    Shiboken::Conversions::registerConverterName(converter, "QHttpServerRouterRule&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QHttpServerRouterRule).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QHttpServerRouterRuleWrapper).name());

    qRegisterMetaType< ::QHttpServerRouterRule *>();

    return pyType;
}
