// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtlocation_python.h"

// main header
#include "qgeocodingmanager_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QtLocation/qgeocodereply.h>
#include <QtPositioning/qgeoaddress.h>
#include <QtPositioning/qgeocoordinate.h>
#include <QtPositioning/qgeoshape.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qlocale.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QGeoCodingManagerWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

void QGeoCodingManagerWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGeoCodingManager", funcName);
        return;
    }
}

void QGeoCodingManagerWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGeoCodingManager", funcName);
        return;
    }
}

void QGeoCodingManagerWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGeoCodingManager", funcName);
        return;
    }
}

void QGeoCodingManagerWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGeoCodingManager", funcName);
        return;
    }
}

bool QGeoCodingManagerWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGeoCodingManager", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QGeoCodingManager", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QGeoCodingManagerWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGeoCodingManager", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QGeoCodingManager", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QGeoCodingManagerWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGeoCodingManager", funcName);
        return;
    }
}

const QMetaObject *QGeoCodingManagerWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QGeoCodingManager::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QGeoCodingManagerWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QGeoCodingManager::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QGeoCodingManagerWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QGeoCodingManagerWrapper *>(this));
    return QGeoCodingManager::qt_metacast(_clname);
}

QGeoCodingManagerWrapper::~QGeoCodingManagerWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QGeoCodingManagerFunc_geocode(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoCodingManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoCodingManager_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "geocode", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoCodingManager_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:geocode", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGeoCodingManager::geocode(QGeoAddress,const QGeoShape&=)->QGeoCodeReply*
    // 1: QGeoCodingManager::geocode(QString,int=,int=,const QGeoShape&=)->QGeoCodeReply*
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // geocode(QString,int,int,QGeoShape)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 1; // geocode(QString,int,int,QGeoShape)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 1; // geocode(QString,int,int,QGeoShape)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoShape_IDX]), (pyArgs[3])))) {
                    overloadId = 1; // geocode(QString,int,int,QGeoShape)
                }
            }
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // geocode(QGeoAddress,QGeoShape)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoShape_IDX]), (pyArgs[1])))) {
            overloadId = 0; // geocode(QGeoAddress,QGeoShape)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "geocode", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoCodingManager_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // geocode(const QGeoAddress &address, const QGeoShape &bounds)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_bounds = Shiboken::String::createStaticString("bounds");
                if (PyDict_Contains(kwds, key_bounds) != 0) {
                    value = PyDict_GetItem(kwds, key_bounds);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_bounds);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "geocode", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoCodingManager_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoShape_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "geocode", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoCodingManager_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_bounds);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "geocode", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoCodingManager_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QGeoAddress cppArg0_local;
            ::QGeoAddress *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QGeoShape cppArg1_local = QGeoShape();
            ::QGeoShape *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1]) {
                if (pythonToCpp[1].isValue())
                    pythonToCpp[1](pyArgs[1], &cppArg1_local);
                else
                    pythonToCpp[1](pyArgs[1], &cppArg1);
                }

            if (Shiboken::Errors::occurred() == nullptr) {
                // geocode(QGeoAddress,QGeoShape)
                QGeoCodeReply * cppResult = cppSelf->geocode(*cppArg0, *cppArg1);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoCodeReply_IDX]), cppResult);
                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 1: // geocode(const QString &searchString, int limit, int offset, const QGeoShape &bounds)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_limit = Shiboken::String::createStaticString("limit");
                if (PyDict_Contains(kwds, key_limit) != 0) {
                    value = PyDict_GetItem(kwds, key_limit);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_limit);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "geocode", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoCodingManager_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "geocode", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoCodingManager_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_limit);
                }
                static PyObject *const key_offset = Shiboken::String::createStaticString("offset");
                if (PyDict_Contains(kwds, key_offset) != 0) {
                    value = PyDict_GetItem(kwds, key_offset);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_offset);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "geocode", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoCodingManager_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "geocode", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoCodingManager_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_offset);
                }
                static PyObject *const key_bounds = Shiboken::String::createStaticString("bounds");
                if (PyDict_Contains(kwds, key_bounds) != 0) {
                    value = PyDict_GetItem(kwds, key_bounds);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_bounds);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "geocode", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoCodingManager_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoShape_IDX]), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "geocode", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoCodingManager_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_bounds);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "geocode", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoCodingManager_IDX]);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1 = -1;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2 = 0;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QGeoShape cppArg3_local = QGeoShape();
            ::QGeoShape *cppArg3 = &cppArg3_local;
            if (pythonToCpp[3]) {
                if (pythonToCpp[3].isValue())
                    pythonToCpp[3](pyArgs[3], &cppArg3_local);
                else
                    pythonToCpp[3](pyArgs[3], &cppArg3);
                }

            if (Shiboken::Errors::occurred() == nullptr) {
                // geocode(QString,int,int,QGeoShape)
                QGeoCodeReply * cppResult = cppSelf->geocode(cppArg0, cppArg1, cppArg2, *cppArg3);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoCodeReply_IDX]), cppResult);
                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoCodingManagerFunc_locale(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoCodingManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoCodingManager_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // locale()const
        QLocale cppResult = const_cast<const ::QGeoCodingManager *>(cppSelf)->locale();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoCodingManagerFunc_managerName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoCodingManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoCodingManager_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // managerName()const
        QString cppResult = const_cast<const ::QGeoCodingManager *>(cppSelf)->managerName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoCodingManagerFunc_managerVersion(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoCodingManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoCodingManager_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // managerVersion()const
        int cppResult = const_cast<const ::QGeoCodingManager *>(cppSelf)->managerVersion();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoCodingManagerFunc_reverseGeocode(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoCodingManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoCodingManager_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "reverseGeocode", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoCodingManager_IDX]);

    if (PyArg_ParseTuple(args, "|OO:reverseGeocode", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGeoCodingManager::reverseGeocode(QGeoCoordinate,const QGeoShape&=)->QGeoCodeReply*
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // reverseGeocode(QGeoCoordinate,QGeoShape)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoShape_IDX]), (pyArgs[1])))) {
            overloadId = 0; // reverseGeocode(QGeoCoordinate,QGeoShape)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "reverseGeocode", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoCodingManager_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_bounds = Shiboken::String::createStaticString("bounds");
            if (PyDict_Contains(kwds, key_bounds) != 0) {
                value = PyDict_GetItem(kwds, key_bounds);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_bounds);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "reverseGeocode", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoCodingManager_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoShape_IDX]), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "reverseGeocode", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoCodingManager_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_bounds);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "reverseGeocode", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoCodingManager_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QGeoCoordinate cppArg0_local;
        ::QGeoCoordinate *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QGeoShape cppArg1_local = QGeoShape();
        ::QGeoShape *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1]) {
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // reverseGeocode(QGeoCoordinate,QGeoShape)
            QGeoCodeReply * cppResult = cppSelf->reverseGeocode(*cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoCodeReply_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoCodingManagerFunc_setLocale(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoCodingManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoCodingManager_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoCodingManager::setLocale(QLocale)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), (pyArg)))) {
        overloadId = 0; // setLocale(QLocale)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLocale", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoCodingManager_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QLocale cppArg0_local;
        ::QLocale *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setLocale(QLocale)
            cppSelf->setLocale(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QGeoCodingManager_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QGeoCodingManager_methods[] = {
    {"geocode", reinterpret_cast<PyCFunction>(Sbk_QGeoCodingManagerFunc_geocode), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"locale", reinterpret_cast<PyCFunction>(Sbk_QGeoCodingManagerFunc_locale), METH_NOARGS, nullptr},
    {"managerName", reinterpret_cast<PyCFunction>(Sbk_QGeoCodingManagerFunc_managerName), METH_NOARGS, nullptr},
    {"managerVersion", reinterpret_cast<PyCFunction>(Sbk_QGeoCodingManagerFunc_managerVersion), METH_NOARGS, nullptr},
    {"reverseGeocode", reinterpret_cast<PyCFunction>(Sbk_QGeoCodingManagerFunc_reverseGeocode), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setLocale", reinterpret_cast<PyCFunction>(Sbk_QGeoCodingManagerFunc_setLocale), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QGeoCodingManager_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QGeoCodingManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoCodingManager_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QGeoCodingManagerWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QGeoCodingManager_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QGeoCodingManager_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QGeoCodingManager_Type = nullptr;
static PyTypeObject *Sbk_QGeoCodingManager_TypeF(void)
{
    return _Sbk_QGeoCodingManager_Type;
}

static PyType_Slot Sbk_QGeoCodingManager_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QGeoCodingManager_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QGeoCodingManager_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QGeoCodingManager_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QGeoCodingManager_methods)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QGeoCodingManager_spec = {
    "2:PySide6.QtLocation.QGeoCodingManager",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QGeoCodingManager_slots
};

} //extern "C"

static void *Sbk_QGeoCodingManager_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QGeoCodingManager *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QGeoCodingManager_PythonToCpp_QGeoCodingManager_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QGeoCodingManager_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QGeoCodingManager_PythonToCpp_QGeoCodingManager_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QGeoCodingManager_TypeF()))
        return QGeoCodingManager_PythonToCpp_QGeoCodingManager_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QGeoCodingManager_PTR_CppToPython_QGeoCodingManager(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QGeoCodingManager *>(const_cast<void *>(cppIn)), Sbk_QGeoCodingManager_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QGeoCodingManager_SignatureStrings[] = {
    "1:PySide6.QtLocation.QGeoCodingManager.geocode(self,address:PySide6.QtPositioning.QGeoAddress,bounds:PySide6.QtPositioning.QGeoShape=QGeoShape())->PySide6.QtLocation.QGeoCodeReply",
    "0:PySide6.QtLocation.QGeoCodingManager.geocode(self,searchString:QString,limit:int=-1,offset:int=0,bounds:PySide6.QtPositioning.QGeoShape=QGeoShape())->PySide6.QtLocation.QGeoCodeReply",
    "PySide6.QtLocation.QGeoCodingManager.locale(self)->PySide6.QtCore.QLocale",
    "PySide6.QtLocation.QGeoCodingManager.managerName(self)->QString",
    "PySide6.QtLocation.QGeoCodingManager.managerVersion(self)->int",
    "PySide6.QtLocation.QGeoCodingManager.reverseGeocode(self,coordinate:PySide6.QtPositioning.QGeoCoordinate,bounds:PySide6.QtPositioning.QGeoShape=QGeoShape())->PySide6.QtLocation.QGeoCodeReply",
    "PySide6.QtLocation.QGeoCodingManager.setLocale(self,locale:typing.Union[PySide6.QtCore.QLocale, PySide6.QtCore.QLocale.Language])",
    nullptr}; // Sentinel
#else
static constexpr size_t QGeoCodingManager_SignatureByteSize = 256;
static constexpr uint8_t QGeoCodingManager_SignatureBytes[256] = {
    0x78, 0xda, 0xc5, 0x52, 0xb1, 0x6a, 0xc3, 0x30, 0x10, 0xdd, 0xf3, 0x15, 0x1d, 0x63, 0x50, 0x44,
    0xb2, 0x64, 0x30, 0xa4, 0x50, 0x3c, 0x64, 0x71, 0x4b, 0x1c, 0xd3, 0x2e, 0xa5, 0xc3, 0xd5, 0x3a,
    0x3b, 0x02, 0x59, 0x67, 0x24, 0xa5, 0xe0, 0xbf, 0xef, 0x25, 0x6a, 0xdd, 0x14, 0xd2, 0xe0, 0x06,
    0x4a, 0xa7, 0x93, 0x74, 0xef, 0x3d, 0x3d, 0xdd, 0xd3, 0x22, 0xdd, 0xf4, 0xa5, 0x56, 0xb8, 0x94,
    0x45, 0xc8, 0xa9, 0x82, 0xa0, 0xc9, 0xca, 0x62, 0x8d, 0x94, 0x91, 0xd2, 0xb6, 0xb9, 0x07, 0x0b,
    0x0d, 0x3a, 0xd9, 0x20, 0x55, 0xa4, 0x70, 0xea, 0xd1, 0xd4, 0x02, 0x94, 0x72, 0xe8, 0xfd, 0x09,
    0x73, 0x43, 0x5e, 0x1f, 0x98, 0xcc, 0x38, 0x92, 0xef, 0x22, 0x42, 0xbc, 0xd2, 0xde, 0xaa, 0x4b,
    0xc0, 0x72, 0x07, 0x1d, 0xae, 0x86, 0xd5, 0x34, 0x49, 0x66, 0xb7, 0x3f, 0x1b, 0xc2, 0x2d, 0x76,
    0xa6, 0x9f, 0xcc, 0xaf, 0xf0, 0xec, 0x11, 0x5c, 0xb5, 0x2b, 0x83, 0x63, 0x40, 0x5a, 0xc4, 0x2a,
    0x8c, 0x6e, 0x75, 0x48, 0xb5, 0x0d, 0xab, 0xd9, 0x42, 0x50, 0x5d, 0x7b, 0x8c, 0xbb, 0xf9, 0x1f,
    0x19, 0x1f, 0x65, 0xdb, 0x70, 0xcb, 0x44, 0xd7, 0xdf, 0x34, 0x33, 0x72, 0x28, 0x8b, 0xfc, 0xd8,
    0x1d, 0xa7, 0xd4, 0xc6, 0xfa, 0x00, 0xed, 0x20, 0xf7, 0xf1, 0xf2, 0x5f, 0xf1, 0x9f, 0xd0, 0x79,
    0x06, 0x7c, 0x4a, 0xf0, 0x80, 0xc6, 0xd1, 0x1d, 0xbe, 0x31, 0x13, 0xd7, 0xa7, 0x31, 0x54, 0x44,
    0x8e, 0x31, 0x10, 0xf0, 0xc2, 0x6c, 0xb3, 0x01, 0xf4, 0x9f, 0x39, 0xf0, 0x67, 0xc8, 0xbf, 0xa2,
    0x10, 0x31, 0x96, 0x34, 0xf4, 0xdd, 0xe1, 0xea, 0x47, 0xcb, 0xa4, 0xe7, 0xf3, 0xe1, 0x88, 0x9b,
    0xf3, 0xe7, 0x32, 0x07, 0xdb, 0xec, 0x59, 0xfb, 0x25, 0x99, 0xbc, 0x03, 0x59, 0x7f, 0x41, 0x21
};
#endif

PyTypeObject *init_QGeoCodingManager(PyObject *module)
{
    if (SbkPySide6_QtLocationTypeStructs[SBK_QGeoCodingManager_IDX].type != nullptr)
        return SbkPySide6_QtLocationTypeStructs[SBK_QGeoCodingManager_IDX].type;

    Shiboken::AutoDecRef Sbk_QGeoCodingManager_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QGeoCodingManager_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QGeoCodingManager",
        "QGeoCodingManager*",
        &Sbk_QGeoCodingManager_spec,
        &Shiboken::callCppDestructor< QGeoCodingManager >,
        Sbk_QGeoCodingManager_Type_bases.object(),
        0);
    auto *pyType = Sbk_QGeoCodingManager_TypeF(); // references _Sbk_QGeoCodingManager_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QGeoCodingManager_SignatureStrings);
#else
    InitSignatureBytes(pyType, QGeoCodingManager_SignatureBytes, QGeoCodingManager_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QGeoCodingManager_PropertyStrings);
    SbkPySide6_QtLocationTypeStructs[SBK_QGeoCodingManager_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QGeoCodingManager_PythonToCpp_QGeoCodingManager_PTR,
        is_QGeoCodingManager_PythonToCpp_QGeoCodingManager_PTR_Convertible,
        QGeoCodingManager_PTR_CppToPython_QGeoCodingManager);

    Shiboken::Conversions::registerConverterName(converter, "QGeoCodingManager");
    Shiboken::Conversions::registerConverterName(converter, "QGeoCodingManager*");
    Shiboken::Conversions::registerConverterName(converter, "QGeoCodingManager&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QGeoCodingManager).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QGeoCodingManagerWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QGeoCodingManager_TypeF(), &Sbk_QGeoCodingManager_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::QGeoCodingManager::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QGeoCodingManager::staticMetaObject, sizeof(QGeoCodingManagerWrapper));

    return pyType;
}
