// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtlocation_python.h"

// main header
#include "qgeomaneuver_wrapper.h"

// Argument includes
#include <QMap>
#include <QString>
#include <QtLocation/qgeomaneuver.h>
#include <QtPositioning/qgeocoordinate.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGeoManeuver_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QGeoManeuver >()))
        return -1;

    ::QGeoManeuver *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QGeoManeuver", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QGeoManeuver::QGeoManeuver()
    // 1: QGeoManeuver::QGeoManeuver(QGeoManeuver)
    if (numArgs == 0) {
        overloadId = 0; // QGeoManeuver()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoManeuver_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QGeoManeuver(QGeoManeuver)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoManeuver_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtLocationTypeStructs[SBK_QGeoManeuver_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QGeoManeuver()
        {

            // QGeoManeuver()
            cptr = new ::QGeoManeuver();
            break;
        }
        case 1: // QGeoManeuver(const QGeoManeuver &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QGeoManeuver cppArg0_local;
            ::QGeoManeuver *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QGeoManeuver(QGeoManeuver)
                cptr = new ::QGeoManeuver(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QGeoManeuver >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoManeuver_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QGeoManeuverFunc_direction(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoManeuver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoManeuver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // direction()const
        QGeoManeuver::InstructionDirection cppResult = const_cast<const ::QGeoManeuver *>(cppSelf)->direction();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoManeuver_InstructionDirection_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoManeuverFunc_distanceToNextInstruction(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoManeuver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoManeuver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // distanceToNextInstruction()const
        qreal cppResult = const_cast<const ::QGeoManeuver *>(cppSelf)->distanceToNextInstruction();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoManeuverFunc_extendedAttributes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoManeuver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoManeuver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // extendedAttributes()const
        QMap<QString,QVariant> cppResult = const_cast<const ::QGeoManeuver *>(cppSelf)->extendedAttributes();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QMap_QString_QVariant_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoManeuverFunc_instructionText(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoManeuver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoManeuver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // instructionText()const
        QString cppResult = const_cast<const ::QGeoManeuver *>(cppSelf)->instructionText();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoManeuverFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoManeuver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoManeuver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QGeoManeuver *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoManeuverFunc_position(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoManeuver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoManeuver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // position()const
        QGeoCoordinate cppResult = const_cast<const ::QGeoManeuver *>(cppSelf)->position();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoManeuverFunc_setDirection(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoManeuver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoManeuver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoManeuver::setDirection(QGeoManeuver::InstructionDirection)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoManeuver_InstructionDirection_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setDirection(QGeoManeuver::InstructionDirection)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDirection", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoManeuver_IDX]);

    // Call function/method
    {
        ::QGeoManeuver::InstructionDirection cppArg0{QGeoManeuver::NoDirection};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDirection(QGeoManeuver::InstructionDirection)
            cppSelf->setDirection(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoManeuverFunc_setDistanceToNextInstruction(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoManeuver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoManeuver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoManeuver::setDistanceToNextInstruction(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setDistanceToNextInstruction(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDistanceToNextInstruction", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoManeuver_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDistanceToNextInstruction(qreal)
            cppSelf->setDistanceToNextInstruction(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoManeuverFunc_setExtendedAttributes(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoManeuver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoManeuver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoManeuver::setExtendedAttributes(QMap<QString,QVariant>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QMap_QString_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // setExtendedAttributes(QMap<QString,QVariant>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setExtendedAttributes", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoManeuver_IDX]);

    // Call function/method
    {
        ::QMap<QString,QVariant> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setExtendedAttributes(QMap<QString,QVariant>)
            cppSelf->setExtendedAttributes(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoManeuverFunc_setInstructionText(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoManeuver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoManeuver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoManeuver::setInstructionText(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setInstructionText(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setInstructionText", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoManeuver_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setInstructionText(QString)
            cppSelf->setInstructionText(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoManeuverFunc_setPosition(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoManeuver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoManeuver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoManeuver::setPosition(QGeoCoordinate)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), (pyArg)))) {
        overloadId = 0; // setPosition(QGeoCoordinate)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPosition", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoManeuver_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGeoCoordinate cppArg0_local;
        ::QGeoCoordinate *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setPosition(QGeoCoordinate)
            cppSelf->setPosition(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoManeuverFunc_setTimeToNextInstruction(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoManeuver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoManeuver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoManeuver::setTimeToNextInstruction(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setTimeToNextInstruction(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTimeToNextInstruction", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoManeuver_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTimeToNextInstruction(int)
            cppSelf->setTimeToNextInstruction(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoManeuverFunc_setWaypoint(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoManeuver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoManeuver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoManeuver::setWaypoint(QGeoCoordinate)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), (pyArg)))) {
        overloadId = 0; // setWaypoint(QGeoCoordinate)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setWaypoint", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoManeuver_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGeoCoordinate cppArg0_local;
        ::QGeoCoordinate *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setWaypoint(QGeoCoordinate)
            cppSelf->setWaypoint(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoManeuverFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoManeuver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoManeuver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoManeuver::swap(QGeoManeuver&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoManeuver_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QGeoManeuver&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoManeuver_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGeoManeuver cppArg0_local;
        ::QGeoManeuver *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QGeoManeuver&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoManeuverFunc_timeToNextInstruction(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoManeuver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoManeuver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // timeToNextInstruction()const
        int cppResult = const_cast<const ::QGeoManeuver *>(cppSelf)->timeToNextInstruction();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoManeuverFunc_waypoint(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoManeuver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoManeuver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // waypoint()const
        QGeoCoordinate cppResult = const_cast<const ::QGeoManeuver *>(cppSelf)->waypoint();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoManeuver__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QGeoManeuver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoManeuver_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoManeuver_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QGeoManeuver_PropertyStrings[] = {
    "direction:",
    "distanceToNextInstruction:",
    "extendedAttributes:",
    "instructionText:",
    "position:",
    "timeToNextInstruction:",
    "valid:isValid",
    "waypoint:",
    nullptr // Sentinel
};

static const char *Sbk_QGeoManeuver_EnumFlagInfo[] = {
    "InstructionDirection:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QGeoManeuver_methods[] = {
    {"direction", reinterpret_cast<PyCFunction>(Sbk_QGeoManeuverFunc_direction), METH_NOARGS, nullptr},
    {"distanceToNextInstruction", reinterpret_cast<PyCFunction>(Sbk_QGeoManeuverFunc_distanceToNextInstruction), METH_NOARGS, nullptr},
    {"extendedAttributes", reinterpret_cast<PyCFunction>(Sbk_QGeoManeuverFunc_extendedAttributes), METH_NOARGS, nullptr},
    {"instructionText", reinterpret_cast<PyCFunction>(Sbk_QGeoManeuverFunc_instructionText), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QGeoManeuverFunc_isValid), METH_NOARGS, nullptr},
    {"position", reinterpret_cast<PyCFunction>(Sbk_QGeoManeuverFunc_position), METH_NOARGS, nullptr},
    {"setDirection", reinterpret_cast<PyCFunction>(Sbk_QGeoManeuverFunc_setDirection), METH_O, nullptr},
    {"setDistanceToNextInstruction", reinterpret_cast<PyCFunction>(Sbk_QGeoManeuverFunc_setDistanceToNextInstruction), METH_O, nullptr},
    {"setExtendedAttributes", reinterpret_cast<PyCFunction>(Sbk_QGeoManeuverFunc_setExtendedAttributes), METH_O, nullptr},
    {"setInstructionText", reinterpret_cast<PyCFunction>(Sbk_QGeoManeuverFunc_setInstructionText), METH_O, nullptr},
    {"setPosition", reinterpret_cast<PyCFunction>(Sbk_QGeoManeuverFunc_setPosition), METH_O, nullptr},
    {"setTimeToNextInstruction", reinterpret_cast<PyCFunction>(Sbk_QGeoManeuverFunc_setTimeToNextInstruction), METH_O, nullptr},
    {"setWaypoint", reinterpret_cast<PyCFunction>(Sbk_QGeoManeuverFunc_setWaypoint), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QGeoManeuverFunc_swap), METH_O, nullptr},
    {"timeToNextInstruction", reinterpret_cast<PyCFunction>(Sbk_QGeoManeuverFunc_timeToNextInstruction), METH_NOARGS, nullptr},
    {"waypoint", reinterpret_cast<PyCFunction>(Sbk_QGeoManeuverFunc_waypoint), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QGeoManeuver__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QGeoManeuver_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QGeoManeuver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoManeuver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoManeuver_IDX]), (pyArg)))) {
                // operator!=(const QGeoManeuver &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QGeoManeuver cppArg0_local;
                ::QGeoManeuver *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoManeuver_IDX]), (pyArg)))) {
                // operator==(const QGeoManeuver &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QGeoManeuver cppArg0_local;
                ::QGeoManeuver *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QGeoManeuver_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QGeoManeuver_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QGeoManeuver_Type = nullptr;
static PyTypeObject *Sbk_QGeoManeuver_TypeF(void)
{
    return _Sbk_QGeoManeuver_Type;
}

static PyType_Slot Sbk_QGeoManeuver_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QGeoManeuver_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QGeoManeuver_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QGeoManeuver_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QGeoManeuver_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QGeoManeuver_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QGeoManeuver_spec = {
    "2:PySide6.QtLocation.QGeoManeuver",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QGeoManeuver_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QGeoManeuver_InstructionDirection(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QGeoManeuver::InstructionDirection>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QGeoManeuver::InstructionDirection *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QGeoManeuver_InstructionDirection_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoManeuver_InstructionDirection_IDX])))
        return Enum_PythonToCpp_QGeoManeuver_InstructionDirection;
    return {};
}

static PyObject *QGeoManeuver_InstructionDirection_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QGeoManeuver::InstructionDirection>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QGeoManeuver::InstructionDirection *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoManeuver_InstructionDirection_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QGeoManeuver_PythonToCpp_QGeoManeuver_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QGeoManeuver_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QGeoManeuver_PythonToCpp_QGeoManeuver_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QGeoManeuver_TypeF()))
        return QGeoManeuver_PythonToCpp_QGeoManeuver_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QGeoManeuver_PTR_CppToPython_QGeoManeuver(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QGeoManeuver_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QGeoManeuver_COPY_CppToPython_QGeoManeuver(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QGeoManeuver *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QGeoManeuver_TypeF(), new ::QGeoManeuver(*source), true, true);
}

// Python to C++ copy conversion.
static void QGeoManeuver_PythonToCpp_QGeoManeuver_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QGeoManeuver *>(cppOut) = *reinterpret_cast< ::QGeoManeuver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoManeuver_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QGeoManeuver_PythonToCpp_QGeoManeuver_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QGeoManeuver_TypeF()))
        return QGeoManeuver_PythonToCpp_QGeoManeuver_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QGeoManeuver_SignatureStrings[] = {
    "1:PySide6.QtLocation.QGeoManeuver(self,*:KeywordOnly=None,valid:bool=None,position:QGeoCoordinate=None,instructionText:QString=None,direction:QGeoManeuver.InstructionDirection=None,timeToNextInstruction:int=None,distanceToNextInstruction:qreal=None,waypoint:QGeoCoordinate=None,extendedAttributes:QMap[QString, QVariant]=None)",
    "0:PySide6.QtLocation.QGeoManeuver(self,other:PySide6.QtLocation.QGeoManeuver,*:KeywordOnly=None,valid:bool=None,position:QGeoCoordinate=None,instructionText:QString=None,direction:QGeoManeuver.InstructionDirection=None,timeToNextInstruction:int=None,distanceToNextInstruction:qreal=None,waypoint:QGeoCoordinate=None,extendedAttributes:QMap[QString, QVariant]=None)",
    "PySide6.QtLocation.QGeoManeuver.direction(self)->PySide6.QtLocation.QGeoManeuver.InstructionDirection",
    "PySide6.QtLocation.QGeoManeuver.distanceToNextInstruction(self)->qreal",
    "PySide6.QtLocation.QGeoManeuver.extendedAttributes(self)->QMap[QString, QVariant]",
    "PySide6.QtLocation.QGeoManeuver.instructionText(self)->QString",
    "PySide6.QtLocation.QGeoManeuver.isValid(self)->bool",
    "PySide6.QtLocation.QGeoManeuver.position(self)->PySide6.QtPositioning.QGeoCoordinate",
    "PySide6.QtLocation.QGeoManeuver.setDirection(self,direction:PySide6.QtLocation.QGeoManeuver.InstructionDirection)",
    "PySide6.QtLocation.QGeoManeuver.setDistanceToNextInstruction(self,distance:qreal)",
    "PySide6.QtLocation.QGeoManeuver.setExtendedAttributes(self,extendedAttributes:QMap[QString, QVariant])",
    "PySide6.QtLocation.QGeoManeuver.setInstructionText(self,instructionText:QString)",
    "PySide6.QtLocation.QGeoManeuver.setPosition(self,position:PySide6.QtPositioning.QGeoCoordinate)",
    "PySide6.QtLocation.QGeoManeuver.setTimeToNextInstruction(self,secs:int)",
    "PySide6.QtLocation.QGeoManeuver.setWaypoint(self,coordinate:PySide6.QtPositioning.QGeoCoordinate)",
    "PySide6.QtLocation.QGeoManeuver.swap(self,other:PySide6.QtLocation.QGeoManeuver)",
    "PySide6.QtLocation.QGeoManeuver.timeToNextInstruction(self)->int",
    "PySide6.QtLocation.QGeoManeuver.waypoint(self)->PySide6.QtPositioning.QGeoCoordinate",
    "PySide6.QtLocation.QGeoManeuver.__copy__(self)->typing.Self",
    "PySide6.QtLocation.QGeoManeuver.__ne__(self,rhs:PySide6.QtLocation.QGeoManeuver)->bool",
    "PySide6.QtLocation.QGeoManeuver.__eq__(self,rhs:PySide6.QtLocation.QGeoManeuver)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QGeoManeuver_SignatureByteSize = 416;
static constexpr uint8_t QGeoManeuver_SignatureBytes[416] = {
    0x78, 0xda, 0xed, 0x54, 0xc1, 0x4e, 0xc3, 0x30, 0x0c, 0xbd, 0xf3, 0x15, 0x1c, 0x19, 0x1a, 0x15,
    0x5c, 0x38, 0x54, 0x02, 0x09, 0x31, 0x84, 0x26, 0xd8, 0x58, 0xb5, 0x69, 0x1c, 0x10, 0xaa, 0xb2,
    0xd6, 0xb0, 0x48, 0x25, 0xe9, 0x12, 0x6f, 0xa5, 0x7f, 0x4f, 0xba, 0x34, 0x5d, 0xc7, 0x5a, 0x92,
    0x4d, 0x3b, 0x72, 0x8c, 0xec, 0xf7, 0xec, 0xe7, 0xe7, 0xf8, 0xca, 0x1f, 0xe5, 0x63, 0x1a, 0xc3,
    0xb5, 0x17, 0xe0, 0x33, 0x8f, 0x08, 0x52, 0xce, 0xbc, 0xe0, 0x11, 0xf8, 0x80, 0x30, 0x58, 0xae,
    0x40, 0x9c, 0x49, 0x48, 0x3e, 0xba, 0xe7, 0xfe, 0x13, 0xe4, 0x19, 0x17, 0xf1, 0x0b, 0x4b, 0xf2,
    0x9b, 0x21, 0x67, 0xd0, 0x5d, 0x91, 0x84, 0xc6, 0xfe, 0x8c, 0xf3, 0x44, 0xbf, 0x53, 0x2e, 0x69,
    0x81, 0xf6, 0x0b, 0xf4, 0x3d, 0x57, 0xb9, 0x94, 0x11, 0x04, 0x1d, 0xa4, 0x4c, 0xa2, 0x58, 0x46,
    0x45, 0x7c, 0x02, 0xdf, 0xe8, 0x07, 0x63, 0x14, 0x94, 0x7d, 0xea, 0x60, 0x4c, 0x05, 0x44, 0x15,
    0xd4, 0x14, 0xf6, 0xfa, 0x1b, 0x4c, 0xcf, 0x64, 0x68, 0x00, 0xd2, 0x2f, 0x98, 0xf0, 0xa1, 0x22,
    0xaa, 0xe5, 0xf8, 0x94, 0xa1, 0xe1, 0x93, 0x48, 0x58, 0xd4, 0x90, 0xb2, 0x10, 0x40, 0xca, 0x76,
    0x33, 0x92, 0xa7, 0x5c, 0x41, 0x1a, 0xdb, 0x55, 0x30, 0x60, 0x31, 0xc4, 0x77, 0xa8, 0xda, 0x9c,
    0x2d, 0x11, 0xa4, 0x1f, 0x0c, 0x48, 0xfa, 0x56, 0xb6, 0xdd, 0x3d, 0x0d, 0xa6, 0x44, 0x50, 0xc2,
    0xf0, 0x7d, 0x9d, 0xdf, 0x39, 0xb9, 0x74, 0x1b, 0x23, 0xc7, 0x39, 0x08, 0x5b, 0xea, 0xff, 0xb0,
    0x2d, 0xc3, 0xb6, 0xcc, 0xcf, 0xab, 0x24, 0xae, 0x87, 0xde, 0xb9, 0xb8, 0xb5, 0x01, 0x9a, 0xc4,
    0x3b, 0x54, 0x69, 0x11, 0x6e, 0xaa, 0xae, 0xf5, 0x5b, 0x69, 0x76, 0xd5, 0x1b, 0x7c, 0xcb, 0x10,
    0xac, 0x8c, 0xbf, 0xec, 0xaf, 0xe8, 0x34, 0x93, 0x1d, 0x2e, 0xa7, 0xc5, 0xb2, 0x19, 0x58, 0xb1,
    0x73, 0x56, 0x8c, 0x59, 0xc7, 0xdd, 0x81, 0x8f, 0xca, 0x88, 0xaa, 0xec, 0x6d, 0x9b, 0x6f, 0x25,
    0x95, 0x80, 0xbd, 0x2d, 0x27, 0x6b, 0xbb, 0x7b, 0x88, 0xa3, 0x1d, 0xb7, 0x8a, 0x7f, 0xb9, 0x5a,
    0x6d, 0xbb, 0x5e, 0x6e, 0x27, 0xc6, 0x87, 0x66, 0x83, 0xf7, 0x58, 0x7b, 0xa7, 0x32, 0xfd, 0x06,
    0xd7, 0xdb, 0x2e, 0x81, 0x13, 0xe1, 0xa8, 0xee, 0xe9, 0xe6, 0xe0, 0xb8, 0x58, 0xeb, 0xc4, 0x3f,
    0x69, 0xba, 0x2b, 0xba, 0x98, 0x84, 0x48, 0x16, 0x17, 0xc6, 0x89, 0xe7, 0xb5, 0xbc, 0x2d, 0x1a,
    0x1a, 0x55, 0x4d, 0x1c, 0xab, 0xd3, 0x8c, 0xa4, 0x7b, 0x1c, 0x6f, 0x3b, 0x21, 0xb6, 0xea, 0x56,
    0x1f, 0x47, 0xe9, 0xb0, 0x12, 0x64, 0x75, 0xc1, 0xc7, 0xfa, 0x6c, 0x61, 0x18, 0xf1, 0x34, 0x0f,
    0x43, 0x43, 0x8a, 0x79, 0x5a, 0xb0, 0x8c, 0xd5, 0xcb, 0x01, 0xcb, 0xa0, 0x44, 0x76, 0xc5, 0x5c,
    0x5a, 0x47, 0xe4, 0x78, 0x54, 0xc2, 0x10, 0x16, 0x07, 0xd0, 0xfe, 0x00, 0x38, 0x6b, 0x4b, 0x2c
};
#endif

PyTypeObject *init_QGeoManeuver(PyObject *module)
{
    if (SbkPySide6_QtLocationTypeStructs[SBK_QGeoManeuver_IDX].type != nullptr)
        return SbkPySide6_QtLocationTypeStructs[SBK_QGeoManeuver_IDX].type;

    Shiboken::AutoDecRef Sbk_QGeoManeuver_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QGeoManeuver_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QGeoManeuver",
        "QGeoManeuver",
        &Sbk_QGeoManeuver_spec,
        &Shiboken::callCppDestructor< ::QGeoManeuver >,
        Sbk_QGeoManeuver_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QGeoManeuver_TypeF(); // references _Sbk_QGeoManeuver_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QGeoManeuver_SignatureStrings);
#else
    InitSignatureBytes(pyType, QGeoManeuver_SignatureBytes, QGeoManeuver_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QGeoManeuver_PropertyStrings);
    SbkPySide6_QtLocationTypeStructs[SBK_QGeoManeuver_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QGeoManeuver_PythonToCpp_QGeoManeuver_PTR,
        is_QGeoManeuver_PythonToCpp_QGeoManeuver_PTR_Convertible,
        QGeoManeuver_PTR_CppToPython_QGeoManeuver,
        QGeoManeuver_COPY_CppToPython_QGeoManeuver);

    Shiboken::Conversions::registerConverterName(converter, "QGeoManeuver");
    Shiboken::Conversions::registerConverterName(converter, "QGeoManeuver*");
    Shiboken::Conversions::registerConverterName(converter, "QGeoManeuver&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QGeoManeuver).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QGeoManeuver_PythonToCpp_QGeoManeuver_COPY,
        is_QGeoManeuver_PythonToCpp_QGeoManeuver_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QGeoManeuver_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'InstructionDirection'.
    const char *InstructionDirection_Initializer[] = {
        "NoDirection",
        "DirectionForward",
        "DirectionBearRight",
        "DirectionLightRight",
        "DirectionRight",
        "DirectionHardRight",
        "DirectionUTurnRight",
        "DirectionUTurnLeft",
        "DirectionHardLeft",
        "DirectionLeft",
        "DirectionLightLeft",
        "DirectionBearLeft",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t InstructionDirection_InitializerValues[] = {
        uint8_t(QGeoManeuver::InstructionDirection::NoDirection),         //  0x00  0
        uint8_t(QGeoManeuver::InstructionDirection::DirectionForward),    //  0x01  1
        uint8_t(QGeoManeuver::InstructionDirection::DirectionBearRight),  //  0x02  2
        uint8_t(QGeoManeuver::InstructionDirection::DirectionLightRight), //  0x03  3
        uint8_t(QGeoManeuver::InstructionDirection::DirectionRight),      //  0x04  4
        uint8_t(QGeoManeuver::InstructionDirection::DirectionHardRight),  //  0x05  5
        uint8_t(QGeoManeuver::InstructionDirection::DirectionUTurnRight), //  0x06  6
        uint8_t(QGeoManeuver::InstructionDirection::DirectionUTurnLeft),  //  0x07  7
        uint8_t(QGeoManeuver::InstructionDirection::DirectionHardLeft),   //  0x08  8
        uint8_t(QGeoManeuver::InstructionDirection::DirectionLeft),       //  0x09  9
        uint8_t(QGeoManeuver::InstructionDirection::DirectionLightLeft),  //  0x0a  10
        uint8_t(QGeoManeuver::InstructionDirection::DirectionBearLeft)    //  0x0b  11
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QGeoManeuver_TypeF(),
        "2:PySide6.QtLocation.QGeoManeuver.InstructionDirection",
        InstructionDirection_Initializer, InstructionDirection_InitializerValues);
    SbkPySide6_QtLocationTypeStructs[SBK_QGeoManeuver_InstructionDirection_IDX].type = EType;
    // Register converter for enum 'QGeoManeuver::InstructionDirection'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QGeoManeuver_InstructionDirection_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QGeoManeuver_InstructionDirection,
            is_Enum_PythonToCpp_QGeoManeuver_InstructionDirection_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QGeoManeuver::InstructionDirection");
        Shiboken::Conversions::registerConverterAlias(converter, "InstructionDirection");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'InstructionDirection' enum.

    qRegisterMetaType< ::QGeoManeuver >("QGeoManeuver");
    qRegisterMetaType< ::QGeoManeuver::InstructionDirection >("QGeoManeuver::InstructionDirection");

    return pyType;
}
