// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtlocation_python.h"

// main header
#include "qgeoroute_wrapper.h"

// Argument includes
#include <QList>
#include <QMap>
#include <QString>
#include <QtLocation/qgeoroute.h>
#include <QtLocation/qgeorouterequest.h>
#include <QtLocation/qgeoroutesegment.h>
#include <QtPositioning/qgeocoordinate.h>
#include <QtPositioning/qgeorectangle.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGeoRoute_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QGeoRoute >()))
        return -1;

    ::QGeoRoute *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QGeoRoute", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QGeoRoute::QGeoRoute()
    // 1: QGeoRoute::QGeoRoute(QGeoRoute)
    if (numArgs == 0) {
        overloadId = 0; // QGeoRoute()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QGeoRoute(QGeoRoute)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QGeoRoute()
        {

            // QGeoRoute()
            cptr = new ::QGeoRoute();
            break;
        }
        case 1: // QGeoRoute(const QGeoRoute &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QGeoRoute cppArg0_local;
            ::QGeoRoute *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QGeoRoute(QGeoRoute)
                cptr = new ::QGeoRoute(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QGeoRoute >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QGeoRouteFunc_bounds(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // bounds()const
        QGeoRectangle cppResult = const_cast<const ::QGeoRoute *>(cppSelf)->bounds();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRouteFunc_distance(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // distance()const
        qreal cppResult = const_cast<const ::QGeoRoute *>(cppSelf)->distance();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRouteFunc_extendedAttributes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // extendedAttributes()const
        QMap<QString,QVariant> cppResult = const_cast<const ::QGeoRoute *>(cppSelf)->extendedAttributes();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QMap_QString_QVariant_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRouteFunc_firstRouteSegment(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // firstRouteSegment()const
        QGeoRouteSegment cppResult = const_cast<const ::QGeoRoute *>(cppSelf)->firstRouteSegment();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteSegment_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRouteFunc_legIndex(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // legIndex()const
        int cppResult = const_cast<const ::QGeoRoute *>(cppSelf)->legIndex();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRouteFunc_overallRoute(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // overallRoute()const
        QGeoRoute cppResult = const_cast<const ::QGeoRoute *>(cppSelf)->overallRoute();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRouteFunc_path(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // path()const
        QList<QGeoCoordinate> cppResult = const_cast<const ::QGeoRoute *>(cppSelf)->path();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QList_QGeoCoordinate_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRouteFunc_request(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // request()const
        QGeoRouteRequest* cppResult = new QGeoRouteRequest(const_cast<const ::QGeoRoute *>(cppSelf)->request());
        pyResult = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]), cppResult, true, true);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRouteFunc_routeId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // routeId()const
        QString cppResult = const_cast<const ::QGeoRoute *>(cppSelf)->routeId();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRouteFunc_routeLegs(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // routeLegs()const
        QList<QGeoRoute> cppResult = const_cast<const ::QGeoRoute *>(cppSelf)->routeLegs();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QList_QGeoRoute_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRouteFunc_segments(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // segments()const
        QList<QGeoRouteSegment> cppResult = const_cast<const ::QGeoRoute *>(cppSelf)->segments();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QList_QGeoRouteSegment_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRouteFunc_segmentsCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // segmentsCount()const
        qsizetype cppResult = const_cast<const ::QGeoRoute *>(cppSelf)->segmentsCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRouteFunc_setBounds(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRoute::setBounds(QGeoRectangle)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), (pyArg)))) {
        overloadId = 0; // setBounds(QGeoRectangle)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBounds", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGeoRectangle cppArg0_local;
        ::QGeoRectangle *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setBounds(QGeoRectangle)
            cppSelf->setBounds(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRouteFunc_setDistance(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRoute::setDistance(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setDistance(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDistance", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDistance(qreal)
            cppSelf->setDistance(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRouteFunc_setExtendedAttributes(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRoute::setExtendedAttributes(QMap<QString,QVariant>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QMap_QString_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // setExtendedAttributes(QMap<QString,QVariant>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setExtendedAttributes", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]);

    // Call function/method
    {
        ::QMap<QString,QVariant> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setExtendedAttributes(QMap<QString,QVariant>)
            cppSelf->setExtendedAttributes(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRouteFunc_setFirstRouteSegment(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRoute::setFirstRouteSegment(QGeoRouteSegment)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteSegment_IDX]), (pyArg)))) {
        overloadId = 0; // setFirstRouteSegment(QGeoRouteSegment)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFirstRouteSegment", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGeoRouteSegment cppArg0_local;
        ::QGeoRouteSegment *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setFirstRouteSegment(QGeoRouteSegment)
            cppSelf->setFirstRouteSegment(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRouteFunc_setLegIndex(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRoute::setLegIndex(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setLegIndex(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLegIndex", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLegIndex(int)
            cppSelf->setLegIndex(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRouteFunc_setOverallRoute(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRoute::setOverallRoute(QGeoRoute)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), (pyArg)))) {
        overloadId = 0; // setOverallRoute(QGeoRoute)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOverallRoute", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGeoRoute cppArg0_local;
        ::QGeoRoute *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setOverallRoute(QGeoRoute)
            cppSelf->setOverallRoute(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRouteFunc_setPath(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRoute::setPath(QList<QGeoCoordinate>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QList_QGeoCoordinate_IDX], (pyArg)))) {
        overloadId = 0; // setPath(QList<QGeoCoordinate>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPath", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]);

    // Call function/method
    {
        ::QList<QGeoCoordinate> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPath(QList<QGeoCoordinate>)
            cppSelf->setPath(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRouteFunc_setRequest(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRoute::setRequest(QGeoRouteRequest)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]), (pyArg)))) {
        overloadId = 0; // setRequest(QGeoRouteRequest)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRequest", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGeoRouteRequest *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRequest(QGeoRouteRequest)
            cppSelf->setRequest(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRouteFunc_setRouteId(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRoute::setRouteId(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setRouteId(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRouteId", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRouteId(QString)
            cppSelf->setRouteId(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRouteFunc_setRouteLegs(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRoute::setRouteLegs(QList<QGeoRoute>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QList_QGeoRoute_IDX], (pyArg)))) {
        overloadId = 0; // setRouteLegs(QList<QGeoRoute>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRouteLegs", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]);

    // Call function/method
    {
        ::QList<QGeoRoute> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRouteLegs(QList<QGeoRoute>)
            cppSelf->setRouteLegs(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRouteFunc_setTravelMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRoute::setTravelMode(QGeoRouteRequest::TravelMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_TravelMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setTravelMode(QGeoRouteRequest::TravelMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTravelMode", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]);

    // Call function/method
    {
        ::QGeoRouteRequest::TravelMode cppArg0 = static_cast< ::QGeoRouteRequest::TravelMode>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTravelMode(QGeoRouteRequest::TravelMode)
            cppSelf->setTravelMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRouteFunc_setTravelTime(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRoute::setTravelTime(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setTravelTime(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTravelTime", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTravelTime(int)
            cppSelf->setTravelTime(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRouteFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRoute::swap(QGeoRoute&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QGeoRoute&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGeoRoute cppArg0_local;
        ::QGeoRoute *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QGeoRoute&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRouteFunc_travelMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // travelMode()const
        QGeoRouteRequest::TravelMode cppResult = const_cast<const ::QGeoRoute *>(cppSelf)->travelMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_TravelMode_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRouteFunc_travelTime(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // travelTime()const
        int cppResult = const_cast<const ::QGeoRoute *>(cppSelf)->travelTime();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRoute__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QGeoRoute_PropertyStrings[] = {
    "bounds:",
    "distance:",
    "extendedAttributes:",
    "legIndex:",
    "overallRoute:",
    "path::",
    "routeId:",
    "routeLegs:",
    "segments:",
    "segmentsCount:",
    "travelTime:",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QGeoRoute_methods[] = {
    {"bounds", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_bounds), METH_NOARGS, nullptr},
    {"distance", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_distance), METH_NOARGS, nullptr},
    {"extendedAttributes", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_extendedAttributes), METH_NOARGS, nullptr},
    {"firstRouteSegment", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_firstRouteSegment), METH_NOARGS, nullptr},
    {"legIndex", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_legIndex), METH_NOARGS, nullptr},
    {"overallRoute", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_overallRoute), METH_NOARGS, nullptr},
    {"path", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_path), METH_NOARGS, nullptr},
    {"request", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_request), METH_NOARGS, nullptr},
    {"routeId", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_routeId), METH_NOARGS, nullptr},
    {"routeLegs", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_routeLegs), METH_NOARGS, nullptr},
    {"segments", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_segments), METH_NOARGS, nullptr},
    {"segmentsCount", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_segmentsCount), METH_NOARGS, nullptr},
    {"setBounds", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_setBounds), METH_O, nullptr},
    {"setDistance", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_setDistance), METH_O, nullptr},
    {"setExtendedAttributes", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_setExtendedAttributes), METH_O, nullptr},
    {"setFirstRouteSegment", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_setFirstRouteSegment), METH_O, nullptr},
    {"setLegIndex", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_setLegIndex), METH_O, nullptr},
    {"setOverallRoute", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_setOverallRoute), METH_O, nullptr},
    {"setPath", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_setPath), METH_O, nullptr},
    {"setRequest", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_setRequest), METH_O, nullptr},
    {"setRouteId", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_setRouteId), METH_O, nullptr},
    {"setRouteLegs", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_setRouteLegs), METH_O, nullptr},
    {"setTravelMode", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_setTravelMode), METH_O, nullptr},
    {"setTravelTime", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_setTravelTime), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_swap), METH_O, nullptr},
    {"travelMode", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_travelMode), METH_NOARGS, nullptr},
    {"travelTime", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_travelTime), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QGeoRoute__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QGeoRoute_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), (pyArg)))) {
                // operator!=(const QGeoRoute &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QGeoRoute cppArg0_local;
                ::QGeoRoute *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), (pyArg)))) {
                // operator==(const QGeoRoute &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QGeoRoute cppArg0_local;
                ::QGeoRoute *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QGeoRoute_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QGeoRoute_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QGeoRoute_Type = nullptr;
static PyTypeObject *Sbk_QGeoRoute_TypeF(void)
{
    return _Sbk_QGeoRoute_Type;
}

static PyType_Slot Sbk_QGeoRoute_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QGeoRoute_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QGeoRoute_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QGeoRoute_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QGeoRoute_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QGeoRoute_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QGeoRoute_spec = {
    "2:PySide6.QtLocation.QGeoRoute",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QGeoRoute_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QGeoRoute_PythonToCpp_QGeoRoute_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QGeoRoute_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QGeoRoute_PythonToCpp_QGeoRoute_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QGeoRoute_TypeF()))
        return QGeoRoute_PythonToCpp_QGeoRoute_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QGeoRoute_PTR_CppToPython_QGeoRoute(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QGeoRoute_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QGeoRoute_COPY_CppToPython_QGeoRoute(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QGeoRoute *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QGeoRoute_TypeF(), new ::QGeoRoute(*source), true, true);
}

// Python to C++ copy conversion.
static void QGeoRoute_PythonToCpp_QGeoRoute_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QGeoRoute *>(cppOut) = *reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QGeoRoute_PythonToCpp_QGeoRoute_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QGeoRoute_TypeF()))
        return QGeoRoute_PythonToCpp_QGeoRoute_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QGeoRoute_SignatureStrings[] = {
    "1:PySide6.QtLocation.QGeoRoute(self,*:KeywordOnly=None,routeId:QString=None,bounds:QGeoRectangle=None,travelTime:int=None,distance:qreal=None,path:QList[PySide6.QtPositioning.QGeoCoordinate]=None,routeLegs:QList[PySide6.QtLocation.QGeoRoute]=None,extendedAttributes:QMap[QString, QVariant]=None,legIndex:int=None,overallRoute:QGeoRoute=None,segmentsCount:qsizetype=None,segments:QList[PySide6.QtLocation.QGeoRouteSegment]=None)",
    "0:PySide6.QtLocation.QGeoRoute(self,other:PySide6.QtLocation.QGeoRoute,*:KeywordOnly=None,routeId:QString=None,bounds:QGeoRectangle=None,travelTime:int=None,distance:qreal=None,path:QList[PySide6.QtPositioning.QGeoCoordinate]=None,routeLegs:QList[PySide6.QtLocation.QGeoRoute]=None,extendedAttributes:QMap[QString, QVariant]=None,legIndex:int=None,overallRoute:QGeoRoute=None,segmentsCount:qsizetype=None,segments:QList[PySide6.QtLocation.QGeoRouteSegment]=None)",
    "PySide6.QtLocation.QGeoRoute.bounds(self)->PySide6.QtPositioning.QGeoRectangle",
    "PySide6.QtLocation.QGeoRoute.distance(self)->qreal",
    "PySide6.QtLocation.QGeoRoute.extendedAttributes(self)->QMap[QString, QVariant]",
    "PySide6.QtLocation.QGeoRoute.firstRouteSegment(self)->PySide6.QtLocation.QGeoRouteSegment",
    "PySide6.QtLocation.QGeoRoute.legIndex(self)->int",
    "PySide6.QtLocation.QGeoRoute.overallRoute(self)->PySide6.QtLocation.QGeoRoute",
    "PySide6.QtLocation.QGeoRoute.path(self)->QList[PySide6.QtPositioning.QGeoCoordinate]",
    "PySide6.QtLocation.QGeoRoute.request(self)->PySide6.QtLocation.QGeoRouteRequest",
    "PySide6.QtLocation.QGeoRoute.routeId(self)->QString",
    "PySide6.QtLocation.QGeoRoute.routeLegs(self)->QList[PySide6.QtLocation.QGeoRoute]",
    "PySide6.QtLocation.QGeoRoute.segments(self)->QList[PySide6.QtLocation.QGeoRouteSegment]",
    "PySide6.QtLocation.QGeoRoute.segmentsCount(self)->qsizetype",
    "PySide6.QtLocation.QGeoRoute.setBounds(self,bounds:typing.Union[PySide6.QtPositioning.QGeoRectangle, PySide6.QtPositioning.QGeoShape, QList[PySide6.QtPositioning.QGeoCoordinate]])",
    "PySide6.QtLocation.QGeoRoute.setDistance(self,distance:qreal)",
    "PySide6.QtLocation.QGeoRoute.setExtendedAttributes(self,extendedAttributes:QMap[QString, QVariant])",
    "PySide6.QtLocation.QGeoRoute.setFirstRouteSegment(self,routeSegment:PySide6.QtLocation.QGeoRouteSegment)",
    "PySide6.QtLocation.QGeoRoute.setLegIndex(self,idx:int)",
    "PySide6.QtLocation.QGeoRoute.setOverallRoute(self,route:PySide6.QtLocation.QGeoRoute)",
    "PySide6.QtLocation.QGeoRoute.setPath(self,path:QList[PySide6.QtPositioning.QGeoCoordinate])",
    "PySide6.QtLocation.QGeoRoute.setRequest(self,request:PySide6.QtLocation.QGeoRouteRequest)",
    "PySide6.QtLocation.QGeoRoute.setRouteId(self,id:QString)",
    "PySide6.QtLocation.QGeoRoute.setRouteLegs(self,legs:QList[PySide6.QtLocation.QGeoRoute])",
    "PySide6.QtLocation.QGeoRoute.setTravelMode(self,mode:PySide6.QtLocation.QGeoRouteRequest.TravelMode)",
    "PySide6.QtLocation.QGeoRoute.setTravelTime(self,secs:int)",
    "PySide6.QtLocation.QGeoRoute.swap(self,other:PySide6.QtLocation.QGeoRoute)",
    "PySide6.QtLocation.QGeoRoute.travelMode(self)->PySide6.QtLocation.QGeoRouteRequest.TravelMode",
    "PySide6.QtLocation.QGeoRoute.travelTime(self)->int",
    "PySide6.QtLocation.QGeoRoute.__copy__(self)->typing.Self",
    "PySide6.QtLocation.QGeoRoute.__ne__(self,rhs:PySide6.QtLocation.QGeoRoute)->bool",
    "PySide6.QtLocation.QGeoRoute.__eq__(self,rhs:PySide6.QtLocation.QGeoRoute)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QGeoRoute_SignatureByteSize = 583;
static constexpr uint8_t QGeoRoute_SignatureBytes[583] = {
    0x78, 0xda, 0xed, 0x56, 0x3d, 0x6f, 0xdb, 0x30, 0x10, 0xdd, 0xfb, 0x2b, 0x32, 0xd6, 0x81, 0x62,
    0xb4, 0x4b, 0x06, 0x02, 0x0d, 0xd0, 0xa6, 0x1f, 0x08, 0xe2, 0x24, 0x96, 0x95, 0x76, 0x31, 0x02,
    0x83, 0x96, 0x2e, 0x32, 0x01, 0x99, 0x94, 0x49, 0x3a, 0x89, 0xfa, 0xeb, 0x4b, 0x89, 0xa2, 0xac,
    0xda, 0x16, 0x79, 0xde, 0x3a, 0x74, 0xb3, 0xc9, 0x7b, 0x8f, 0xef, 0xee, 0x78, 0x8f, 0xfa, 0x48,
    0xa6, 0x55, 0xc2, 0x32, 0xb8, 0x1c, 0xc7, 0x7a, 0x22, 0x52, 0xaa, 0x99, 0xe0, 0xe3, 0xf8, 0x07,
    0x88, 0x99, 0xd8, 0x6a, 0x78, 0xaf, 0xa0, 0x78, 0x8e, 0xce, 0xc9, 0x2d, 0x54, 0xaf, 0x42, 0x66,
    0x0f, 0xbc, 0xa8, 0x3e, 0xdd, 0x0b, 0x0e, 0x91, 0xac, 0x77, 0x6f, 0x32, 0x12, 0x27, 0x5a, 0x32,
    0x9e, 0xdb, 0xc5, 0xa5, 0xd8, 0xf2, 0x4c, 0x91, 0x06, 0x0d, 0xa9, 0xa6, 0x3c, 0x2f, 0xc0, 0xee,
    0x68, 0x49, 0x5f, 0xa0, 0x78, 0x64, 0x6b, 0x20, 0x8c, 0x6b, 0xbb, 0x96, 0x31, 0x65, 0x42, 0x52,
    0x20, 0x1b, 0x09, 0xb4, 0xb0, 0x6b, 0x25, 0xd5, 0x2b, 0x12, 0x4f, 0xcc, 0xce, 0x7c, 0x27, 0x6b,
    0x2a, 0x14, 0xab, 0x65, 0x99, 0x73, 0x1a, 0x65, 0xd7, 0xc2, 0x48, 0x61, 0x9c, 0x6a, 0x78, 0xea,
    0x89, 0x99, 0x40, 0xae, 0x0e, 0xa0, 0x87, 0x19, 0xb5, 0x10, 0x78, 0xd3, 0xc0, 0x33, 0xc8, 0x3e,
    0x6b, 0xa3, 0x7f, 0x69, 0xd6, 0x0d, 0xf6, 0x8e, 0x96, 0xf3, 0x36, 0x9f, 0xe8, 0x2c, 0xfe, 0x45,
    0x25, 0xa3, 0x5c, 0xb7, 0xf1, 0x05, 0xe4, 0x37, 0x26, 0xfe, 0x6d, 0x27, 0x5f, 0xbc, 0x80, 0xa4,
    0x45, 0xd1, 0x90, 0x92, 0x8e, 0xde, 0xee, 0x29, 0xc8, 0xd7, 0xc0, 0xb5, 0xba, 0x36, 0x05, 0xd1,
    0x64, 0xa3, 0xd8, 0x6f, 0xd0, 0x55, 0xb9, 0xb7, 0x89, 0x10, 0x9b, 0xd8, 0x50, 0xab, 0x61, 0xf4,
    0xee, 0x03, 0xa2, 0x57, 0x42, 0xaf, 0x40, 0x7a, 0xe3, 0xfe, 0xb7, 0xf3, 0x1f, 0x69, 0xa7, 0x2f,
    0x74, 0x6c, 0x8b, 0xdf, 0xf4, 0x74, 0x74, 0x71, 0x35, 0x5c, 0xbd, 0xae, 0x33, 0x7e, 0x3a, 0xd7,
    0x1d, 0x47, 0xd8, 0x34, 0xc9, 0x0f, 0x39, 0xac, 0xa9, 0x03, 0x0f, 0x94, 0xd6, 0x4f, 0xf7, 0xcc,
    0xa4, 0xd2, 0xfd, 0x32, 0x1c, 0xe6, 0x36, 0x58, 0x31, 0x3f, 0xb3, 0x6b, 0xa6, 0x23, 0x64, 0x21,
    0x40, 0xbf, 0xd7, 0x18, 0x15, 0x7e, 0xb6, 0xfa, 0x92, 0x77, 0x95, 0xc1, 0xdf, 0x75, 0x3f, 0xa9,
    0x84, 0xcd, 0x16, 0x14, 0xaa, 0x46, 0x33, 0x1b, 0x1a, 0xe0, 0xb3, 0x03, 0xde, 0xe9, 0xb4, 0xcd,
    0x43, 0x60, 0xea, 0x39, 0x1c, 0xca, 0xee, 0xc8, 0x38, 0xfa, 0x19, 0xdd, 0xac, 0xe0, 0x09, 0xdd,
    0xc8, 0xe0, 0x78, 0x9b, 0x01, 0xed, 0xae, 0xb8, 0x9b, 0xd3, 0x10, 0x56, 0x7f, 0xd9, 0xcd, 0x9a,
    0x33, 0x3d, 0x83, 0xab, 0x7b, 0xf6, 0x93, 0x9b, 0xe0, 0x39, 0x62, 0xfa, 0xa2, 0xb3, 0xe1, 0xa0,
    0x64, 0x45, 0x4b, 0x13, 0x70, 0xc2, 0xdd, 0x78, 0x1a, 0x05, 0x35, 0x7f, 0xed, 0x0f, 0xf4, 0x9e,
    0xf9, 0x86, 0xd1, 0xdf, 0x8e, 0xcf, 0xf6, 0x09, 0x3e, 0x1a, 0x3e, 0xe3, 0xfb, 0xd1, 0x81, 0xb7,
    0xee, 0xde, 0xae, 0x10, 0x44, 0xeb, 0xc3, 0x07, 0x4d, 0xfa, 0xf3, 0x1f, 0xb1, 0xac, 0x71, 0xf5,
    0x30, 0xec, 0x61, 0xdf, 0x05, 0xac, 0x34, 0xaf, 0xa6, 0x30, 0xeb, 0xd4, 0xb9, 0xc1, 0xc9, 0x8f,
    0x5f, 0x98, 0x7b, 0xd6, 0x33, 0x85, 0xa8, 0x75, 0x08, 0x82, 0xb0, 0x06, 0x04, 0x73, 0xcf, 0x1e,
    0x4c, 0x05, 0xdd, 0x77, 0x00, 0x12, 0xd8, 0x79, 0x44, 0xfd, 0xae, 0xa2, 0x5e, 0xed, 0x30, 0xf1,
    0x63, 0xf3, 0x89, 0x71, 0x27, 0xb2, 0xb6, 0x37, 0x6b, 0xf3, 0x0b, 0x93, 0xeb, 0x78, 0x07, 0xc4,
    0x1e, 0x52, 0x7f, 0xc7, 0xd8, 0x43, 0x14, 0xa4, 0x0a, 0x73, 0x79, 0x5e, 0x69, 0x89, 0xfd, 0xda,
    0x0a, 0x50, 0xe9, 0xbf, 0xd3, 0xc4, 0x59, 0x7d, 0x2f, 0x47, 0x0c, 0x7b, 0x97, 0x1f, 0xe6, 0x6d,
    0x5c, 0x2c, 0x52, 0x51, 0x56, 0x8b, 0x85, 0x03, 0xb4, 0x46, 0x98, 0x98, 0x7f, 0x21, 0x20, 0x87,
    0x16, 0x16, 0xc9, 0x95, 0xf2, 0x17, 0xe5, 0xe2, 0x6a, 0x29, 0x44, 0x11, 0x22, 0x84, 0xcd, 0xa9,
    0x84, 0x7f, 0x00, 0x82, 0x55, 0xb5, 0x92
};
#endif

PyTypeObject *init_QGeoRoute(PyObject *module)
{
    if (SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX].type != nullptr)
        return SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX].type;

    Shiboken::AutoDecRef Sbk_QGeoRoute_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QGeoRoute_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QGeoRoute",
        "QGeoRoute",
        &Sbk_QGeoRoute_spec,
        &Shiboken::callCppDestructor< ::QGeoRoute >,
        Sbk_QGeoRoute_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QGeoRoute_TypeF(); // references _Sbk_QGeoRoute_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QGeoRoute_SignatureStrings);
#else
    InitSignatureBytes(pyType, QGeoRoute_SignatureBytes, QGeoRoute_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QGeoRoute_PropertyStrings);
    SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QGeoRoute_PythonToCpp_QGeoRoute_PTR,
        is_QGeoRoute_PythonToCpp_QGeoRoute_PTR_Convertible,
        QGeoRoute_PTR_CppToPython_QGeoRoute,
        QGeoRoute_COPY_CppToPython_QGeoRoute);

    Shiboken::Conversions::registerConverterName(converter, "QGeoRoute");
    Shiboken::Conversions::registerConverterName(converter, "QGeoRoute*");
    Shiboken::Conversions::registerConverterName(converter, "QGeoRoute&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QGeoRoute).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QGeoRoute_PythonToCpp_QGeoRoute_COPY,
        is_QGeoRoute_PythonToCpp_QGeoRoute_COPY_Convertible);

    qRegisterMetaType< ::QGeoRoute >("QGeoRoute");

    return pyType;
}
