// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtlocation_python.h"

// main header
#include "qgeorouterequest_wrapper.h"

// Argument includes
#include <QList>
#include <QtLocation/qgeorouterequest.h>
#include <QtPositioning/qgeocoordinate.h>
#include <QtPositioning/qgeorectangle.h>
#include <qdatetime.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGeoRouteRequest_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QGeoRouteRequest >()))
        return -1;

    ::QGeoRouteRequest *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]);

    if (PyArg_ParseTuple(args, "|OO:QGeoRouteRequest", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QGeoRouteRequest::QGeoRouteRequest(QGeoCoordinate,QGeoCoordinate)
    // 1: QGeoRouteRequest::QGeoRouteRequest(QGeoRouteRequest)
    // 2: QGeoRouteRequest::QGeoRouteRequest(const QList<QGeoCoordinate>&=)
    if (numArgs == 0) {
        overloadId = 2; // QGeoRouteRequest(QList<QGeoCoordinate>)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QGeoRouteRequest(QGeoRouteRequest)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), (pyArgs[1])))) {
        overloadId = 0; // QGeoRouteRequest(QGeoCoordinate,QGeoCoordinate)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QList_QGeoCoordinate_IDX], (pyArgs[0])))) {
        overloadId = 2; // QGeoRouteRequest(QList<QGeoCoordinate>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QGeoRouteRequest(const QGeoCoordinate &origin, const QGeoCoordinate &destination)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QGeoCoordinate cppArg0_local;
            ::QGeoCoordinate *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QGeoCoordinate cppArg1_local;
            ::QGeoCoordinate *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QGeoRouteRequest(QGeoCoordinate,QGeoCoordinate)
                cptr = new ::QGeoRouteRequest(*cppArg0, *cppArg1);
            }
            break;
        }
        case 1: // QGeoRouteRequest(const QGeoRouteRequest &other)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QGeoRouteRequest *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QGeoRouteRequest(QGeoRouteRequest)
                cptr = new ::QGeoRouteRequest(*cppArg0);
            }
            break;
        }
        case 2: // QGeoRouteRequest(const QList<QGeoCoordinate> &waypoints)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_waypoints = Shiboken::String::createStaticString("waypoints");
                if (PyDict_Contains(kwds, key_waypoints) != 0) {
                    value = PyDict_GetItem(kwds, key_waypoints);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_waypoints);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QList_QGeoCoordinate_IDX], (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_waypoints);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]);
                }
            }
            ::QList<QGeoCoordinate> cppArg0 = QList<QGeoCoordinate>();
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QGeoRouteRequest(QList<QGeoCoordinate>)
                cptr = new ::QGeoRouteRequest(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QGeoRouteRequest >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QGeoRouteRequestFunc_departureTime(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRouteRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // departureTime()const
        QDateTime cppResult = const_cast<const ::QGeoRouteRequest *>(cppSelf)->departureTime();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRouteRequestFunc_excludeAreas(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRouteRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // excludeAreas()const
        QList<QGeoRectangle> cppResult = const_cast<const ::QGeoRouteRequest *>(cppSelf)->excludeAreas();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QList_QGeoRectangle_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRouteRequestFunc_featureTypes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRouteRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // featureTypes()const
        QList<QGeoRouteRequest::FeatureType> cppResult = const_cast<const ::QGeoRouteRequest *>(cppSelf)->featureTypes();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QList_QGeoRouteRequest_FeatureType_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRouteRequestFunc_featureWeight(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRouteRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRouteRequest::featureWeight(QGeoRouteRequest::FeatureType)const->QGeoRouteRequest::FeatureWeight
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_FeatureType_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // featureWeight(QGeoRouteRequest::FeatureType)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "featureWeight", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]);

    // Call function/method
    {
        ::QGeoRouteRequest::FeatureType cppArg0{QGeoRouteRequest::NoFeature};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // featureWeight(QGeoRouteRequest::FeatureType)const
            QGeoRouteRequest::FeatureWeight cppResult = const_cast<const ::QGeoRouteRequest *>(cppSelf)->featureWeight(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_FeatureWeight_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRouteRequestFunc_maneuverDetail(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRouteRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maneuverDetail()const
        QGeoRouteRequest::ManeuverDetail cppResult = const_cast<const ::QGeoRouteRequest *>(cppSelf)->maneuverDetail();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_ManeuverDetail_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRouteRequestFunc_numberAlternativeRoutes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRouteRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // numberAlternativeRoutes()const
        int cppResult = const_cast<const ::QGeoRouteRequest *>(cppSelf)->numberAlternativeRoutes();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRouteRequestFunc_routeOptimization(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRouteRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // routeOptimization()const
        QFlags<QGeoRouteRequest::RouteOptimization> cppResult = const_cast<const ::QGeoRouteRequest *>(cppSelf)->routeOptimization();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QFlags_QGeoRouteRequest_RouteOptimization_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRouteRequestFunc_segmentDetail(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRouteRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // segmentDetail()const
        QGeoRouteRequest::SegmentDetail cppResult = const_cast<const ::QGeoRouteRequest *>(cppSelf)->segmentDetail();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_SegmentDetail_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRouteRequestFunc_setDepartureTime(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRouteRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRouteRequest::setDepartureTime(QDateTime)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // setDepartureTime(QDateTime)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDepartureTime", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setDepartureTime(QDateTime)
            cppSelf->setDepartureTime(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRouteRequestFunc_setExcludeAreas(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRouteRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRouteRequest::setExcludeAreas(QList<QGeoRectangle>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QList_QGeoRectangle_IDX], (pyArg)))) {
        overloadId = 0; // setExcludeAreas(QList<QGeoRectangle>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setExcludeAreas", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]);

    // Call function/method
    {
        ::QList<QGeoRectangle> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setExcludeAreas(QList<QGeoRectangle>)
            cppSelf->setExcludeAreas(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRouteRequestFunc_setFeatureWeight(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRouteRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setFeatureWeight", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGeoRouteRequest::setFeatureWeight(QGeoRouteRequest::FeatureType,QGeoRouteRequest::FeatureWeight)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_FeatureType_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_FeatureWeight_IDX])))->converter, (pyArgs[1])))) {
        overloadId = 0; // setFeatureWeight(QGeoRouteRequest::FeatureType,QGeoRouteRequest::FeatureWeight)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setFeatureWeight", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]);

    // Call function/method
    {
        ::QGeoRouteRequest::FeatureType cppArg0{QGeoRouteRequest::NoFeature};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QGeoRouteRequest::FeatureWeight cppArg1{QGeoRouteRequest::NeutralFeatureWeight};
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFeatureWeight(QGeoRouteRequest::FeatureType,QGeoRouteRequest::FeatureWeight)
            cppSelf->setFeatureWeight(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRouteRequestFunc_setManeuverDetail(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRouteRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRouteRequest::setManeuverDetail(QGeoRouteRequest::ManeuverDetail)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_ManeuverDetail_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setManeuverDetail(QGeoRouteRequest::ManeuverDetail)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setManeuverDetail", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]);

    // Call function/method
    {
        ::QGeoRouteRequest::ManeuverDetail cppArg0{QGeoRouteRequest::NoManeuvers};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setManeuverDetail(QGeoRouteRequest::ManeuverDetail)
            cppSelf->setManeuverDetail(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRouteRequestFunc_setNumberAlternativeRoutes(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRouteRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRouteRequest::setNumberAlternativeRoutes(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setNumberAlternativeRoutes(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setNumberAlternativeRoutes", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setNumberAlternativeRoutes(int)
            cppSelf->setNumberAlternativeRoutes(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRouteRequestFunc_setRouteOptimization(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRouteRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRouteRequest::setRouteOptimization(QFlags<QGeoRouteRequest::RouteOptimization>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QFlags_QGeoRouteRequest_RouteOptimization_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setRouteOptimization(QFlags<QGeoRouteRequest::RouteOptimization>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRouteOptimization", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]);

    // Call function/method
    {
        ::QFlags<QGeoRouteRequest::RouteOptimization> cppArg0 = QFlags<QGeoRouteRequest::RouteOptimization>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRouteOptimization(QFlags<QGeoRouteRequest::RouteOptimization>)
            cppSelf->setRouteOptimization(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRouteRequestFunc_setSegmentDetail(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRouteRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRouteRequest::setSegmentDetail(QGeoRouteRequest::SegmentDetail)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_SegmentDetail_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setSegmentDetail(QGeoRouteRequest::SegmentDetail)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSegmentDetail", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]);

    // Call function/method
    {
        ::QGeoRouteRequest::SegmentDetail cppArg0{QGeoRouteRequest::NoSegmentData};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSegmentDetail(QGeoRouteRequest::SegmentDetail)
            cppSelf->setSegmentDetail(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRouteRequestFunc_setTravelModes(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRouteRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRouteRequest::setTravelModes(QFlags<QGeoRouteRequest::TravelMode>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QFlags_QGeoRouteRequest_TravelMode_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setTravelModes(QFlags<QGeoRouteRequest::TravelMode>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTravelModes", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]);

    // Call function/method
    {
        ::QFlags<QGeoRouteRequest::TravelMode> cppArg0 = QFlags<QGeoRouteRequest::TravelMode>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTravelModes(QFlags<QGeoRouteRequest::TravelMode>)
            cppSelf->setTravelModes(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRouteRequestFunc_setWaypoints(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRouteRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRouteRequest::setWaypoints(QList<QGeoCoordinate>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QList_QGeoCoordinate_IDX], (pyArg)))) {
        overloadId = 0; // setWaypoints(QList<QGeoCoordinate>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setWaypoints", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]);

    // Call function/method
    {
        ::QList<QGeoCoordinate> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setWaypoints(QList<QGeoCoordinate>)
            cppSelf->setWaypoints(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRouteRequestFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRouteRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRouteRequest::swap(QGeoRouteRequest&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QGeoRouteRequest&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGeoRouteRequest *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QGeoRouteRequest&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRouteRequestFunc_travelModes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRouteRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // travelModes()const
        QFlags<QGeoRouteRequest::TravelMode> cppResult = const_cast<const ::QGeoRouteRequest *>(cppSelf)->travelModes();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QFlags_QGeoRouteRequest_TravelMode_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRouteRequestFunc_waypoints(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRouteRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // waypoints()const
        QList<QGeoCoordinate> cppResult = const_cast<const ::QGeoRouteRequest *>(cppSelf)->waypoints();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QList_QGeoCoordinate_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QGeoRouteRequest_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QGeoRouteRequest_EnumFlagInfo[] = {
    "FeatureType:Flag:FeatureTypes",
    "FeatureWeight:Flag:FeatureWeights",
    "ManeuverDetail:Flag:ManeuverDetails",
    "RouteOptimization:Flag:RouteOptimizations",
    "SegmentDetail:Flag:SegmentDetails",
    "TravelMode:Flag:TravelModes",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QGeoRouteRequest_methods[] = {
    {"departureTime", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteRequestFunc_departureTime), METH_NOARGS, nullptr},
    {"excludeAreas", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteRequestFunc_excludeAreas), METH_NOARGS, nullptr},
    {"featureTypes", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteRequestFunc_featureTypes), METH_NOARGS, nullptr},
    {"featureWeight", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteRequestFunc_featureWeight), METH_O, nullptr},
    {"maneuverDetail", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteRequestFunc_maneuverDetail), METH_NOARGS, nullptr},
    {"numberAlternativeRoutes", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteRequestFunc_numberAlternativeRoutes), METH_NOARGS, nullptr},
    {"routeOptimization", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteRequestFunc_routeOptimization), METH_NOARGS, nullptr},
    {"segmentDetail", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteRequestFunc_segmentDetail), METH_NOARGS, nullptr},
    {"setDepartureTime", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteRequestFunc_setDepartureTime), METH_O, nullptr},
    {"setExcludeAreas", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteRequestFunc_setExcludeAreas), METH_O, nullptr},
    {"setFeatureWeight", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteRequestFunc_setFeatureWeight), METH_VARARGS, nullptr},
    {"setManeuverDetail", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteRequestFunc_setManeuverDetail), METH_O, nullptr},
    {"setNumberAlternativeRoutes", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteRequestFunc_setNumberAlternativeRoutes), METH_O, nullptr},
    {"setRouteOptimization", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteRequestFunc_setRouteOptimization), METH_O, nullptr},
    {"setSegmentDetail", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteRequestFunc_setSegmentDetail), METH_O, nullptr},
    {"setTravelModes", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteRequestFunc_setTravelModes), METH_O, nullptr},
    {"setWaypoints", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteRequestFunc_setWaypoints), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteRequestFunc_swap), METH_O, nullptr},
    {"travelModes", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteRequestFunc_travelModes), METH_NOARGS, nullptr},
    {"waypoints", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteRequestFunc_waypoints), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QGeoRouteRequest_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QGeoRouteRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]), (pyArg)))) {
                // operator!=(const QGeoRouteRequest &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QGeoRouteRequest *cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]), (pyArg)))) {
                // operator==(const QGeoRouteRequest &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QGeoRouteRequest *cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QGeoRouteRequest_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QGeoRouteRequest_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QGeoRouteRequest_Type = nullptr;
static PyTypeObject *Sbk_QGeoRouteRequest_TypeF(void)
{
    return _Sbk_QGeoRouteRequest_Type;
}

static PyType_Slot Sbk_QGeoRouteRequest_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QGeoRouteRequest_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QGeoRouteRequest_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QGeoRouteRequest_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QGeoRouteRequest_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QGeoRouteRequest_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QGeoRouteRequest_spec = {
    "2:PySide6.QtLocation.QGeoRouteRequest",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QGeoRouteRequest_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QGeoRouteRequest_TravelMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QGeoRouteRequest::TravelMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QGeoRouteRequest::TravelMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QGeoRouteRequest_TravelMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_TravelMode_IDX])))
        return Enum_PythonToCpp_QGeoRouteRequest_TravelMode;
    return {};
}

static PyObject *QGeoRouteRequest_TravelMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QGeoRouteRequest::TravelMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QGeoRouteRequest::TravelMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_TravelMode_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QGeoRouteRequest_TravelMode(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QGeoRouteRequest::TravelMode>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QGeoRouteRequest::TravelMode> *>(cppOut) = value;

}

static PyObject *QGeoRouteRequest_TravelMode_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QGeoRouteRequest::TravelMode> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_TravelMode_IDX]), flags.toInt());

}

static void Enum_PythonToCpp_QGeoRouteRequest_FeatureType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QGeoRouteRequest::FeatureType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QGeoRouteRequest::FeatureType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QGeoRouteRequest_FeatureType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_FeatureType_IDX])))
        return Enum_PythonToCpp_QGeoRouteRequest_FeatureType;
    return {};
}

static PyObject *QGeoRouteRequest_FeatureType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QGeoRouteRequest::FeatureType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QGeoRouteRequest::FeatureType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_FeatureType_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QGeoRouteRequest_FeatureType(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QGeoRouteRequest::FeatureType>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QGeoRouteRequest::FeatureType> *>(cppOut) = value;

}

static PyObject *QGeoRouteRequest_FeatureType_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QGeoRouteRequest::FeatureType> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_FeatureType_IDX]), flags.toInt());

}

static void Enum_PythonToCpp_QGeoRouteRequest_FeatureWeight(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QGeoRouteRequest::FeatureWeight>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QGeoRouteRequest::FeatureWeight *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QGeoRouteRequest_FeatureWeight_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_FeatureWeight_IDX])))
        return Enum_PythonToCpp_QGeoRouteRequest_FeatureWeight;
    return {};
}

static PyObject *QGeoRouteRequest_FeatureWeight_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QGeoRouteRequest::FeatureWeight>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QGeoRouteRequest::FeatureWeight *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_FeatureWeight_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QGeoRouteRequest_FeatureWeight(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QGeoRouteRequest::FeatureWeight>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QGeoRouteRequest::FeatureWeight> *>(cppOut) = value;

}

static PyObject *QGeoRouteRequest_FeatureWeight_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QGeoRouteRequest::FeatureWeight> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_FeatureWeight_IDX]), flags.toInt());

}

static void Enum_PythonToCpp_QGeoRouteRequest_RouteOptimization(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QGeoRouteRequest::RouteOptimization>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QGeoRouteRequest::RouteOptimization *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QGeoRouteRequest_RouteOptimization_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_RouteOptimization_IDX])))
        return Enum_PythonToCpp_QGeoRouteRequest_RouteOptimization;
    return {};
}

static PyObject *QGeoRouteRequest_RouteOptimization_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QGeoRouteRequest::RouteOptimization>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QGeoRouteRequest::RouteOptimization *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_RouteOptimization_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QGeoRouteRequest_RouteOptimization(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QGeoRouteRequest::RouteOptimization>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QGeoRouteRequest::RouteOptimization> *>(cppOut) = value;

}

static PyObject *QGeoRouteRequest_RouteOptimization_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QGeoRouteRequest::RouteOptimization> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_RouteOptimization_IDX]), flags.toInt());

}

static void Enum_PythonToCpp_QGeoRouteRequest_SegmentDetail(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QGeoRouteRequest::SegmentDetail>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QGeoRouteRequest::SegmentDetail *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QGeoRouteRequest_SegmentDetail_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_SegmentDetail_IDX])))
        return Enum_PythonToCpp_QGeoRouteRequest_SegmentDetail;
    return {};
}

static PyObject *QGeoRouteRequest_SegmentDetail_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QGeoRouteRequest::SegmentDetail>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QGeoRouteRequest::SegmentDetail *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_SegmentDetail_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QGeoRouteRequest_SegmentDetail(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QGeoRouteRequest::SegmentDetail>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QGeoRouteRequest::SegmentDetail> *>(cppOut) = value;

}

static PyObject *QGeoRouteRequest_SegmentDetail_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QGeoRouteRequest::SegmentDetail> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_SegmentDetail_IDX]), flags.toInt());

}

static void Enum_PythonToCpp_QGeoRouteRequest_ManeuverDetail(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QGeoRouteRequest::ManeuverDetail>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QGeoRouteRequest::ManeuverDetail *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QGeoRouteRequest_ManeuverDetail_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_ManeuverDetail_IDX])))
        return Enum_PythonToCpp_QGeoRouteRequest_ManeuverDetail;
    return {};
}

static PyObject *QGeoRouteRequest_ManeuverDetail_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QGeoRouteRequest::ManeuverDetail>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QGeoRouteRequest::ManeuverDetail *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_ManeuverDetail_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QGeoRouteRequest_ManeuverDetail(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QGeoRouteRequest::ManeuverDetail>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QGeoRouteRequest::ManeuverDetail> *>(cppOut) = value;

}

static PyObject *QGeoRouteRequest_ManeuverDetail_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QGeoRouteRequest::ManeuverDetail> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_ManeuverDetail_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QGeoRouteRequest_PythonToCpp_QGeoRouteRequest_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QGeoRouteRequest_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QGeoRouteRequest_PythonToCpp_QGeoRouteRequest_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QGeoRouteRequest_TypeF()))
        return QGeoRouteRequest_PythonToCpp_QGeoRouteRequest_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QGeoRouteRequest_PTR_CppToPython_QGeoRouteRequest(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QGeoRouteRequest_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QGeoRouteRequest_SignatureStrings[] = {
    "2:PySide6.QtLocation.QGeoRouteRequest(self,origin:PySide6.QtPositioning.QGeoCoordinate,destination:PySide6.QtPositioning.QGeoCoordinate)",
    "1:PySide6.QtLocation.QGeoRouteRequest(self,other:PySide6.QtLocation.QGeoRouteRequest)",
    "0:PySide6.QtLocation.QGeoRouteRequest(self,waypoints:QList[PySide6.QtPositioning.QGeoCoordinate]=QList<QGeoCoordinate>())",
    "PySide6.QtLocation.QGeoRouteRequest.departureTime(self)->PySide6.QtCore.QDateTime",
    "PySide6.QtLocation.QGeoRouteRequest.excludeAreas(self)->QList[PySide6.QtPositioning.QGeoRectangle]",
    "PySide6.QtLocation.QGeoRouteRequest.featureTypes(self)->QList[PySide6.QtLocation.QGeoRouteRequest.FeatureType]",
    "PySide6.QtLocation.QGeoRouteRequest.featureWeight(self,featureType:PySide6.QtLocation.QGeoRouteRequest.FeatureType)->PySide6.QtLocation.QGeoRouteRequest.FeatureWeight",
    "PySide6.QtLocation.QGeoRouteRequest.maneuverDetail(self)->PySide6.QtLocation.QGeoRouteRequest.ManeuverDetail",
    "PySide6.QtLocation.QGeoRouteRequest.numberAlternativeRoutes(self)->int",
    "PySide6.QtLocation.QGeoRouteRequest.routeOptimization(self)->PySide6.QtLocation.QGeoRouteRequest.RouteOptimization",
    "PySide6.QtLocation.QGeoRouteRequest.segmentDetail(self)->PySide6.QtLocation.QGeoRouteRequest.SegmentDetail",
    "PySide6.QtLocation.QGeoRouteRequest.setDepartureTime(self,departureTime:PySide6.QtCore.QDateTime)",
    "PySide6.QtLocation.QGeoRouteRequest.setExcludeAreas(self,areas:QList[PySide6.QtPositioning.QGeoRectangle])",
    "PySide6.QtLocation.QGeoRouteRequest.setFeatureWeight(self,featureType:PySide6.QtLocation.QGeoRouteRequest.FeatureType,featureWeight:PySide6.QtLocation.QGeoRouteRequest.FeatureWeight)",
    "PySide6.QtLocation.QGeoRouteRequest.setManeuverDetail(self,maneuverDetail:PySide6.QtLocation.QGeoRouteRequest.ManeuverDetail)",
    "PySide6.QtLocation.QGeoRouteRequest.setNumberAlternativeRoutes(self,alternatives:int)",
    "PySide6.QtLocation.QGeoRouteRequest.setRouteOptimization(self,optimization:PySide6.QtLocation.QGeoRouteRequest.RouteOptimization)",
    "PySide6.QtLocation.QGeoRouteRequest.setSegmentDetail(self,segmentDetail:PySide6.QtLocation.QGeoRouteRequest.SegmentDetail)",
    "PySide6.QtLocation.QGeoRouteRequest.setTravelModes(self,travelModes:PySide6.QtLocation.QGeoRouteRequest.TravelMode)",
    "PySide6.QtLocation.QGeoRouteRequest.setWaypoints(self,waypoints:QList[PySide6.QtPositioning.QGeoCoordinate])",
    "PySide6.QtLocation.QGeoRouteRequest.swap(self,other:PySide6.QtLocation.QGeoRouteRequest)",
    "PySide6.QtLocation.QGeoRouteRequest.travelModes(self)->PySide6.QtLocation.QGeoRouteRequest.TravelMode",
    "PySide6.QtLocation.QGeoRouteRequest.waypoints(self)->QList[PySide6.QtPositioning.QGeoCoordinate]",
    "PySide6.QtLocation.QGeoRouteRequest.__ne__(self,rhs:PySide6.QtLocation.QGeoRouteRequest)->bool",
    "PySide6.QtLocation.QGeoRouteRequest.__eq__(self,rhs:PySide6.QtLocation.QGeoRouteRequest)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QGeoRouteRequest_SignatureByteSize = 460;
static constexpr uint8_t QGeoRouteRequest_SignatureBytes[460] = {
    0x78, 0xda, 0xad, 0x96, 0x5f, 0x4f, 0xc2, 0x30, 0x14, 0xc5, 0xdf, 0xf9, 0x24, 0x2c, 0xa9, 0x44,
    0x7d, 0xf0, 0xa1, 0x51, 0x12, 0x02, 0xea, 0x0b, 0x28, 0x1b, 0x24, 0x3c, 0x18, 0xb2, 0x14, 0x76,
    0x19, 0x4d, 0xb6, 0x76, 0x74, 0x1d, 0x88, 0x9f, 0xde, 0x6d, 0x88, 0xfb, 0x83, 0x93, 0x5b, 0xf4,
    0x6d, 0xb4, 0xf7, 0xdc, 0x73, 0xb8, 0xe5, 0x47, 0x77, 0x4b, 0xc7, 0xfb, 0x09, 0xf7, 0xe0, 0xae,
    0x63, 0xeb, 0xa1, 0x5c, 0x32, 0xcd, 0xa5, 0xe8, 0xd8, 0xcf, 0x20, 0x1d, 0x99, 0x68, 0x70, 0x60,
    0x93, 0x40, 0xac, 0xdb, 0x31, 0x04, 0x2b, 0x22, 0x15, 0xf7, 0xb9, 0x28, 0xd5, 0x8f, 0x65, 0xcc,
    0xb3, 0x7a, 0x2e, 0xfc, 0x5c, 0xd2, 0x97, 0x52, 0x79, 0x5c, 0x30, 0x0d, 0xc4, 0x4b, 0x55, 0xd9,
    0x53, 0xba, 0x8b, 0x12, 0x58, 0xad, 0x1b, 0x83, 0x20, 0x7a, 0x0d, 0x0a, 0x53, 0x6e, 0xb5, 0xae,
    0xf1, 0x5d, 0x77, 0x6c, 0x1f, 0x49, 0x2e, 0x74, 0x4c, 0xed, 0x21, 0x8f, 0xf5, 0x1b, 0x26, 0xf6,
    0xfc, 0x21, 0xaf, 0xbd, 0xaf, 0xae, 0x76, 0xdb, 0x96, 0xd5, 0x42, 0xf8, 0x76, 0x3c, 0x88, 0x98,
    0xd2, 0x89, 0x82, 0x29, 0x0f, 0x21, 0x4f, 0x61, 0x5d, 0x75, 0x0b, 0x61, 0x5f, 0x2a, 0xe8, 0xd8,
    0x83, 0xb4, 0x63, 0xb6, 0x8f, 0xea, 0x08, 0xef, 0xcb, 0x20, 0xf1, 0xa0, 0xa7, 0x80, 0xc5, 0xc7,
    0x86, 0xe7, 0xbe, 0x8e, 0x03, 0x4b, 0xcd, 0x84, 0x1f, 0xc0, 0x1c, 0x65, 0xb1, 0x02, 0x96, 0x47,
    0xde, 0x47, 0xd0, 0x68, 0xd1, 0xac, 0x7e, 0x2a, 0xd4, 0x46, 0x76, 0x33, 0xe0, 0xfe, 0xfa, 0xeb,
    0xa4, 0x4a, 0x09, 0xa8, 0xa1, 0x67, 0x65, 0xbe, 0x67, 0x15, 0x07, 0x53, 0x54, 0xcc, 0x90, 0x09,
    0x48, 0xb6, 0xa0, 0x06, 0xa0, 0x19, 0x0f, 0x4e, 0xcf, 0xb2, 0x59, 0x39, 0xaa, 0x28, 0x51, 0x66,
    0x22, 0x09, 0x17, 0xa0, 0x7a, 0x81, 0x06, 0x95, 0x31, 0xb6, 0x85, 0x7c, 0xf7, 0xfb, 0x34, 0xd2,
    0x1f, 0x31, 0xaa, 0x8d, 0xca, 0x3e, 0xbc, 0x46, 0x9a, 0x87, 0xfc, 0x23, 0x2f, 0x31, 0x89, 0xed,
    0xd4, 0xc5, 0x28, 0xcb, 0x18, 0xfc, 0x10, 0x84, 0x36, 0x9f, 0xd2, 0xa4, 0x2c, 0x44, 0x5a, 0xa5,
    0xd5, 0x75, 0xbe, 0x48, 0x05, 0x39, 0xda, 0xc4, 0x9a, 0x85, 0x75, 0x78, 0xac, 0xf3, 0x46, 0x58,
    0xf6, 0x48, 0xf1, 0xcc, 0xa1, 0xad, 0x9e, 0xfe, 0x15, 0x04, 0x52, 0xe1, 0x8a, 0x1a, 0x43, 0x81,
    0x8e, 0x3d, 0x3a, 0x05, 0x83, 0x54, 0x61, 0xa1, 0xe6, 0x94, 0xa0, 0xdd, 0x5f, 0x7e, 0x21, 0x85,
    0xb0, 0x62, 0x39, 0xa6, 0x29, 0x34, 0xe8, 0xae, 0xce, 0x8f, 0xe0, 0x10, 0x59, 0x5a, 0xa1, 0x17,
    0x31, 0x84, 0x4e, 0x30, 0x39, 0xe1, 0x88, 0x54, 0xd0, 0xa2, 0xc6, 0x4c, 0xa1, 0xad, 0xa7, 0x8a,
    0x6d, 0x21, 0x18, 0x49, 0xef, 0x38, 0x46, 0x5d, 0x2c, 0xa0, 0x6c, 0x8b, 0x06, 0x68, 0xcf, 0xd9,
    0xf1, 0x6e, 0xfe, 0xc3, 0x55, 0x8d, 0x34, 0xdb, 0xb1, 0xc8, 0xf8, 0x2d, 0x03, 0xd3, 0x58, 0xd7,
    0xc6, 0x86, 0xfc, 0xdf, 0x2b, 0x86, 0x85, 0x72, 0xd9, 0x55, 0x06, 0x85, 0xb8, 0xfc, 0x4b, 0x03,
    0x42, 0x19, 0xb8, 0xae, 0x00, 0xd7, 0x3d, 0x4c, 0x48, 0xad, 0x51, 0x07, 0x9e, 0xa6, 0x58, 0x48,
    0x19, 0x20, 0xdb, 0xc3, 0xe6, 0xc2, 0xf6, 0x9f, 0x16, 0x0e, 0x07, 0x69
};
#endif

PyTypeObject *init_QGeoRouteRequest(PyObject *module)
{
    if (SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX].type != nullptr)
        return SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX].type;

    Shiboken::AutoDecRef Sbk_QGeoRouteRequest_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QGeoRouteRequest_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QGeoRouteRequest",
        "QGeoRouteRequest*",
        &Sbk_QGeoRouteRequest_spec,
        &Shiboken::callCppDestructor< ::QGeoRouteRequest >,
        Sbk_QGeoRouteRequest_Type_bases.object(),
        0);
    auto *pyType = Sbk_QGeoRouteRequest_TypeF(); // references _Sbk_QGeoRouteRequest_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QGeoRouteRequest_SignatureStrings);
#else
    InitSignatureBytes(pyType, QGeoRouteRequest_SignatureBytes, QGeoRouteRequest_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QGeoRouteRequest_PropertyStrings);
    SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QGeoRouteRequest_PythonToCpp_QGeoRouteRequest_PTR,
        is_QGeoRouteRequest_PythonToCpp_QGeoRouteRequest_PTR_Convertible,
        QGeoRouteRequest_PTR_CppToPython_QGeoRouteRequest);

    Shiboken::Conversions::registerConverterName(converter, "QGeoRouteRequest");
    Shiboken::Conversions::registerConverterName(converter, "QGeoRouteRequest*");
    Shiboken::Conversions::registerConverterName(converter, "QGeoRouteRequest&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QGeoRouteRequest).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QGeoRouteRequest_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'TravelMode'.
    const char *TravelMode_Initializer[] = {
        "CarTravel",
        "PedestrianTravel",
        "BicycleTravel",
        "PublicTransitTravel",
        "TruckTravel",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t TravelMode_InitializerValues[] = {
        uint8_t(QGeoRouteRequest::TravelMode::CarTravel),           //  0x01  1
        uint8_t(QGeoRouteRequest::TravelMode::PedestrianTravel),    //  0x02  2
        uint8_t(QGeoRouteRequest::TravelMode::BicycleTravel),       //  0x04  4
        uint8_t(QGeoRouteRequest::TravelMode::PublicTransitTravel), //  0x08  8
        uint8_t(QGeoRouteRequest::TravelMode::TruckTravel)          //  0x10  16
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QGeoRouteRequest_TypeF(),
        "2:PySide6.QtLocation.QGeoRouteRequest.TravelMode",
        TravelMode_Initializer, TravelMode_InitializerValues);
    SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_TravelMode_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtLocationTypeStructs[SBK_QFlags_QGeoRouteRequest_TravelMode_IDX].type =
        EType;
    // Register converter for enum 'QGeoRouteRequest::TravelMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QGeoRouteRequest_TravelMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QGeoRouteRequest_TravelMode,
            is_Enum_PythonToCpp_QGeoRouteRequest_TravelMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QGeoRouteRequest::TravelMode");
        Shiboken::Conversions::registerConverterAlias(converter, "TravelMode");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QGeoRouteRequest_TravelMode_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QGeoRouteRequest_TravelMode,
            is_Enum_PythonToCpp_QGeoRouteRequest_TravelMode_Convertible);
        // Register converter for flag 'QFlags<QGeoRouteRequest::TravelMode>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QGeoRouteRequest::TravelMode>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QGeoRouteRequest::TravelModes");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'TravelMode' enum/flags.

    // Initialization of enum 'FeatureType'.
    const char *FeatureType_Initializer[] = {
        "NoFeature",
        "TollFeature",
        "HighwayFeature",
        "PublicTransitFeature",
        "FerryFeature",
        "TunnelFeature",
        "DirtRoadFeature",
        "ParksFeature",
        "MotorPoolLaneFeature",
        "TrafficFeature",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t FeatureType_InitializerValues[] = {
        uint16_t(QGeoRouteRequest::FeatureType::NoFeature),            //  0x0000  0
        uint16_t(QGeoRouteRequest::FeatureType::TollFeature),          //  0x0001  1
        uint16_t(QGeoRouteRequest::FeatureType::HighwayFeature),       //  0x0002  2
        uint16_t(QGeoRouteRequest::FeatureType::PublicTransitFeature), //  0x0004  4
        uint16_t(QGeoRouteRequest::FeatureType::FerryFeature),         //  0x0008  8
        uint16_t(QGeoRouteRequest::FeatureType::TunnelFeature),        //  0x0010  16
        uint16_t(QGeoRouteRequest::FeatureType::DirtRoadFeature),      //  0x0020  32
        uint16_t(QGeoRouteRequest::FeatureType::ParksFeature),         //  0x0040  64
        uint16_t(QGeoRouteRequest::FeatureType::MotorPoolLaneFeature), //  0x0080  128
        uint16_t(QGeoRouteRequest::FeatureType::TrafficFeature)        //  0x0100  256
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QGeoRouteRequest_TypeF(),
        "2:PySide6.QtLocation.QGeoRouteRequest.FeatureType",
        FeatureType_Initializer, FeatureType_InitializerValues);
    SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_FeatureType_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtLocationTypeStructs[SBK_QFlags_QGeoRouteRequest_FeatureType_IDX].type =
        EType;
    // Register converter for enum 'QGeoRouteRequest::FeatureType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QGeoRouteRequest_FeatureType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QGeoRouteRequest_FeatureType,
            is_Enum_PythonToCpp_QGeoRouteRequest_FeatureType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QGeoRouteRequest::FeatureType");
        Shiboken::Conversions::registerConverterAlias(converter, "FeatureType");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QGeoRouteRequest_FeatureType_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QGeoRouteRequest_FeatureType,
            is_Enum_PythonToCpp_QGeoRouteRequest_FeatureType_Convertible);
        // Register converter for flag 'QFlags<QGeoRouteRequest::FeatureType>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QGeoRouteRequest::FeatureType>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QGeoRouteRequest::FeatureTypes");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'FeatureType' enum/flags.

    // Initialization of enum 'FeatureWeight'.
    const char *FeatureWeight_Initializer[] = {
        "NeutralFeatureWeight",
        "PreferFeatureWeight",
        "RequireFeatureWeight",
        "AvoidFeatureWeight",
        "DisallowFeatureWeight",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t FeatureWeight_InitializerValues[] = {
        uint8_t(QGeoRouteRequest::FeatureWeight::NeutralFeatureWeight), //  0x00  0
        uint8_t(QGeoRouteRequest::FeatureWeight::PreferFeatureWeight),  //  0x01  1
        uint8_t(QGeoRouteRequest::FeatureWeight::RequireFeatureWeight), //  0x02  2
        uint8_t(QGeoRouteRequest::FeatureWeight::AvoidFeatureWeight),   //  0x04  4
        uint8_t(QGeoRouteRequest::FeatureWeight::DisallowFeatureWeight) //  0x08  8
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QGeoRouteRequest_TypeF(),
        "2:PySide6.QtLocation.QGeoRouteRequest.FeatureWeight",
        FeatureWeight_Initializer, FeatureWeight_InitializerValues);
    SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_FeatureWeight_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtLocationTypeStructs[SBK_QFlags_QGeoRouteRequest_FeatureWeight_IDX].type =
        EType;
    // Register converter for enum 'QGeoRouteRequest::FeatureWeight'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QGeoRouteRequest_FeatureWeight_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QGeoRouteRequest_FeatureWeight,
            is_Enum_PythonToCpp_QGeoRouteRequest_FeatureWeight_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QGeoRouteRequest::FeatureWeight");
        Shiboken::Conversions::registerConverterAlias(converter, "FeatureWeight");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QGeoRouteRequest_FeatureWeight_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QGeoRouteRequest_FeatureWeight,
            is_Enum_PythonToCpp_QGeoRouteRequest_FeatureWeight_Convertible);
        // Register converter for flag 'QFlags<QGeoRouteRequest::FeatureWeight>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QGeoRouteRequest::FeatureWeight>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QGeoRouteRequest::FeatureWeights");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'FeatureWeight' enum/flags.

    // Initialization of enum 'RouteOptimization'.
    const char *RouteOptimization_Initializer[] = {
        "ShortestRoute",
        "FastestRoute",
        "MostEconomicRoute",
        "MostScenicRoute",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t RouteOptimization_InitializerValues[] = {
        uint8_t(QGeoRouteRequest::RouteOptimization::ShortestRoute),     //  0x01  1
        uint8_t(QGeoRouteRequest::RouteOptimization::FastestRoute),      //  0x02  2
        uint8_t(QGeoRouteRequest::RouteOptimization::MostEconomicRoute), //  0x04  4
        uint8_t(QGeoRouteRequest::RouteOptimization::MostScenicRoute)    //  0x08  8
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QGeoRouteRequest_TypeF(),
        "2:PySide6.QtLocation.QGeoRouteRequest.RouteOptimization",
        RouteOptimization_Initializer, RouteOptimization_InitializerValues);
    SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_RouteOptimization_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtLocationTypeStructs[SBK_QFlags_QGeoRouteRequest_RouteOptimization_IDX].type =
        EType;
    // Register converter for enum 'QGeoRouteRequest::RouteOptimization'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QGeoRouteRequest_RouteOptimization_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QGeoRouteRequest_RouteOptimization,
            is_Enum_PythonToCpp_QGeoRouteRequest_RouteOptimization_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QGeoRouteRequest::RouteOptimization");
        Shiboken::Conversions::registerConverterAlias(converter, "RouteOptimization");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QGeoRouteRequest_RouteOptimization_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QGeoRouteRequest_RouteOptimization,
            is_Enum_PythonToCpp_QGeoRouteRequest_RouteOptimization_Convertible);
        // Register converter for flag 'QFlags<QGeoRouteRequest::RouteOptimization>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QGeoRouteRequest::RouteOptimization>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QGeoRouteRequest::RouteOptimizations");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'RouteOptimization' enum/flags.

    // Initialization of enum 'SegmentDetail'.
    const char *SegmentDetail_Initializer[] = {
        "NoSegmentData",
        "BasicSegmentData",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t SegmentDetail_InitializerValues[] = {
        uint8_t(QGeoRouteRequest::SegmentDetail::NoSegmentData),   //  0x00  0
        uint8_t(QGeoRouteRequest::SegmentDetail::BasicSegmentData) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QGeoRouteRequest_TypeF(),
        "2:PySide6.QtLocation.QGeoRouteRequest.SegmentDetail",
        SegmentDetail_Initializer, SegmentDetail_InitializerValues);
    SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_SegmentDetail_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtLocationTypeStructs[SBK_QFlags_QGeoRouteRequest_SegmentDetail_IDX].type =
        EType;
    // Register converter for enum 'QGeoRouteRequest::SegmentDetail'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QGeoRouteRequest_SegmentDetail_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QGeoRouteRequest_SegmentDetail,
            is_Enum_PythonToCpp_QGeoRouteRequest_SegmentDetail_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QGeoRouteRequest::SegmentDetail");
        Shiboken::Conversions::registerConverterAlias(converter, "SegmentDetail");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QGeoRouteRequest_SegmentDetail_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QGeoRouteRequest_SegmentDetail,
            is_Enum_PythonToCpp_QGeoRouteRequest_SegmentDetail_Convertible);
        // Register converter for flag 'QFlags<QGeoRouteRequest::SegmentDetail>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QGeoRouteRequest::SegmentDetail>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QGeoRouteRequest::SegmentDetails");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'SegmentDetail' enum/flags.

    // Initialization of enum 'ManeuverDetail'.
    const char *ManeuverDetail_Initializer[] = {
        "NoManeuvers",
        "BasicManeuvers",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ManeuverDetail_InitializerValues[] = {
        uint8_t(QGeoRouteRequest::ManeuverDetail::NoManeuvers),   //  0x00  0
        uint8_t(QGeoRouteRequest::ManeuverDetail::BasicManeuvers) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QGeoRouteRequest_TypeF(),
        "2:PySide6.QtLocation.QGeoRouteRequest.ManeuverDetail",
        ManeuverDetail_Initializer, ManeuverDetail_InitializerValues);
    SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_ManeuverDetail_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtLocationTypeStructs[SBK_QFlags_QGeoRouteRequest_ManeuverDetail_IDX].type =
        EType;
    // Register converter for enum 'QGeoRouteRequest::ManeuverDetail'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QGeoRouteRequest_ManeuverDetail_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QGeoRouteRequest_ManeuverDetail,
            is_Enum_PythonToCpp_QGeoRouteRequest_ManeuverDetail_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QGeoRouteRequest::ManeuverDetail");
        Shiboken::Conversions::registerConverterAlias(converter, "ManeuverDetail");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QGeoRouteRequest_ManeuverDetail_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QGeoRouteRequest_ManeuverDetail,
            is_Enum_PythonToCpp_QGeoRouteRequest_ManeuverDetail_Convertible);
        // Register converter for flag 'QFlags<QGeoRouteRequest::ManeuverDetail>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QGeoRouteRequest::ManeuverDetail>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QGeoRouteRequest::ManeuverDetails");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'ManeuverDetail' enum/flags.

    qRegisterMetaType< ::QGeoRouteRequest *>();
    qRegisterMetaType< ::QGeoRouteRequest::TravelMode >("QGeoRouteRequest::TravelMode");
    qRegisterMetaType< ::QGeoRouteRequest::FeatureType >("QGeoRouteRequest::FeatureType");
    qRegisterMetaType< ::QGeoRouteRequest::FeatureWeight >("QGeoRouteRequest::FeatureWeight");
    qRegisterMetaType< ::QGeoRouteRequest::RouteOptimization >("QGeoRouteRequest::RouteOptimization");
    qRegisterMetaType< ::QGeoRouteRequest::SegmentDetail >("QGeoRouteRequest::SegmentDetail");
    qRegisterMetaType< ::QGeoRouteRequest::ManeuverDetail >("QGeoRouteRequest::ManeuverDetail");

    return pyType;
}
