// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtlocation_python.h"

// main header
#include "qgeoroutesegment_wrapper.h"

// Argument includes
#include <QList>
#include <QtLocation/qgeomaneuver.h>
#include <QtLocation/qgeoroutesegment.h>
#include <QtPositioning/qgeocoordinate.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGeoRouteSegment_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QGeoRouteSegment >()))
        return -1;

    ::QGeoRouteSegment *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QGeoRouteSegment", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QGeoRouteSegment::QGeoRouteSegment()
    // 1: QGeoRouteSegment::QGeoRouteSegment(QGeoRouteSegment)
    if (numArgs == 0) {
        overloadId = 0; // QGeoRouteSegment()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteSegment_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QGeoRouteSegment(QGeoRouteSegment)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteSegment_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteSegment_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QGeoRouteSegment()
        {

            // QGeoRouteSegment()
            cptr = new ::QGeoRouteSegment();
            break;
        }
        case 1: // QGeoRouteSegment(const QGeoRouteSegment &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QGeoRouteSegment cppArg0_local;
            ::QGeoRouteSegment *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QGeoRouteSegment(QGeoRouteSegment)
                cptr = new ::QGeoRouteSegment(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QGeoRouteSegment >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteSegment_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QGeoRouteSegmentFunc_distance(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRouteSegment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteSegment_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // distance()const
        qreal cppResult = const_cast<const ::QGeoRouteSegment *>(cppSelf)->distance();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRouteSegmentFunc_isLegLastSegment(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRouteSegment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteSegment_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isLegLastSegment()const
        bool cppResult = const_cast<const ::QGeoRouteSegment *>(cppSelf)->isLegLastSegment();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRouteSegmentFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRouteSegment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteSegment_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QGeoRouteSegment *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRouteSegmentFunc_maneuver(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRouteSegment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteSegment_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maneuver()const
        QGeoManeuver cppResult = const_cast<const ::QGeoRouteSegment *>(cppSelf)->maneuver();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoManeuver_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRouteSegmentFunc_nextRouteSegment(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRouteSegment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteSegment_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // nextRouteSegment()const
        QGeoRouteSegment cppResult = const_cast<const ::QGeoRouteSegment *>(cppSelf)->nextRouteSegment();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteSegment_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRouteSegmentFunc_path(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRouteSegment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteSegment_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // path()const
        QList<QGeoCoordinate> cppResult = const_cast<const ::QGeoRouteSegment *>(cppSelf)->path();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QList_QGeoCoordinate_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRouteSegmentFunc_setDistance(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRouteSegment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteSegment_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRouteSegment::setDistance(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setDistance(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDistance", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteSegment_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDistance(qreal)
            cppSelf->setDistance(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRouteSegmentFunc_setManeuver(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRouteSegment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteSegment_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRouteSegment::setManeuver(QGeoManeuver)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoManeuver_IDX]), (pyArg)))) {
        overloadId = 0; // setManeuver(QGeoManeuver)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setManeuver", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteSegment_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGeoManeuver cppArg0_local;
        ::QGeoManeuver *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setManeuver(QGeoManeuver)
            cppSelf->setManeuver(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRouteSegmentFunc_setNextRouteSegment(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRouteSegment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteSegment_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRouteSegment::setNextRouteSegment(QGeoRouteSegment)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteSegment_IDX]), (pyArg)))) {
        overloadId = 0; // setNextRouteSegment(QGeoRouteSegment)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setNextRouteSegment", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteSegment_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGeoRouteSegment cppArg0_local;
        ::QGeoRouteSegment *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setNextRouteSegment(QGeoRouteSegment)
            cppSelf->setNextRouteSegment(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRouteSegmentFunc_setPath(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRouteSegment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteSegment_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRouteSegment::setPath(QList<QGeoCoordinate>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QList_QGeoCoordinate_IDX], (pyArg)))) {
        overloadId = 0; // setPath(QList<QGeoCoordinate>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPath", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteSegment_IDX]);

    // Call function/method
    {
        ::QList<QGeoCoordinate> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPath(QList<QGeoCoordinate>)
            cppSelf->setPath(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRouteSegmentFunc_setTravelTime(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRouteSegment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteSegment_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRouteSegment::setTravelTime(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setTravelTime(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTravelTime", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteSegment_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTravelTime(int)
            cppSelf->setTravelTime(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRouteSegmentFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRouteSegment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteSegment_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRouteSegment::swap(QGeoRouteSegment&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteSegment_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QGeoRouteSegment&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteSegment_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGeoRouteSegment cppArg0_local;
        ::QGeoRouteSegment *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QGeoRouteSegment&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRouteSegmentFunc_travelTime(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRouteSegment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteSegment_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // travelTime()const
        int cppResult = const_cast<const ::QGeoRouteSegment *>(cppSelf)->travelTime();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRouteSegment__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QGeoRouteSegment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteSegment_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteSegment_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QGeoRouteSegment_PropertyStrings[] = {
    "distance:",
    "maneuver:",
    "path:",
    "travelTime:",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QGeoRouteSegment_methods[] = {
    {"distance", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteSegmentFunc_distance), METH_NOARGS, nullptr},
    {"isLegLastSegment", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteSegmentFunc_isLegLastSegment), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteSegmentFunc_isValid), METH_NOARGS, nullptr},
    {"maneuver", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteSegmentFunc_maneuver), METH_NOARGS, nullptr},
    {"nextRouteSegment", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteSegmentFunc_nextRouteSegment), METH_NOARGS, nullptr},
    {"path", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteSegmentFunc_path), METH_NOARGS, nullptr},
    {"setDistance", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteSegmentFunc_setDistance), METH_O, nullptr},
    {"setManeuver", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteSegmentFunc_setManeuver), METH_O, nullptr},
    {"setNextRouteSegment", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteSegmentFunc_setNextRouteSegment), METH_O, nullptr},
    {"setPath", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteSegmentFunc_setPath), METH_O, nullptr},
    {"setTravelTime", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteSegmentFunc_setTravelTime), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteSegmentFunc_swap), METH_O, nullptr},
    {"travelTime", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteSegmentFunc_travelTime), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteSegment__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QGeoRouteSegment_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QGeoRouteSegment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteSegment_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteSegment_IDX]), (pyArg)))) {
                // operator!=(const QGeoRouteSegment &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QGeoRouteSegment cppArg0_local;
                ::QGeoRouteSegment *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteSegment_IDX]), (pyArg)))) {
                // operator==(const QGeoRouteSegment &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QGeoRouteSegment cppArg0_local;
                ::QGeoRouteSegment *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QGeoRouteSegment_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QGeoRouteSegment_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QGeoRouteSegment_Type = nullptr;
static PyTypeObject *Sbk_QGeoRouteSegment_TypeF(void)
{
    return _Sbk_QGeoRouteSegment_Type;
}

static PyType_Slot Sbk_QGeoRouteSegment_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QGeoRouteSegment_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QGeoRouteSegment_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QGeoRouteSegment_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QGeoRouteSegment_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QGeoRouteSegment_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QGeoRouteSegment_spec = {
    "2:PySide6.QtLocation.QGeoRouteSegment",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QGeoRouteSegment_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QGeoRouteSegment_PythonToCpp_QGeoRouteSegment_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QGeoRouteSegment_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QGeoRouteSegment_PythonToCpp_QGeoRouteSegment_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QGeoRouteSegment_TypeF()))
        return QGeoRouteSegment_PythonToCpp_QGeoRouteSegment_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QGeoRouteSegment_PTR_CppToPython_QGeoRouteSegment(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QGeoRouteSegment_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QGeoRouteSegment_COPY_CppToPython_QGeoRouteSegment(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QGeoRouteSegment *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QGeoRouteSegment_TypeF(), new ::QGeoRouteSegment(*source), true, true);
}

// Python to C++ copy conversion.
static void QGeoRouteSegment_PythonToCpp_QGeoRouteSegment_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QGeoRouteSegment *>(cppOut) = *reinterpret_cast< ::QGeoRouteSegment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteSegment_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QGeoRouteSegment_PythonToCpp_QGeoRouteSegment_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QGeoRouteSegment_TypeF()))
        return QGeoRouteSegment_PythonToCpp_QGeoRouteSegment_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QGeoRouteSegment_SignatureStrings[] = {
    "1:PySide6.QtLocation.QGeoRouteSegment(self,*:KeywordOnly=None,travelTime:int=None,distance:qreal=None,path:QList[PySide6.QtPositioning.QGeoCoordinate]=None,maneuver:QGeoManeuver=None)",
    "0:PySide6.QtLocation.QGeoRouteSegment(self,other:PySide6.QtLocation.QGeoRouteSegment,*:KeywordOnly=None,travelTime:int=None,distance:qreal=None,path:QList[PySide6.QtPositioning.QGeoCoordinate]=None,maneuver:QGeoManeuver=None)",
    "PySide6.QtLocation.QGeoRouteSegment.distance(self)->qreal",
    "PySide6.QtLocation.QGeoRouteSegment.isLegLastSegment(self)->bool",
    "PySide6.QtLocation.QGeoRouteSegment.isValid(self)->bool",
    "PySide6.QtLocation.QGeoRouteSegment.maneuver(self)->PySide6.QtLocation.QGeoManeuver",
    "PySide6.QtLocation.QGeoRouteSegment.nextRouteSegment(self)->PySide6.QtLocation.QGeoRouteSegment",
    "PySide6.QtLocation.QGeoRouteSegment.path(self)->QList[PySide6.QtPositioning.QGeoCoordinate]",
    "PySide6.QtLocation.QGeoRouteSegment.setDistance(self,distance:qreal)",
    "PySide6.QtLocation.QGeoRouteSegment.setManeuver(self,maneuver:PySide6.QtLocation.QGeoManeuver)",
    "PySide6.QtLocation.QGeoRouteSegment.setNextRouteSegment(self,routeSegment:PySide6.QtLocation.QGeoRouteSegment)",
    "PySide6.QtLocation.QGeoRouteSegment.setPath(self,path:QList[PySide6.QtPositioning.QGeoCoordinate])",
    "PySide6.QtLocation.QGeoRouteSegment.setTravelTime(self,secs:int)",
    "PySide6.QtLocation.QGeoRouteSegment.swap(self,other:PySide6.QtLocation.QGeoRouteSegment)",
    "PySide6.QtLocation.QGeoRouteSegment.travelTime(self)->int",
    "PySide6.QtLocation.QGeoRouteSegment.__copy__(self)->typing.Self",
    "PySide6.QtLocation.QGeoRouteSegment.__ne__(self,rhs:PySide6.QtLocation.QGeoRouteSegment)->bool",
    "PySide6.QtLocation.QGeoRouteSegment.__eq__(self,rhs:PySide6.QtLocation.QGeoRouteSegment)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QGeoRouteSegment_SignatureByteSize = 334;
static constexpr uint8_t QGeoRouteSegment_SignatureBytes[334] = {
    0x78, 0xda, 0xcd, 0x94, 0x4d, 0x4f, 0x84, 0x30, 0x10, 0x86, 0xef, 0xfe, 0x12, 0xd7, 0x20, 0xd1,
    0x8b, 0x87, 0x26, 0x7a, 0xd1, 0xc4, 0x83, 0xec, 0x0a, 0xb2, 0xf1, 0x62, 0x4c, 0x53, 0x61, 0x84,
    0x26, 0xd0, 0xb2, 0xed, 0xec, 0xae, 0xfc, 0x7b, 0x0b, 0x6c, 0x5d, 0xfc, 0xd8, 0x38, 0x78, 0xf2,
    0x48, 0xdb, 0xf7, 0x99, 0x99, 0x77, 0x66, 0x38, 0x67, 0x71, 0x9b, 0xca, 0x1c, 0x2e, 0xc2, 0x04,
    0x23, 0x9d, 0x09, 0x94, 0x5a, 0x85, 0xc9, 0x2d, 0xe8, 0x07, 0xbd, 0x46, 0x48, 0xa1, 0xa8, 0x41,
    0xe1, 0xb1, 0x85, 0xea, 0x35, 0x38, 0x61, 0x77, 0xd0, 0x6e, 0xb5, 0xc9, 0xef, 0x55, 0xd5, 0x5e,
    0x2e, 0xb4, 0x82, 0x00, 0x8d, 0xd8, 0x40, 0xb5, 0x94, 0x35, 0x30, 0xa9, 0x70, 0x38, 0xcb, 0xa5,
    0x45, 0xa1, 0x32, 0x60, 0x2b, 0x03, 0xa2, 0x1a, 0xce, 0x1a, 0x81, 0x25, 0x4b, 0x22, 0x77, 0xf3,
    0xb4, 0x0f, 0x17, 0x6b, 0x2b, 0xbb, 0x70, 0x52, 0x15, 0x7d, 0xc4, 0x6b, 0xed, 0xd8, 0x52, 0x09,
    0x84, 0xe7, 0x41, 0x55, 0x0b, 0x05, 0xeb, 0x0d, 0x18, 0xd6, 0xdd, 0xce, 0x77, 0x1f, 0xfd, 0xd5,
    0xec, 0xe8, 0x8c, 0x9e, 0xb7, 0xc6, 0xd2, 0x31, 0x08, 0xcf, 0xff, 0x57, 0x85, 0x84, 0x84, 0x43,
    0x9f, 0x49, 0x5f, 0xe8, 0xec, 0xf4, 0xaa, 0x4f, 0x88, 0xa4, 0x94, 0x36, 0x82, 0x22, 0x12, 0x16,
    0xc7, 0x56, 0x39, 0xc2, 0x8b, 0xd6, 0x54, 0xc0, 0xa3, 0xa8, 0x64, 0x3e, 0x59, 0xe7, 0x4b, 0xf6,
    0xc2, 0x03, 0x1a, 0x6f, 0x06, 0x89, 0xa9, 0xe0, 0x0d, 0xbf, 0xf5, 0xfd, 0x30, 0x7b, 0xfc, 0x94,
    0xc4, 0xef, 0x9a, 0xeb, 0x99, 0x13, 0x7a, 0x4c, 0x62, 0x5b, 0xc0, 0x9b, 0x71, 0x17, 0xbf, 0x4c,
    0xd7, 0x8c, 0x0a, 0x99, 0x8f, 0x7d, 0xdd, 0x0f, 0xd6, 0x2f, 0xf6, 0x92, 0xf1, 0x8b, 0x9f, 0x2c,
    0x0e, 0xcc, 0xe8, 0x84, 0xb2, 0x61, 0xe4, 0x70, 0xb1, 0x77, 0x7c, 0xf2, 0x62, 0x91, 0x43, 0x2c,
    0x3f, 0x36, 0x7b, 0x08, 0x64, 0x21, 0xb3, 0xdd, 0x8e, 0x13, 0x01, 0x5b, 0xd1, 0x4c, 0xfc, 0xbd,
    0xd0, 0xc0, 0xf8, 0x39, 0x2d, 0x37, 0x71, 0x92, 0x38, 0xa5, 0x9c, 0x67, 0xba, 0x69, 0x39, 0xf7,
    0x3a, 0x6c, 0x9b, 0xce, 0x9f, 0xd4, 0x7d, 0x11, 0xf5, 0x0a, 0x76, 0xea, 0xc0, 0x94, 0x96, 0x54,
    0xd2, 0x84, 0xc5, 0xe7, 0x1c, 0x56, 0x7f, 0xc4, 0xbf, 0x03, 0xea, 0xe8, 0x73, 0x52
};
#endif

PyTypeObject *init_QGeoRouteSegment(PyObject *module)
{
    if (SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteSegment_IDX].type != nullptr)
        return SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteSegment_IDX].type;

    Shiboken::AutoDecRef Sbk_QGeoRouteSegment_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QGeoRouteSegment_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QGeoRouteSegment",
        "QGeoRouteSegment",
        &Sbk_QGeoRouteSegment_spec,
        &Shiboken::callCppDestructor< ::QGeoRouteSegment >,
        Sbk_QGeoRouteSegment_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QGeoRouteSegment_TypeF(); // references _Sbk_QGeoRouteSegment_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QGeoRouteSegment_SignatureStrings);
#else
    InitSignatureBytes(pyType, QGeoRouteSegment_SignatureBytes, QGeoRouteSegment_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QGeoRouteSegment_PropertyStrings);
    SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteSegment_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QGeoRouteSegment_PythonToCpp_QGeoRouteSegment_PTR,
        is_QGeoRouteSegment_PythonToCpp_QGeoRouteSegment_PTR_Convertible,
        QGeoRouteSegment_PTR_CppToPython_QGeoRouteSegment,
        QGeoRouteSegment_COPY_CppToPython_QGeoRouteSegment);

    Shiboken::Conversions::registerConverterName(converter, "QGeoRouteSegment");
    Shiboken::Conversions::registerConverterName(converter, "QGeoRouteSegment*");
    Shiboken::Conversions::registerConverterName(converter, "QGeoRouteSegment&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QGeoRouteSegment).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QGeoRouteSegment_PythonToCpp_QGeoRouteSegment_COPY,
        is_QGeoRouteSegment_PythonToCpp_QGeoRouteSegment_COPY_Convertible);

    qRegisterMetaType< ::QGeoRouteSegment >("QGeoRouteSegment");

    return pyType;
}
