// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtlocation_python.h"

// main header
#include "qgeoroutingmanagerengine_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QMap>
#include <QString>
#include <QtLocation/qgeoroute.h>
#include <QtLocation/qgeoroutereply.h>
#include <QtLocation/qgeorouterequest.h>
#include <QtPositioning/qgeocoordinate.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qlocale.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QGeoRoutingManagerEngineWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QGeoRoutingManagerEngineWrapper::QGeoRoutingManagerEngineWrapper(const ::QMap<QString,QVariant> & parameters, ::QObject * parent) : QGeoRoutingManagerEngine(parameters, parent)
{
}

::QGeoRouteReply * QGeoRoutingManagerEngineWrapper::calculateRoute(const ::QGeoRouteRequest & request)
{
    if (m_PyMethodCache[0]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QGeoRoutingManagerEngine.calculateRoute");
        return nullptr;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "calculateRoute";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        Shiboken::Errors::setPureVirtualMethodError("QGeoRoutingManagerEngine.calculateRoute");
        return nullptr;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]), &request)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]), &request)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGeoRoutingManagerEngine", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteReply_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QGeoRoutingManagerEngine", funcName, Shiboken::SbkType< QGeoRouteReply >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QGeoRouteReply *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QGeoRoutingManagerEngineWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGeoRoutingManagerEngine", funcName);
        return;
    }
}

void QGeoRoutingManagerEngineWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGeoRoutingManagerEngine", funcName);
        return;
    }
}

void QGeoRoutingManagerEngineWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGeoRoutingManagerEngine", funcName);
        return;
    }
}

void QGeoRoutingManagerEngineWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[4]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGeoRoutingManagerEngine", funcName);
        return;
    }
}

bool QGeoRoutingManagerEngineWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGeoRoutingManagerEngine", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QGeoRoutingManagerEngine", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QGeoRoutingManagerEngineWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[6])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGeoRoutingManagerEngine", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QGeoRoutingManagerEngine", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QGeoRoutingManagerEngineWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[7]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[7] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGeoRoutingManagerEngine", funcName);
        return;
    }
}

::QGeoRouteReply * QGeoRoutingManagerEngineWrapper::updateRoute(const ::QGeoRoute & route, const ::QGeoCoordinate & position)
{
    if (m_PyMethodCache[8])
        return this->::QGeoRoutingManagerEngine::updateRoute(route, position);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "updateRoute";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[8] = true;
        gil.release();
        return this->::QGeoRoutingManagerEngine::updateRoute(route, position);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), &route),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), &position)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), &route),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), &position)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGeoRoutingManagerEngine", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteReply_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QGeoRoutingManagerEngine", funcName, Shiboken::SbkType< QGeoRouteReply >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QGeoRouteReply *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

const QMetaObject *QGeoRoutingManagerEngineWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QGeoRoutingManagerEngine::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QGeoRoutingManagerEngineWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QGeoRoutingManagerEngine::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QGeoRoutingManagerEngineWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QGeoRoutingManagerEngineWrapper *>(this));
    return QGeoRoutingManagerEngine::qt_metacast(_clname);
}

QGeoRoutingManagerEngineWrapper::~QGeoRoutingManagerEngineWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGeoRoutingManagerEngine_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoutingManagerEngine_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QGeoRoutingManagerEngine");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QGeoRoutingManagerEngine >()))
        return -1;

    QGeoRoutingManagerEngineWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:QGeoRoutingManagerEngine", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QGeoRoutingManagerEngine::QGeoRoutingManagerEngine(QMap<QString,QVariant>,QObject*=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QMap_QString_QVariant_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // QGeoRoutingManagerEngine(QMap<QString,QVariant>,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 0; // QGeoRoutingManagerEngine(QMap<QString,QVariant>,QObject*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoutingManagerEngine_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoutingManagerEngine_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoutingManagerEngine_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoutingManagerEngine_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                // fall through to handle extra keyword signals and properties
            }
        }
        ::QMap<QString,QVariant> cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return -1;
        ::QObject *cppArg1 = nullptr;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QGeoRoutingManagerEngine(QMap<QString,QVariant>,QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QGeoRoutingManagerEngineWrapper(cppArg0, cppArg1);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QGeoRoutingManagerEngineWrapper(cppArg0, cppArg1);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[1], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QGeoRoutingManagerEngine >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoutingManagerEngine_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoutingManagerEngine_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QGeoRoutingManagerEngineFunc_calculateRoute(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoutingManagerEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoutingManagerEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRoutingManagerEngine::calculateRoute(QGeoRouteRequest)->QGeoRouteReply*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]), (pyArg)))) {
        overloadId = 0; // calculateRoute(QGeoRouteRequest)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "calculateRoute", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoutingManagerEngine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGeoRouteRequest *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // calculateRoute(QGeoRouteRequest)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QGeoRoutingManagerEngine.calculateRoute");
                return {};
            }
            QGeoRouteReply * cppResult = cppSelf->calculateRoute(*cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteReply_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRoutingManagerEngineFunc_locale(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoutingManagerEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoutingManagerEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // locale()const
        QLocale cppResult = const_cast<const ::QGeoRoutingManagerEngine *>(cppSelf)->locale();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRoutingManagerEngineFunc_managerName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoutingManagerEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoutingManagerEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // managerName()const
        QString cppResult = const_cast<const ::QGeoRoutingManagerEngine *>(cppSelf)->managerName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRoutingManagerEngineFunc_managerVersion(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoutingManagerEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoutingManagerEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // managerVersion()const
        int cppResult = const_cast<const ::QGeoRoutingManagerEngine *>(cppSelf)->managerVersion();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRoutingManagerEngineFunc_measurementSystem(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoutingManagerEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoutingManagerEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // measurementSystem()const
        QLocale::MeasurementSystem cppResult = const_cast<const ::QGeoRoutingManagerEngine *>(cppSelf)->measurementSystem();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_MeasurementSystem_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRoutingManagerEngineFunc_setLocale(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoutingManagerEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoutingManagerEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRoutingManagerEngine::setLocale(QLocale)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), (pyArg)))) {
        overloadId = 0; // setLocale(QLocale)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLocale", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoutingManagerEngine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QLocale cppArg0_local;
        ::QLocale *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setLocale(QLocale)
            cppSelf->setLocale(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRoutingManagerEngineFunc_setMeasurementSystem(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoutingManagerEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoutingManagerEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRoutingManagerEngine::setMeasurementSystem(QLocale::MeasurementSystem)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_MeasurementSystem_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setMeasurementSystem(QLocale::MeasurementSystem)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMeasurementSystem", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoutingManagerEngine_IDX]);

    // Call function/method
    {
        ::QLocale::MeasurementSystem cppArg0{QLocale::MetricSystem};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMeasurementSystem(QLocale::MeasurementSystem)
            cppSelf->setMeasurementSystem(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRoutingManagerEngineFunc_setSupportedFeatureTypes(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoutingManagerEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoutingManagerEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRoutingManagerEngine::setSupportedFeatureTypes(QFlags<QGeoRouteRequest::FeatureType>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QFlags_QGeoRouteRequest_FeatureType_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setSupportedFeatureTypes(QFlags<QGeoRouteRequest::FeatureType>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSupportedFeatureTypes", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoutingManagerEngine_IDX]);

    // Call function/method
    {
        ::QFlags<QGeoRouteRequest::FeatureType> cppArg0 = QFlags<QGeoRouteRequest::FeatureType>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSupportedFeatureTypes(QFlags<QGeoRouteRequest::FeatureType>)
            cppSelf->setSupportedFeatureTypes(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRoutingManagerEngineFunc_setSupportedFeatureWeights(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoutingManagerEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoutingManagerEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRoutingManagerEngine::setSupportedFeatureWeights(QFlags<QGeoRouteRequest::FeatureWeight>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QFlags_QGeoRouteRequest_FeatureWeight_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setSupportedFeatureWeights(QFlags<QGeoRouteRequest::FeatureWeight>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSupportedFeatureWeights", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoutingManagerEngine_IDX]);

    // Call function/method
    {
        ::QFlags<QGeoRouteRequest::FeatureWeight> cppArg0 = QFlags<QGeoRouteRequest::FeatureWeight>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSupportedFeatureWeights(QFlags<QGeoRouteRequest::FeatureWeight>)
            cppSelf->setSupportedFeatureWeights(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRoutingManagerEngineFunc_setSupportedManeuverDetails(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoutingManagerEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoutingManagerEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRoutingManagerEngine::setSupportedManeuverDetails(QFlags<QGeoRouteRequest::ManeuverDetail>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QFlags_QGeoRouteRequest_ManeuverDetail_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setSupportedManeuverDetails(QFlags<QGeoRouteRequest::ManeuverDetail>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSupportedManeuverDetails", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoutingManagerEngine_IDX]);

    // Call function/method
    {
        ::QFlags<QGeoRouteRequest::ManeuverDetail> cppArg0 = QFlags<QGeoRouteRequest::ManeuverDetail>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSupportedManeuverDetails(QFlags<QGeoRouteRequest::ManeuverDetail>)
            cppSelf->setSupportedManeuverDetails(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRoutingManagerEngineFunc_setSupportedRouteOptimizations(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoutingManagerEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoutingManagerEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRoutingManagerEngine::setSupportedRouteOptimizations(QFlags<QGeoRouteRequest::RouteOptimization>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QFlags_QGeoRouteRequest_RouteOptimization_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setSupportedRouteOptimizations(QFlags<QGeoRouteRequest::RouteOptimization>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSupportedRouteOptimizations", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoutingManagerEngine_IDX]);

    // Call function/method
    {
        ::QFlags<QGeoRouteRequest::RouteOptimization> cppArg0 = QFlags<QGeoRouteRequest::RouteOptimization>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSupportedRouteOptimizations(QFlags<QGeoRouteRequest::RouteOptimization>)
            cppSelf->setSupportedRouteOptimizations(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRoutingManagerEngineFunc_setSupportedSegmentDetails(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoutingManagerEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoutingManagerEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRoutingManagerEngine::setSupportedSegmentDetails(QFlags<QGeoRouteRequest::SegmentDetail>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QFlags_QGeoRouteRequest_SegmentDetail_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setSupportedSegmentDetails(QFlags<QGeoRouteRequest::SegmentDetail>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSupportedSegmentDetails", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoutingManagerEngine_IDX]);

    // Call function/method
    {
        ::QFlags<QGeoRouteRequest::SegmentDetail> cppArg0 = QFlags<QGeoRouteRequest::SegmentDetail>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSupportedSegmentDetails(QFlags<QGeoRouteRequest::SegmentDetail>)
            cppSelf->setSupportedSegmentDetails(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRoutingManagerEngineFunc_setSupportedTravelModes(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoutingManagerEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoutingManagerEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRoutingManagerEngine::setSupportedTravelModes(QFlags<QGeoRouteRequest::TravelMode>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QFlags_QGeoRouteRequest_TravelMode_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setSupportedTravelModes(QFlags<QGeoRouteRequest::TravelMode>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSupportedTravelModes", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoutingManagerEngine_IDX]);

    // Call function/method
    {
        ::QFlags<QGeoRouteRequest::TravelMode> cppArg0 = QFlags<QGeoRouteRequest::TravelMode>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSupportedTravelModes(QFlags<QGeoRouteRequest::TravelMode>)
            cppSelf->setSupportedTravelModes(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRoutingManagerEngineFunc_supportedFeatureTypes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoutingManagerEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoutingManagerEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // supportedFeatureTypes()const
        QFlags<QGeoRouteRequest::FeatureType> cppResult = const_cast<const ::QGeoRoutingManagerEngine *>(cppSelf)->supportedFeatureTypes();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QFlags_QGeoRouteRequest_FeatureType_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRoutingManagerEngineFunc_supportedFeatureWeights(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoutingManagerEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoutingManagerEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // supportedFeatureWeights()const
        QFlags<QGeoRouteRequest::FeatureWeight> cppResult = const_cast<const ::QGeoRoutingManagerEngine *>(cppSelf)->supportedFeatureWeights();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QFlags_QGeoRouteRequest_FeatureWeight_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRoutingManagerEngineFunc_supportedManeuverDetails(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoutingManagerEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoutingManagerEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // supportedManeuverDetails()const
        QFlags<QGeoRouteRequest::ManeuverDetail> cppResult = const_cast<const ::QGeoRoutingManagerEngine *>(cppSelf)->supportedManeuverDetails();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QFlags_QGeoRouteRequest_ManeuverDetail_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRoutingManagerEngineFunc_supportedRouteOptimizations(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoutingManagerEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoutingManagerEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // supportedRouteOptimizations()const
        QFlags<QGeoRouteRequest::RouteOptimization> cppResult = const_cast<const ::QGeoRoutingManagerEngine *>(cppSelf)->supportedRouteOptimizations();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QFlags_QGeoRouteRequest_RouteOptimization_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRoutingManagerEngineFunc_supportedSegmentDetails(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoutingManagerEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoutingManagerEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // supportedSegmentDetails()const
        QFlags<QGeoRouteRequest::SegmentDetail> cppResult = const_cast<const ::QGeoRoutingManagerEngine *>(cppSelf)->supportedSegmentDetails();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QFlags_QGeoRouteRequest_SegmentDetail_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRoutingManagerEngineFunc_supportedTravelModes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoutingManagerEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoutingManagerEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // supportedTravelModes()const
        QFlags<QGeoRouteRequest::TravelMode> cppResult = const_cast<const ::QGeoRoutingManagerEngine *>(cppSelf)->supportedTravelModes();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QFlags_QGeoRouteRequest_TravelMode_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRoutingManagerEngineFunc_updateRoute(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoutingManagerEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoutingManagerEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "updateRoute", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGeoRoutingManagerEngine::updateRoute(QGeoRoute,QGeoCoordinate)->QGeoRouteReply*
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), (pyArgs[1])))) {
        overloadId = 0; // updateRoute(QGeoRoute,QGeoCoordinate)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "updateRoute", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoutingManagerEngine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QGeoRoute cppArg0_local;
        ::QGeoRoute *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QGeoCoordinate cppArg1_local;
        ::QGeoCoordinate *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // updateRoute(QGeoRoute,QGeoCoordinate)
            QGeoRouteReply * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGeoRoutingManagerEngine::updateRoute(*cppArg0, *cppArg1)
                : cppSelf->updateRoute(*cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteReply_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QGeoRoutingManagerEngine_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QGeoRoutingManagerEngine_methods[] = {
    {"calculateRoute", reinterpret_cast<PyCFunction>(Sbk_QGeoRoutingManagerEngineFunc_calculateRoute), METH_O, nullptr},
    {"locale", reinterpret_cast<PyCFunction>(Sbk_QGeoRoutingManagerEngineFunc_locale), METH_NOARGS, nullptr},
    {"managerName", reinterpret_cast<PyCFunction>(Sbk_QGeoRoutingManagerEngineFunc_managerName), METH_NOARGS, nullptr},
    {"managerVersion", reinterpret_cast<PyCFunction>(Sbk_QGeoRoutingManagerEngineFunc_managerVersion), METH_NOARGS, nullptr},
    {"measurementSystem", reinterpret_cast<PyCFunction>(Sbk_QGeoRoutingManagerEngineFunc_measurementSystem), METH_NOARGS, nullptr},
    {"setLocale", reinterpret_cast<PyCFunction>(Sbk_QGeoRoutingManagerEngineFunc_setLocale), METH_O, nullptr},
    {"setMeasurementSystem", reinterpret_cast<PyCFunction>(Sbk_QGeoRoutingManagerEngineFunc_setMeasurementSystem), METH_O, nullptr},
    {"setSupportedFeatureTypes", reinterpret_cast<PyCFunction>(Sbk_QGeoRoutingManagerEngineFunc_setSupportedFeatureTypes), METH_O, nullptr},
    {"setSupportedFeatureWeights", reinterpret_cast<PyCFunction>(Sbk_QGeoRoutingManagerEngineFunc_setSupportedFeatureWeights), METH_O, nullptr},
    {"setSupportedManeuverDetails", reinterpret_cast<PyCFunction>(Sbk_QGeoRoutingManagerEngineFunc_setSupportedManeuverDetails), METH_O, nullptr},
    {"setSupportedRouteOptimizations", reinterpret_cast<PyCFunction>(Sbk_QGeoRoutingManagerEngineFunc_setSupportedRouteOptimizations), METH_O, nullptr},
    {"setSupportedSegmentDetails", reinterpret_cast<PyCFunction>(Sbk_QGeoRoutingManagerEngineFunc_setSupportedSegmentDetails), METH_O, nullptr},
    {"setSupportedTravelModes", reinterpret_cast<PyCFunction>(Sbk_QGeoRoutingManagerEngineFunc_setSupportedTravelModes), METH_O, nullptr},
    {"supportedFeatureTypes", reinterpret_cast<PyCFunction>(Sbk_QGeoRoutingManagerEngineFunc_supportedFeatureTypes), METH_NOARGS, nullptr},
    {"supportedFeatureWeights", reinterpret_cast<PyCFunction>(Sbk_QGeoRoutingManagerEngineFunc_supportedFeatureWeights), METH_NOARGS, nullptr},
    {"supportedManeuverDetails", reinterpret_cast<PyCFunction>(Sbk_QGeoRoutingManagerEngineFunc_supportedManeuverDetails), METH_NOARGS, nullptr},
    {"supportedRouteOptimizations", reinterpret_cast<PyCFunction>(Sbk_QGeoRoutingManagerEngineFunc_supportedRouteOptimizations), METH_NOARGS, nullptr},
    {"supportedSegmentDetails", reinterpret_cast<PyCFunction>(Sbk_QGeoRoutingManagerEngineFunc_supportedSegmentDetails), METH_NOARGS, nullptr},
    {"supportedTravelModes", reinterpret_cast<PyCFunction>(Sbk_QGeoRoutingManagerEngineFunc_supportedTravelModes), METH_NOARGS, nullptr},
    {"updateRoute", reinterpret_cast<PyCFunction>(Sbk_QGeoRoutingManagerEngineFunc_updateRoute), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QGeoRoutingManagerEngine_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QGeoRoutingManagerEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoutingManagerEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QGeoRoutingManagerEngineWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QGeoRoutingManagerEngine_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QGeoRoutingManagerEngine_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QGeoRoutingManagerEngine_Type = nullptr;
static PyTypeObject *Sbk_QGeoRoutingManagerEngine_TypeF(void)
{
    return _Sbk_QGeoRoutingManagerEngine_Type;
}

static PyType_Slot Sbk_QGeoRoutingManagerEngine_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QGeoRoutingManagerEngine_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QGeoRoutingManagerEngine_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QGeoRoutingManagerEngine_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QGeoRoutingManagerEngine_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QGeoRoutingManagerEngine_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QGeoRoutingManagerEngine_spec = {
    "2:PySide6.QtLocation.QGeoRoutingManagerEngine",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QGeoRoutingManagerEngine_slots
};

} //extern "C"

static void *Sbk_QGeoRoutingManagerEngine_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QGeoRoutingManagerEngine *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QGeoRoutingManagerEngine_PythonToCpp_QGeoRoutingManagerEngine_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QGeoRoutingManagerEngine_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QGeoRoutingManagerEngine_PythonToCpp_QGeoRoutingManagerEngine_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QGeoRoutingManagerEngine_TypeF()))
        return QGeoRoutingManagerEngine_PythonToCpp_QGeoRoutingManagerEngine_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QGeoRoutingManagerEngine_PTR_CppToPython_QGeoRoutingManagerEngine(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QGeoRoutingManagerEngine *>(const_cast<void *>(cppIn)), Sbk_QGeoRoutingManagerEngine_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QGeoRoutingManagerEngine_SignatureStrings[] = {
    "PySide6.QtLocation.QGeoRoutingManagerEngine(self,parameters:QMap[QString, QVariant],parent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtLocation.QGeoRoutingManagerEngine.calculateRoute(self,request:PySide6.QtLocation.QGeoRouteRequest)->PySide6.QtLocation.QGeoRouteReply",
    "PySide6.QtLocation.QGeoRoutingManagerEngine.locale(self)->PySide6.QtCore.QLocale",
    "PySide6.QtLocation.QGeoRoutingManagerEngine.managerName(self)->QString",
    "PySide6.QtLocation.QGeoRoutingManagerEngine.managerVersion(self)->int",
    "PySide6.QtLocation.QGeoRoutingManagerEngine.measurementSystem(self)->PySide6.QtCore.QLocale.MeasurementSystem",
    "PySide6.QtLocation.QGeoRoutingManagerEngine.setLocale(self,locale:typing.Union[PySide6.QtCore.QLocale, PySide6.QtCore.QLocale.Language])",
    "PySide6.QtLocation.QGeoRoutingManagerEngine.setMeasurementSystem(self,system:PySide6.QtCore.QLocale.MeasurementSystem)",
    "PySide6.QtLocation.QGeoRoutingManagerEngine.setSupportedFeatureTypes(self,featureTypes:PySide6.QtLocation.QGeoRouteRequest.FeatureType)",
    "PySide6.QtLocation.QGeoRoutingManagerEngine.setSupportedFeatureWeights(self,featureWeights:PySide6.QtLocation.QGeoRouteRequest.FeatureWeight)",
    "PySide6.QtLocation.QGeoRoutingManagerEngine.setSupportedManeuverDetails(self,maneuverDetails:PySide6.QtLocation.QGeoRouteRequest.ManeuverDetail)",
    "PySide6.QtLocation.QGeoRoutingManagerEngine.setSupportedRouteOptimizations(self,optimizations:PySide6.QtLocation.QGeoRouteRequest.RouteOptimization)",
    "PySide6.QtLocation.QGeoRoutingManagerEngine.setSupportedSegmentDetails(self,segmentDetails:PySide6.QtLocation.QGeoRouteRequest.SegmentDetail)",
    "PySide6.QtLocation.QGeoRoutingManagerEngine.setSupportedTravelModes(self,travelModes:PySide6.QtLocation.QGeoRouteRequest.TravelMode)",
    "PySide6.QtLocation.QGeoRoutingManagerEngine.supportedFeatureTypes(self)->PySide6.QtLocation.QGeoRouteRequest.FeatureType",
    "PySide6.QtLocation.QGeoRoutingManagerEngine.supportedFeatureWeights(self)->PySide6.QtLocation.QGeoRouteRequest.FeatureWeight",
    "PySide6.QtLocation.QGeoRoutingManagerEngine.supportedManeuverDetails(self)->PySide6.QtLocation.QGeoRouteRequest.ManeuverDetail",
    "PySide6.QtLocation.QGeoRoutingManagerEngine.supportedRouteOptimizations(self)->PySide6.QtLocation.QGeoRouteRequest.RouteOptimization",
    "PySide6.QtLocation.QGeoRoutingManagerEngine.supportedSegmentDetails(self)->PySide6.QtLocation.QGeoRouteRequest.SegmentDetail",
    "PySide6.QtLocation.QGeoRoutingManagerEngine.supportedTravelModes(self)->PySide6.QtLocation.QGeoRouteRequest.TravelMode",
    "PySide6.QtLocation.QGeoRoutingManagerEngine.updateRoute(self,route:PySide6.QtLocation.QGeoRoute,position:PySide6.QtPositioning.QGeoCoordinate)->PySide6.QtLocation.QGeoRouteReply",
    nullptr}; // Sentinel
#else
static constexpr size_t QGeoRoutingManagerEngine_SignatureByteSize = 464;
static constexpr uint8_t QGeoRoutingManagerEngine_SignatureBytes[464] = {
    0x78, 0xda, 0xa5, 0x96, 0x3d, 0x4f, 0xc3, 0x30, 0x10, 0x86, 0x77, 0x7e, 0x05, 0x23, 0x95, 0x42,
    0x46, 0x86, 0x4a, 0xb0, 0xf0, 0xb5, 0x34, 0xb4, 0x69, 0xf8, 0x18, 0x10, 0x83, 0x69, 0x8e, 0x60,
    0xe4, 0xd8, 0xc6, 0x3e, 0x23, 0x85, 0x5f, 0x8f, 0xd3, 0xa4, 0x34, 0xee, 0x17, 0xb6, 0xd9, 0x92,
    0xf3, 0xdd, 0xfb, 0x3e, 0xbe, 0xf8, 0x14, 0xcf, 0x9a, 0x82, 0x96, 0x70, 0x96, 0xe6, 0x38, 0x11,
    0x0b, 0x82, 0x54, 0xf0, 0x34, 0xbf, 0x05, 0x31, 0x17, 0x06, 0x29, 0xaf, 0x32, 0xc2, 0x49, 0x05,
    0xea, 0x9a, 0x57, 0x94, 0xc3, 0x89, 0x06, 0xf6, 0x96, 0x48, 0xa2, 0x48, 0x0d, 0x08, 0x4a, 0x8f,
    0xf3, 0x8c, 0xc8, 0xe7, 0xbc, 0x40, 0x65, 0x33, 0x93, 0xe3, 0xfc, 0x91, 0x28, 0x4a, 0x38, 0xbe,
    0xb4, 0x29, 0xc0, 0x71, 0x3c, 0xfb, 0x95, 0xbe, 0x14, 0x0a, 0xd2, 0x7c, 0xfa, 0xfa, 0x01, 0x0b,
    0x3c, 0xe7, 0x86, 0x31, 0x89, 0x6a, 0x74, 0x34, 0xf3, 0xb7, 0x4e, 0x17, 0x84, 0x2d, 0x0c, 0x23,
    0x08, 0xed, 0x6a, 0x4f, 0xa2, 0xe0, 0xd3, 0x80, 0x1e, 0xfa, 0x6c, 0xe9, 0xc0, 0xbc, 0xcb, 0x19,
    0x9d, 0x5e, 0x1c, 0xce, 0x92, 0xac, 0x09, 0xe2, 0x61, 0x36, 0x83, 0x75, 0x1c, 0x8e, 0x76, 0xb7,
    0xd3, 0xc9, 0x72, 0x35, 0x48, 0xb0, 0xee, 0xde, 0xee, 0x6c, 0x6f, 0x57, 0xaa, 0x7d, 0x67, 0x63,
    0x64, 0x1e, 0xed, 0xe7, 0xb1, 0x79, 0x2b, 0x25, 0xca, 0x31, 0x4c, 0x05, 0x88, 0x36, 0x0a, 0x6a,
    0xfb, 0x15, 0x8b, 0x46, 0x23, 0xd4, 0x87, 0x37, 0x9a, 0x66, 0x9b, 0xf9, 0x41, 0x6e, 0x1a, 0x70,
    0xb2, 0x6e, 0x67, 0xd2, 0xb5, 0x76, 0x8c, 0x8d, 0xb4, 0x99, 0xe9, 0x03, 0xb7, 0xb5, 0xcf, 0xbb,
    0x7d, 0x93, 0xe3, 0x3d, 0x3c, 0x13, 0xc2, 0x2b, 0x63, 0x1d, 0x5e, 0x46, 0xa1, 0x20, 0xd9, 0xce,
    0x9d, 0x27, 0x7a, 0xf9, 0x3c, 0xf6, 0xdd, 0x7e, 0xb0, 0x6d, 0x61, 0xa4, 0x14, 0x0a, 0xa1, 0xbc,
    0x01, 0x82, 0x56, 0xea, 0xbe, 0x91, 0xa0, 0x3b, 0xeb, 0xb7, 0x41, 0xc4, 0xe7, 0xa8, 0xa7, 0x03,
    0x89, 0x7f, 0x73, 0x3c, 0x01, 0xad, 0xde, 0xd1, 0x25, 0xe9, 0x63, 0x21, 0x2c, 0x5d, 0x49, 0x3c,
    0x8d, 0x5d, 0x01, 0xf3, 0x05, 0xea, 0x0a, 0x90, 0x50, 0xd6, 0xe3, 0xd4, 0x6e, 0xd0, 0x8b, 0xc7,
    0x15, 0x8a, 0x07, 0x5a, 0x8a, 0x4e, 0x25, 0xd2, 0x9a, 0x7e, 0x2f, 0xcb, 0x7a, 0x26, 0x31, 0x0c,
    0x79, 0x11, 0x6d, 0x29, 0xc5, 0x43, 0x15, 0x50, 0xb5, 0x47, 0xd0, 0x69, 0x92, 0x76, 0x62, 0x5e,
    0x44, 0x8e, 0x4c, 0x3c, 0xcd, 0xbd, 0x22, 0x5f, 0xc0, 0x32, 0x51, 0xae, 0x0e, 0x32, 0xae, 0x03,
    0x5e, 0x1c, 0x6b, 0x81, 0x40, 0x88, 0xbd, 0xb3, 0xf4, 0xe7, 0x5f, 0x60, 0x6b, 0x80, 0xfe, 0x65,
    0x3c, 0x1c, 0x9e, 0x30, 0xeb, 0xae, 0x32, 0xce, 0x7c, 0xd7, 0xac, 0x78, 0xba, 0xbb, 0xa5, 0x71,
    0xf6, 0x7b, 0x26, 0xc3, 0x93, 0x60, 0xab, 0x3a, 0x0e, 0x62, 0xc7, 0x24, 0x78, 0x02, 0x38, 0x95,
    0x71, 0xe6, 0x9b, 0x07, 0xdf, 0xd3, 0x79, 0x5d, 0x16, 0x64, 0x6b, 0x64, 0xb9, 0x71, 0x2b, 0x6a,
    0x1f, 0x0f, 0x0e, 0x58, 0x22, 0x85, 0xa6, 0x6d, 0x68, 0x90, 0x35, 0xeb, 0x43, 0xed, 0x2f, 0xb7,
    0x4d, 0xbc, 0x14, 0x42, 0x95, 0x94, 0x5b, 0x69, 0xaf, 0xab, 0xd3, 0x0f, 0x36, 0x50, 0xdb, 0x82
};
#endif

PyTypeObject *init_QGeoRoutingManagerEngine(PyObject *module)
{
    if (SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoutingManagerEngine_IDX].type != nullptr)
        return SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoutingManagerEngine_IDX].type;

    Shiboken::AutoDecRef Sbk_QGeoRoutingManagerEngine_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QGeoRoutingManagerEngine_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QGeoRoutingManagerEngine",
        "QGeoRoutingManagerEngine*",
        &Sbk_QGeoRoutingManagerEngine_spec,
        &Shiboken::callCppDestructor< QGeoRoutingManagerEngine >,
        Sbk_QGeoRoutingManagerEngine_Type_bases.object(),
        0);
    auto *pyType = Sbk_QGeoRoutingManagerEngine_TypeF(); // references _Sbk_QGeoRoutingManagerEngine_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QGeoRoutingManagerEngine_SignatureStrings);
#else
    InitSignatureBytes(pyType, QGeoRoutingManagerEngine_SignatureBytes, QGeoRoutingManagerEngine_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QGeoRoutingManagerEngine_PropertyStrings);
    SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoutingManagerEngine_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QGeoRoutingManagerEngine_PythonToCpp_QGeoRoutingManagerEngine_PTR,
        is_QGeoRoutingManagerEngine_PythonToCpp_QGeoRoutingManagerEngine_PTR_Convertible,
        QGeoRoutingManagerEngine_PTR_CppToPython_QGeoRoutingManagerEngine);

    Shiboken::Conversions::registerConverterName(converter, "QGeoRoutingManagerEngine");
    Shiboken::Conversions::registerConverterName(converter, "QGeoRoutingManagerEngine*");
    Shiboken::Conversions::registerConverterName(converter, "QGeoRoutingManagerEngine&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QGeoRoutingManagerEngine).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QGeoRoutingManagerEngineWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QGeoRoutingManagerEngine_TypeF(), &Sbk_QGeoRoutingManagerEngine_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::QGeoRoutingManagerEngine::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QGeoRoutingManagerEngine::staticMetaObject, sizeof(QGeoRoutingManagerEngineWrapper));

    return pyType;
}
