// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtlocation_python.h"

// main header
#include "qgeoserviceproviderfactory_wrapper.h"

// Argument includes
#include <QMap>
#include <QString>
#include <QtLocation/qgeocodingmanagerengine.h>
#include <QtLocation/qgeoroutingmanagerengine.h>
#include <QtLocation/qgeoserviceprovider.h>
#include <QtLocation/qplacemanagerengine.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QGeoServiceProviderFactoryWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QGeoServiceProviderFactoryWrapper::QGeoServiceProviderFactoryWrapper()
{
}

::QGeoCodingManagerEngine * QGeoServiceProviderFactoryWrapper::createGeocodingManagerEngine(const ::QMap<QString,QVariant> & parameters, ::QGeoServiceProvider::Error * error, ::QString * errorString) const
{
    if (m_PyMethodCache[0])
        return this->::QGeoServiceProviderFactory::createGeocodingManagerEngine(parameters, error, errorString);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "createGeocodingManagerEngine";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QGeoServiceProviderFactory::createGeocodingManagerEngine(parameters, error, errorString);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[3] = {
        Shiboken::Conversions::copyToPython(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QMap_QString_QVariant_IDX], &parameters),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_Error_IDX])))->converter, error),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], errorString)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNN)",
        Shiboken::Conversions::copyToPython(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QMap_QString_QVariant_IDX], &parameters),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_Error_IDX])))->converter, error),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], errorString)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 3, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGeoServiceProviderFactory", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoCodingManagerEngine_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QGeoServiceProviderFactory", funcName, Shiboken::SbkType< QGeoCodingManagerEngine >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QGeoCodingManagerEngine *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QPlaceManagerEngine * QGeoServiceProviderFactoryWrapper::createPlaceManagerEngine(const ::QMap<QString,QVariant> & parameters, ::QGeoServiceProvider::Error * error, ::QString * errorString) const
{
    if (m_PyMethodCache[1])
        return this->::QGeoServiceProviderFactory::createPlaceManagerEngine(parameters, error, errorString);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "createPlaceManagerEngine";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QGeoServiceProviderFactory::createPlaceManagerEngine(parameters, error, errorString);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[3] = {
        Shiboken::Conversions::copyToPython(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QMap_QString_QVariant_IDX], &parameters),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_Error_IDX])))->converter, error),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], errorString)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNN)",
        Shiboken::Conversions::copyToPython(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QMap_QString_QVariant_IDX], &parameters),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_Error_IDX])))->converter, error),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], errorString)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 3, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGeoServiceProviderFactory", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceManagerEngine_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QGeoServiceProviderFactory", funcName, Shiboken::SbkType< QPlaceManagerEngine >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QPlaceManagerEngine *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QGeoRoutingManagerEngine * QGeoServiceProviderFactoryWrapper::createRoutingManagerEngine(const ::QMap<QString,QVariant> & parameters, ::QGeoServiceProvider::Error * error, ::QString * errorString) const
{
    if (m_PyMethodCache[2])
        return this->::QGeoServiceProviderFactory::createRoutingManagerEngine(parameters, error, errorString);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "createRoutingManagerEngine";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QGeoServiceProviderFactory::createRoutingManagerEngine(parameters, error, errorString);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[3] = {
        Shiboken::Conversions::copyToPython(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QMap_QString_QVariant_IDX], &parameters),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_Error_IDX])))->converter, error),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], errorString)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNN)",
        Shiboken::Conversions::copyToPython(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QMap_QString_QVariant_IDX], &parameters),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_Error_IDX])))->converter, error),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], errorString)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 3, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGeoServiceProviderFactory", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoutingManagerEngine_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QGeoServiceProviderFactory", funcName, Shiboken::SbkType< QGeoRoutingManagerEngine >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QGeoRoutingManagerEngine *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QGeoServiceProviderFactoryWrapper::~QGeoServiceProviderFactoryWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGeoServiceProviderFactory_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QGeoServiceProviderFactory >()))
        return -1;

    QGeoServiceProviderFactoryWrapper *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProviderFactory_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QGeoServiceProviderFactory()
        cptr = new QGeoServiceProviderFactoryWrapper();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QGeoServiceProviderFactory >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QGeoServiceProviderFactoryFunc_createGeocodingManagerEngine(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoServiceProviderFactory *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProviderFactory_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "createGeocodingManagerEngine", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGeoServiceProviderFactory::createGeocodingManagerEngine(QMap<QString,QVariant>,QGeoServiceProvider::Error*,QString*)const->QGeoCodingManagerEngine*
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QMap_QString_QVariant_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_Error_IDX])))->converter, (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
        overloadId = 0; // createGeocodingManagerEngine(QMap<QString,QVariant>,QGeoServiceProvider::Error*,QString*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "createGeocodingManagerEngine", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProviderFactory_IDX]);

    // Call function/method
    {
        ::QMap<QString,QVariant> cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QGeoServiceProvider::Error cppArg1{QGeoServiceProvider::NoError};
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QString *cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createGeocodingManagerEngine(QMap<QString,QVariant>,QGeoServiceProvider::Error*,QString*)const
            QGeoCodingManagerEngine * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QGeoServiceProviderFactory *>(cppSelf)->::QGeoServiceProviderFactory::createGeocodingManagerEngine(cppArg0, &cppArg1, cppArg2)
                : const_cast<const ::QGeoServiceProviderFactory *>(cppSelf)->createGeocodingManagerEngine(cppArg0, &cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoCodingManagerEngine_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoServiceProviderFactoryFunc_createPlaceManagerEngine(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoServiceProviderFactory *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProviderFactory_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "createPlaceManagerEngine", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGeoServiceProviderFactory::createPlaceManagerEngine(QMap<QString,QVariant>,QGeoServiceProvider::Error*,QString*)const->QPlaceManagerEngine*
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QMap_QString_QVariant_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_Error_IDX])))->converter, (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
        overloadId = 0; // createPlaceManagerEngine(QMap<QString,QVariant>,QGeoServiceProvider::Error*,QString*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "createPlaceManagerEngine", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProviderFactory_IDX]);

    // Call function/method
    {
        ::QMap<QString,QVariant> cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QGeoServiceProvider::Error cppArg1{QGeoServiceProvider::NoError};
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QString *cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createPlaceManagerEngine(QMap<QString,QVariant>,QGeoServiceProvider::Error*,QString*)const
            QPlaceManagerEngine * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QGeoServiceProviderFactory *>(cppSelf)->::QGeoServiceProviderFactory::createPlaceManagerEngine(cppArg0, &cppArg1, cppArg2)
                : const_cast<const ::QGeoServiceProviderFactory *>(cppSelf)->createPlaceManagerEngine(cppArg0, &cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceManagerEngine_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoServiceProviderFactoryFunc_createRoutingManagerEngine(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoServiceProviderFactory *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProviderFactory_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "createRoutingManagerEngine", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGeoServiceProviderFactory::createRoutingManagerEngine(QMap<QString,QVariant>,QGeoServiceProvider::Error*,QString*)const->QGeoRoutingManagerEngine*
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QMap_QString_QVariant_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_Error_IDX])))->converter, (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
        overloadId = 0; // createRoutingManagerEngine(QMap<QString,QVariant>,QGeoServiceProvider::Error*,QString*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "createRoutingManagerEngine", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProviderFactory_IDX]);

    // Call function/method
    {
        ::QMap<QString,QVariant> cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QGeoServiceProvider::Error cppArg1{QGeoServiceProvider::NoError};
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QString *cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createRoutingManagerEngine(QMap<QString,QVariant>,QGeoServiceProvider::Error*,QString*)const
            QGeoRoutingManagerEngine * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QGeoServiceProviderFactory *>(cppSelf)->::QGeoServiceProviderFactory::createRoutingManagerEngine(cppArg0, &cppArg1, cppArg2)
                : const_cast<const ::QGeoServiceProviderFactory *>(cppSelf)->createRoutingManagerEngine(cppArg0, &cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoutingManagerEngine_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QGeoServiceProviderFactory_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QGeoServiceProviderFactory_methods[] = {
    {"createGeocodingManagerEngine", reinterpret_cast<PyCFunction>(Sbk_QGeoServiceProviderFactoryFunc_createGeocodingManagerEngine), METH_VARARGS, nullptr},
    {"createPlaceManagerEngine", reinterpret_cast<PyCFunction>(Sbk_QGeoServiceProviderFactoryFunc_createPlaceManagerEngine), METH_VARARGS, nullptr},
    {"createRoutingManagerEngine", reinterpret_cast<PyCFunction>(Sbk_QGeoServiceProviderFactoryFunc_createRoutingManagerEngine), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QGeoServiceProviderFactory_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QGeoServiceProviderFactory *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProviderFactory_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QGeoServiceProviderFactoryWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QGeoServiceProviderFactory_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QGeoServiceProviderFactory_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QGeoServiceProviderFactory_Type = nullptr;
static PyTypeObject *Sbk_QGeoServiceProviderFactory_TypeF(void)
{
    return _Sbk_QGeoServiceProviderFactory_Type;
}

static PyType_Slot Sbk_QGeoServiceProviderFactory_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QGeoServiceProviderFactory_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QGeoServiceProviderFactory_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QGeoServiceProviderFactory_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QGeoServiceProviderFactory_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QGeoServiceProviderFactory_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QGeoServiceProviderFactory_spec = {
    "2:PySide6.QtLocation.QGeoServiceProviderFactory",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QGeoServiceProviderFactory_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QGeoServiceProviderFactory_PythonToCpp_QGeoServiceProviderFactory_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QGeoServiceProviderFactory_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QGeoServiceProviderFactory_PythonToCpp_QGeoServiceProviderFactory_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QGeoServiceProviderFactory_TypeF()))
        return QGeoServiceProviderFactory_PythonToCpp_QGeoServiceProviderFactory_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QGeoServiceProviderFactory_PTR_CppToPython_QGeoServiceProviderFactory(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QGeoServiceProviderFactory *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QGeoServiceProviderFactory_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QGeoServiceProviderFactory_SignatureStrings[] = {
    "PySide6.QtLocation.QGeoServiceProviderFactory(self)",
    "PySide6.QtLocation.QGeoServiceProviderFactory.createGeocodingManagerEngine(self,parameters:QMap[QString, QVariant],error:PySide6.QtLocation.QGeoServiceProvider.Error,errorString:QString*)->PySide6.QtLocation.QGeoCodingManagerEngine",
    "PySide6.QtLocation.QGeoServiceProviderFactory.createPlaceManagerEngine(self,parameters:QMap[QString, QVariant],error:PySide6.QtLocation.QGeoServiceProvider.Error,errorString:QString*)->PySide6.QtLocation.QPlaceManagerEngine",
    "PySide6.QtLocation.QGeoServiceProviderFactory.createRoutingManagerEngine(self,parameters:QMap[QString, QVariant],error:PySide6.QtLocation.QGeoServiceProvider.Error,errorString:QString*)->PySide6.QtLocation.QGeoRoutingManagerEngine",
    nullptr}; // Sentinel
#else
static constexpr size_t QGeoServiceProviderFactory_SignatureByteSize = 175;
static constexpr uint8_t QGeoServiceProviderFactory_SignatureBytes[175] = {
    0x78, 0xda, 0xcd, 0x91, 0xb1, 0x0e, 0x82, 0x40, 0x10, 0x44, 0x7b, 0xbe, 0xc2, 0x52, 0x0c, 0x5e,
    0x69, 0x41, 0x61, 0x63, 0xd0, 0x46, 0x92, 0x3b, 0x49, 0x6c, 0x8c, 0xc5, 0xe6, 0x58, 0xc9, 0x25,
    0x70, 0x4b, 0x96, 0x95, 0x84, 0xbf, 0x17, 0xc5, 0x0e, 0x4d, 0x94, 0x8a, 0x7a, 0x66, 0xde, 0xce,
    0x64, 0x75, 0x97, 0xb9, 0x1c, 0x37, 0xca, 0xc8, 0x91, 0x2c, 0x88, 0x23, 0xaf, 0xcc, 0x01, 0x29,
    0x43, 0x6e, 0x9d, 0x45, 0xcd, 0xd4, 0xf6, 0x32, 0xef, 0xc1, 0x0a, 0x71, 0xb7, 0x6c, 0xb0, 0xbc,
    0x85, 0x81, 0xfe, 0x27, 0xa3, 0x2c, 0x23, 0x08, 0xf6, 0xba, 0xa5, 0xdc, 0xf9, 0x22, 0x05, 0x0f,
    0x05, 0x72, 0xe2, 0x0b, 0xe7, 0xf1, 0x05, 0x8c, 0x6a, 0x60, 0xa8, 0x50, 0x90, 0x9b, 0xd8, 0xa4,
    0x50, 0x5f, 0x4c, 0x26, 0xdc, 0x3b, 0xa3, 0x85, 0x39, 0x03, 0x3b, 0xf0, 0x72, 0x8d, 0x90, 0x99,
    0x38, 0xfe, 0xed, 0xb0, 0x4a, 0x9e, 0xe6, 0x21, 0x32, 0x90, 0xe2, 0x37, 0x71, 0x15, 0xae, 0xb7,
    0x5f, 0x18, 0xbb, 0x71, 0xb9, 0x49, 0x3b, 0x75, 0x09, 0x16, 0xe7, 0xb8, 0x71, 0x5c, 0x6c, 0xd2,
    0xbe, 0x13, 0xdd, 0x65, 0xbe, 0x5f, 0xfc, 0xd4, 0x2e, 0x78, 0x00, 0xdc, 0x05, 0x14, 0x4f
};
#endif

PyTypeObject *init_QGeoServiceProviderFactory(PyObject *module)
{
    if (SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProviderFactory_IDX].type != nullptr)
        return SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProviderFactory_IDX].type;

    Shiboken::AutoDecRef Sbk_QGeoServiceProviderFactory_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QGeoServiceProviderFactory_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QGeoServiceProviderFactory",
        "QGeoServiceProviderFactory*",
        &Sbk_QGeoServiceProviderFactory_spec,
        &Shiboken::callCppDestructor< QGeoServiceProviderFactory >,
        Sbk_QGeoServiceProviderFactory_Type_bases.object(),
        0);
    auto *pyType = Sbk_QGeoServiceProviderFactory_TypeF(); // references _Sbk_QGeoServiceProviderFactory_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QGeoServiceProviderFactory_SignatureStrings);
#else
    InitSignatureBytes(pyType, QGeoServiceProviderFactory_SignatureBytes, QGeoServiceProviderFactory_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QGeoServiceProviderFactory_PropertyStrings);
    SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProviderFactory_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QGeoServiceProviderFactory_PythonToCpp_QGeoServiceProviderFactory_PTR,
        is_QGeoServiceProviderFactory_PythonToCpp_QGeoServiceProviderFactory_PTR_Convertible,
        QGeoServiceProviderFactory_PTR_CppToPython_QGeoServiceProviderFactory);

    Shiboken::Conversions::registerConverterName(converter, "QGeoServiceProviderFactory");
    Shiboken::Conversions::registerConverterName(converter, "QGeoServiceProviderFactory*");
    Shiboken::Conversions::registerConverterName(converter, "QGeoServiceProviderFactory&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QGeoServiceProviderFactory).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QGeoServiceProviderFactoryWrapper).name());

    qRegisterMetaType< ::QGeoServiceProviderFactory *>();

    return pyType;
}
