// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtlocation_python.h"

// main header
#include "qplace_wrapper.h"

// Argument includes
#include <QList>
#include <QMap>
#include <QString>
#include <QStringList>
#include <QtLocation/qlocation.h>
#include <QtLocation/qplace.h>
#include <QtLocation/qplaceattribute.h>
#include <QtLocation/qplacecategory.h>
#include <QtLocation/qplacecontactdetail.h>
#include <QtLocation/qplacecontent.h>
#include <QtLocation/qplaceicon.h>
#include <QtLocation/qplaceratings.h>
#include <QtLocation/qplacesupplier.h>
#include <QtPositioning/qgeolocation.h>
#include <qurl.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPlace_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QPlace >()))
        return -1;

    ::QPlace *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QPlace", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QPlace::QPlace()
    // 1: QPlace::QPlace(QPlace)
    if (numArgs == 0) {
        overloadId = 0; // QPlace()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QPlace(QPlace)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QPlace()
        {

            // QPlace()
            cptr = new ::QPlace();
            break;
        }
        case 1: // QPlace(const QPlace &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPlace cppArg0_local;
            ::QPlace *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QPlace(QPlace)
                cptr = new ::QPlace(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QPlace >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QPlaceFunc_appendContactDetail(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "appendContactDetail", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPlace::appendContactDetail(QString,QPlaceContactDetail)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContactDetail_IDX]), (pyArgs[1])))) {
        overloadId = 0; // appendContactDetail(QString,QPlaceContactDetail)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "appendContactDetail", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QPlaceContactDetail cppArg1_local;
        ::QPlaceContactDetail *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // appendContactDetail(QString,QPlaceContactDetail)
            cppSelf->appendContactDetail(cppArg0, *cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceFunc_attribution(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // attribution()const
        QString cppResult = const_cast<const ::QPlace *>(cppSelf)->attribution();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceFunc_categories(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // categories()const
        QList<QPlaceCategory> cppResult = const_cast<const ::QPlace *>(cppSelf)->categories();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QList_QPlaceCategory_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceFunc_contactDetails(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlace::contactDetails(QString)const->QList<QPlaceContactDetail>
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // contactDetails(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "contactDetails", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // contactDetails(QString)const
            QList<QPlaceContactDetail> cppResult = const_cast<const ::QPlace *>(cppSelf)->contactDetails(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QList_QPlaceContactDetail_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceFunc_contactTypes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // contactTypes()const
        QStringList cppResult = const_cast<const ::QPlace *>(cppSelf)->contactTypes();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceFunc_content(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlace::content(QPlaceContent::Type)const->QMap<int,QPlaceContent>
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_Type_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // content(QPlaceContent::Type)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "content", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]);

    // Call function/method
    {
        ::QPlaceContent::Type cppArg0{QPlaceContent::NoType};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // content(QPlaceContent::Type)const
            QMap<int,QPlaceContent> cppResult = const_cast<const ::QPlace *>(cppSelf)->content(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QMap_int_QPlaceContent_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceFunc_detailsFetched(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // detailsFetched()const
        bool cppResult = const_cast<const ::QPlace *>(cppSelf)->detailsFetched();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceFunc_extendedAttribute(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlace::extendedAttribute(QString)const->QPlaceAttribute
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // extendedAttribute(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "extendedAttribute", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // extendedAttribute(QString)const
            QPlaceAttribute cppResult = const_cast<const ::QPlace *>(cppSelf)->extendedAttribute(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceAttribute_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceFunc_extendedAttributeTypes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // extendedAttributeTypes()const
        QStringList cppResult = const_cast<const ::QPlace *>(cppSelf)->extendedAttributeTypes();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceFunc_icon(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // icon()const
        QPlaceIcon cppResult = const_cast<const ::QPlace *>(cppSelf)->icon();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceIcon_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceFunc_insertContent(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "insertContent", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPlace::insertContent(QPlaceContent::Type,QMap<int,QPlaceContent>)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_Type_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QMap_int_QPlaceContent_IDX], (pyArgs[1])))) {
        overloadId = 0; // insertContent(QPlaceContent::Type,QMap<int,QPlaceContent>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "insertContent", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]);

    // Call function/method
    {
        ::QPlaceContent::Type cppArg0{QPlaceContent::NoType};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QMap<int,QPlaceContent> cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // insertContent(QPlaceContent::Type,QMap<int,QPlaceContent>)
            cppSelf->insertContent(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceFunc_isEmpty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isEmpty()const
        bool cppResult = const_cast<const ::QPlace *>(cppSelf)->isEmpty();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceFunc_location(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // location()const
        QGeoLocation cppResult = const_cast<const ::QPlace *>(cppSelf)->location();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoLocation_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // name()const
        QString cppResult = const_cast<const ::QPlace *>(cppSelf)->name();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceFunc_placeId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // placeId()const
        QString cppResult = const_cast<const ::QPlace *>(cppSelf)->placeId();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceFunc_primaryEmail(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // primaryEmail()const
        QString cppResult = const_cast<const ::QPlace *>(cppSelf)->primaryEmail();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceFunc_primaryFax(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // primaryFax()const
        QString cppResult = const_cast<const ::QPlace *>(cppSelf)->primaryFax();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceFunc_primaryPhone(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // primaryPhone()const
        QString cppResult = const_cast<const ::QPlace *>(cppSelf)->primaryPhone();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceFunc_primaryWebsite(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // primaryWebsite()const
        QUrl cppResult = const_cast<const ::QPlace *>(cppSelf)->primaryWebsite();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceFunc_ratings(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ratings()const
        QPlaceRatings cppResult = const_cast<const ::QPlace *>(cppSelf)->ratings();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceRatings_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceFunc_removeContactDetails(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlace::removeContactDetails(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // removeContactDetails(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeContactDetails", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeContactDetails(QString)
            cppSelf->removeContactDetails(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceFunc_removeExtendedAttribute(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlace::removeExtendedAttribute(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // removeExtendedAttribute(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeExtendedAttribute", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeExtendedAttribute(QString)
            cppSelf->removeExtendedAttribute(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceFunc_setAttribution(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlace::setAttribution(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setAttribution(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAttribution", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAttribution(QString)
            cppSelf->setAttribution(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceFunc_setCategories(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlace::setCategories(QList<QPlaceCategory>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QList_QPlaceCategory_IDX], (pyArg)))) {
        overloadId = 0; // setCategories(QList<QPlaceCategory>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCategories", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]);

    // Call function/method
    {
        ::QList<QPlaceCategory> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCategories(QList<QPlaceCategory>)
            cppSelf->setCategories(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceFunc_setCategory(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlace::setCategory(QPlaceCategory)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceCategory_IDX]), (pyArg)))) {
        overloadId = 0; // setCategory(QPlaceCategory)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCategory", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPlaceCategory cppArg0_local;
        ::QPlaceCategory *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setCategory(QPlaceCategory)
            cppSelf->setCategory(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceFunc_setContactDetails(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setContactDetails", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPlace::setContactDetails(QString,QList<QPlaceContactDetail>)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QList_QPlaceContactDetail_IDX], (pyArgs[1])))) {
        overloadId = 0; // setContactDetails(QString,QList<QPlaceContactDetail>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setContactDetails", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QList<QPlaceContactDetail> cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setContactDetails(QString,QList<QPlaceContactDetail>)
            cppSelf->setContactDetails(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceFunc_setContent(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setContent", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPlace::setContent(QPlaceContent::Type,QMap<int,QPlaceContent>)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_Type_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QMap_int_QPlaceContent_IDX], (pyArgs[1])))) {
        overloadId = 0; // setContent(QPlaceContent::Type,QMap<int,QPlaceContent>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setContent", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]);

    // Call function/method
    {
        ::QPlaceContent::Type cppArg0{QPlaceContent::NoType};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QMap<int,QPlaceContent> cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setContent(QPlaceContent::Type,QMap<int,QPlaceContent>)
            cppSelf->setContent(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceFunc_setDetailsFetched(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlace::setDetailsFetched(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setDetailsFetched(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDetailsFetched", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDetailsFetched(bool)
            cppSelf->setDetailsFetched(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceFunc_setExtendedAttribute(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setExtendedAttribute", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPlace::setExtendedAttribute(QString,QPlaceAttribute)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceAttribute_IDX]), (pyArgs[1])))) {
        overloadId = 0; // setExtendedAttribute(QString,QPlaceAttribute)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setExtendedAttribute", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QPlaceAttribute cppArg1_local;
        ::QPlaceAttribute *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setExtendedAttribute(QString,QPlaceAttribute)
            cppSelf->setExtendedAttribute(cppArg0, *cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceFunc_setIcon(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlace::setIcon(QPlaceIcon)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceIcon_IDX]), (pyArg)))) {
        overloadId = 0; // setIcon(QPlaceIcon)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setIcon", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPlaceIcon cppArg0_local;
        ::QPlaceIcon *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setIcon(QPlaceIcon)
            cppSelf->setIcon(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceFunc_setLocation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlace::setLocation(QGeoLocation)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoLocation_IDX]), (pyArg)))) {
        overloadId = 0; // setLocation(QGeoLocation)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLocation", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGeoLocation cppArg0_local;
        ::QGeoLocation *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setLocation(QGeoLocation)
            cppSelf->setLocation(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceFunc_setName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlace::setName(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setName", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setName(QString)
            cppSelf->setName(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceFunc_setPlaceId(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlace::setPlaceId(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setPlaceId(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPlaceId", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPlaceId(QString)
            cppSelf->setPlaceId(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceFunc_setRatings(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlace::setRatings(QPlaceRatings)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceRatings_IDX]), (pyArg)))) {
        overloadId = 0; // setRatings(QPlaceRatings)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRatings", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPlaceRatings cppArg0_local;
        ::QPlaceRatings *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setRatings(QPlaceRatings)
            cppSelf->setRatings(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceFunc_setSupplier(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlace::setSupplier(QPlaceSupplier)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSupplier_IDX]), (pyArg)))) {
        overloadId = 0; // setSupplier(QPlaceSupplier)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSupplier", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPlaceSupplier cppArg0_local;
        ::QPlaceSupplier *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setSupplier(QPlaceSupplier)
            cppSelf->setSupplier(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceFunc_setTotalContentCount(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setTotalContentCount", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPlace::setTotalContentCount(QPlaceContent::Type,int)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_Type_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // setTotalContentCount(QPlaceContent::Type,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setTotalContentCount", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]);

    // Call function/method
    {
        ::QPlaceContent::Type cppArg0{QPlaceContent::NoType};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTotalContentCount(QPlaceContent::Type,int)
            cppSelf->setTotalContentCount(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceFunc_setVisibility(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlace::setVisibility(QLocation::Visibility)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QLocation_Visibility_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setVisibility(QLocation::Visibility)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setVisibility", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]);

    // Call function/method
    {
        ::QLocation::Visibility cppArg0{QLocation::UnspecifiedVisibility};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setVisibility(QLocation::Visibility)
            cppSelf->setVisibility(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceFunc_supplier(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // supplier()const
        QPlaceSupplier cppResult = const_cast<const ::QPlace *>(cppSelf)->supplier();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSupplier_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlace::swap(QPlace&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QPlace&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPlace cppArg0_local;
        ::QPlace *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QPlace&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceFunc_totalContentCount(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlace::totalContentCount(QPlaceContent::Type)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_Type_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // totalContentCount(QPlaceContent::Type)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "totalContentCount", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]);

    // Call function/method
    {
        ::QPlaceContent::Type cppArg0{QPlaceContent::NoType};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // totalContentCount(QPlaceContent::Type)const
            int cppResult = const_cast<const ::QPlace *>(cppSelf)->totalContentCount(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceFunc_visibility(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // visibility()const
        QLocation::Visibility cppResult = const_cast<const ::QPlace *>(cppSelf)->visibility();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QLocation_Visibility_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlace__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QPlace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QPlace_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QPlace_methods[] = {
    {"appendContactDetail", reinterpret_cast<PyCFunction>(Sbk_QPlaceFunc_appendContactDetail), METH_VARARGS, nullptr},
    {"attribution", reinterpret_cast<PyCFunction>(Sbk_QPlaceFunc_attribution), METH_NOARGS, nullptr},
    {"categories", reinterpret_cast<PyCFunction>(Sbk_QPlaceFunc_categories), METH_NOARGS, nullptr},
    {"contactDetails", reinterpret_cast<PyCFunction>(Sbk_QPlaceFunc_contactDetails), METH_O, nullptr},
    {"contactTypes", reinterpret_cast<PyCFunction>(Sbk_QPlaceFunc_contactTypes), METH_NOARGS, nullptr},
    {"content", reinterpret_cast<PyCFunction>(Sbk_QPlaceFunc_content), METH_O, nullptr},
    {"detailsFetched", reinterpret_cast<PyCFunction>(Sbk_QPlaceFunc_detailsFetched), METH_NOARGS, nullptr},
    {"extendedAttribute", reinterpret_cast<PyCFunction>(Sbk_QPlaceFunc_extendedAttribute), METH_O, nullptr},
    {"extendedAttributeTypes", reinterpret_cast<PyCFunction>(Sbk_QPlaceFunc_extendedAttributeTypes), METH_NOARGS, nullptr},
    {"icon", reinterpret_cast<PyCFunction>(Sbk_QPlaceFunc_icon), METH_NOARGS, nullptr},
    {"insertContent", reinterpret_cast<PyCFunction>(Sbk_QPlaceFunc_insertContent), METH_VARARGS, nullptr},
    {"isEmpty", reinterpret_cast<PyCFunction>(Sbk_QPlaceFunc_isEmpty), METH_NOARGS, nullptr},
    {"location", reinterpret_cast<PyCFunction>(Sbk_QPlaceFunc_location), METH_NOARGS, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_QPlaceFunc_name), METH_NOARGS, nullptr},
    {"placeId", reinterpret_cast<PyCFunction>(Sbk_QPlaceFunc_placeId), METH_NOARGS, nullptr},
    {"primaryEmail", reinterpret_cast<PyCFunction>(Sbk_QPlaceFunc_primaryEmail), METH_NOARGS, nullptr},
    {"primaryFax", reinterpret_cast<PyCFunction>(Sbk_QPlaceFunc_primaryFax), METH_NOARGS, nullptr},
    {"primaryPhone", reinterpret_cast<PyCFunction>(Sbk_QPlaceFunc_primaryPhone), METH_NOARGS, nullptr},
    {"primaryWebsite", reinterpret_cast<PyCFunction>(Sbk_QPlaceFunc_primaryWebsite), METH_NOARGS, nullptr},
    {"ratings", reinterpret_cast<PyCFunction>(Sbk_QPlaceFunc_ratings), METH_NOARGS, nullptr},
    {"removeContactDetails", reinterpret_cast<PyCFunction>(Sbk_QPlaceFunc_removeContactDetails), METH_O, nullptr},
    {"removeExtendedAttribute", reinterpret_cast<PyCFunction>(Sbk_QPlaceFunc_removeExtendedAttribute), METH_O, nullptr},
    {"setAttribution", reinterpret_cast<PyCFunction>(Sbk_QPlaceFunc_setAttribution), METH_O, nullptr},
    {"setCategories", reinterpret_cast<PyCFunction>(Sbk_QPlaceFunc_setCategories), METH_O, nullptr},
    {"setCategory", reinterpret_cast<PyCFunction>(Sbk_QPlaceFunc_setCategory), METH_O, nullptr},
    {"setContactDetails", reinterpret_cast<PyCFunction>(Sbk_QPlaceFunc_setContactDetails), METH_VARARGS, nullptr},
    {"setContent", reinterpret_cast<PyCFunction>(Sbk_QPlaceFunc_setContent), METH_VARARGS, nullptr},
    {"setDetailsFetched", reinterpret_cast<PyCFunction>(Sbk_QPlaceFunc_setDetailsFetched), METH_O, nullptr},
    {"setExtendedAttribute", reinterpret_cast<PyCFunction>(Sbk_QPlaceFunc_setExtendedAttribute), METH_VARARGS, nullptr},
    {"setIcon", reinterpret_cast<PyCFunction>(Sbk_QPlaceFunc_setIcon), METH_O, nullptr},
    {"setLocation", reinterpret_cast<PyCFunction>(Sbk_QPlaceFunc_setLocation), METH_O, nullptr},
    {"setName", reinterpret_cast<PyCFunction>(Sbk_QPlaceFunc_setName), METH_O, nullptr},
    {"setPlaceId", reinterpret_cast<PyCFunction>(Sbk_QPlaceFunc_setPlaceId), METH_O, nullptr},
    {"setRatings", reinterpret_cast<PyCFunction>(Sbk_QPlaceFunc_setRatings), METH_O, nullptr},
    {"setSupplier", reinterpret_cast<PyCFunction>(Sbk_QPlaceFunc_setSupplier), METH_O, nullptr},
    {"setTotalContentCount", reinterpret_cast<PyCFunction>(Sbk_QPlaceFunc_setTotalContentCount), METH_VARARGS, nullptr},
    {"setVisibility", reinterpret_cast<PyCFunction>(Sbk_QPlaceFunc_setVisibility), METH_O, nullptr},
    {"supplier", reinterpret_cast<PyCFunction>(Sbk_QPlaceFunc_supplier), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QPlaceFunc_swap), METH_O, nullptr},
    {"totalContentCount", reinterpret_cast<PyCFunction>(Sbk_QPlaceFunc_totalContentCount), METH_O, nullptr},
    {"visibility", reinterpret_cast<PyCFunction>(Sbk_QPlaceFunc_visibility), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QPlace__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QPlace_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QPlace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), (pyArg)))) {
                // operator!=(const QPlace &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QPlace cppArg0_local;
                ::QPlace *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), (pyArg)))) {
                // operator==(const QPlace &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QPlace cppArg0_local;
                ::QPlace *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QPlace_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QPlace_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QPlace_Type = nullptr;
static PyTypeObject *Sbk_QPlace_TypeF(void)
{
    return _Sbk_QPlace_Type;
}

static PyType_Slot Sbk_QPlace_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QPlace_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QPlace_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QPlace_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QPlace_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QPlace_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QPlace_spec = {
    "2:PySide6.QtLocation.QPlace",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QPlace_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QPlace_PythonToCpp_QPlace_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QPlace_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QPlace_PythonToCpp_QPlace_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QPlace_TypeF()))
        return QPlace_PythonToCpp_QPlace_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QPlace_PTR_CppToPython_QPlace(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QPlace_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QPlace_COPY_CppToPython_QPlace(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QPlace *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QPlace_TypeF(), new ::QPlace(*source), true, true);
}

// Python to C++ copy conversion.
static void QPlace_PythonToCpp_QPlace_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QPlace *>(cppOut) = *reinterpret_cast< ::QPlace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QPlace_PythonToCpp_QPlace_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QPlace_TypeF()))
        return QPlace_PythonToCpp_QPlace_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QPlace_SignatureStrings[] = {
    "1:PySide6.QtLocation.QPlace(self)",
    "0:PySide6.QtLocation.QPlace(self,other:PySide6.QtLocation.QPlace)",
    "PySide6.QtLocation.QPlace.appendContactDetail(self,contactType:QString,detail:PySide6.QtLocation.QPlaceContactDetail)",
    "PySide6.QtLocation.QPlace.attribution(self)->QString",
    "PySide6.QtLocation.QPlace.categories(self)->QList[PySide6.QtLocation.QPlaceCategory]",
    "PySide6.QtLocation.QPlace.contactDetails(self,contactType:QString)->QList[PySide6.QtLocation.QPlaceContactDetail]",
    "PySide6.QtLocation.QPlace.contactTypes(self)->QStringList",
    "PySide6.QtLocation.QPlace.content(self,type:PySide6.QtLocation.QPlaceContent.Type)->QMap[int, PySide6.QtLocation.QPlaceContent]",
    "PySide6.QtLocation.QPlace.detailsFetched(self)->bool",
    "PySide6.QtLocation.QPlace.extendedAttribute(self,attributeType:QString)->PySide6.QtLocation.QPlaceAttribute",
    "PySide6.QtLocation.QPlace.extendedAttributeTypes(self)->QStringList",
    "PySide6.QtLocation.QPlace.icon(self)->PySide6.QtLocation.QPlaceIcon",
    "PySide6.QtLocation.QPlace.insertContent(self,type:PySide6.QtLocation.QPlaceContent.Type,content:QMap[int, PySide6.QtLocation.QPlaceContent])",
    "PySide6.QtLocation.QPlace.isEmpty(self)->bool",
    "PySide6.QtLocation.QPlace.location(self)->PySide6.QtPositioning.QGeoLocation",
    "PySide6.QtLocation.QPlace.name(self)->QString",
    "PySide6.QtLocation.QPlace.placeId(self)->QString",
    "PySide6.QtLocation.QPlace.primaryEmail(self)->QString",
    "PySide6.QtLocation.QPlace.primaryFax(self)->QString",
    "PySide6.QtLocation.QPlace.primaryPhone(self)->QString",
    "PySide6.QtLocation.QPlace.primaryWebsite(self)->PySide6.QtCore.QUrl",
    "PySide6.QtLocation.QPlace.ratings(self)->PySide6.QtLocation.QPlaceRatings",
    "PySide6.QtLocation.QPlace.removeContactDetails(self,contactType:QString)",
    "PySide6.QtLocation.QPlace.removeExtendedAttribute(self,attributeType:QString)",
    "PySide6.QtLocation.QPlace.setAttribution(self,attribution:QString)",
    "PySide6.QtLocation.QPlace.setCategories(self,categories:QList[PySide6.QtLocation.QPlaceCategory])",
    "PySide6.QtLocation.QPlace.setCategory(self,category:PySide6.QtLocation.QPlaceCategory)",
    "PySide6.QtLocation.QPlace.setContactDetails(self,contactType:QString,details:QList[PySide6.QtLocation.QPlaceContactDetail])",
    "PySide6.QtLocation.QPlace.setContent(self,type:PySide6.QtLocation.QPlaceContent.Type,content:QMap[int, PySide6.QtLocation.QPlaceContent])",
    "PySide6.QtLocation.QPlace.setDetailsFetched(self,fetched:bool)",
    "PySide6.QtLocation.QPlace.setExtendedAttribute(self,attributeType:QString,attribute:PySide6.QtLocation.QPlaceAttribute)",
    "PySide6.QtLocation.QPlace.setIcon(self,icon:PySide6.QtLocation.QPlaceIcon)",
    "PySide6.QtLocation.QPlace.setLocation(self,location:PySide6.QtPositioning.QGeoLocation)",
    "PySide6.QtLocation.QPlace.setName(self,name:QString)",
    "PySide6.QtLocation.QPlace.setPlaceId(self,identifier:QString)",
    "PySide6.QtLocation.QPlace.setRatings(self,ratings:PySide6.QtLocation.QPlaceRatings)",
    "PySide6.QtLocation.QPlace.setSupplier(self,supplier:PySide6.QtLocation.QPlaceSupplier)",
    "PySide6.QtLocation.QPlace.setTotalContentCount(self,type:PySide6.QtLocation.QPlaceContent.Type,total:int)",
    "PySide6.QtLocation.QPlace.setVisibility(self,visibility:PySide6.QtLocation.QLocation.Visibility)",
    "PySide6.QtLocation.QPlace.supplier(self)->PySide6.QtLocation.QPlaceSupplier",
    "PySide6.QtLocation.QPlace.swap(self,other:PySide6.QtLocation.QPlace)",
    "PySide6.QtLocation.QPlace.totalContentCount(self,type:PySide6.QtLocation.QPlaceContent.Type)->int",
    "PySide6.QtLocation.QPlace.visibility(self)->PySide6.QtLocation.QLocation.Visibility",
    "PySide6.QtLocation.QPlace.__copy__(self)->typing.Self",
    "PySide6.QtLocation.QPlace.__ne__(self,rhs:PySide6.QtLocation.QPlace)->bool",
    "PySide6.QtLocation.QPlace.__eq__(self,rhs:PySide6.QtLocation.QPlace)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QPlace_SignatureByteSize = 619;
static constexpr uint8_t QPlace_SignatureBytes[619] = {
    0x78, 0xda, 0xcd, 0x57, 0xc1, 0x6e, 0xdb, 0x30, 0x0c, 0xbd, 0xf7, 0x2b, 0x76, 0x5c, 0x01, 0xcd,
    0xd8, 0x2e, 0x3b, 0xe8, 0x30, 0xa0, 0x48, 0xd3, 0xa1, 0x40, 0x36, 0xd8, 0x4d, 0xb7, 0x1d, 0x8a,
    0xc1, 0x50, 0x6c, 0x26, 0x11, 0x60, 0x4b, 0x9e, 0xa5, 0x64, 0xf5, 0xdf, 0x4f, 0xaa, 0xe5, 0xc4,
    0x4e, 0x6a, 0x4a, 0x4e, 0x2f, 0xbb, 0x85, 0x36, 0xdf, 0x7b, 0x14, 0x49, 0x91, 0xce, 0x27, 0x1a,
    0x37, 0x4b, 0x9e, 0xc3, 0xe7, 0x28, 0xd1, 0x0b, 0x99, 0x31, 0xcd, 0xa5, 0x88, 0x92, 0xb8, 0x60,
    0x19, 0xbc, 0x57, 0x50, 0xac, 0xaf, 0xaf, 0x3e, 0x7a, 0x3c, 0x88, 0xd4, 0x5b, 0xa8, 0xc7, 0x9d,
    0xae, 0xaf, 0x46, 0x5f, 0x45, 0xac, 0xaa, 0x40, 0xe4, 0x33, 0x29, 0x34, 0xcb, 0xf4, 0x2d, 0x68,
    0xc6, 0x8b, 0x96, 0x33, 0x6b, 0x1f, 0x3d, 0x36, 0x15, 0xd0, 0x64, 0xa9, 0x6b, 0x2e, 0x36, 0x24,
    0x7f, 0x79, 0x3f, 0x2e, 0x34, 0xa0, 0x41, 0x55, 0xb5, 0x21, 0x5c, 0xed, 0xec, 0xa3, 0xf6, 0x8c,
    0x1f, 0xbe, 0x38, 0x0d, 0x04, 0x64, 0x2c, 0xd8, 0xc8, 0x9a, 0x83, 0x3a, 0x60, 0x16, 0x5c, 0xe9,
    0xa7, 0xf1, 0x70, 0x5a, 0x40, 0xf3, 0x1b, 0x23, 0xed, 0x87, 0xac, 0x46, 0x8f, 0x1e, 0x20, 0xd6,
    0x27, 0x0a, 0x50, 0xb4, 0xec, 0xea, 0xe4, 0xf0, 0x56, 0xc1, 0x83, 0x04, 0xa1, 0xdb, 0x20, 0xb5,
    0x8d, 0x0e, 0x8d, 0xc6, 0xb8, 0x46, 0x56, 0xc5, 0xf2, 0x7f, 0x63, 0xd5, 0x13, 0x17, 0x9a, 0xbc,
    0xf3, 0x21, 0xb0, 0xc8, 0xdb, 0xf2, 0xab, 0x3b, 0xd0, 0xd9, 0x16, 0xf2, 0x2e, 0xf6, 0x95, 0x94,
    0x05, 0x02, 0x82, 0x67, 0x43, 0x9b, 0x43, 0x7e, 0xe3, 0x4a, 0xee, 0x5a, 0xb6, 0xeb, 0x00, 0x38,
    0xc9, 0xf2, 0x28, 0xd1, 0x01, 0x3f, 0x45, 0xeb, 0x82, 0x24, 0xf3, 0xec, 0xd8, 0x93, 0xa3, 0x5e,
    0xf7, 0xc6, 0x09, 0xe3, 0x10, 0x0a, 0x6a, 0x3d, 0xbb, 0xac, 0x5c, 0xc4, 0x95, 0x99, 0x4e, 0x28,
    0x1a, 0x76, 0xd7, 0xb8, 0x9a, 0x97, 0x95, 0x6e, 0x02, 0xcb, 0x55, 0x38, 0xfb, 0x3c, 0x05, 0xb1,
    0x54, 0xdc, 0xbe, 0x31, 0x29, 0x8c, 0x92, 0xaf, 0x20, 0x3b, 0x24, 0x42, 0x26, 0x58, 0x09, 0xe1,
    0xf7, 0xbb, 0x7a, 0xc9, 0x6c, 0x3e, 0x01, 0x50, 0xf3, 0x92, 0xd5, 0xcd, 0xbc, 0xec, 0x86, 0xd6,
    0x14, 0xd4, 0x1d, 0x7b, 0x9e, 0x8c, 0x89, 0xb7, 0x52, 0xc0, 0x64, 0xd4, 0x2f, 0x58, 0x99, 0xcc,
    0xc1, 0x79, 0x46, 0x67, 0xb2, 0x86, 0x28, 0xf9, 0x51, 0x63, 0xf5, 0xa8, 0x8d, 0x25, 0x36, 0xca,
    0xdb, 0x91, 0x0f, 0xad, 0x1f, 0xc6, 0x04, 0xa5, 0xdc, 0x0f, 0xc7, 0x14, 0x32, 0xef, 0xbc, 0x44,
    0xf3, 0x29, 0xf7, 0x1a, 0x61, 0x53, 0xa0, 0x6f, 0x4e, 0xb6, 0x01, 0xe9, 0xad, 0x87, 0x40, 0x8a,
    0xd9, 0x70, 0x37, 0x90, 0xe3, 0xae, 0xa0, 0xa1, 0x4b, 0x22, 0x4c, 0xa1, 0x19, 0xf0, 0x37, 0xd4,
    0xcb, 0xeb, 0xa3, 0x0d, 0xab, 0x87, 0x5b, 0xbd, 0xfe, 0xd3, 0x0c, 0xb6, 0x50, 0x80, 0xf6, 0x7f,
    0x30, 0xa0, 0x4c, 0x24, 0xb7, 0xe7, 0x9b, 0x85, 0xac, 0x5b, 0x83, 0xda, 0x81, 0xe5, 0x81, 0x4f,
    0xe9, 0xc5, 0xe3, 0x53, 0xea, 0xdf, 0x35, 0x1e, 0xdd, 0xfb, 0x6e, 0x57, 0x10, 0xbb, 0x35, 0x28,
    0xba, 0x2e, 0x3c, 0x54, 0x8b, 0xfe, 0xdc, 0x25, 0xdd, 0x14, 0xa6, 0xfe, 0xf1, 0xeb, 0xe1, 0xfd,
    0xde, 0x8d, 0x60, 0x62, 0x87, 0x71, 0xe0, 0x6d, 0x8a, 0x7b, 0x93, 0x98, 0x18, 0x37, 0xa1, 0xf9,
    0x9a, 0x9b, 0x2f, 0xcc, 0x30, 0xf4, 0x43, 0x6f, 0x64, 0x11, 0x37, 0xbf, 0xa8, 0x6f, 0x70, 0x79,
    0x38, 0x97, 0xbb, 0xaa, 0x2a, 0x4c, 0x08, 0x2d, 0xa9, 0x72, 0xd6, 0x38, 0x6b, 0xe7, 0xef, 0xa1,
    0x7d, 0x94, 0x9a, 0x15, 0xae, 0x47, 0x67, 0x72, 0x77, 0xc1, 0x5d, 0xd0, 0x96, 0x81, 0x9a, 0x4b,
    0xe0, 0x51, 0xfa, 0xc9, 0x15, 0x5f, 0xf1, 0x82, 0xbb, 0x45, 0x4c, 0xf6, 0x07, 0xfb, 0x55, 0xa1,
    0xc3, 0xaf, 0x23, 0x0e, 0x15, 0xe8, 0xa7, 0x07, 0x5b, 0x13, 0x5d, 0x5e, 0x30, 0xae, 0xbf, 0xac,
    0x7a, 0xf3, 0xdf, 0x0a, 0xfd, 0xd6, 0xc4, 0x9a, 0x43, 0x98, 0xa4, 0x22, 0x0a, 0xfb, 0x61, 0x42,
    0x47, 0x0e, 0xfd, 0x4a, 0x1e, 0x11, 0xce, 0x34, 0xcd, 0x64, 0xd5, 0xa4, 0x69, 0xc7, 0x68, 0xc2,
    0xb5, 0xd7, 0x6d, 0x69, 0x2c, 0x14, 0x25, 0xc0, 0x61, 0x48, 0xbd, 0x45, 0x5a, 0xdd, 0xff, 0xf5,
    0x95, 0xa6, 0xf0, 0x67, 0x12, 0xd5, 0x3f, 0x8f, 0x58, 0x2f, 0x57
};
#endif

PyTypeObject *init_QPlace(PyObject *module)
{
    if (SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX].type != nullptr)
        return SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX].type;

    Shiboken::AutoDecRef Sbk_QPlace_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QPlace_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QPlace",
        "QPlace",
        &Sbk_QPlace_spec,
        &Shiboken::callCppDestructor< ::QPlace >,
        Sbk_QPlace_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QPlace_TypeF(); // references _Sbk_QPlace_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QPlace_SignatureStrings);
#else
    InitSignatureBytes(pyType, QPlace_SignatureBytes, QPlace_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QPlace_PropertyStrings);
    SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QPlace_PythonToCpp_QPlace_PTR,
        is_QPlace_PythonToCpp_QPlace_PTR_Convertible,
        QPlace_PTR_CppToPython_QPlace,
        QPlace_COPY_CppToPython_QPlace);

    Shiboken::Conversions::registerConverterName(converter, "QPlace");
    Shiboken::Conversions::registerConverterName(converter, "QPlace*");
    Shiboken::Conversions::registerConverterName(converter, "QPlace&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QPlace).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QPlace_PythonToCpp_QPlace_COPY,
        is_QPlace_PythonToCpp_QPlace_COPY_Convertible);

    qRegisterMetaType< ::QPlace >("QPlace");

    return pyType;
}
