// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtlocation_python.h"

// main header
#include "qplacecontent_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtLocation/qplacecontent.h>
#include <QtLocation/qplacesupplier.h>
#include <QtLocation/qplaceuser.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPlaceContent_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QPlaceContent >()))
        return -1;

    ::QPlaceContent *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_IDX]);

    if (PyArg_ParseTuple(args, "|O:QPlaceContent", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QPlaceContent::QPlaceContent(QPlaceContent::Type=)
    // 1: QPlaceContent::QPlaceContent(QPlaceContent)
    if (numArgs == 0) {
        overloadId = 0; // QPlaceContent(QPlaceContent::Type)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_Type_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // QPlaceContent(QPlaceContent::Type)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QPlaceContent(QPlaceContent)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QPlaceContent(QPlaceContent::Type type)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_type = Shiboken::String::createStaticString("type");
                if (PyDict_Contains(kwds, key_type) != 0) {
                    value = PyDict_GetItem(kwds, key_type);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_type);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_Type_IDX])))->converter, (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_type);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_IDX]);
                }
            }
            ::QPlaceContent::Type cppArg0(QPlaceContent::Type::NoType);
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QPlaceContent(QPlaceContent::Type)
                cptr = new ::QPlaceContent(cppArg0);
            }
            break;
        }
        case 1: // QPlaceContent(const QPlaceContent &other)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPlaceContent cppArg0_local;
            ::QPlaceContent *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QPlaceContent(QPlaceContent)
                cptr = new ::QPlaceContent(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QPlaceContent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QPlaceContentFunc_attribution(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceContent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QPlaceContent", "attribution() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // attribution()const
        QString cppResult = const_cast<const ::QPlaceContent *>(cppSelf)->attribution();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceContentFunc_dataTags(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceContent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // dataTags()const
        QList<QPlaceContent::DataTag> cppResult = const_cast<const ::QPlaceContent *>(cppSelf)->dataTags();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QList_QPlaceContent_DataTag_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceContentFunc_setAttribution(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceContent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlaceContent::setAttribution(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setAttribution(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAttribution", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_IDX]);

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QPlaceContent", "setAttribution(const QString &attribution)");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAttribution(QString)
            cppSelf->setAttribution(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceContentFunc_setSupplier(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceContent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlaceContent::setSupplier(QPlaceSupplier)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSupplier_IDX]), (pyArg)))) {
        overloadId = 0; // setSupplier(QPlaceSupplier)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSupplier", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_IDX]);

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QPlaceContent", "setSupplier(const QPlaceSupplier &supplier)");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPlaceSupplier cppArg0_local;
        ::QPlaceSupplier *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setSupplier(QPlaceSupplier)
            cppSelf->setSupplier(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceContentFunc_setUser(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceContent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlaceContent::setUser(QPlaceUser)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceUser_IDX]), (pyArg)))) {
        overloadId = 0; // setUser(QPlaceUser)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUser", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_IDX]);

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QPlaceContent", "setUser(const QPlaceUser &user)");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPlaceUser cppArg0_local;
        ::QPlaceUser *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setUser(QPlaceUser)
            cppSelf->setUser(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceContentFunc_setValue(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceContent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setValue", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPlaceContent::setValue(QPlaceContent::DataTag,QVariant)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_DataTag_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[1])))) {
        overloadId = 0; // setValue(QPlaceContent::DataTag,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setValue", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_IDX]);

    // Call function/method
    {
        ::QPlaceContent::DataTag cppArg0{QPlaceContent::ContentSupplier};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QVariant cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setValue(QPlaceContent::DataTag,QVariant)
            cppSelf->setValue(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceContentFunc_supplier(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceContent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QPlaceContent", "supplier() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // supplier()const
        QPlaceSupplier cppResult = const_cast<const ::QPlaceContent *>(cppSelf)->supplier();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSupplier_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceContentFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceContent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlaceContent::swap(QPlaceContent&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QPlaceContent&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPlaceContent cppArg0_local;
        ::QPlaceContent *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QPlaceContent&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceContentFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceContent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        QPlaceContent::Type cppResult = const_cast<const ::QPlaceContent *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_Type_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceContentFunc_user(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceContent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QPlaceContent", "user() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // user()const
        QPlaceUser cppResult = const_cast<const ::QPlaceContent *>(cppSelf)->user();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceUser_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceContentFunc_value(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceContent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlaceContent::value(QPlaceContent::DataTag)const->QVariant
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_DataTag_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // value(QPlaceContent::DataTag)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "value", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_IDX]);

    // Call function/method
    {
        ::QPlaceContent::DataTag cppArg0{QPlaceContent::ContentSupplier};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // value(QPlaceContent::DataTag)const
            QVariant cppResult = const_cast<const ::QPlaceContent *>(cppSelf)->value(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceContent__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QPlaceContent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QPlaceContent_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QPlaceContent_EnumFlagInfo[] = {
    "DataTag:Enum",
    "Type:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QPlaceContent_methods[] = {
    {"attribution", reinterpret_cast<PyCFunction>(Sbk_QPlaceContentFunc_attribution), METH_NOARGS, nullptr},
    {"dataTags", reinterpret_cast<PyCFunction>(Sbk_QPlaceContentFunc_dataTags), METH_NOARGS, nullptr},
    {"setAttribution", reinterpret_cast<PyCFunction>(Sbk_QPlaceContentFunc_setAttribution), METH_O, nullptr},
    {"setSupplier", reinterpret_cast<PyCFunction>(Sbk_QPlaceContentFunc_setSupplier), METH_O, nullptr},
    {"setUser", reinterpret_cast<PyCFunction>(Sbk_QPlaceContentFunc_setUser), METH_O, nullptr},
    {"setValue", reinterpret_cast<PyCFunction>(Sbk_QPlaceContentFunc_setValue), METH_VARARGS, nullptr},
    {"supplier", reinterpret_cast<PyCFunction>(Sbk_QPlaceContentFunc_supplier), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QPlaceContentFunc_swap), METH_O, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QPlaceContentFunc_type), METH_NOARGS, nullptr},
    {"user", reinterpret_cast<PyCFunction>(Sbk_QPlaceContentFunc_user), METH_NOARGS, nullptr},
    {"value", reinterpret_cast<PyCFunction>(Sbk_QPlaceContentFunc_value), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QPlaceContent__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QPlaceContent_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QPlaceContent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_IDX]), (pyArg)))) {
                // operator!=(const QPlaceContent &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QPlaceContent cppArg0_local;
                ::QPlaceContent *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_IDX]), (pyArg)))) {
                // operator==(const QPlaceContent &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QPlaceContent cppArg0_local;
                ::QPlaceContent *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QPlaceContent_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QPlaceContent_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QPlaceContent_Type = nullptr;
static PyTypeObject *Sbk_QPlaceContent_TypeF(void)
{
    return _Sbk_QPlaceContent_Type;
}

static PyType_Slot Sbk_QPlaceContent_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QPlaceContent_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QPlaceContent_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QPlaceContent_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QPlaceContent_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QPlaceContent_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QPlaceContent_spec = {
    "2:PySide6.QtLocation.QPlaceContent",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QPlaceContent_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QPlaceContent_Type(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QPlaceContent::Type>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QPlaceContent::Type *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QPlaceContent_Type_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_Type_IDX])))
        return Enum_PythonToCpp_QPlaceContent_Type;
    return {};
}

static PyObject *QPlaceContent_Type_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QPlaceContent::Type>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QPlaceContent::Type *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_Type_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QPlaceContent_DataTag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QPlaceContent::DataTag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QPlaceContent::DataTag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QPlaceContent_DataTag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_DataTag_IDX])))
        return Enum_PythonToCpp_QPlaceContent_DataTag;
    return {};
}

static PyObject *QPlaceContent_DataTag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QPlaceContent::DataTag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QPlaceContent::DataTag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_DataTag_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QPlaceContent_PythonToCpp_QPlaceContent_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QPlaceContent_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QPlaceContent_PythonToCpp_QPlaceContent_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QPlaceContent_TypeF()))
        return QPlaceContent_PythonToCpp_QPlaceContent_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QPlaceContent_PTR_CppToPython_QPlaceContent(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QPlaceContent_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QPlaceContent_COPY_CppToPython_QPlaceContent(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QPlaceContent *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QPlaceContent_TypeF(), new ::QPlaceContent(*source), true, true);
}

// Python to C++ copy conversion.
static void QPlaceContent_PythonToCpp_QPlaceContent_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QPlaceContent *>(cppOut) = *reinterpret_cast< ::QPlaceContent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QPlaceContent_PythonToCpp_QPlaceContent_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QPlaceContent_TypeF()))
        return QPlaceContent_PythonToCpp_QPlaceContent_COPY;
    return {};
}

// Implicit conversions.
static void QPlaceContent_Type_PythonToCpp_QPlaceContent(PyObject *pyIn, void *cppOut)
{
    ::QPlaceContent::Type cppIn{QPlaceContent::NoType};
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_Type_IDX])))->converter, pyIn, &cppIn);
    *reinterpret_cast<::QPlaceContent *>(cppOut) = ::QPlaceContent(cppIn);
}
static PythonToCppFunc is_QPlaceContent_Type_PythonToCpp_QPlaceContent_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_Type_IDX]), pyIn))
        return QPlaceContent_Type_PythonToCpp_QPlaceContent;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QPlaceContent_SignatureStrings[] = {
    "1:PySide6.QtLocation.QPlaceContent(self,type:PySide6.QtLocation.QPlaceContent.Type=QPlaceContent.Type.NoType)",
    "0:PySide6.QtLocation.QPlaceContent(self,other:PySide6.QtLocation.QPlaceContent)",
    "PySide6.QtLocation.QPlaceContent.attribution(self)->QString",
    "PySide6.QtLocation.QPlaceContent.dataTags(self)->QList[PySide6.QtLocation.QPlaceContent.DataTag]",
    "PySide6.QtLocation.QPlaceContent.setAttribution(self,attribution:QString)",
    "PySide6.QtLocation.QPlaceContent.setSupplier(self,supplier:PySide6.QtLocation.QPlaceSupplier)",
    "PySide6.QtLocation.QPlaceContent.setUser(self,user:PySide6.QtLocation.QPlaceUser)",
    "PySide6.QtLocation.QPlaceContent.setValue(self,tag:PySide6.QtLocation.QPlaceContent.DataTag,arg__2:QVariant)",
    "PySide6.QtLocation.QPlaceContent.supplier(self)->PySide6.QtLocation.QPlaceSupplier",
    "PySide6.QtLocation.QPlaceContent.swap(self,other:typing.Union[PySide6.QtLocation.QPlaceContent, PySide6.QtLocation.QPlaceContent.Type])",
    "PySide6.QtLocation.QPlaceContent.type(self)->PySide6.QtLocation.QPlaceContent.Type",
    "PySide6.QtLocation.QPlaceContent.user(self)->PySide6.QtLocation.QPlaceUser",
    "PySide6.QtLocation.QPlaceContent.value(self,tag:PySide6.QtLocation.QPlaceContent.DataTag)->QVariant",
    "PySide6.QtLocation.QPlaceContent.__copy__(self)->typing.Self",
    "PySide6.QtLocation.QPlaceContent.__ne__(self,other:typing.Union[PySide6.QtLocation.QPlaceContent, PySide6.QtLocation.QPlaceContent.Type])->bool",
    "PySide6.QtLocation.QPlaceContent.__eq__(self,other:typing.Union[PySide6.QtLocation.QPlaceContent, PySide6.QtLocation.QPlaceContent.Type])->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QPlaceContent_SignatureByteSize = 296;
static constexpr uint8_t QPlaceContent_SignatureBytes[296] = {
    0x78, 0xda, 0xbd, 0x53, 0xc1, 0x4a, 0xc3, 0x40, 0x10, 0xbd, 0xf7, 0x2b, 0x3c, 0x1a, 0x48, 0x83,
    0x7a, 0xf0, 0x10, 0xb0, 0x20, 0x7a, 0x2c, 0xd2, 0x90, 0xb6, 0x17, 0x29, 0xcb, 0x34, 0x1d, 0xe3,
    0x42, 0xd8, 0x8d, 0xd9, 0x89, 0x92, 0xbf, 0x77, 0xd7, 0x6e, 0x24, 0x28, 0x3a, 0x43, 0x41, 0x4f,
    0x61, 0x37, 0xef, 0xbd, 0x79, 0x3b, 0x6f, 0xe6, 0x32, 0x5f, 0x0d, 0xa5, 0x3e, 0xe0, 0x75, 0x56,
    0xd0, 0xd2, 0x56, 0x40, 0xda, 0x9a, 0xac, 0x58, 0x35, 0x50, 0xe1, 0x9d, 0x35, 0x84, 0x86, 0xce,
    0x1d, 0x36, 0x4f, 0x29, 0x0d, 0x2d, 0xb2, 0xd0, 0x6c, 0xed, 0x51, 0x37, 0xdf, 0xaf, 0xb2, 0x07,
    0x1b, 0x3e, 0xc9, 0xec, 0x42, 0x58, 0xcd, 0xd2, 0x33, 0x76, 0x2c, 0x36, 0x99, 0xb1, 0x86, 0x80,
    0xa8, 0xd3, 0xfb, 0x3e, 0xfc, 0xf9, 0x50, 0x4e, 0xe6, 0x8b, 0xa2, 0xf4, 0x57, 0xa6, 0xe6, 0xb9,
    0x07, 0x20, 0x58, 0x43, 0xed, 0x3e, 0x89, 0x4b, 0xed, 0xe8, 0x91, 0xa5, 0xdd, 0x1f, 0x69, 0x3b,
    0xbe, 0x80, 0x43, 0xba, 0xfd, 0xe2, 0x2f, 0x9d, 0x18, 0xce, 0xa3, 0xd3, 0x44, 0xa4, 0x54, 0xf6,
    0x6d, 0xdb, 0x68, 0xec, 0x8e, 0x32, 0x2e, 0x9e, 0x7e, 0xee, 0xe1, 0x88, 0x97, 0xa9, 0x6f, 0xdc,
    0xa8, 0xdc, 0xbb, 0xdf, 0x54, 0x03, 0x4e, 0xa6, 0xb8, 0x85, 0xa6, 0xc7, 0x38, 0x5b, 0x50, 0xe7,
    0xd2, 0xb6, 0xa6, 0xd0, 0xd5, 0x4a, 0x5d, 0xe5, 0xc5, 0x16, 0x3a, 0x0d, 0xa2, 0x19, 0x70, 0xd3,
    0xce, 0xf8, 0x1c, 0xd9, 0x96, 0x08, 0x24, 0xdf, 0xa0, 0x9d, 0x4e, 0xaa, 0xdf, 0x0e, 0x1f, 0x54,
    0xb6, 0x31, 0x1e, 0xca, 0x4e, 0x48, 0x7a, 0x26, 0xda, 0xa3, 0x9d, 0xe0, 0x69, 0x61, 0x2b, 0xd9,
    0x67, 0x4d, 0x45, 0x79, 0xc9, 0xde, 0x09, 0x3a, 0x15, 0x62, 0xe6, 0xa5, 0x5e, 0x4f, 0x8b, 0x38,
    0xac, 0x5a, 0x4c, 0x97, 0xaf, 0xa1, 0x54, 0x65, 0xdb, 0x41, 0xa9, 0xd1, 0x72, 0x4c, 0xa2, 0xf4,
    0x27, 0x09, 0xd9, 0x60, 0xa4, 0xfe, 0x69, 0x90, 0xf3, 0xc5, 0xde, 0xda, 0x46, 0xe2, 0x07, 0x5f,
    0xfe, 0xd1, 0xcf, 0x3b, 0x26, 0x4d, 0x2f, 0x08
};
#endif

PyTypeObject *init_QPlaceContent(PyObject *module)
{
    if (SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_IDX].type != nullptr)
        return SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_IDX].type;

    Shiboken::AutoDecRef Sbk_QPlaceContent_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QPlaceContent_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QPlaceContent",
        "QPlaceContent",
        &Sbk_QPlaceContent_spec,
        &Shiboken::callCppDestructor< ::QPlaceContent >,
        Sbk_QPlaceContent_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QPlaceContent_TypeF(); // references _Sbk_QPlaceContent_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QPlaceContent_SignatureStrings);
#else
    InitSignatureBytes(pyType, QPlaceContent_SignatureBytes, QPlaceContent_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QPlaceContent_PropertyStrings);
    SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QPlaceContent_PythonToCpp_QPlaceContent_PTR,
        is_QPlaceContent_PythonToCpp_QPlaceContent_PTR_Convertible,
        QPlaceContent_PTR_CppToPython_QPlaceContent,
        QPlaceContent_COPY_CppToPython_QPlaceContent);

    Shiboken::Conversions::registerConverterName(converter, "QPlaceContent");
    Shiboken::Conversions::registerConverterName(converter, "QPlaceContent*");
    Shiboken::Conversions::registerConverterName(converter, "QPlaceContent&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QPlaceContent).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QPlaceContent_PythonToCpp_QPlaceContent_COPY,
        is_QPlaceContent_PythonToCpp_QPlaceContent_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QPlaceContent_Type_PythonToCpp_QPlaceContent,
        is_QPlaceContent_Type_PythonToCpp_QPlaceContent_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QPlaceContent_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Type'.
    const char *Type_Initializer[] = {
        "NoType",
        "ImageType",
        "ReviewType",
        "EditorialType",
        "CustomType",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t Type_InitializerValues[] = {
        uint16_t(QPlaceContent::Type::NoType),        //  0x0000  0
        uint16_t(QPlaceContent::Type::ImageType),     //  0x0001  1
        uint16_t(QPlaceContent::Type::ReviewType),    //  0x0002  2
        uint16_t(QPlaceContent::Type::EditorialType), //  0x0003  3
        uint16_t(QPlaceContent::Type::CustomType)     //  0x0100  256
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QPlaceContent_TypeF(),
        "2:PySide6.QtLocation.QPlaceContent.Type",
        Type_Initializer, Type_InitializerValues);
    SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_Type_IDX].type = EType;
    // Register converter for enum 'QPlaceContent::Type'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QPlaceContent_Type_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QPlaceContent_Type,
            is_Enum_PythonToCpp_QPlaceContent_Type_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QPlaceContent::Type");
        Shiboken::Conversions::registerConverterAlias(converter, "Type");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Type' enum.

    // Initialization of enum 'DataTag'.
    const char *DataTag_Initializer[] = {
        "ContentSupplier",
        "ContentUser",
        "ContentAttribution",
        "ImageId",
        "ImageUrl",
        "ImageMimeType",
        "EditorialTitle",
        "EditorialText",
        "EditorialLanguage",
        "ReviewId",
        "ReviewDateTime",
        "ReviewTitle",
        "ReviewText",
        "ReviewLanguage",
        "ReviewRating",
        "CustomDataTag",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t DataTag_InitializerValues[] = {
        uint16_t(QPlaceContent::DataTag::ContentSupplier),    //  0x0000  0
        uint16_t(QPlaceContent::DataTag::ContentUser),        //  0x0001  1
        uint16_t(QPlaceContent::DataTag::ContentAttribution), //  0x0002  2
        uint16_t(QPlaceContent::DataTag::ImageId),            //  0x0003  3
        uint16_t(QPlaceContent::DataTag::ImageUrl),           //  0x0004  4
        uint16_t(QPlaceContent::DataTag::ImageMimeType),      //  0x0005  5
        uint16_t(QPlaceContent::DataTag::EditorialTitle),     //  0x0006  6
        uint16_t(QPlaceContent::DataTag::EditorialText),      //  0x0007  7
        uint16_t(QPlaceContent::DataTag::EditorialLanguage),  //  0x0008  8
        uint16_t(QPlaceContent::DataTag::ReviewId),           //  0x0009  9
        uint16_t(QPlaceContent::DataTag::ReviewDateTime),     //  0x000a  10
        uint16_t(QPlaceContent::DataTag::ReviewTitle),        //  0x000b  11
        uint16_t(QPlaceContent::DataTag::ReviewText),         //  0x000c  12
        uint16_t(QPlaceContent::DataTag::ReviewLanguage),     //  0x000d  13
        uint16_t(QPlaceContent::DataTag::ReviewRating),       //  0x000e  14
        uint16_t(QPlaceContent::DataTag::CustomDataTag)       //  0x03e8  1000
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QPlaceContent_TypeF(),
        "2:PySide6.QtLocation.QPlaceContent.DataTag",
        DataTag_Initializer, DataTag_InitializerValues);
    SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_DataTag_IDX].type = EType;
    // Register converter for enum 'QPlaceContent::DataTag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QPlaceContent_DataTag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QPlaceContent_DataTag,
            is_Enum_PythonToCpp_QPlaceContent_DataTag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QPlaceContent::DataTag");
        Shiboken::Conversions::registerConverterAlias(converter, "DataTag");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'DataTag' enum.

    qRegisterMetaType< ::QPlaceContent >("QPlaceContent");
    qRegisterMetaType< ::QPlaceContent::Type >("QPlaceContent::Type");
    qRegisterMetaType< ::QPlaceContent::DataTag >("QPlaceContent::DataTag");

    return pyType;
}
