// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtlocation_python.h"

// main header
#include "qplacecontentrequest_wrapper.h"

// Argument includes
#include <QString>
#include <QtLocation/qplacecontent.h>
#include <QtLocation/qplacecontentrequest.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPlaceContentRequest_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QPlaceContentRequest >()))
        return -1;

    ::QPlaceContentRequest *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QPlaceContentRequest", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QPlaceContentRequest::QPlaceContentRequest()
    // 1: QPlaceContentRequest::QPlaceContentRequest(QPlaceContentRequest)
    if (numArgs == 0) {
        overloadId = 0; // QPlaceContentRequest()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContentRequest_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QPlaceContentRequest(QPlaceContentRequest)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContentRequest_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContentRequest_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QPlaceContentRequest()
        {

            // QPlaceContentRequest()
            cptr = new ::QPlaceContentRequest();
            break;
        }
        case 1: // QPlaceContentRequest(const QPlaceContentRequest &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPlaceContentRequest cppArg0_local;
            ::QPlaceContentRequest *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QPlaceContentRequest(QPlaceContentRequest)
                cptr = new ::QPlaceContentRequest(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QPlaceContentRequest >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContentRequest_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QPlaceContentRequestFunc_clear(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceContentRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContentRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clear()
        cppSelf->clear();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceContentRequestFunc_contentContext(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceContentRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContentRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // contentContext()const
        QVariant cppResult = const_cast<const ::QPlaceContentRequest *>(cppSelf)->contentContext();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceContentRequestFunc_contentType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceContentRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContentRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // contentType()const
        QPlaceContent::Type cppResult = const_cast<const ::QPlaceContentRequest *>(cppSelf)->contentType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_Type_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceContentRequestFunc_limit(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceContentRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContentRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // limit()const
        int cppResult = const_cast<const ::QPlaceContentRequest *>(cppSelf)->limit();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceContentRequestFunc_placeId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceContentRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContentRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // placeId()const
        QString cppResult = const_cast<const ::QPlaceContentRequest *>(cppSelf)->placeId();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceContentRequestFunc_setContentContext(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceContentRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContentRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlaceContentRequest::setContentContext(QVariant)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // setContentContext(QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setContentContext", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContentRequest_IDX]);

    // Call function/method
    {
        ::QVariant cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setContentContext(QVariant)
            cppSelf->setContentContext(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceContentRequestFunc_setContentType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceContentRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContentRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlaceContentRequest::setContentType(QPlaceContent::Type)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContent_Type_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setContentType(QPlaceContent::Type)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setContentType", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContentRequest_IDX]);

    // Call function/method
    {
        ::QPlaceContent::Type cppArg0{QPlaceContent::NoType};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setContentType(QPlaceContent::Type)
            cppSelf->setContentType(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceContentRequestFunc_setLimit(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceContentRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContentRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlaceContentRequest::setLimit(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setLimit(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLimit", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContentRequest_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLimit(int)
            cppSelf->setLimit(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceContentRequestFunc_setPlaceId(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceContentRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContentRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlaceContentRequest::setPlaceId(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setPlaceId(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPlaceId", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContentRequest_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPlaceId(QString)
            cppSelf->setPlaceId(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceContentRequestFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceContentRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContentRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlaceContentRequest::swap(QPlaceContentRequest&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContentRequest_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QPlaceContentRequest&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContentRequest_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPlaceContentRequest cppArg0_local;
        ::QPlaceContentRequest *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QPlaceContentRequest&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceContentRequest__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QPlaceContentRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContentRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContentRequest_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QPlaceContentRequest_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QPlaceContentRequest_methods[] = {
    {"clear", reinterpret_cast<PyCFunction>(Sbk_QPlaceContentRequestFunc_clear), METH_NOARGS, nullptr},
    {"contentContext", reinterpret_cast<PyCFunction>(Sbk_QPlaceContentRequestFunc_contentContext), METH_NOARGS, nullptr},
    {"contentType", reinterpret_cast<PyCFunction>(Sbk_QPlaceContentRequestFunc_contentType), METH_NOARGS, nullptr},
    {"limit", reinterpret_cast<PyCFunction>(Sbk_QPlaceContentRequestFunc_limit), METH_NOARGS, nullptr},
    {"placeId", reinterpret_cast<PyCFunction>(Sbk_QPlaceContentRequestFunc_placeId), METH_NOARGS, nullptr},
    {"setContentContext", reinterpret_cast<PyCFunction>(Sbk_QPlaceContentRequestFunc_setContentContext), METH_O, nullptr},
    {"setContentType", reinterpret_cast<PyCFunction>(Sbk_QPlaceContentRequestFunc_setContentType), METH_O, nullptr},
    {"setLimit", reinterpret_cast<PyCFunction>(Sbk_QPlaceContentRequestFunc_setLimit), METH_O, nullptr},
    {"setPlaceId", reinterpret_cast<PyCFunction>(Sbk_QPlaceContentRequestFunc_setPlaceId), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QPlaceContentRequestFunc_swap), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QPlaceContentRequest__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QPlaceContentRequest_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QPlaceContentRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContentRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContentRequest_IDX]), (pyArg)))) {
                // operator!=(const QPlaceContentRequest &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QPlaceContentRequest cppArg0_local;
                ::QPlaceContentRequest *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContentRequest_IDX]), (pyArg)))) {
                // operator==(const QPlaceContentRequest &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QPlaceContentRequest cppArg0_local;
                ::QPlaceContentRequest *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QPlaceContentRequest_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QPlaceContentRequest_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QPlaceContentRequest_Type = nullptr;
static PyTypeObject *Sbk_QPlaceContentRequest_TypeF(void)
{
    return _Sbk_QPlaceContentRequest_Type;
}

static PyType_Slot Sbk_QPlaceContentRequest_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QPlaceContentRequest_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QPlaceContentRequest_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QPlaceContentRequest_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QPlaceContentRequest_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QPlaceContentRequest_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QPlaceContentRequest_spec = {
    "2:PySide6.QtLocation.QPlaceContentRequest",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QPlaceContentRequest_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QPlaceContentRequest_PythonToCpp_QPlaceContentRequest_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QPlaceContentRequest_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QPlaceContentRequest_PythonToCpp_QPlaceContentRequest_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QPlaceContentRequest_TypeF()))
        return QPlaceContentRequest_PythonToCpp_QPlaceContentRequest_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QPlaceContentRequest_PTR_CppToPython_QPlaceContentRequest(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QPlaceContentRequest_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QPlaceContentRequest_COPY_CppToPython_QPlaceContentRequest(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QPlaceContentRequest *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QPlaceContentRequest_TypeF(), new ::QPlaceContentRequest(*source), true, true);
}

// Python to C++ copy conversion.
static void QPlaceContentRequest_PythonToCpp_QPlaceContentRequest_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QPlaceContentRequest *>(cppOut) = *reinterpret_cast< ::QPlaceContentRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContentRequest_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QPlaceContentRequest_PythonToCpp_QPlaceContentRequest_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QPlaceContentRequest_TypeF()))
        return QPlaceContentRequest_PythonToCpp_QPlaceContentRequest_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QPlaceContentRequest_SignatureStrings[] = {
    "1:PySide6.QtLocation.QPlaceContentRequest(self)",
    "0:PySide6.QtLocation.QPlaceContentRequest(self,other:PySide6.QtLocation.QPlaceContentRequest)",
    "PySide6.QtLocation.QPlaceContentRequest.clear(self)",
    "PySide6.QtLocation.QPlaceContentRequest.contentContext(self)->QVariant",
    "PySide6.QtLocation.QPlaceContentRequest.contentType(self)->PySide6.QtLocation.QPlaceContent.Type",
    "PySide6.QtLocation.QPlaceContentRequest.limit(self)->int",
    "PySide6.QtLocation.QPlaceContentRequest.placeId(self)->QString",
    "PySide6.QtLocation.QPlaceContentRequest.setContentContext(self,context:QVariant)",
    "PySide6.QtLocation.QPlaceContentRequest.setContentType(self,type:PySide6.QtLocation.QPlaceContent.Type)",
    "PySide6.QtLocation.QPlaceContentRequest.setLimit(self,limit:int)",
    "PySide6.QtLocation.QPlaceContentRequest.setPlaceId(self,identifier:QString)",
    "PySide6.QtLocation.QPlaceContentRequest.swap(self,other:PySide6.QtLocation.QPlaceContentRequest)",
    "PySide6.QtLocation.QPlaceContentRequest.__copy__(self)->typing.Self",
    "PySide6.QtLocation.QPlaceContentRequest.__ne__(self,rhs:PySide6.QtLocation.QPlaceContentRequest)->bool",
    "PySide6.QtLocation.QPlaceContentRequest.__eq__(self,rhs:PySide6.QtLocation.QPlaceContentRequest)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QPlaceContentRequest_SignatureByteSize = 237;
static constexpr uint8_t QPlaceContentRequest_SignatureBytes[237] = {
    0x78, 0xda, 0xb5, 0x92, 0x31, 0x0f, 0x82, 0x30, 0x10, 0x85, 0x77, 0x7f, 0x89, 0x24, 0xa5, 0xd1,
    0xc5, 0x81, 0xc1, 0xc5, 0xc9, 0xc4, 0x01, 0xc4, 0xb8, 0x92, 0x5a, 0x4f, 0xbd, 0xa4, 0xb6, 0x50,
    0xce, 0x28, 0xff, 0xde, 0xa2, 0x40, 0x4c, 0x1c, 0x6c, 0x35, 0x6e, 0xbd, 0xe6, 0xde, 0xbb, 0x77,
    0x5f, 0x3b, 0x4d, 0xd2, 0x26, 0xc7, 0x3d, 0xcc, 0x78, 0x46, 0x2b, 0x23, 0x05, 0xa1, 0xd1, 0x3c,
    0x4b, 0x95, 0x90, 0xb0, 0x30, 0x9a, 0x40, 0xd3, 0x1a, 0xaa, 0x0b, 0xd4, 0x34, 0xae, 0x41, 0x1d,
    0xa2, 0xd1, 0x24, 0xa8, 0x9f, 0x19, 0x3a, 0x81, 0xf5, 0x95, 0x44, 0x23, 0xcf, 0x46, 0x2e, 0x15,
    0x08, 0xdb, 0x25, 0xf2, 0xd6, 0x3c, 0xcb, 0xc7, 0xed, 0xad, 0x5b, 0x27, 0x9e, 0x67, 0x5b, 0x61,
    0x51, 0x68, 0x0a, 0xb5, 0xd9, 0x34, 0x25, 0xf4, 0x1e, 0x9f, 0xa4, 0xbc, 0x6d, 0xf6, 0x1e, 0xa0,
    0xf0, 0x8c, 0x43, 0x3c, 0x0c, 0x48, 0x56, 0xb6, 0x77, 0xcb, 0xfd, 0xb0, 0x59, 0x4e, 0x16, 0xf5,
    0xd1, 0x5b, 0x5e, 0x03, 0x2d, 0xde, 0x11, 0x31, 0xf9, 0x2c, 0x92, 0x1e, 0x54, 0xf4, 0x85, 0xe1,
    0x00, 0x8b, 0x91, 0x3b, 0x25, 0x5e, 0xbc, 0x82, 0xe6, 0xac, 0x06, 0x66, 0xec, 0x81, 0x2f, 0xc1,
    0xc0, 0xa0, 0xe9, 0x0b, 0x3b, 0xe6, 0x44, 0x9a, 0xf0, 0x80, 0xee, 0xe7, 0x76, 0x10, 0x03, 0xbc,
    0xae, 0xa2, 0xfc, 0xeb, 0xd7, 0x2f, 0x0a, 0x69, 0xca, 0xa6, 0x28, 0xfa, 0x67, 0x76, 0x44, 0x5d,
    0x40, 0x9e, 0xbb, 0x2a, 0xc0, 0x43, 0x43, 0xe7, 0xc0, 0xec, 0xa9, 0xf6, 0x0e, 0x19, 0xcf, 0x77,
    0xc6, 0xa8, 0x80, 0x31, 0x50, 0xfd, 0x30, 0xe6, 0x0e, 0x3b, 0x42, 0xb4, 0x13
};
#endif

PyTypeObject *init_QPlaceContentRequest(PyObject *module)
{
    if (SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContentRequest_IDX].type != nullptr)
        return SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContentRequest_IDX].type;

    Shiboken::AutoDecRef Sbk_QPlaceContentRequest_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QPlaceContentRequest_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QPlaceContentRequest",
        "QPlaceContentRequest",
        &Sbk_QPlaceContentRequest_spec,
        &Shiboken::callCppDestructor< ::QPlaceContentRequest >,
        Sbk_QPlaceContentRequest_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QPlaceContentRequest_TypeF(); // references _Sbk_QPlaceContentRequest_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QPlaceContentRequest_SignatureStrings);
#else
    InitSignatureBytes(pyType, QPlaceContentRequest_SignatureBytes, QPlaceContentRequest_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QPlaceContentRequest_PropertyStrings);
    SbkPySide6_QtLocationTypeStructs[SBK_QPlaceContentRequest_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QPlaceContentRequest_PythonToCpp_QPlaceContentRequest_PTR,
        is_QPlaceContentRequest_PythonToCpp_QPlaceContentRequest_PTR_Convertible,
        QPlaceContentRequest_PTR_CppToPython_QPlaceContentRequest,
        QPlaceContentRequest_COPY_CppToPython_QPlaceContentRequest);

    Shiboken::Conversions::registerConverterName(converter, "QPlaceContentRequest");
    Shiboken::Conversions::registerConverterName(converter, "QPlaceContentRequest*");
    Shiboken::Conversions::registerConverterName(converter, "QPlaceContentRequest&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QPlaceContentRequest).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QPlaceContentRequest_PythonToCpp_QPlaceContentRequest_COPY,
        is_QPlaceContentRequest_PythonToCpp_QPlaceContentRequest_COPY_Convertible);

    qRegisterMetaType< ::QPlaceContentRequest >("QPlaceContentRequest");

    return pyType;
}
