// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtlocation_python.h"

// main header
#include "qplaceicon_wrapper.h"

// Argument includes
#include <QMap>
#include <QString>
#include <QtLocation/qplaceicon.h>
#include <QtLocation/qplacemanager.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qsize.h>
#include <qurl.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPlaceIcon_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QPlaceIcon >()))
        return -1;

    ::QPlaceIcon *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QPlaceIcon", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QPlaceIcon::QPlaceIcon()
    // 1: QPlaceIcon::QPlaceIcon(QPlaceIcon)
    if (numArgs == 0) {
        overloadId = 0; // QPlaceIcon()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceIcon_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QPlaceIcon(QPlaceIcon)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceIcon_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceIcon_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QPlaceIcon()
        {

            // QPlaceIcon()
            cptr = new ::QPlaceIcon();
            break;
        }
        case 1: // QPlaceIcon(const QPlaceIcon &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPlaceIcon cppArg0_local;
            ::QPlaceIcon *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QPlaceIcon(QPlaceIcon)
                cptr = new ::QPlaceIcon(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QPlaceIcon >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceIcon_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QPlaceIconFunc_isEmpty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceIcon *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceIcon_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isEmpty()const
        bool cppResult = const_cast<const ::QPlaceIcon *>(cppSelf)->isEmpty();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceIconFunc_manager(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceIcon *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceIcon_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // manager()const
        QPlaceManager * cppResult = const_cast<const ::QPlaceIcon *>(cppSelf)->manager();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceManager_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceIconFunc_parameters(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceIcon *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceIcon_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // parameters()const
        QMap<QString,QVariant> cppResult = const_cast<const ::QPlaceIcon *>(cppSelf)->parameters();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QMap_QString_QVariant_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceIconFunc_setManager(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceIcon *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceIcon_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlaceIcon::setManager(QPlaceManager*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceManager_IDX]), (pyArg)))) {
        overloadId = 0; // setManager(QPlaceManager*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setManager", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceIcon_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPlaceManager *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setManager(QPlaceManager*)
            cppSelf->setManager(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceIconFunc_setParameters(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceIcon *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceIcon_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlaceIcon::setParameters(QMap<QString,QVariant>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QMap_QString_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // setParameters(QMap<QString,QVariant>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setParameters", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceIcon_IDX]);

    // Call function/method
    {
        ::QMap<QString,QVariant> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setParameters(QMap<QString,QVariant>)
            cppSelf->setParameters(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceIconFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceIcon *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceIcon_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlaceIcon::swap(QPlaceIcon&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceIcon_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QPlaceIcon&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceIcon_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPlaceIcon cppArg0_local;
        ::QPlaceIcon *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QPlaceIcon&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceIconFunc_url(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceIcon *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceIcon_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "url", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceIcon_IDX]);

    if (PyArg_ParseTuple(args, "|O:url", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPlaceIcon::url(const QSize&=)const->QUrl
    if (numArgs == 0) {
        overloadId = 0; // url(QSize)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArgs[0])))) {
        overloadId = 0; // url(QSize)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "url", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceIcon_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_size = Shiboken::String::createStaticString("size");
            if (PyDict_Contains(kwds, key_size) != 0) {
                value = PyDict_GetItem(kwds, key_size);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_size);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "url", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceIcon_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "url", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceIcon_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_size);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "url", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceIcon_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QSize cppArg0_local = QSize();
        ::QSize *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0]) {
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // url(QSize)const
            QUrl cppResult = const_cast<const ::QPlaceIcon *>(cppSelf)->url(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceIcon__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QPlaceIcon *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceIcon_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceIcon_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QPlaceIcon_PropertyStrings[] = {
    "manager::",
    "parameters::",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QPlaceIcon_methods[] = {
    {"isEmpty", reinterpret_cast<PyCFunction>(Sbk_QPlaceIconFunc_isEmpty), METH_NOARGS, nullptr},
    {"manager", reinterpret_cast<PyCFunction>(Sbk_QPlaceIconFunc_manager), METH_NOARGS, nullptr},
    {"parameters", reinterpret_cast<PyCFunction>(Sbk_QPlaceIconFunc_parameters), METH_NOARGS, nullptr},
    {"setManager", reinterpret_cast<PyCFunction>(Sbk_QPlaceIconFunc_setManager), METH_O, nullptr},
    {"setParameters", reinterpret_cast<PyCFunction>(Sbk_QPlaceIconFunc_setParameters), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QPlaceIconFunc_swap), METH_O, nullptr},
    {"url", reinterpret_cast<PyCFunction>(Sbk_QPlaceIconFunc_url), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QPlaceIcon__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QPlaceIcon_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QPlaceIcon *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceIcon_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceIcon_IDX]), (pyArg)))) {
                // operator!=(const QPlaceIcon &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QPlaceIcon cppArg0_local;
                ::QPlaceIcon *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceIcon_IDX]), (pyArg)))) {
                // operator==(const QPlaceIcon &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QPlaceIcon cppArg0_local;
                ::QPlaceIcon *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QPlaceIcon_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QPlaceIcon_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QPlaceIcon_Type = nullptr;
static PyTypeObject *Sbk_QPlaceIcon_TypeF(void)
{
    return _Sbk_QPlaceIcon_Type;
}

static PyType_Slot Sbk_QPlaceIcon_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QPlaceIcon_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QPlaceIcon_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QPlaceIcon_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QPlaceIcon_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QPlaceIcon_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QPlaceIcon_spec = {
    "2:PySide6.QtLocation.QPlaceIcon",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QPlaceIcon_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QPlaceIcon_PythonToCpp_QPlaceIcon_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QPlaceIcon_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QPlaceIcon_PythonToCpp_QPlaceIcon_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QPlaceIcon_TypeF()))
        return QPlaceIcon_PythonToCpp_QPlaceIcon_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QPlaceIcon_PTR_CppToPython_QPlaceIcon(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QPlaceIcon_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QPlaceIcon_COPY_CppToPython_QPlaceIcon(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QPlaceIcon *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QPlaceIcon_TypeF(), new ::QPlaceIcon(*source), true, true);
}

// Python to C++ copy conversion.
static void QPlaceIcon_PythonToCpp_QPlaceIcon_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QPlaceIcon *>(cppOut) = *reinterpret_cast< ::QPlaceIcon *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceIcon_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QPlaceIcon_PythonToCpp_QPlaceIcon_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QPlaceIcon_TypeF()))
        return QPlaceIcon_PythonToCpp_QPlaceIcon_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QPlaceIcon_SignatureStrings[] = {
    "1:PySide6.QtLocation.QPlaceIcon(self,*:KeywordOnly=None,parameters:QMap[QString, QVariant]=None,manager:QPlaceManager=None)",
    "0:PySide6.QtLocation.QPlaceIcon(self,other:PySide6.QtLocation.QPlaceIcon,*:KeywordOnly=None,parameters:QMap[QString, QVariant]=None,manager:QPlaceManager=None)",
    "PySide6.QtLocation.QPlaceIcon.isEmpty(self)->bool",
    "PySide6.QtLocation.QPlaceIcon.manager(self)->PySide6.QtLocation.QPlaceManager",
    "PySide6.QtLocation.QPlaceIcon.parameters(self)->QMap[QString, QVariant]",
    "PySide6.QtLocation.QPlaceIcon.setManager(self,manager:PySide6.QtLocation.QPlaceManager)",
    "PySide6.QtLocation.QPlaceIcon.setParameters(self,parameters:QMap[QString, QVariant])",
    "PySide6.QtLocation.QPlaceIcon.swap(self,other:PySide6.QtLocation.QPlaceIcon)",
    "PySide6.QtLocation.QPlaceIcon.url(self,size:PySide6.QtCore.QSize=QSize())->PySide6.QtCore.QUrl",
    "PySide6.QtLocation.QPlaceIcon.__copy__(self)->typing.Self",
    "PySide6.QtLocation.QPlaceIcon.__ne__(self,rhs:PySide6.QtLocation.QPlaceIcon)->bool",
    "PySide6.QtLocation.QPlaceIcon.__eq__(self,rhs:PySide6.QtLocation.QPlaceIcon)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QPlaceIcon_SignatureByteSize = 266;
static constexpr uint8_t QPlaceIcon_SignatureBytes[266] = {
    0x78, 0xda, 0xb5, 0x92, 0xb1, 0x4e, 0xc3, 0x30, 0x10, 0x86, 0x77, 0x9e, 0x82, 0xb1, 0x41, 0xc1,
    0x82, 0x85, 0x21, 0x52, 0x59, 0x10, 0x03, 0x2a, 0x81, 0x58, 0x11, 0x2c, 0x08, 0x59, 0x6e, 0x7a,
    0x6d, 0x2d, 0x39, 0xb6, 0x39, 0x1b, 0x55, 0xe6, 0xe9, 0x89, 0xe2, 0x04, 0xda, 0xa1, 0xbd, 0x30,
    0xb0, 0x58, 0x3a, 0xdf, 0xfd, 0xdf, 0xfd, 0xe7, 0xf3, 0x75, 0x51, 0xc5, 0x5a, 0xad, 0xe0, 0x86,
    0xf1, 0xf0, 0x68, 0x1b, 0x19, 0x94, 0x35, 0x8c, 0x57, 0x5a, 0x36, 0xf0, 0xd0, 0x58, 0x33, 0xf3,
    0xa0, 0xd7, 0xf9, 0x45, 0xb1, 0x80, 0xb8, 0xb3, 0xb8, 0x7a, 0x36, 0x3a, 0xce, 0x9f, 0xac, 0x81,
    0xdc, 0x49, 0x94, 0x2d, 0x04, 0x40, 0x5f, 0xf0, 0x52, 0xba, 0x37, 0x5e, 0x07, 0x54, 0x66, 0x93,
    0x9f, 0xf3, 0x57, 0x89, 0x4a, 0x9a, 0xf0, 0x9e, 0xea, 0x5a, 0x69, 0xe4, 0x06, 0xb0, 0x48, 0xc8,
    0x32, 0x45, 0x7d, 0x2a, 0x3b, 0xbb, 0x9a, 0xd2, 0xdb, 0x86, 0x6d, 0x27, 0x3f, 0x59, 0xf8, 0x5f,
    0xfe, 0x4e, 0x36, 0x65, 0xca, 0xdf, 0xb7, 0x2e, 0xc4, 0xde, 0x65, 0x76, 0x79, 0xbb, 0xb4, 0x56,
    0x13, 0x8a, 0xa1, 0xd7, 0xa8, 0x38, 0x5a, 0x3c, 0xb8, 0x20, 0x68, 0xbf, 0x13, 0x8e, 0xc0, 0x23,
    0x83, 0x12, 0x1c, 0x0f, 0xa1, 0xdc, 0x33, 0xf6, 0xf3, 0x22, 0x94, 0xbd, 0x8c, 0xe6, 0x56, 0x87,
    0x16, 0x27, 0x2c, 0x85, 0x84, 0xee, 0xa4, 0x9b, 0xfc, 0x2f, 0x28, 0xd8, 0x27, 0xea, 0xc4, 0xf2,
    0xea, 0x0b, 0xf6, 0x50, 0x77, 0x16, 0x81, 0xf1, 0xba, 0xbb, 0x9c, 0xf7, 0xe7, 0x2c, 0x3b, 0xd8,
    0x56, 0x4a, 0xbf, 0x20, 0xb5, 0x6e, 0x21, 0x1a, 0xeb, 0xa2, 0x10, 0xe3, 0x7a, 0x42, 0x74, 0xdd,
    0xb0, 0xac, 0xee, 0x22, 0x52, 0x69, 0x60, 0xd0, 0xe5, 0xb8, 0xf5, 0xc4, 0x94, 0x93, 0xfe, 0x9e,
    0x10, 0xf0, 0xf1, 0x67, 0xe4, 0x37, 0xc7, 0x43, 0x79, 0xb6
};
#endif

PyTypeObject *init_QPlaceIcon(PyObject *module)
{
    if (SbkPySide6_QtLocationTypeStructs[SBK_QPlaceIcon_IDX].type != nullptr)
        return SbkPySide6_QtLocationTypeStructs[SBK_QPlaceIcon_IDX].type;

    Shiboken::AutoDecRef Sbk_QPlaceIcon_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QPlaceIcon_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QPlaceIcon",
        "QPlaceIcon",
        &Sbk_QPlaceIcon_spec,
        &Shiboken::callCppDestructor< ::QPlaceIcon >,
        Sbk_QPlaceIcon_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QPlaceIcon_TypeF(); // references _Sbk_QPlaceIcon_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QPlaceIcon_SignatureStrings);
#else
    InitSignatureBytes(pyType, QPlaceIcon_SignatureBytes, QPlaceIcon_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QPlaceIcon_PropertyStrings);
    SbkPySide6_QtLocationTypeStructs[SBK_QPlaceIcon_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QPlaceIcon_PythonToCpp_QPlaceIcon_PTR,
        is_QPlaceIcon_PythonToCpp_QPlaceIcon_PTR_Convertible,
        QPlaceIcon_PTR_CppToPython_QPlaceIcon,
        QPlaceIcon_COPY_CppToPython_QPlaceIcon);

    Shiboken::Conversions::registerConverterName(converter, "QPlaceIcon");
    Shiboken::Conversions::registerConverterName(converter, "QPlaceIcon*");
    Shiboken::Conversions::registerConverterName(converter, "QPlaceIcon&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QPlaceIcon).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QPlaceIcon_PythonToCpp_QPlaceIcon_COPY,
        is_QPlaceIcon_PythonToCpp_QPlaceIcon_COPY_Convertible);

    qRegisterMetaType< ::QPlaceIcon >("QPlaceIcon");

    return pyType;
}

PyTypeObject *init_QPlaceIconStaticFields(PyObject *module)
{
    auto *obType = PyObject_GetAttrString(module, "QPlaceIcon");
    auto *type = reinterpret_cast<PyTypeObject *>(obType);
    Shiboken::AutoDecRef dict(PepType_GetDict(type));
    PyDict_SetItemString(dict, "SingleUrl",
                         Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &QPlaceIcon::SingleUrl));
    return type;
}
