// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtlocation_python.h"

// main header
#include "qplaceproposedsearchresult_wrapper.h"

// Argument includes
#include <QString>
#include <QtLocation/qplaceicon.h>
#include <QtLocation/qplacesearchrequest.h>
#include <QtLocation/qplacesearchresult.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

QPlaceProposedSearchResultWrapper::QPlaceProposedSearchResultWrapper()
{
}

QPlaceProposedSearchResultWrapper::QPlaceProposedSearchResultWrapper(const ::QPlaceSearchResult & other) : QPlaceProposedSearchResult(other)
{
}

QPlaceProposedSearchResultWrapper::~QPlaceProposedSearchResultWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPlaceProposedSearchResult_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QPlaceProposedSearchResult >()))
        return -1;

    QPlaceProposedSearchResultWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QPlaceProposedSearchResult", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QPlaceProposedSearchResult::QPlaceProposedSearchResult()
    // 1: QPlaceProposedSearchResult::QPlaceProposedSearchResult(QPlaceSearchResult)
    if (numArgs == 0) {
        overloadId = 0; // QPlaceProposedSearchResult()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchResult_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QPlaceProposedSearchResult(QPlaceSearchResult)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceProposedSearchResult_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceProposedSearchResult_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QPlaceProposedSearchResult()
        {

            // QPlaceProposedSearchResult()
            cptr = new QPlaceProposedSearchResultWrapper();
            break;
        }
        case 1: // QPlaceProposedSearchResult(const QPlaceSearchResult &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPlaceSearchResult *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QPlaceProposedSearchResult(QPlaceSearchResult)
                cptr = new QPlaceProposedSearchResultWrapper(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QPlaceProposedSearchResult >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceProposedSearchResult_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QPlaceProposedSearchResultFunc_searchRequest(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceProposedSearchResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceProposedSearchResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // searchRequest()const
        QPlaceSearchRequest* cppResult = new QPlaceSearchRequest(const_cast<const ::QPlaceProposedSearchResult *>(cppSelf)->searchRequest());
        pyResult = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchRequest_IDX]), cppResult, true, true);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceProposedSearchResultFunc_setSearchRequest(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceProposedSearchResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceProposedSearchResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlaceProposedSearchResult::setSearchRequest(QPlaceSearchRequest)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchRequest_IDX]), (pyArg)))) {
        overloadId = 0; // setSearchRequest(QPlaceSearchRequest)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSearchRequest", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceProposedSearchResult_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPlaceSearchRequest *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSearchRequest(QPlaceSearchRequest)
            cppSelf->setSearchRequest(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QPlaceProposedSearchResult_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QPlaceProposedSearchResult_methods[] = {
    {"searchRequest", reinterpret_cast<PyCFunction>(Sbk_QPlaceProposedSearchResultFunc_searchRequest), METH_NOARGS, nullptr},
    {"setSearchRequest", reinterpret_cast<PyCFunction>(Sbk_QPlaceProposedSearchResultFunc_setSearchRequest), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QPlaceProposedSearchResult_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QPlaceProposedSearchResult_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QPlaceProposedSearchResult_Type = nullptr;
static PyTypeObject *Sbk_QPlaceProposedSearchResult_TypeF(void)
{
    return _Sbk_QPlaceProposedSearchResult_Type;
}

static PyType_Slot Sbk_QPlaceProposedSearchResult_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QPlaceProposedSearchResult_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QPlaceProposedSearchResult_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QPlaceProposedSearchResult_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QPlaceProposedSearchResult_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QPlaceProposedSearchResult_spec = {
    "2:PySide6.QtLocation.QPlaceProposedSearchResult",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QPlaceProposedSearchResult_slots
};

} //extern "C"

static void *Sbk_QPlaceProposedSearchResult_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QPlaceSearchResult >())
        return dynamic_cast< ::QPlaceProposedSearchResult *>(reinterpret_cast< ::QPlaceSearchResult *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QPlaceProposedSearchResult_PythonToCpp_QPlaceProposedSearchResult_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QPlaceProposedSearchResult_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QPlaceProposedSearchResult_PythonToCpp_QPlaceProposedSearchResult_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QPlaceProposedSearchResult_TypeF()))
        return QPlaceProposedSearchResult_PythonToCpp_QPlaceProposedSearchResult_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QPlaceProposedSearchResult_PTR_CppToPython_QPlaceProposedSearchResult(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QPlaceProposedSearchResult *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QPlaceProposedSearchResult_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QPlaceProposedSearchResult_SignatureStrings[] = {
    "1:PySide6.QtLocation.QPlaceProposedSearchResult(self)",
    "0:PySide6.QtLocation.QPlaceProposedSearchResult(self,other:PySide6.QtLocation.QPlaceSearchResult)",
    "PySide6.QtLocation.QPlaceProposedSearchResult.searchRequest(self)->PySide6.QtLocation.QPlaceSearchRequest",
    "PySide6.QtLocation.QPlaceProposedSearchResult.setSearchRequest(self,request:PySide6.QtLocation.QPlaceSearchRequest)",
    nullptr}; // Sentinel
#else
static constexpr size_t QPlaceProposedSearchResult_SignatureByteSize = 112;
static constexpr uint8_t QPlaceProposedSearchResult_SignatureBytes[112] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0xf1, 0xc9,
    0x4f, 0x4e, 0x2c, 0xc9, 0xcc, 0xcf, 0xd3, 0x0b, 0x0c, 0xc8, 0x49, 0x4c, 0x4e, 0x0d, 0x28, 0xca,
    0x2f, 0xc8, 0x2f, 0x4e, 0x4d, 0x09, 0x4e, 0x4d, 0x2c, 0x4a, 0xce, 0x08, 0x4a, 0x2d, 0x2e, 0xcd,
    0x29, 0xd1, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0xe4, 0x32, 0x20, 0x43, 0x97, 0x4e, 0x7e, 0x49, 0x46,
    0x6a, 0x11, 0x6e, 0x8d, 0xc8, 0x1a, 0x34, 0xb9, 0x48, 0x32, 0x5f, 0xaf, 0x18, 0xca, 0x29, 0x2c,
    0x4d, 0x2d, 0x86, 0xba, 0x51, 0xd7, 0x8e, 0xa0, 0x4d, 0x60, 0xd5, 0x24, 0xdb, 0x54, 0x12, 0x8c,
    0x61, 0x99, 0x4e, 0x11, 0x84, 0x63, 0x45, 0x9c, 0x95, 0x9a, 0x5c, 0x00, 0x2d, 0xb8, 0x8a, 0xf5
};
#endif

PyTypeObject *init_QPlaceProposedSearchResult(PyObject *module)
{
    if (SbkPySide6_QtLocationTypeStructs[SBK_QPlaceProposedSearchResult_IDX].type != nullptr)
        return SbkPySide6_QtLocationTypeStructs[SBK_QPlaceProposedSearchResult_IDX].type;

    Shiboken::AutoDecRef Sbk_QPlaceProposedSearchResult_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchResult_IDX]))));

    _Sbk_QPlaceProposedSearchResult_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QPlaceProposedSearchResult",
        "QPlaceProposedSearchResult*",
        &Sbk_QPlaceProposedSearchResult_spec,
        &Shiboken::callCppDestructor< QPlaceProposedSearchResult >,
        Sbk_QPlaceProposedSearchResult_Type_bases.object(),
        0);
    auto *pyType = Sbk_QPlaceProposedSearchResult_TypeF(); // references _Sbk_QPlaceProposedSearchResult_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QPlaceProposedSearchResult_SignatureStrings);
#else
    InitSignatureBytes(pyType, QPlaceProposedSearchResult_SignatureBytes, QPlaceProposedSearchResult_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QPlaceProposedSearchResult_PropertyStrings);
    SbkPySide6_QtLocationTypeStructs[SBK_QPlaceProposedSearchResult_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QPlaceProposedSearchResult_PythonToCpp_QPlaceProposedSearchResult_PTR,
        is_QPlaceProposedSearchResult_PythonToCpp_QPlaceProposedSearchResult_PTR_Convertible,
        QPlaceProposedSearchResult_PTR_CppToPython_QPlaceProposedSearchResult);

    Shiboken::Conversions::registerConverterName(converter, "QPlaceProposedSearchResult");
    Shiboken::Conversions::registerConverterName(converter, "QPlaceProposedSearchResult*");
    Shiboken::Conversions::registerConverterName(converter, "QPlaceProposedSearchResult&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QPlaceProposedSearchResult).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QPlaceProposedSearchResultWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QPlaceProposedSearchResult_TypeF(), &Sbk_QPlaceProposedSearchResult_typeDiscovery);

    qRegisterMetaType< ::QPlaceProposedSearchResult *>();

    return pyType;
}
