// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtlocation_python.h"

// main header
#include "qplaceratings_wrapper.h"

// Argument includes
#include <QtLocation/qplaceratings.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPlaceRatings_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QPlaceRatings >()))
        return -1;

    ::QPlaceRatings *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QPlaceRatings", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QPlaceRatings::QPlaceRatings()
    // 1: QPlaceRatings::QPlaceRatings(QPlaceRatings)
    if (numArgs == 0) {
        overloadId = 0; // QPlaceRatings()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceRatings_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QPlaceRatings(QPlaceRatings)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceRatings_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceRatings_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QPlaceRatings()
        {

            // QPlaceRatings()
            cptr = new ::QPlaceRatings();
            break;
        }
        case 1: // QPlaceRatings(const QPlaceRatings &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPlaceRatings cppArg0_local;
            ::QPlaceRatings *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QPlaceRatings(QPlaceRatings)
                cptr = new ::QPlaceRatings(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QPlaceRatings >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceRatings_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QPlaceRatingsFunc_average(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceRatings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceRatings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // average()const
        qreal cppResult = const_cast<const ::QPlaceRatings *>(cppSelf)->average();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceRatingsFunc_count(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceRatings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceRatings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // count()const
        int cppResult = const_cast<const ::QPlaceRatings *>(cppSelf)->count();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceRatingsFunc_isEmpty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceRatings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceRatings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isEmpty()const
        bool cppResult = const_cast<const ::QPlaceRatings *>(cppSelf)->isEmpty();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceRatingsFunc_maximum(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceRatings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceRatings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maximum()const
        qreal cppResult = const_cast<const ::QPlaceRatings *>(cppSelf)->maximum();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceRatingsFunc_setAverage(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceRatings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceRatings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlaceRatings::setAverage(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setAverage(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAverage", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceRatings_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAverage(qreal)
            cppSelf->setAverage(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceRatingsFunc_setCount(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceRatings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceRatings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlaceRatings::setCount(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setCount(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCount", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceRatings_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCount(int)
            cppSelf->setCount(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceRatingsFunc_setMaximum(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceRatings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceRatings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlaceRatings::setMaximum(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setMaximum(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMaximum", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceRatings_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMaximum(qreal)
            cppSelf->setMaximum(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceRatingsFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceRatings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceRatings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlaceRatings::swap(QPlaceRatings&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceRatings_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QPlaceRatings&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceRatings_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPlaceRatings cppArg0_local;
        ::QPlaceRatings *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QPlaceRatings&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceRatings__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QPlaceRatings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceRatings_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceRatings_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QPlaceRatings_PropertyStrings[] = {
    "average::",
    "count::",
    "maximum::",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QPlaceRatings_methods[] = {
    {"average", reinterpret_cast<PyCFunction>(Sbk_QPlaceRatingsFunc_average), METH_NOARGS, nullptr},
    {"count", reinterpret_cast<PyCFunction>(Sbk_QPlaceRatingsFunc_count), METH_NOARGS, nullptr},
    {"isEmpty", reinterpret_cast<PyCFunction>(Sbk_QPlaceRatingsFunc_isEmpty), METH_NOARGS, nullptr},
    {"maximum", reinterpret_cast<PyCFunction>(Sbk_QPlaceRatingsFunc_maximum), METH_NOARGS, nullptr},
    {"setAverage", reinterpret_cast<PyCFunction>(Sbk_QPlaceRatingsFunc_setAverage), METH_O, nullptr},
    {"setCount", reinterpret_cast<PyCFunction>(Sbk_QPlaceRatingsFunc_setCount), METH_O, nullptr},
    {"setMaximum", reinterpret_cast<PyCFunction>(Sbk_QPlaceRatingsFunc_setMaximum), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QPlaceRatingsFunc_swap), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QPlaceRatings__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QPlaceRatings_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QPlaceRatings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceRatings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceRatings_IDX]), (pyArg)))) {
                // operator!=(const QPlaceRatings &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QPlaceRatings cppArg0_local;
                ::QPlaceRatings *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceRatings_IDX]), (pyArg)))) {
                // operator==(const QPlaceRatings &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QPlaceRatings cppArg0_local;
                ::QPlaceRatings *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QPlaceRatings_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QPlaceRatings_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QPlaceRatings_Type = nullptr;
static PyTypeObject *Sbk_QPlaceRatings_TypeF(void)
{
    return _Sbk_QPlaceRatings_Type;
}

static PyType_Slot Sbk_QPlaceRatings_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QPlaceRatings_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QPlaceRatings_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QPlaceRatings_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QPlaceRatings_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QPlaceRatings_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QPlaceRatings_spec = {
    "2:PySide6.QtLocation.QPlaceRatings",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QPlaceRatings_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QPlaceRatings_PythonToCpp_QPlaceRatings_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QPlaceRatings_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QPlaceRatings_PythonToCpp_QPlaceRatings_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QPlaceRatings_TypeF()))
        return QPlaceRatings_PythonToCpp_QPlaceRatings_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QPlaceRatings_PTR_CppToPython_QPlaceRatings(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QPlaceRatings_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QPlaceRatings_COPY_CppToPython_QPlaceRatings(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QPlaceRatings *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QPlaceRatings_TypeF(), new ::QPlaceRatings(*source), true, true);
}

// Python to C++ copy conversion.
static void QPlaceRatings_PythonToCpp_QPlaceRatings_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QPlaceRatings *>(cppOut) = *reinterpret_cast< ::QPlaceRatings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceRatings_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QPlaceRatings_PythonToCpp_QPlaceRatings_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QPlaceRatings_TypeF()))
        return QPlaceRatings_PythonToCpp_QPlaceRatings_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QPlaceRatings_SignatureStrings[] = {
    "1:PySide6.QtLocation.QPlaceRatings(self,*:KeywordOnly=None,average:qreal=None,maximum:qreal=None,count:int=None)",
    "0:PySide6.QtLocation.QPlaceRatings(self,other:PySide6.QtLocation.QPlaceRatings,*:KeywordOnly=None,average:qreal=None,maximum:qreal=None,count:int=None)",
    "PySide6.QtLocation.QPlaceRatings.average(self)->qreal",
    "PySide6.QtLocation.QPlaceRatings.count(self)->int",
    "PySide6.QtLocation.QPlaceRatings.isEmpty(self)->bool",
    "PySide6.QtLocation.QPlaceRatings.maximum(self)->qreal",
    "PySide6.QtLocation.QPlaceRatings.setAverage(self,average:qreal)",
    "PySide6.QtLocation.QPlaceRatings.setCount(self,count:int)",
    "PySide6.QtLocation.QPlaceRatings.setMaximum(self,max:qreal)",
    "PySide6.QtLocation.QPlaceRatings.swap(self,other:PySide6.QtLocation.QPlaceRatings)",
    "PySide6.QtLocation.QPlaceRatings.__copy__(self)->typing.Self",
    "PySide6.QtLocation.QPlaceRatings.__ne__(self,rhs:PySide6.QtLocation.QPlaceRatings)->bool",
    "PySide6.QtLocation.QPlaceRatings.__eq__(self,rhs:PySide6.QtLocation.QPlaceRatings)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QPlaceRatings_SignatureByteSize = 226;
static constexpr uint8_t QPlaceRatings_SignatureBytes[226] = {
    0x78, 0xda, 0xad, 0x92, 0xcb, 0x0e, 0x82, 0x30, 0x10, 0x45, 0xf7, 0x7e, 0x89, 0x18, 0x24, 0xba,
    0x71, 0x41, 0xa2, 0x89, 0x31, 0xae, 0x7c, 0x81, 0x7e, 0x40, 0x53, 0x61, 0x84, 0x26, 0xd0, 0xc1,
    0xb6, 0x3e, 0xfa, 0xf7, 0x22, 0x82, 0xe2, 0xaa, 0xc5, 0xb8, 0x9c, 0x49, 0xcf, 0xbd, 0x77, 0x66,
    0x3a, 0xf6, 0x03, 0x7d, 0x60, 0x31, 0x4c, 0xbc, 0x50, 0xad, 0x31, 0xa2, 0x8a, 0x21, 0xf7, 0xc2,
    0x20, 0xa3, 0x11, 0xec, 0xcb, 0x82, 0x27, 0xb2, 0x2f, 0x21, 0x3b, 0xb9, 0x03, 0x7f, 0x05, 0xfa,
    0x86, 0x22, 0xde, 0xf1, 0x4c, 0x4f, 0xb7, 0xc8, 0xc1, 0xa5, 0x57, 0x10, 0x34, 0x01, 0xff, 0x2c,
    0x80, 0x66, 0xaf, 0x56, 0x4e, 0xef, 0x2c, 0xbf, 0xe4, 0xed, 0x56, 0x84, 0x17, 0xae, 0x7c, 0xc6,
    0x55, 0x55, 0x3a, 0xbd, 0x91, 0xa5, 0x21, 0xaa, 0x14, 0x84, 0xf1, 0xed, 0xff, 0x72, 0x99, 0x9c,
    0xbc, 0x5a, 0xb6, 0x4a, 0xe7, 0x0c, 0x67, 0x95, 0x94, 0x99, 0xaa, 0x6c, 0x1a, 0xa6, 0x74, 0x33,
    0x13, 0x4c, 0x2e, 0xf3, 0x42, 0xe9, 0x86, 0x39, 0x22, 0x5a, 0xd8, 0xd4, 0x03, 0x76, 0x0c, 0x27,
    0x41, 0xcd, 0x5b, 0x53, 0x7d, 0x6f, 0xce, 0xb1, 0xe2, 0x17, 0xef, 0xf9, 0x3e, 0x1b, 0xb5, 0x23,
    0x37, 0xad, 0xc8, 0xcf, 0x03, 0xd9, 0xbb, 0xde, 0x68, 0xd1, 0xe5, 0x8f, 0x58, 0x48, 0x12, 0x12,
    0x61, 0xa1, 0x09, 0x69, 0xf6, 0xa7, 0x74, 0x51, 0xf6, 0xbd, 0x43, 0x59, 0xd9, 0xc0, 0x1c, 0x6a,
    0xd4, 0x15, 0xa9, 0x34, 0xe7, 0xb1, 0x3d, 0x2a, 0x21, 0x70, 0xfe, 0x45, 0xf8, 0x01, 0x2e, 0x29,
    0x64, 0xda
};
#endif

PyTypeObject *init_QPlaceRatings(PyObject *module)
{
    if (SbkPySide6_QtLocationTypeStructs[SBK_QPlaceRatings_IDX].type != nullptr)
        return SbkPySide6_QtLocationTypeStructs[SBK_QPlaceRatings_IDX].type;

    Shiboken::AutoDecRef Sbk_QPlaceRatings_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QPlaceRatings_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QPlaceRatings",
        "QPlaceRatings",
        &Sbk_QPlaceRatings_spec,
        &Shiboken::callCppDestructor< ::QPlaceRatings >,
        Sbk_QPlaceRatings_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QPlaceRatings_TypeF(); // references _Sbk_QPlaceRatings_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QPlaceRatings_SignatureStrings);
#else
    InitSignatureBytes(pyType, QPlaceRatings_SignatureBytes, QPlaceRatings_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QPlaceRatings_PropertyStrings);
    SbkPySide6_QtLocationTypeStructs[SBK_QPlaceRatings_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QPlaceRatings_PythonToCpp_QPlaceRatings_PTR,
        is_QPlaceRatings_PythonToCpp_QPlaceRatings_PTR_Convertible,
        QPlaceRatings_PTR_CppToPython_QPlaceRatings,
        QPlaceRatings_COPY_CppToPython_QPlaceRatings);

    Shiboken::Conversions::registerConverterName(converter, "QPlaceRatings");
    Shiboken::Conversions::registerConverterName(converter, "QPlaceRatings*");
    Shiboken::Conversions::registerConverterName(converter, "QPlaceRatings&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QPlaceRatings).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QPlaceRatings_PythonToCpp_QPlaceRatings_COPY,
        is_QPlaceRatings_PythonToCpp_QPlaceRatings_COPY_Convertible);

    qRegisterMetaType< ::QPlaceRatings >("QPlaceRatings");

    return pyType;
}
