// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtlocation_python.h"

// main header
#include "qplaceresult_wrapper.h"

// Argument includes
#include <QString>
#include <QtLocation/qplace.h>
#include <QtLocation/qplaceicon.h>
#include <QtLocation/qplacesearchresult.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

QPlaceResultWrapper::QPlaceResultWrapper()
{
}

QPlaceResultWrapper::QPlaceResultWrapper(const ::QPlaceSearchResult & other) : QPlaceResult(other)
{
}

QPlaceResultWrapper::~QPlaceResultWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPlaceResult_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QPlaceResult >()))
        return -1;

    QPlaceResultWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QPlaceResult", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QPlaceResult::QPlaceResult()
    // 1: QPlaceResult::QPlaceResult(QPlaceSearchResult)
    if (numArgs == 0) {
        overloadId = 0; // QPlaceResult()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchResult_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QPlaceResult(QPlaceSearchResult)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceResult_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceResult_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QPlaceResult()
        {

            // QPlaceResult()
            cptr = new QPlaceResultWrapper();
            break;
        }
        case 1: // QPlaceResult(const QPlaceSearchResult &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPlaceSearchResult *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QPlaceResult(QPlaceSearchResult)
                cptr = new QPlaceResultWrapper(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QPlaceResult >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceResult_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QPlaceResultFunc_distance(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // distance()const
        qreal cppResult = const_cast<const ::QPlaceResult *>(cppSelf)->distance();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceResultFunc_isSponsored(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isSponsored()const
        bool cppResult = const_cast<const ::QPlaceResult *>(cppSelf)->isSponsored();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceResultFunc_place(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // place()const
        QPlace cppResult = const_cast<const ::QPlaceResult *>(cppSelf)->place();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceResultFunc_setDistance(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlaceResult::setDistance(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setDistance(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDistance", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceResult_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDistance(qreal)
            cppSelf->setDistance(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceResultFunc_setPlace(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlaceResult::setPlace(QPlace)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), (pyArg)))) {
        overloadId = 0; // setPlace(QPlace)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPlace", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceResult_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPlace cppArg0_local;
        ::QPlace *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setPlace(QPlace)
            cppSelf->setPlace(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceResultFunc_setSponsored(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlaceResult::setSponsored(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setSponsored(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSponsored", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceResult_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSponsored(bool)
            cppSelf->setSponsored(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QPlaceResult_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QPlaceResult_methods[] = {
    {"distance", reinterpret_cast<PyCFunction>(Sbk_QPlaceResultFunc_distance), METH_NOARGS, nullptr},
    {"isSponsored", reinterpret_cast<PyCFunction>(Sbk_QPlaceResultFunc_isSponsored), METH_NOARGS, nullptr},
    {"place", reinterpret_cast<PyCFunction>(Sbk_QPlaceResultFunc_place), METH_NOARGS, nullptr},
    {"setDistance", reinterpret_cast<PyCFunction>(Sbk_QPlaceResultFunc_setDistance), METH_O, nullptr},
    {"setPlace", reinterpret_cast<PyCFunction>(Sbk_QPlaceResultFunc_setPlace), METH_O, nullptr},
    {"setSponsored", reinterpret_cast<PyCFunction>(Sbk_QPlaceResultFunc_setSponsored), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QPlaceResult_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QPlaceResult_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QPlaceResult_Type = nullptr;
static PyTypeObject *Sbk_QPlaceResult_TypeF(void)
{
    return _Sbk_QPlaceResult_Type;
}

static PyType_Slot Sbk_QPlaceResult_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QPlaceResult_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QPlaceResult_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QPlaceResult_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QPlaceResult_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QPlaceResult_spec = {
    "2:PySide6.QtLocation.QPlaceResult",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QPlaceResult_slots
};

} //extern "C"

static void *Sbk_QPlaceResult_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QPlaceSearchResult >())
        return dynamic_cast< ::QPlaceResult *>(reinterpret_cast< ::QPlaceSearchResult *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QPlaceResult_PythonToCpp_QPlaceResult_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QPlaceResult_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QPlaceResult_PythonToCpp_QPlaceResult_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QPlaceResult_TypeF()))
        return QPlaceResult_PythonToCpp_QPlaceResult_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QPlaceResult_PTR_CppToPython_QPlaceResult(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QPlaceResult *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QPlaceResult_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QPlaceResult_SignatureStrings[] = {
    "1:PySide6.QtLocation.QPlaceResult(self)",
    "0:PySide6.QtLocation.QPlaceResult(self,other:PySide6.QtLocation.QPlaceSearchResult)",
    "PySide6.QtLocation.QPlaceResult.distance(self)->qreal",
    "PySide6.QtLocation.QPlaceResult.isSponsored(self)->bool",
    "PySide6.QtLocation.QPlaceResult.place(self)->PySide6.QtLocation.QPlace",
    "PySide6.QtLocation.QPlaceResult.setDistance(self,distance:qreal)",
    "PySide6.QtLocation.QPlaceResult.setPlace(self,place:PySide6.QtLocation.QPlace)",
    "PySide6.QtLocation.QPlaceResult.setSponsored(self,sponsored:bool)",
    nullptr}; // Sentinel
#else
static constexpr size_t QPlaceResult_SignatureByteSize = 156;
static constexpr uint8_t QPlaceResult_SignatureBytes[156] = {
    0x78, 0xda, 0x8d, 0x90, 0x31, 0x0e, 0x02, 0x21, 0x10, 0x45, 0xfb, 0x3d, 0x89, 0x24, 0x48, 0xb4,
    0xb1, 0xa0, 0xb0, 0xb2, 0xb4, 0x60, 0xe5, 0x04, 0x08, 0x63, 0x96, 0x84, 0x30, 0x2b, 0x83, 0x85,
    0xb7, 0x37, 0xbb, 0x1b, 0x8c, 0x16, 0x04, 0x3a, 0x26, 0xf9, 0xef, 0xe7, 0xf1, 0x8f, 0x52, 0xbd,
    0xb5, 0x77, 0x70, 0x12, 0x63, 0xbe, 0xa2, 0x35, 0xd9, 0x63, 0x14, 0xa3, 0x0a, 0xc6, 0xc2, 0x0d,
    0xe8, 0x15, 0xf2, 0x8e, 0x20, 0x3c, 0xd8, 0x70, 0xe8, 0xca, 0x71, 0xcc, 0x13, 0xa4, 0x7a, 0x54,
    0x83, 0x49, 0x76, 0xda, 0x00, 0x36, 0x34, 0x1a, 0x85, 0xf3, 0x94, 0x4d, 0xb4, 0xb0, 0x29, 0xec,
    0xcf, 0xcf, 0x04, 0x26, 0x34, 0x29, 0x4f, 0x7a, 0xc6, 0x48, 0x98, 0xc0, 0x15, 0xf0, 0x8e, 0xd8,
    0xe6, 0xe6, 0xe5, 0x5d, 0x88, 0x6a, 0xb8, 0x59, 0x43, 0x90, 0x2f, 0xbf, 0xde, 0xbc, 0xfc, 0x42,
    0xae, 0xfa, 0xac, 0xa7, 0x40, 0x7d, 0x55, 0xf8, 0x6a, 0x55, 0x1f, 0xb4, 0xab, 0xee, 0x7f, 0x0f,
    0x4e, 0xe5, 0x94, 0xcb, 0x2e, 0x6c, 0xf8, 0x00, 0x87, 0xe5, 0xba, 0xff
};
#endif

PyTypeObject *init_QPlaceResult(PyObject *module)
{
    if (SbkPySide6_QtLocationTypeStructs[SBK_QPlaceResult_IDX].type != nullptr)
        return SbkPySide6_QtLocationTypeStructs[SBK_QPlaceResult_IDX].type;

    Shiboken::AutoDecRef Sbk_QPlaceResult_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchResult_IDX]))));

    _Sbk_QPlaceResult_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QPlaceResult",
        "QPlaceResult*",
        &Sbk_QPlaceResult_spec,
        &Shiboken::callCppDestructor< QPlaceResult >,
        Sbk_QPlaceResult_Type_bases.object(),
        0);
    auto *pyType = Sbk_QPlaceResult_TypeF(); // references _Sbk_QPlaceResult_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QPlaceResult_SignatureStrings);
#else
    InitSignatureBytes(pyType, QPlaceResult_SignatureBytes, QPlaceResult_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QPlaceResult_PropertyStrings);
    SbkPySide6_QtLocationTypeStructs[SBK_QPlaceResult_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QPlaceResult_PythonToCpp_QPlaceResult_PTR,
        is_QPlaceResult_PythonToCpp_QPlaceResult_PTR_Convertible,
        QPlaceResult_PTR_CppToPython_QPlaceResult);

    Shiboken::Conversions::registerConverterName(converter, "QPlaceResult");
    Shiboken::Conversions::registerConverterName(converter, "QPlaceResult*");
    Shiboken::Conversions::registerConverterName(converter, "QPlaceResult&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QPlaceResult).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QPlaceResultWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QPlaceResult_TypeF(), &Sbk_QPlaceResult_typeDiscovery);

    qRegisterMetaType< ::QPlaceResult *>();

    return pyType;
}
