// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtmultimedia_python.h"

// main header
#include "qabstractvideobuffer_mapdata_wrapper.h"

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QAbstractVideoBuffer_MapData_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QAbstractVideoBuffer::MapData >()))
        return -1;

    ::QAbstractVideoBuffer::MapData *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "MapData", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: MapData::MapData()
    // 1: MapData::MapData(QAbstractVideoBuffer::MapData)
    if (numArgs == 0) {
        overloadId = 0; // MapData()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAbstractVideoBuffer_MapData_IDX]), (pyArgs[0])))) {
        overloadId = 1; // MapData(QAbstractVideoBuffer::MapData)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QAbstractVideoBuffer_MapData_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtMultimediaTypeStructs[SBK_QAbstractVideoBuffer_MapData_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // MapData()
        {

            // MapData()
            cptr = new ::QAbstractVideoBuffer::MapData();
            break;
        }
        case 1: // MapData(const QAbstractVideoBuffer::MapData &MapData)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QAbstractVideoBuffer::MapData cppArg0_local;
            ::QAbstractVideoBuffer::MapData *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // MapData(QAbstractVideoBuffer::MapData)
                cptr = new ::QAbstractVideoBuffer::MapData(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QAbstractVideoBuffer::MapData >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QAbstractVideoBuffer_MapData_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QAbstractVideoBuffer_MapData__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QAbstractVideoBuffer::MapData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAbstractVideoBuffer_MapData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAbstractVideoBuffer_MapData_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QAbstractVideoBuffer_MapData_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QAbstractVideoBuffer_MapData_methods[] = {
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QAbstractVideoBuffer_MapData__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QAbstractVideoBuffer_MapData_get_planeCount(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractVideoBuffer::MapData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAbstractVideoBuffer_MapData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int cppOut_local = cppSelf->planeCount;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QAbstractVideoBuffer_MapData_set_planeCount(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QAbstractVideoBuffer::MapData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAbstractVideoBuffer_MapData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("planeCount");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("planeCount", "int");
        return -1;
    }

    auto cppOut_local = cppSelf->planeCount;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->planeCount = cppOut_local;

    return 0;
}




// Getters and Setters for MapData
static PyGetSetDef Sbk_QAbstractVideoBuffer_MapData_getsetlist[] = {
    {const_cast<char *>("planeCount"), Sbk_QAbstractVideoBuffer_MapData_get_planeCount, Sbk_QAbstractVideoBuffer_MapData_set_planeCount, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QAbstractVideoBuffer_MapData_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QAbstractVideoBuffer_MapData_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QAbstractVideoBuffer_MapData_Type = nullptr;
static PyTypeObject *Sbk_QAbstractVideoBuffer_MapData_TypeF(void)
{
    return _Sbk_QAbstractVideoBuffer_MapData_Type;
}

static PyType_Slot Sbk_QAbstractVideoBuffer_MapData_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QAbstractVideoBuffer_MapData_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QAbstractVideoBuffer_MapData_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QAbstractVideoBuffer_MapData_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QAbstractVideoBuffer_MapData_getsetlist)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QAbstractVideoBuffer_MapData_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QAbstractVideoBuffer_MapData_spec = {
    "2:PySide6.QtMultimedia.QAbstractVideoBuffer.MapData",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QAbstractVideoBuffer_MapData_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void MapData_PythonToCpp_MapData_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QAbstractVideoBuffer_MapData_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_MapData_PythonToCpp_MapData_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QAbstractVideoBuffer_MapData_TypeF()))
        return MapData_PythonToCpp_MapData_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *MapData_PTR_CppToPython_MapData(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QAbstractVideoBuffer_MapData_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *MapData_COPY_CppToPython_MapData(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QAbstractVideoBuffer::MapData *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QAbstractVideoBuffer_MapData_TypeF(), new ::QAbstractVideoBuffer::MapData(*source), true, true);
}

// Python to C++ copy conversion.
static void MapData_PythonToCpp_MapData_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QAbstractVideoBuffer::MapData *>(cppOut) = *reinterpret_cast< ::QAbstractVideoBuffer::MapData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAbstractVideoBuffer_MapData_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_MapData_PythonToCpp_MapData_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QAbstractVideoBuffer_MapData_TypeF()))
        return MapData_PythonToCpp_MapData_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QAbstractVideoBuffer_MapData_SignatureStrings[] = {
    "1:PySide6.QtMultimedia.QAbstractVideoBuffer.MapData(self)",
    "0:PySide6.QtMultimedia.QAbstractVideoBuffer.MapData(self,MapData:PySide6.QtMultimedia.QAbstractVideoBuffer.MapData)",
    "PySide6.QtMultimedia.QAbstractVideoBuffer.MapData.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QAbstractVideoBuffer_MapData_SignatureByteSize = 101;
static constexpr uint8_t QAbstractVideoBuffer_MapData_SignatureBytes[101] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0xf1, 0x2d,
    0xcd, 0x29, 0xc9, 0xcc, 0x4d, 0x4d, 0xc9, 0x4c, 0xd4, 0x0b, 0x74, 0x4c, 0x2a, 0x2e, 0x29, 0x4a,
    0x4c, 0x2e, 0x09, 0x03, 0xca, 0xe5, 0x3b, 0x95, 0xa6, 0xa5, 0xa5, 0x16, 0xe9, 0xf9, 0x26, 0x16,
    0xb8, 0x24, 0x96, 0x24, 0x6a, 0x14, 0xa7, 0xe6, 0xa4, 0x69, 0x72, 0x19, 0x90, 0xa9, 0x53, 0x07,
    0xca, 0x21, 0x5d, 0xbb, 0x26, 0x17, 0xc9, 0x5a, 0xf4, 0xe2, 0xe3, 0x93, 0xf3, 0x0b, 0x2a, 0xe3,
    0xe3, 0x21, 0x8e, 0xd6, 0xb5, 0x2b, 0xa9, 0x2c, 0xc8, 0xcc, 0x4b, 0xd7, 0x0b, 0x06, 0xf2, 0xb8,
    0x00, 0x03, 0x76, 0x5b, 0x36
};
#endif

PyTypeObject *init_QAbstractVideoBuffer_MapData(PyObject *enclosingClass)
{
    if (SbkPySide6_QtMultimediaTypeStructs[SBK_QAbstractVideoBuffer_MapData_IDX].type != nullptr)
        return SbkPySide6_QtMultimediaTypeStructs[SBK_QAbstractVideoBuffer_MapData_IDX].type;

    Shiboken::AutoDecRef Sbk_QAbstractVideoBuffer_MapData_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QAbstractVideoBuffer_MapData_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "MapData",
        "QAbstractVideoBuffer::MapData",
        &Sbk_QAbstractVideoBuffer_MapData_spec,
        &Shiboken::callCppDestructor< ::QAbstractVideoBuffer::MapData >,
        Sbk_QAbstractVideoBuffer_MapData_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass | Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QAbstractVideoBuffer_MapData_TypeF(); // references _Sbk_QAbstractVideoBuffer_MapData_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QAbstractVideoBuffer_MapData_SignatureStrings);
#else
    InitSignatureBytes(pyType, QAbstractVideoBuffer_MapData_SignatureBytes, QAbstractVideoBuffer_MapData_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QAbstractVideoBuffer_MapData_PropertyStrings);
    SbkPySide6_QtMultimediaTypeStructs[SBK_QAbstractVideoBuffer_MapData_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        MapData_PythonToCpp_MapData_PTR,
        is_MapData_PythonToCpp_MapData_PTR_Convertible,
        MapData_PTR_CppToPython_MapData,
        MapData_COPY_CppToPython_MapData);

    Shiboken::Conversions::registerConverterName(converter, "QAbstractVideoBuffer::MapData");
    Shiboken::Conversions::registerConverterName(converter, "QAbstractVideoBuffer::MapData*");
    Shiboken::Conversions::registerConverterName(converter, "QAbstractVideoBuffer::MapData&");
    Shiboken::Conversions::registerConverterAlias(converter, "MapData");
    Shiboken::Conversions::registerConverterAlias(converter, "MapData*");
    Shiboken::Conversions::registerConverterAlias(converter, "MapData&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QAbstractVideoBuffer::MapData).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        MapData_PythonToCpp_MapData_COPY,
        is_MapData_PythonToCpp_MapData_COPY_Convertible);

    qRegisterMetaType< ::QAbstractVideoBuffer::MapData >("MapData");
    qRegisterMetaType< ::QAbstractVideoBuffer::MapData >("QAbstractVideoBuffer::MapData");

    return pyType;
}
