// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtmultimedia_python.h"

// main header
#include "qabstractvideobuffer_wrapper.h"

// inner classes
#include "qabstractvideobuffer_mapdata_wrapper.h"

// Argument includes
#include <QtMultimedia/qabstractvideobuffer.h>
#include <QtMultimedia/qvideoframe.h>
#include <QtMultimedia/qvideoframeformat.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QAbstractVideoBufferWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QAbstractVideoBufferWrapper::QAbstractVideoBufferWrapper()
{
}

::QVideoFrameFormat QAbstractVideoBufferWrapper::format() const
{
    if (m_PyMethodCache[0]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QAbstractVideoBuffer.format");
        return {};
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return {};
    static PyObject *nameCache[2] = {};
    static const char *funcName = "format";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        Shiboken::Errors::setPureVirtualMethodError("QAbstractVideoBuffer.format");
        return {};
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractVideoBuffer", funcName);
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrameFormat_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstractVideoBuffer", funcName, Shiboken::SbkType< QVideoFrameFormat >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QVideoFrameFormat cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QAbstractVideoBuffer::MapData QAbstractVideoBufferWrapper::map(::QVideoFrame::MapMode mode)
{
    if (m_PyMethodCache[1]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QAbstractVideoBuffer.map");
        return {};
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return {};
    static PyObject *nameCache[2] = {};
    static const char *funcName = "map";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        Shiboken::Errors::setPureVirtualMethodError("QAbstractVideoBuffer.map");
        return {};
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_MapMode_IDX])))->converter, &mode)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_MapMode_IDX])))->converter, &mode)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractVideoBuffer", funcName);
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAbstractVideoBuffer_MapData_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstractVideoBuffer", funcName, Shiboken::SbkType< QAbstractVideoBuffer::MapData >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QAbstractVideoBuffer::MapData cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QAbstractVideoBufferWrapper::unmap()
{
    if (m_PyMethodCache[2]) {
        return this->::QAbstractVideoBuffer::unmap();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "unmap";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QAbstractVideoBuffer::unmap();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractVideoBuffer", funcName);
        return;
    }
}

QAbstractVideoBufferWrapper::~QAbstractVideoBufferWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QAbstractVideoBuffer_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAbstractVideoBuffer_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QAbstractVideoBuffer");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QAbstractVideoBuffer >()))
        return -1;

    QAbstractVideoBufferWrapper *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtMultimediaTypeStructs[SBK_QAbstractVideoBuffer_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QAbstractVideoBuffer()
        cptr = new QAbstractVideoBufferWrapper();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QAbstractVideoBuffer >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QAbstractVideoBufferFunc_format(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractVideoBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAbstractVideoBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // format()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QAbstractVideoBuffer.format");
            return {};
        }
        QVideoFrameFormat cppResult = const_cast<const ::QAbstractVideoBuffer *>(cppSelf)->format();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrameFormat_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractVideoBufferFunc_map(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractVideoBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAbstractVideoBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractVideoBuffer::map(QVideoFrame::MapMode)->QAbstractVideoBuffer::MapData
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_MapMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // map(QVideoFrame::MapMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "map", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QAbstractVideoBuffer_IDX]);

    // Call function/method
    {
        ::QVideoFrame::MapMode cppArg0{QVideoFrame::NotMapped};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // map(QVideoFrame::MapMode)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QAbstractVideoBuffer.map");
                return {};
            }
            QAbstractVideoBuffer::MapData cppResult = cppSelf->map(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAbstractVideoBuffer_MapData_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractVideoBufferFunc_unmap(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractVideoBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAbstractVideoBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // unmap()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QAbstractVideoBuffer::unmap()
            : cppSelf->unmap();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QAbstractVideoBuffer_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QAbstractVideoBuffer_methods[] = {
    {"format", reinterpret_cast<PyCFunction>(Sbk_QAbstractVideoBufferFunc_format), METH_NOARGS, nullptr},
    {"map", reinterpret_cast<PyCFunction>(Sbk_QAbstractVideoBufferFunc_map), METH_O, nullptr},
    {"unmap", reinterpret_cast<PyCFunction>(Sbk_QAbstractVideoBufferFunc_unmap), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QAbstractVideoBuffer_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QAbstractVideoBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAbstractVideoBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QAbstractVideoBufferWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QAbstractVideoBuffer_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QAbstractVideoBuffer_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QAbstractVideoBuffer_Type = nullptr;
static PyTypeObject *Sbk_QAbstractVideoBuffer_TypeF(void)
{
    return _Sbk_QAbstractVideoBuffer_Type;
}

static PyType_Slot Sbk_QAbstractVideoBuffer_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QAbstractVideoBuffer_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QAbstractVideoBuffer_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QAbstractVideoBuffer_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QAbstractVideoBuffer_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QAbstractVideoBuffer_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QAbstractVideoBuffer_spec = {
    "2:PySide6.QtMultimedia.QAbstractVideoBuffer",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QAbstractVideoBuffer_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAbstractVideoBuffer_PythonToCpp_QAbstractVideoBuffer_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QAbstractVideoBuffer_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAbstractVideoBuffer_PythonToCpp_QAbstractVideoBuffer_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QAbstractVideoBuffer_TypeF()))
        return QAbstractVideoBuffer_PythonToCpp_QAbstractVideoBuffer_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAbstractVideoBuffer_PTR_CppToPython_QAbstractVideoBuffer(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QAbstractVideoBuffer *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QAbstractVideoBuffer_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QAbstractVideoBuffer_SignatureStrings[] = {
    "PySide6.QtMultimedia.QAbstractVideoBuffer(self)",
    "PySide6.QtMultimedia.QAbstractVideoBuffer.format(self)->PySide6.QtMultimedia.QVideoFrameFormat",
    "PySide6.QtMultimedia.QAbstractVideoBuffer.map(self,mode:PySide6.QtMultimedia.QVideoFrame.MapMode)->PySide6.QtMultimedia.QAbstractVideoBuffer.MapData",
    "PySide6.QtMultimedia.QAbstractVideoBuffer.unmap(self)",
    nullptr}; // Sentinel
#else
static constexpr size_t QAbstractVideoBuffer_SignatureByteSize = 124;
static constexpr uint8_t QAbstractVideoBuffer_SignatureBytes[124] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0xf1, 0x2d, 0xcd, 0x29,
    0xc9, 0xcc, 0x4d, 0x4d, 0xc9, 0x4c, 0xd4, 0x0b, 0x74, 0x4c, 0x2a, 0x2e, 0x29, 0x4a, 0x4c, 0x2e,
    0x09, 0x03, 0xca, 0xe5, 0x3b, 0x95, 0xa6, 0xa5, 0xa5, 0x16, 0x69, 0x14, 0xa7, 0xe6, 0xa4, 0x69,
    0x72, 0x05, 0x10, 0xab, 0x5e, 0x2f, 0x2d, 0xbf, 0x28, 0x37, 0xb1, 0x04, 0xa2, 0x4d, 0xd7, 0x0e,
    0xbb, 0x3e, 0xb0, 0x7a, 0xb7, 0xa2, 0xc4, 0xdc, 0x54, 0x37, 0xb0, 0x6a, 0x12, 0x8c, 0xcf, 0x4d,
    0x2c, 0x00, 0x9b, 0xad, 0x93, 0x9b, 0x9f, 0x92, 0x6a, 0x45, 0xc8, 0x78, 0x3d, 0xdf, 0xc4, 0x02,
    0x5f, 0xa0, 0x42, 0x9c, 0x2e, 0xc1, 0x66, 0x05, 0x50, 0x8f, 0x4b, 0x62, 0x49, 0x22, 0x09, 0x8e,
    0x2a, 0xcd, 0x83, 0x39, 0x4b, 0x93, 0x0b, 0x00, 0x2b, 0x63, 0x7e, 0xcc
};
#endif

PyTypeObject *init_QAbstractVideoBuffer(PyObject *module)
{
    if (SbkPySide6_QtMultimediaTypeStructs[SBK_QAbstractVideoBuffer_IDX].type != nullptr)
        return SbkPySide6_QtMultimediaTypeStructs[SBK_QAbstractVideoBuffer_IDX].type;

    Shiboken::AutoDecRef Sbk_QAbstractVideoBuffer_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QAbstractVideoBuffer_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QAbstractVideoBuffer",
        "QAbstractVideoBuffer*",
        &Sbk_QAbstractVideoBuffer_spec,
        &Shiboken::callCppDestructor< QAbstractVideoBuffer >,
        Sbk_QAbstractVideoBuffer_Type_bases.object(),
        0);
    auto *pyType = Sbk_QAbstractVideoBuffer_TypeF(); // references _Sbk_QAbstractVideoBuffer_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QAbstractVideoBuffer_SignatureStrings);
#else
    InitSignatureBytes(pyType, QAbstractVideoBuffer_SignatureBytes, QAbstractVideoBuffer_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QAbstractVideoBuffer_PropertyStrings);
    SbkPySide6_QtMultimediaTypeStructs[SBK_QAbstractVideoBuffer_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAbstractVideoBuffer_PythonToCpp_QAbstractVideoBuffer_PTR,
        is_QAbstractVideoBuffer_PythonToCpp_QAbstractVideoBuffer_PTR_Convertible,
        QAbstractVideoBuffer_PTR_CppToPython_QAbstractVideoBuffer);

    Shiboken::Conversions::registerConverterName(converter, "QAbstractVideoBuffer");
    Shiboken::Conversions::registerConverterName(converter, "QAbstractVideoBuffer*");
    Shiboken::Conversions::registerConverterName(converter, "QAbstractVideoBuffer&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QAbstractVideoBuffer).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QAbstractVideoBufferWrapper).name());

    qRegisterMetaType< ::QAbstractVideoBuffer *>();

    return pyType;
}
