// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtmultimedia_python.h"

// main header
#include "qaudioformat_wrapper.h"

// Argument includes
#include <QtMultimedia/qaudioformat.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QAudioFormat_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QAudioFormat >()))
        return -1;

    ::QAudioFormat *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QAudioFormat", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QAudioFormat::QAudioFormat()
    // 1: QAudioFormat::QAudioFormat(QAudioFormat)
    if (numArgs == 0) {
        overloadId = 0; // QAudioFormat()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QAudioFormat(QAudioFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QAudioFormat()
        {

            // QAudioFormat()
            cptr = new ::QAudioFormat();
            break;
        }
        case 1: // QAudioFormat(const QAudioFormat &QAudioFormat)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QAudioFormat cppArg0_local;
            ::QAudioFormat *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QAudioFormat(QAudioFormat)
                cptr = new ::QAudioFormat(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QAudioFormat >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QAudioFormatFunc_bytesForDuration(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAudioFormat::bytesForDuration(qint64)const->qint32
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArg)))) {
        overloadId = 0; // bytesForDuration(qint64)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "bytesForDuration", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]);

    // Call function/method
    {
        qint64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // bytesForDuration(qint64)const
            qint32 cppResult = const_cast<const ::QAudioFormat *>(cppSelf)->bytesForDuration(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint32>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioFormatFunc_bytesForFrames(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAudioFormat::bytesForFrames(qint32)const->qint32
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint32>(), (pyArg)))) {
        overloadId = 0; // bytesForFrames(qint32)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "bytesForFrames", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]);

    // Call function/method
    {
        qint32 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // bytesForFrames(qint32)const
            qint32 cppResult = const_cast<const ::QAudioFormat *>(cppSelf)->bytesForFrames(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint32>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioFormatFunc_bytesPerFrame(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // bytesPerFrame()const
        int cppResult = const_cast<const ::QAudioFormat *>(cppSelf)->bytesPerFrame();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioFormatFunc_bytesPerSample(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // bytesPerSample()const
        int cppResult = const_cast<const ::QAudioFormat *>(cppSelf)->bytesPerSample();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioFormatFunc_channelConfig(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // channelConfig()const
        QAudioFormat::ChannelConfig cppResult = const_cast<const ::QAudioFormat *>(cppSelf)->channelConfig();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_ChannelConfig_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioFormatFunc_channelCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // channelCount()const
        int cppResult = const_cast<const ::QAudioFormat *>(cppSelf)->channelCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioFormatFunc_channelOffset(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAudioFormat::channelOffset(QAudioFormat::AudioChannelPosition)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_AudioChannelPosition_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // channelOffset(QAudioFormat::AudioChannelPosition)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "channelOffset", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]);

    // Call function/method
    {
        ::QAudioFormat::AudioChannelPosition cppArg0{QAudioFormat::UnknownPosition};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // channelOffset(QAudioFormat::AudioChannelPosition)const
            int cppResult = const_cast<const ::QAudioFormat *>(cppSelf)->channelOffset(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioFormatFunc_defaultChannelConfigForChannelCount(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QAudioFormat::defaultChannelConfigForChannelCount(int)->QAudioFormat::ChannelConfig
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // defaultChannelConfigForChannelCount(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "defaultChannelConfigForChannelCount", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // defaultChannelConfigForChannelCount(int)
            QAudioFormat::ChannelConfig cppResult = ::QAudioFormat::defaultChannelConfigForChannelCount(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_ChannelConfig_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioFormatFunc_durationForBytes(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAudioFormat::durationForBytes(qint32)const->qint64
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint32>(), (pyArg)))) {
        overloadId = 0; // durationForBytes(qint32)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "durationForBytes", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]);

    // Call function/method
    {
        qint32 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // durationForBytes(qint32)const
            qint64 cppResult = const_cast<const ::QAudioFormat *>(cppSelf)->durationForBytes(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioFormatFunc_durationForFrames(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAudioFormat::durationForFrames(qint32)const->qint64
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint32>(), (pyArg)))) {
        overloadId = 0; // durationForFrames(qint32)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "durationForFrames", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]);

    // Call function/method
    {
        qint32 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // durationForFrames(qint32)const
            qint64 cppResult = const_cast<const ::QAudioFormat *>(cppSelf)->durationForFrames(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioFormatFunc_framesForBytes(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAudioFormat::framesForBytes(qint32)const->qint32
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint32>(), (pyArg)))) {
        overloadId = 0; // framesForBytes(qint32)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "framesForBytes", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]);

    // Call function/method
    {
        qint32 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // framesForBytes(qint32)const
            qint32 cppResult = const_cast<const ::QAudioFormat *>(cppSelf)->framesForBytes(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint32>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioFormatFunc_framesForDuration(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAudioFormat::framesForDuration(qint64)const->qint32
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArg)))) {
        overloadId = 0; // framesForDuration(qint64)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "framesForDuration", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]);

    // Call function/method
    {
        qint64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // framesForDuration(qint64)const
            qint32 cppResult = const_cast<const ::QAudioFormat *>(cppSelf)->framesForDuration(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint32>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioFormatFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QAudioFormat *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioFormatFunc_normalizedSampleValue(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAudioFormat::normalizedSampleValue(PyBuffer)const->float
    if (Shiboken::Buffer::checkType(pyArg)) {
        overloadId = 0; // normalizedSampleValue(const void*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "normalizedSampleValue", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]);

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // normalizedSampleValue(const void*)const
            // Begin code injection
            // TEMPLATE - pybuffer_const_char - START
            Py_ssize_t bufferLen;
            char *sample_out = reinterpret_cast<char*>(Shiboken::Buffer::getPointer(pyArg, &bufferLen));
            // TEMPLATE - pybuffer_const_char - END
            // End of code injection

            float cppResult = const_cast<const ::QAudioFormat *>(cppSelf)->normalizedSampleValue(sample_out);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioFormatFunc_sampleFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sampleFormat()const
        QAudioFormat::SampleFormat cppResult = const_cast<const ::QAudioFormat *>(cppSelf)->sampleFormat();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_SampleFormat_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioFormatFunc_sampleRate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sampleRate()const
        int cppResult = const_cast<const ::QAudioFormat *>(cppSelf)->sampleRate();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioFormatFunc_setChannelConfig(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAudioFormat::setChannelConfig(QAudioFormat::ChannelConfig)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_ChannelConfig_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setChannelConfig(QAudioFormat::ChannelConfig)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setChannelConfig", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]);

    // Call function/method
    {
        ::QAudioFormat::ChannelConfig cppArg0{QAudioFormat::ChannelConfigUnknown};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setChannelConfig(QAudioFormat::ChannelConfig)
            cppSelf->setChannelConfig(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAudioFormatFunc_setChannelCount(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAudioFormat::setChannelCount(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setChannelCount(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setChannelCount", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setChannelCount(int)
            cppSelf->setChannelCount(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAudioFormatFunc_setSampleFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAudioFormat::setSampleFormat(QAudioFormat::SampleFormat)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_SampleFormat_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setSampleFormat(QAudioFormat::SampleFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSampleFormat", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]);

    // Call function/method
    {
        ::QAudioFormat::SampleFormat cppArg0{QAudioFormat::Unknown};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSampleFormat(QAudioFormat::SampleFormat)
            cppSelf->setSampleFormat(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAudioFormatFunc_setSampleRate(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAudioFormat::setSampleRate(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setSampleRate(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSampleRate", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSampleRate(int)
            cppSelf->setSampleRate(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAudioFormat__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QAudioFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QAudioFormat_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QAudioFormat_EnumFlagInfo[] = {
    "AudioChannelPosition:Enum",
    "ChannelConfig:Enum",
    "SampleFormat:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QAudioFormat_methods[] = {
    {"bytesForDuration", reinterpret_cast<PyCFunction>(Sbk_QAudioFormatFunc_bytesForDuration), METH_O, nullptr},
    {"bytesForFrames", reinterpret_cast<PyCFunction>(Sbk_QAudioFormatFunc_bytesForFrames), METH_O, nullptr},
    {"bytesPerFrame", reinterpret_cast<PyCFunction>(Sbk_QAudioFormatFunc_bytesPerFrame), METH_NOARGS, nullptr},
    {"bytesPerSample", reinterpret_cast<PyCFunction>(Sbk_QAudioFormatFunc_bytesPerSample), METH_NOARGS, nullptr},
    {"channelConfig", reinterpret_cast<PyCFunction>(Sbk_QAudioFormatFunc_channelConfig), METH_NOARGS, nullptr},
    {"channelCount", reinterpret_cast<PyCFunction>(Sbk_QAudioFormatFunc_channelCount), METH_NOARGS, nullptr},
    {"channelOffset", reinterpret_cast<PyCFunction>(Sbk_QAudioFormatFunc_channelOffset), METH_O, nullptr},
    {"defaultChannelConfigForChannelCount", reinterpret_cast<PyCFunction>(Sbk_QAudioFormatFunc_defaultChannelConfigForChannelCount), METH_O|METH_STATIC, nullptr},
    {"durationForBytes", reinterpret_cast<PyCFunction>(Sbk_QAudioFormatFunc_durationForBytes), METH_O, nullptr},
    {"durationForFrames", reinterpret_cast<PyCFunction>(Sbk_QAudioFormatFunc_durationForFrames), METH_O, nullptr},
    {"framesForBytes", reinterpret_cast<PyCFunction>(Sbk_QAudioFormatFunc_framesForBytes), METH_O, nullptr},
    {"framesForDuration", reinterpret_cast<PyCFunction>(Sbk_QAudioFormatFunc_framesForDuration), METH_O, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QAudioFormatFunc_isValid), METH_NOARGS, nullptr},
    {"normalizedSampleValue", reinterpret_cast<PyCFunction>(Sbk_QAudioFormatFunc_normalizedSampleValue), METH_O, nullptr},
    {"sampleFormat", reinterpret_cast<PyCFunction>(Sbk_QAudioFormatFunc_sampleFormat), METH_NOARGS, nullptr},
    {"sampleRate", reinterpret_cast<PyCFunction>(Sbk_QAudioFormatFunc_sampleRate), METH_NOARGS, nullptr},
    {"setChannelConfig", reinterpret_cast<PyCFunction>(Sbk_QAudioFormatFunc_setChannelConfig), METH_O, nullptr},
    {"setChannelCount", reinterpret_cast<PyCFunction>(Sbk_QAudioFormatFunc_setChannelCount), METH_O, nullptr},
    {"setSampleFormat", reinterpret_cast<PyCFunction>(Sbk_QAudioFormatFunc_setSampleFormat), METH_O, nullptr},
    {"setSampleRate", reinterpret_cast<PyCFunction>(Sbk_QAudioFormatFunc_setSampleRate), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QAudioFormat__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QAudioFormat_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QAudioFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]), (pyArg)))) {
                // operator!=(const QAudioFormat &b)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QAudioFormat cppArg0_local;
                ::QAudioFormat *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]), (pyArg)))) {
                // operator==(const QAudioFormat &b)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QAudioFormat cppArg0_local;
                ::QAudioFormat *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QAudioFormat_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QAudioFormat_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QAudioFormat__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QAudioFormat_Type = nullptr;
static PyTypeObject *Sbk_QAudioFormat_TypeF(void)
{
    return _Sbk_QAudioFormat_Type;
}

static PyType_Slot Sbk_QAudioFormat_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QAudioFormat__repr__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QAudioFormat_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QAudioFormat_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QAudioFormat_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QAudioFormat_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QAudioFormat_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QAudioFormat_spec = {
    "2:PySide6.QtMultimedia.QAudioFormat",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QAudioFormat_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QAudioFormat_SampleFormat(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAudioFormat::SampleFormat>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAudioFormat::SampleFormat *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAudioFormat_SampleFormat_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_SampleFormat_IDX])))
        return Enum_PythonToCpp_QAudioFormat_SampleFormat;
    return {};
}

static PyObject *QAudioFormat_SampleFormat_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAudioFormat::SampleFormat>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAudioFormat::SampleFormat *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_SampleFormat_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QAudioFormat_AudioChannelPosition(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAudioFormat::AudioChannelPosition>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAudioFormat::AudioChannelPosition *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAudioFormat_AudioChannelPosition_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_AudioChannelPosition_IDX])))
        return Enum_PythonToCpp_QAudioFormat_AudioChannelPosition;
    return {};
}

static PyObject *QAudioFormat_AudioChannelPosition_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAudioFormat::AudioChannelPosition>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAudioFormat::AudioChannelPosition *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_AudioChannelPosition_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QAudioFormat_ChannelConfig(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAudioFormat::ChannelConfig>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAudioFormat::ChannelConfig *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAudioFormat_ChannelConfig_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_ChannelConfig_IDX])))
        return Enum_PythonToCpp_QAudioFormat_ChannelConfig;
    return {};
}

static PyObject *QAudioFormat_ChannelConfig_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAudioFormat::ChannelConfig>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAudioFormat::ChannelConfig *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_ChannelConfig_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAudioFormat_PythonToCpp_QAudioFormat_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QAudioFormat_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAudioFormat_PythonToCpp_QAudioFormat_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QAudioFormat_TypeF()))
        return QAudioFormat_PythonToCpp_QAudioFormat_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAudioFormat_PTR_CppToPython_QAudioFormat(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QAudioFormat_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QAudioFormat_COPY_CppToPython_QAudioFormat(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QAudioFormat *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QAudioFormat_TypeF(), new ::QAudioFormat(*source), true, true);
}

// Python to C++ copy conversion.
static void QAudioFormat_PythonToCpp_QAudioFormat_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QAudioFormat *>(cppOut) = *reinterpret_cast< ::QAudioFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QAudioFormat_PythonToCpp_QAudioFormat_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QAudioFormat_TypeF()))
        return QAudioFormat_PythonToCpp_QAudioFormat_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QAudioFormat_SignatureStrings[] = {
    "1:PySide6.QtMultimedia.QAudioFormat(self)",
    "0:PySide6.QtMultimedia.QAudioFormat(self,QAudioFormat:PySide6.QtMultimedia.QAudioFormat)",
    "PySide6.QtMultimedia.QAudioFormat.bytesForDuration(self,microseconds:qint64)->qint32",
    "PySide6.QtMultimedia.QAudioFormat.bytesForFrames(self,frameCount:qint32)->qint32",
    "PySide6.QtMultimedia.QAudioFormat.bytesPerFrame(self)->int",
    "PySide6.QtMultimedia.QAudioFormat.bytesPerSample(self)->int",
    "PySide6.QtMultimedia.QAudioFormat.channelConfig(self)->PySide6.QtMultimedia.QAudioFormat.ChannelConfig",
    "PySide6.QtMultimedia.QAudioFormat.channelCount(self)->int",
    "PySide6.QtMultimedia.QAudioFormat.channelOffset(self,channel:PySide6.QtMultimedia.QAudioFormat.AudioChannelPosition)->int",
    "PySide6.QtMultimedia.QAudioFormat.defaultChannelConfigForChannelCount(channelCount:int)->PySide6.QtMultimedia.QAudioFormat.ChannelConfig",
    "PySide6.QtMultimedia.QAudioFormat.durationForBytes(self,byteCount:qint32)->qint64",
    "PySide6.QtMultimedia.QAudioFormat.durationForFrames(self,frameCount:qint32)->qint64",
    "PySide6.QtMultimedia.QAudioFormat.framesForBytes(self,byteCount:qint32)->qint32",
    "PySide6.QtMultimedia.QAudioFormat.framesForDuration(self,microseconds:qint64)->qint32",
    "PySide6.QtMultimedia.QAudioFormat.isValid(self)->bool",
    "PySide6.QtMultimedia.QAudioFormat.normalizedSampleValue(self,sample:PyBuffer)->float",
    "PySide6.QtMultimedia.QAudioFormat.sampleFormat(self)->PySide6.QtMultimedia.QAudioFormat.SampleFormat",
    "PySide6.QtMultimedia.QAudioFormat.sampleRate(self)->int",
    "PySide6.QtMultimedia.QAudioFormat.setChannelConfig(self,config:PySide6.QtMultimedia.QAudioFormat.ChannelConfig)",
    "PySide6.QtMultimedia.QAudioFormat.setChannelCount(self,channelCount:int)",
    "PySide6.QtMultimedia.QAudioFormat.setSampleFormat(self,f:PySide6.QtMultimedia.QAudioFormat.SampleFormat)",
    "PySide6.QtMultimedia.QAudioFormat.setSampleRate(self,sampleRate:int)",
    "PySide6.QtMultimedia.QAudioFormat.__copy__(self)->typing.Self",
    "PySide6.QtMultimedia.QAudioFormat.__ne__(self,b:PySide6.QtMultimedia.QAudioFormat)->bool",
    "PySide6.QtMultimedia.QAudioFormat.__eq__(self,b:PySide6.QtMultimedia.QAudioFormat)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QAudioFormat_SignatureByteSize = 386;
static constexpr uint8_t QAudioFormat_SignatureBytes[386] = {
    0x78, 0xda, 0xb5, 0x55, 0x4d, 0x6f, 0x83, 0x30, 0x0c, 0xbd, 0xf7, 0x97, 0x0c, 0x29, 0x45, 0xfb,
    0xa8, 0x7a, 0xe0, 0x50, 0x69, 0x65, 0xea, 0x6d, 0x5a, 0x3b, 0xa4, 0x5d, 0x51, 0x4a, 0x9c, 0x2e,
    0x52, 0x48, 0x5a, 0x12, 0x0e, 0xec, 0xd7, 0x2f, 0x10, 0xe8, 0xd8, 0x3a, 0x09, 0xa7, 0xda, 0x4e,
    0x38, 0x1f, 0xef, 0xd9, 0xb1, 0x9f, 0xcd, 0x5d, 0xb2, 0x6d, 0x32, 0xc1, 0x60, 0x19, 0xef, 0xec,
    0x73, 0x2d, 0xad, 0x28, 0x81, 0x09, 0x1a, 0xef, 0x1e, 0x6b, 0x26, 0xf4, 0x46, 0x57, 0x25, 0xb5,
    0x37, 0x06, 0x24, 0x8f, 0x66, 0xb7, 0xc8, 0x9b, 0x64, 0xbc, 0x33, 0x8d, 0x89, 0x66, 0x93, 0x57,
    0xe2, 0x7d, 0x63, 0xc1, 0x38, 0xfb, 0xa9, 0xae, 0xa8, 0x15, 0x5a, 0x79, 0x3f, 0xa5, 0x28, 0x2a,
    0x6d, 0xa0, 0xd0, 0x8a, 0x99, 0xe4, 0x24, 0x94, 0x5d, 0x2e, 0xa2, 0xf9, 0xaa, 0x35, 0x1e, 0xee,
    0x03, 0x48, 0x37, 0x15, 0x2d, 0xc1, 0x78, 0x4a, 0xde, 0xda, 0xa9, 0xae, 0x95, 0x4d, 0x3c, 0x4f,
    0x30, 0xe1, 0x16, 0x3c, 0xa1, 0x4f, 0xda, 0x7c, 0xe5, 0xc0, 0x01, 0xd0, 0x8c, 0x96, 0x47, 0x19,
    0x88, 0x2d, 0xde, 0xa9, 0x52, 0x20, 0x53, 0xad, 0xb8, 0x38, 0x0c, 0xd0, 0x69, 0x58, 0x3a, 0x86,
    0x85, 0xb8, 0x71, 0xc9, 0xb9, 0x2a, 0xc0, 0x17, 0xce, 0x0d, 0xf4, 0x12, 0xe9, 0xb7, 0xa6, 0xd5,
    0x11, 0x77, 0x76, 0x1f, 0xeb, 0x56, 0x1b, 0xd1, 0x96, 0x1f, 0xed, 0x99, 0x01, 0xa7, 0xee, 0xe8,
    0xdb, 0x53, 0xdd, 0x51, 0x3a, 0x7e, 0xca, 0xf8, 0x5d, 0x89, 0xa3, 0xfd, 0x97, 0xe4, 0xb1, 0x5e,
    0xb8, 0x6e, 0xb9, 0x6e, 0x4b, 0xed, 0xb3, 0xd0, 0x56, 0xfd, 0x17, 0xb1, 0x2d, 0x17, 0x61, 0x8c,
    0x18, 0x01, 0xa3, 0x38, 0x3b, 0xb0, 0x41, 0xc5, 0x88, 0x6a, 0x88, 0x33, 0xdf, 0x9f, 0xf6, 0xad,
    0x30, 0x6f, 0x54, 0x0a, 0x36, 0x68, 0x70, 0xaf, 0xb5, 0x44, 0xa0, 0x54, 0xfb, 0x91, 0xe2, 0x03,
    0x98, 0xef, 0x31, 0xc7, 0x51, 0xfb, 0x46, 0x23, 0xa6, 0xdb, 0x70, 0x5a, 0x5c, 0xd7, 0x9c, 0x43,
    0xe5, 0x38, 0xb9, 0xd4, 0x14, 0xa3, 0x2f, 0x8f, 0x1c, 0x4f, 0x49, 0x8c, 0x78, 0xb2, 0x11, 0x0a,
    0xed, 0xe4, 0x95, 0xda, 0xc0, 0xb9, 0xe0, 0x9a, 0x2d, 0xbd, 0x18, 0x0d, 0xa4, 0xe8, 0xec, 0x24,
    0x50, 0xe2, 0x51, 0xa0, 0xbf, 0x61, 0x46, 0x90, 0x8b, 0xee, 0xc2, 0x11, 0x65, 0x3f, 0x13, 0x4b,
    0x78, 0x12, 0x96, 0xd8, 0x20, 0x47, 0xe7, 0xe4, 0x92, 0xaf, 0x64, 0x63, 0xa3, 0xcd, 0xf3, 0x42,
    0x1f, 0x9b, 0x3c, 0x1f, 0x8a, 0x63, 0x9b, 0xa3, 0x50, 0x87, 0x38, 0x73, 0x2b, 0x14, 0x5a, 0x41,
    0x8f, 0x25, 0x7b, 0xc4, 0xcf, 0x12, 0xad, 0xf7, 0x3c, 0x87, 0xd3, 0x15, 0xc4, 0x9f, 0x0f, 0xd6,
    0xf4, 0x2a
};
#endif

PyTypeObject *init_QAudioFormat(PyObject *module)
{
    if (SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX].type != nullptr)
        return SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX].type;

    Shiboken::AutoDecRef Sbk_QAudioFormat_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QAudioFormat_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QAudioFormat",
        "QAudioFormat",
        &Sbk_QAudioFormat_spec,
        &Shiboken::callCppDestructor< ::QAudioFormat >,
        Sbk_QAudioFormat_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QAudioFormat_TypeF(); // references _Sbk_QAudioFormat_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QAudioFormat_SignatureStrings);
#else
    InitSignatureBytes(pyType, QAudioFormat_SignatureBytes, QAudioFormat_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QAudioFormat_PropertyStrings);
    SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAudioFormat_PythonToCpp_QAudioFormat_PTR,
        is_QAudioFormat_PythonToCpp_QAudioFormat_PTR_Convertible,
        QAudioFormat_PTR_CppToPython_QAudioFormat,
        QAudioFormat_COPY_CppToPython_QAudioFormat);

    Shiboken::Conversions::registerConverterName(converter, "QAudioFormat");
    Shiboken::Conversions::registerConverterName(converter, "QAudioFormat*");
    Shiboken::Conversions::registerConverterName(converter, "QAudioFormat&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QAudioFormat).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QAudioFormat_PythonToCpp_QAudioFormat_COPY,
        is_QAudioFormat_PythonToCpp_QAudioFormat_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QAudioFormat_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'SampleFormat'.
    const char *SampleFormat_Initializer[] = {
        "Unknown",
        "UInt8",
        "Int16",
        "Int32",
        "Float",
        "NSampleFormats",
        nullptr};
    // "uint8_t" used instead of "unsigned short"
    constexpr uint8_t SampleFormat_InitializerValues[] = {
        uint8_t(QAudioFormat::SampleFormat::Unknown),       //  0x00  0
        uint8_t(QAudioFormat::SampleFormat::UInt8),         //  0x01  1
        uint8_t(QAudioFormat::SampleFormat::Int16),         //  0x02  2
        uint8_t(QAudioFormat::SampleFormat::Int32),         //  0x03  3
        uint8_t(QAudioFormat::SampleFormat::Float),         //  0x04  4
        uint8_t(QAudioFormat::SampleFormat::NSampleFormats) //  0x05  5
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAudioFormat_TypeF(),
        "2:PySide6.QtMultimedia.QAudioFormat.SampleFormat",
        SampleFormat_Initializer, SampleFormat_InitializerValues);
    SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_SampleFormat_IDX].type = EType;
    // Register converter for enum 'QAudioFormat::SampleFormat'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAudioFormat_SampleFormat_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAudioFormat_SampleFormat,
            is_Enum_PythonToCpp_QAudioFormat_SampleFormat_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAudioFormat::SampleFormat");
        Shiboken::Conversions::registerConverterAlias(converter, "SampleFormat");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'SampleFormat' enum.

    // Initialization of enum 'AudioChannelPosition'.
    const char *AudioChannelPosition_Initializer[] = {
        "UnknownPosition",
        "FrontLeft",
        "FrontRight",
        "FrontCenter",
        "LFE",
        "BackLeft",
        "BackRight",
        "FrontLeftOfCenter",
        "FrontRightOfCenter",
        "BackCenter",
        "SideLeft",
        "SideRight",
        "TopCenter",
        "TopFrontLeft",
        "TopFrontCenter",
        "TopFrontRight",
        "TopBackLeft",
        "TopBackCenter",
        "TopBackRight",
        "LFE2",
        "TopSideLeft",
        "TopSideRight",
        "BottomFrontCenter",
        "BottomFrontLeft",
        "BottomFrontRight",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t AudioChannelPosition_InitializerValues[] = {
        uint8_t(QAudioFormat::AudioChannelPosition::UnknownPosition),    //  0x00  0
        uint8_t(QAudioFormat::AudioChannelPosition::FrontLeft),          //  0x01  1
        uint8_t(QAudioFormat::AudioChannelPosition::FrontRight),         //  0x02  2
        uint8_t(QAudioFormat::AudioChannelPosition::FrontCenter),        //  0x03  3
        uint8_t(QAudioFormat::AudioChannelPosition::LFE),                //  0x04  4
        uint8_t(QAudioFormat::AudioChannelPosition::BackLeft),           //  0x05  5
        uint8_t(QAudioFormat::AudioChannelPosition::BackRight),          //  0x06  6
        uint8_t(QAudioFormat::AudioChannelPosition::FrontLeftOfCenter),  //  0x07  7
        uint8_t(QAudioFormat::AudioChannelPosition::FrontRightOfCenter), //  0x08  8
        uint8_t(QAudioFormat::AudioChannelPosition::BackCenter),         //  0x09  9
        uint8_t(QAudioFormat::AudioChannelPosition::SideLeft),           //  0x0a  10
        uint8_t(QAudioFormat::AudioChannelPosition::SideRight),          //  0x0b  11
        uint8_t(QAudioFormat::AudioChannelPosition::TopCenter),          //  0x0c  12
        uint8_t(QAudioFormat::AudioChannelPosition::TopFrontLeft),       //  0x0d  13
        uint8_t(QAudioFormat::AudioChannelPosition::TopFrontCenter),     //  0x0e  14
        uint8_t(QAudioFormat::AudioChannelPosition::TopFrontRight),      //  0x0f  15
        uint8_t(QAudioFormat::AudioChannelPosition::TopBackLeft),        //  0x10  16
        uint8_t(QAudioFormat::AudioChannelPosition::TopBackCenter),      //  0x11  17
        uint8_t(QAudioFormat::AudioChannelPosition::TopBackRight),       //  0x12  18
        uint8_t(QAudioFormat::AudioChannelPosition::LFE2),               //  0x13  19
        uint8_t(QAudioFormat::AudioChannelPosition::TopSideLeft),        //  0x14  20
        uint8_t(QAudioFormat::AudioChannelPosition::TopSideRight),       //  0x15  21
        uint8_t(QAudioFormat::AudioChannelPosition::BottomFrontCenter),  //  0x16  22
        uint8_t(QAudioFormat::AudioChannelPosition::BottomFrontLeft),    //  0x17  23
        uint8_t(QAudioFormat::AudioChannelPosition::BottomFrontRight)    //  0x18  24
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAudioFormat_TypeF(),
        "2:PySide6.QtMultimedia.QAudioFormat.AudioChannelPosition",
        AudioChannelPosition_Initializer, AudioChannelPosition_InitializerValues);
    SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_AudioChannelPosition_IDX].type = EType;
    // Register converter for enum 'QAudioFormat::AudioChannelPosition'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAudioFormat_AudioChannelPosition_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAudioFormat_AudioChannelPosition,
            is_Enum_PythonToCpp_QAudioFormat_AudioChannelPosition_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAudioFormat::AudioChannelPosition");
        Shiboken::Conversions::registerConverterAlias(converter, "AudioChannelPosition");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'AudioChannelPosition' enum.

    // Initialization of enum 'ChannelConfig'.
    const char *ChannelConfig_Initializer[] = {
        "ChannelConfigUnknown",
        "ChannelConfigMono",
        "ChannelConfigStereo",
        "ChannelConfig2Dot1",
        "ChannelConfig3Dot0",
        "ChannelConfig3Dot1",
        "ChannelConfigSurround5Dot0",
        "ChannelConfigSurround5Dot1",
        "ChannelConfigSurround7Dot0",
        "ChannelConfigSurround7Dot1",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t ChannelConfig_InitializerValues[] = {
        uint16_t(QAudioFormat::ChannelConfig::ChannelConfigUnknown),       //  0x0000  0
        uint16_t(QAudioFormat::ChannelConfig::ChannelConfigMono),          //  0x0008  8
        uint16_t(QAudioFormat::ChannelConfig::ChannelConfigStereo),        //  0x0006  6
        uint16_t(QAudioFormat::ChannelConfig::ChannelConfig2Dot1),         //  0x0016  22
        uint16_t(QAudioFormat::ChannelConfig::ChannelConfig3Dot0),         //  0x000e  14
        uint16_t(QAudioFormat::ChannelConfig::ChannelConfig3Dot1),         //  0x001e  30
        uint16_t(QAudioFormat::ChannelConfig::ChannelConfigSurround5Dot0), //  0x006e  110
        uint16_t(QAudioFormat::ChannelConfig::ChannelConfigSurround5Dot1), //  0x007e  126
        uint16_t(QAudioFormat::ChannelConfig::ChannelConfigSurround7Dot0), //  0x0c6e  3182
        uint16_t(QAudioFormat::ChannelConfig::ChannelConfigSurround7Dot1)  //  0x0c7e  3198
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAudioFormat_TypeF(),
        "2:PySide6.QtMultimedia.QAudioFormat.ChannelConfig",
        ChannelConfig_Initializer, ChannelConfig_InitializerValues);
    SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_ChannelConfig_IDX].type = EType;
    // Register converter for enum 'QAudioFormat::ChannelConfig'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAudioFormat_ChannelConfig_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAudioFormat_ChannelConfig,
            is_Enum_PythonToCpp_QAudioFormat_ChannelConfig_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAudioFormat::ChannelConfig");
        Shiboken::Conversions::registerConverterAlias(converter, "ChannelConfig");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ChannelConfig' enum.

    qRegisterMetaType< ::QAudioFormat >("QAudioFormat");
    qRegisterMetaType< ::QAudioFormat::SampleFormat >("QAudioFormat::SampleFormat");
    qRegisterMetaType< ::QAudioFormat::AudioChannelPosition >("QAudioFormat::AudioChannelPosition");
    qRegisterMetaType< ::QAudioFormat::ChannelConfig >("QAudioFormat::ChannelConfig");

    return pyType;
}

PyTypeObject *init_QAudioFormatStaticFields(PyObject *module)
{
    auto *obType = PyObject_GetAttrString(module, "QAudioFormat");
    auto *type = reinterpret_cast<PyTypeObject *>(obType);
    Shiboken::AutoDecRef dict(PepType_GetDict(type));
    PyDict_SetItemString(dict, "NChannelPositions",
                         Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &QAudioFormat::NChannelPositions));
    return type;
}
