// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtmultimedia_python.h"

// main header
#include "qcameradevice_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtMultimedia/qcameradevice.h>
#include <QtMultimedia/qtvideo.h>
#include <qbytearray.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qsize.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QCameraDevice_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QCameraDevice >()))
        return -1;

    ::QCameraDevice *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QCameraDevice", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QCameraDevice::QCameraDevice()
    // 1: QCameraDevice::QCameraDevice(QCameraDevice)
    if (numArgs == 0) {
        overloadId = 0; // QCameraDevice()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QCameraDevice(QCameraDevice)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QCameraDevice()
        {

            // QCameraDevice()
            cptr = new ::QCameraDevice();
            break;
        }
        case 1: // QCameraDevice(const QCameraDevice &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QCameraDevice cppArg0_local;
            ::QCameraDevice *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QCameraDevice(QCameraDevice)
                cptr = new ::QCameraDevice(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QCameraDevice >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QCameraDeviceFunc_correctionAngle(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCameraDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // correctionAngle()const
        QtVideo::Rotation cppResult = const_cast<const ::QCameraDevice *>(cppSelf)->correctionAngle();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QtVideo_Rotation_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraDeviceFunc_description(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCameraDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // description()const
        QString cppResult = const_cast<const ::QCameraDevice *>(cppSelf)->description();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraDeviceFunc_id(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCameraDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // id()const
        QByteArray cppResult = const_cast<const ::QCameraDevice *>(cppSelf)->id();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraDeviceFunc_isDefault(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCameraDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isDefault()const
        bool cppResult = const_cast<const ::QCameraDevice *>(cppSelf)->isDefault();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraDeviceFunc_isNull(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCameraDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isNull()const
        bool cppResult = const_cast<const ::QCameraDevice *>(cppSelf)->isNull();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraDeviceFunc_photoResolutions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCameraDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // photoResolutions()const
        QList<QSize> cppResult = const_cast<const ::QCameraDevice *>(cppSelf)->photoResolutions();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtMultimediaTypeConverters[SBK_QtMultimedia_QList_QSize_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraDeviceFunc_position(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCameraDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // position()const
        QCameraDevice::Position cppResult = const_cast<const ::QCameraDevice *>(cppSelf)->position();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_Position_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraDeviceFunc_videoFormats(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCameraDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // videoFormats()const
        QList<QCameraFormat> cppResult = const_cast<const ::QCameraDevice *>(cppSelf)->videoFormats();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtMultimediaTypeConverters[SBK_QtMultimedia_QList_QCameraFormat_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraDevice__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QCameraDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QCameraDevice_PropertyStrings[] = {
    "correctionAngle:",
    "description:",
    "id:",
    "isDefault:",
    "position:",
    "videoFormats:",
    nullptr // Sentinel
};

static const char *Sbk_QCameraDevice_EnumFlagInfo[] = {
    "Position:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QCameraDevice_methods[] = {
    {"correctionAngle", reinterpret_cast<PyCFunction>(Sbk_QCameraDeviceFunc_correctionAngle), METH_NOARGS, nullptr},
    {"description", reinterpret_cast<PyCFunction>(Sbk_QCameraDeviceFunc_description), METH_NOARGS, nullptr},
    {"id", reinterpret_cast<PyCFunction>(Sbk_QCameraDeviceFunc_id), METH_NOARGS, nullptr},
    {"isDefault", reinterpret_cast<PyCFunction>(Sbk_QCameraDeviceFunc_isDefault), METH_NOARGS, nullptr},
    {"isNull", reinterpret_cast<PyCFunction>(Sbk_QCameraDeviceFunc_isNull), METH_NOARGS, nullptr},
    {"photoResolutions", reinterpret_cast<PyCFunction>(Sbk_QCameraDeviceFunc_photoResolutions), METH_NOARGS, nullptr},
    {"position", reinterpret_cast<PyCFunction>(Sbk_QCameraDeviceFunc_position), METH_NOARGS, nullptr},
    {"videoFormats", reinterpret_cast<PyCFunction>(Sbk_QCameraDeviceFunc_videoFormats), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QCameraDevice__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QCameraDevice___nb_bool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QCameraDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return !cppSelf->isNull() ? 1 : 0;
}

// Rich comparison
static PyObject * Sbk_QCameraDevice_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QCameraDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_IDX]), (pyArg)))) {
                // operator!=(const QCameraDevice &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QCameraDevice cppArg0_local;
                ::QCameraDevice *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_IDX]), (pyArg)))) {
                // operator==(const QCameraDevice &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QCameraDevice cppArg0_local;
                ::QCameraDevice *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QCameraDevice_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QCameraDevice_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QCameraDevice__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCameraDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QCameraDevice_Type = nullptr;
static PyTypeObject *Sbk_QCameraDevice_TypeF(void)
{
    return _Sbk_QCameraDevice_Type;
}

static PyType_Slot Sbk_QCameraDevice_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QCameraDevice__repr__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QCameraDevice_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QCameraDevice_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QCameraDevice_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QCameraDevice_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QCameraDevice_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_bool,        reinterpret_cast<void *>(Sbk_QCameraDevice___nb_bool)},
    {0, nullptr}
};
static PyType_Spec Sbk_QCameraDevice_spec = {
    "2:PySide6.QtMultimedia.QCameraDevice",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QCameraDevice_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QCameraDevice_Position(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QCameraDevice::Position>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QCameraDevice::Position *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QCameraDevice_Position_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_Position_IDX])))
        return Enum_PythonToCpp_QCameraDevice_Position;
    return {};
}

static PyObject *QCameraDevice_Position_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QCameraDevice::Position>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QCameraDevice::Position *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_Position_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QCameraDevice_PythonToCpp_QCameraDevice_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QCameraDevice_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QCameraDevice_PythonToCpp_QCameraDevice_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QCameraDevice_TypeF()))
        return QCameraDevice_PythonToCpp_QCameraDevice_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QCameraDevice_PTR_CppToPython_QCameraDevice(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QCameraDevice_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QCameraDevice_COPY_CppToPython_QCameraDevice(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QCameraDevice *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QCameraDevice_TypeF(), new ::QCameraDevice(*source), true, true);
}

// Python to C++ copy conversion.
static void QCameraDevice_PythonToCpp_QCameraDevice_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QCameraDevice *>(cppOut) = *reinterpret_cast< ::QCameraDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QCameraDevice_PythonToCpp_QCameraDevice_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QCameraDevice_TypeF()))
        return QCameraDevice_PythonToCpp_QCameraDevice_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QCameraDevice_SignatureStrings[] = {
    "1:PySide6.QtMultimedia.QCameraDevice(self,*:KeywordOnly=None,id:QByteArray=None,description:QString=None,isDefault:bool=None,position:QCameraDevice.Position=None,videoFormats:QList[PySide6.QtMultimedia.QCameraFormat]=None,correctionAngle:QtVideo.Rotation=None)",
    "0:PySide6.QtMultimedia.QCameraDevice(self,other:PySide6.QtMultimedia.QCameraDevice,*:KeywordOnly=None,id:QByteArray=None,description:QString=None,isDefault:bool=None,position:QCameraDevice.Position=None,videoFormats:QList[PySide6.QtMultimedia.QCameraFormat]=None,correctionAngle:QtVideo.Rotation=None)",
    "PySide6.QtMultimedia.QCameraDevice.correctionAngle(self)->PySide6.QtMultimedia.QtVideo.Rotation",
    "PySide6.QtMultimedia.QCameraDevice.description(self)->QString",
    "PySide6.QtMultimedia.QCameraDevice.id(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtMultimedia.QCameraDevice.isDefault(self)->bool",
    "PySide6.QtMultimedia.QCameraDevice.isNull(self)->bool",
    "PySide6.QtMultimedia.QCameraDevice.photoResolutions(self)->QList[PySide6.QtCore.QSize]",
    "PySide6.QtMultimedia.QCameraDevice.position(self)->PySide6.QtMultimedia.QCameraDevice.Position",
    "PySide6.QtMultimedia.QCameraDevice.videoFormats(self)->QList[PySide6.QtMultimedia.QCameraFormat]",
    "PySide6.QtMultimedia.QCameraDevice.__copy__(self)->typing.Self",
    "PySide6.QtMultimedia.QCameraDevice.__ne__(self,other:PySide6.QtMultimedia.QCameraDevice)->bool",
    "PySide6.QtMultimedia.QCameraDevice.__eq__(self,other:PySide6.QtMultimedia.QCameraDevice)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QCameraDevice_SignatureByteSize = 317;
static constexpr uint8_t QCameraDevice_SignatureBytes[317] = {
    0x78, 0xda, 0xdd, 0x93, 0x3d, 0x4f, 0xc3, 0x30, 0x10, 0x86, 0x77, 0x7e, 0x09, 0x45, 0xc5, 0x82,
    0x85, 0xc1, 0x12, 0x48, 0xa5, 0x15, 0x0b, 0x50, 0x9a, 0x46, 0x62, 0x41, 0x95, 0x65, 0xe2, 0x6b,
    0x6b, 0xc9, 0xf1, 0x05, 0xdb, 0x29, 0x32, 0xbf, 0x9e, 0x84, 0x38, 0x25, 0x0a, 0x6d, 0x71, 0x19,
    0x19, 0x7d, 0xba, 0xf7, 0xb9, 0x8f, 0xf7, 0x7c, 0x49, 0x67, 0x3e, 0x95, 0x02, 0xae, 0x48, 0xe2,
    0x1e, 0x4b, 0xe5, 0x64, 0x0e, 0x42, 0x72, 0x92, 0x8c, 0x79, 0x0e, 0x86, 0x4f, 0x60, 0x23, 0x33,
    0x38, 0xb5, 0xa0, 0x96, 0xc3, 0x33, 0x7a, 0x0f, 0xfe, 0x1d, 0x8d, 0x78, 0xd2, 0xca, 0x5f, 0x4f,
    0x51, 0xc3, 0x50, 0x0a, 0x9a, 0xdc, 0x7a, 0x07, 0x23, 0x63, 0x78, 0x08, 0x09, 0xb0, 0x99, 0x91,
    0x85, 0x93, 0xa8, 0x69, 0x92, 0x3a, 0x23, 0xf5, 0x2a, 0xe4, 0xda, 0x09, 0x2c, 0x79, 0x55, 0x81,
    0xbe, 0x22, 0xaa, 0x26, 0x56, 0xa0, 0x95, 0x4d, 0x66, 0xb7, 0x1c, 0x99, 0x85, 0x70, 0x93, 0xb4,
    0xa9, 0xba, 0xc3, 0x3b, 0x34, 0x39, 0x77, 0x96, 0x26, 0x0f, 0xd2, 0xba, 0x97, 0x43, 0x2d, 0x37,
    0x99, 0x8b, 0x46, 0x9b, 0xa1, 0x31, 0x90, 0xd5, 0xac, 0x91, 0x5e, 0x29, 0xa0, 0x89, 0x7b, 0xae,
    0x69, 0x64, 0x8e, 0x8e, 0x6f, 0x2b, 0x0c, 0x4e, 0x2e, 0xa2, 0x97, 0x80, 0x6e, 0x0d, 0x26, 0x22,
    0xfb, 0x3f, 0x6f, 0xeb, 0xf7, 0xe9, 0x49, 0x8f, 0xf4, 0xb5, 0xbb, 0xc1, 0xf9, 0xcd, 0x6e, 0x65,
    0xaf, 0x4a, 0x0c, 0xbf, 0xb3, 0xb7, 0x96, 0x1d, 0xd6, 0x17, 0xa3, 0x96, 0xe2, 0x67, 0x43, 0x63,
    0x34, 0x40, 0xbe, 0xed, 0x89, 0xc2, 0xb4, 0x1e, 0xb5, 0xb4, 0xda, 0xaa, 0x38, 0xe1, 0xb4, 0x54,
    0xea, 0x58, 0x55, 0xb1, 0x46, 0x87, 0x73, 0xb0, 0xa8, 0xca, 0x7a, 0x6e, 0xbb, 0x1d, 0xbc, 0x67,
    0x72, 0x33, 0x49, 0x2a, 0x3f, 0x60, 0x11, 0x85, 0x0d, 0xe7, 0x73, 0xd8, 0xa3, 0x9d, 0x17, 0x17,
    0x83, 0xef, 0xde, 0xe3, 0xbe, 0x8e, 0xf7, 0x9e, 0x65, 0x4c, 0x01, 0xc6, 0x32, 0x2c, 0x3c, 0x63,
    0x2d, 0xdc, 0xf9, 0xa2, 0x3a, 0x03, 0x92, 0x56, 0xaf, 0x38, 0xb9, 0x86, 0x20, 0x8e, 0xfe, 0xdc,
    0x47, 0x98, 0xc6, 0x18, 0xbc, 0xfd, 0x15, 0xff, 0x09, 0x3a, 0xed, 0x0d, 0xc0
};
#endif

PyTypeObject *init_QCameraDevice(PyObject *module)
{
    if (SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_IDX].type != nullptr)
        return SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_IDX].type;

    Shiboken::AutoDecRef Sbk_QCameraDevice_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QCameraDevice_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QCameraDevice",
        "QCameraDevice",
        &Sbk_QCameraDevice_spec,
        &Shiboken::callCppDestructor< ::QCameraDevice >,
        Sbk_QCameraDevice_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QCameraDevice_TypeF(); // references _Sbk_QCameraDevice_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QCameraDevice_SignatureStrings);
#else
    InitSignatureBytes(pyType, QCameraDevice_SignatureBytes, QCameraDevice_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QCameraDevice_PropertyStrings);
    SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QCameraDevice_PythonToCpp_QCameraDevice_PTR,
        is_QCameraDevice_PythonToCpp_QCameraDevice_PTR_Convertible,
        QCameraDevice_PTR_CppToPython_QCameraDevice,
        QCameraDevice_COPY_CppToPython_QCameraDevice);

    Shiboken::Conversions::registerConverterName(converter, "QCameraDevice");
    Shiboken::Conversions::registerConverterName(converter, "QCameraDevice*");
    Shiboken::Conversions::registerConverterName(converter, "QCameraDevice&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QCameraDevice).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QCameraDevice_PythonToCpp_QCameraDevice_COPY,
        is_QCameraDevice_PythonToCpp_QCameraDevice_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QCameraDevice_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Position'.
    const char *Position_Initializer[] = {
        "UnspecifiedPosition",
        "BackFace",
        "FrontFace",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Position_InitializerValues[] = {
        uint8_t(QCameraDevice::Position::UnspecifiedPosition), //  0x00  0
        uint8_t(QCameraDevice::Position::BackFace),            //  0x01  1
        uint8_t(QCameraDevice::Position::FrontFace)            //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QCameraDevice_TypeF(),
        "2:PySide6.QtMultimedia.QCameraDevice.Position",
        Position_Initializer, Position_InitializerValues);
    SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_Position_IDX].type = EType;
    // Register converter for enum 'QCameraDevice::Position'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QCameraDevice_Position_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QCameraDevice_Position,
            is_Enum_PythonToCpp_QCameraDevice_Position_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QCameraDevice::Position");
        Shiboken::Conversions::registerConverterAlias(converter, "Position");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Position' enum.

    qRegisterMetaType< ::QCameraDevice >("QCameraDevice");
    qRegisterMetaType< ::QCameraDevice::Position >("QCameraDevice::Position");

    return pyType;
}
