// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtmultimedia_python.h"

// main header
#include "qcameraformat_wrapper.h"

// Argument includes
#include <QtMultimedia/qcameradevice.h>
#include <QtMultimedia/qvideoframeformat.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qsize.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QCameraFormat_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QCameraFormat >()))
        return -1;

    ::QCameraFormat *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QCameraFormat", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QCameraFormat::QCameraFormat()
    // 1: QCameraFormat::QCameraFormat(QCameraFormat)
    if (numArgs == 0) {
        overloadId = 0; // QCameraFormat()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraFormat_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QCameraFormat(QCameraFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraFormat_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraFormat_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QCameraFormat()
        {

            // QCameraFormat()
            cptr = new ::QCameraFormat();
            break;
        }
        case 1: // QCameraFormat(const QCameraFormat &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QCameraFormat cppArg0_local;
            ::QCameraFormat *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QCameraFormat(QCameraFormat)
                cptr = new ::QCameraFormat(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QCameraFormat >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraFormat_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QCameraFormatFunc_isNull(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCameraFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isNull()const
        bool cppResult = const_cast<const ::QCameraFormat *>(cppSelf)->isNull();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraFormatFunc_maxFrameRate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCameraFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maxFrameRate()const
        float cppResult = const_cast<const ::QCameraFormat *>(cppSelf)->maxFrameRate();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraFormatFunc_minFrameRate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCameraFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // minFrameRate()const
        float cppResult = const_cast<const ::QCameraFormat *>(cppSelf)->minFrameRate();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraFormatFunc_pixelFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCameraFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pixelFormat()const
        QVideoFrameFormat::PixelFormat cppResult = const_cast<const ::QCameraFormat *>(cppSelf)->pixelFormat();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrameFormat_PixelFormat_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraFormatFunc_resolution(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCameraFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // resolution()const
        QSize cppResult = const_cast<const ::QCameraFormat *>(cppSelf)->resolution();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraFormat__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QCameraFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraFormat_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QCameraFormat_PropertyStrings[] = {
    "maxFrameRate:",
    "minFrameRate:",
    "pixelFormat:",
    "resolution:",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QCameraFormat_methods[] = {
    {"isNull", reinterpret_cast<PyCFunction>(Sbk_QCameraFormatFunc_isNull), METH_NOARGS, nullptr},
    {"maxFrameRate", reinterpret_cast<PyCFunction>(Sbk_QCameraFormatFunc_maxFrameRate), METH_NOARGS, nullptr},
    {"minFrameRate", reinterpret_cast<PyCFunction>(Sbk_QCameraFormatFunc_minFrameRate), METH_NOARGS, nullptr},
    {"pixelFormat", reinterpret_cast<PyCFunction>(Sbk_QCameraFormatFunc_pixelFormat), METH_NOARGS, nullptr},
    {"resolution", reinterpret_cast<PyCFunction>(Sbk_QCameraFormatFunc_resolution), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QCameraFormat__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QCameraFormat___nb_bool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QCameraFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return !cppSelf->isNull() ? 1 : 0;
}

// Rich comparison
static PyObject * Sbk_QCameraFormat_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QCameraFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraFormat_IDX]), (pyArg)))) {
                // operator!=(const QCameraFormat &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QCameraFormat cppArg0_local;
                ::QCameraFormat *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraFormat_IDX]), (pyArg)))) {
                // operator==(const QCameraFormat &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QCameraFormat cppArg0_local;
                ::QCameraFormat *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QCameraFormat_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QCameraFormat_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QCameraFormat_Type = nullptr;
static PyTypeObject *Sbk_QCameraFormat_TypeF(void)
{
    return _Sbk_QCameraFormat_Type;
}

static PyType_Slot Sbk_QCameraFormat_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QCameraFormat_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QCameraFormat_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QCameraFormat_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QCameraFormat_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QCameraFormat_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_bool,        reinterpret_cast<void *>(Sbk_QCameraFormat___nb_bool)},
    {0, nullptr}
};
static PyType_Spec Sbk_QCameraFormat_spec = {
    "2:PySide6.QtMultimedia.QCameraFormat",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QCameraFormat_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QCameraFormat_PythonToCpp_QCameraFormat_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QCameraFormat_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QCameraFormat_PythonToCpp_QCameraFormat_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QCameraFormat_TypeF()))
        return QCameraFormat_PythonToCpp_QCameraFormat_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QCameraFormat_PTR_CppToPython_QCameraFormat(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QCameraFormat_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QCameraFormat_COPY_CppToPython_QCameraFormat(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QCameraFormat *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QCameraFormat_TypeF(), new ::QCameraFormat(*source), true, true);
}

// Python to C++ copy conversion.
static void QCameraFormat_PythonToCpp_QCameraFormat_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QCameraFormat *>(cppOut) = *reinterpret_cast< ::QCameraFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraFormat_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QCameraFormat_PythonToCpp_QCameraFormat_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QCameraFormat_TypeF()))
        return QCameraFormat_PythonToCpp_QCameraFormat_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QCameraFormat_SignatureStrings[] = {
    "1:PySide6.QtMultimedia.QCameraFormat(self,*:KeywordOnly=None,resolution:QSize=None,pixelFormat:QVideoFrameFormat.PixelFormat=None,minFrameRate:float=None,maxFrameRate:float=None)",
    "0:PySide6.QtMultimedia.QCameraFormat(self,other:PySide6.QtMultimedia.QCameraFormat,*:KeywordOnly=None,resolution:QSize=None,pixelFormat:QVideoFrameFormat.PixelFormat=None,minFrameRate:float=None,maxFrameRate:float=None)",
    "PySide6.QtMultimedia.QCameraFormat.isNull(self)->bool",
    "PySide6.QtMultimedia.QCameraFormat.maxFrameRate(self)->float",
    "PySide6.QtMultimedia.QCameraFormat.minFrameRate(self)->float",
    "PySide6.QtMultimedia.QCameraFormat.pixelFormat(self)->PySide6.QtMultimedia.QVideoFrameFormat.PixelFormat",
    "PySide6.QtMultimedia.QCameraFormat.resolution(self)->PySide6.QtCore.QSize",
    "PySide6.QtMultimedia.QCameraFormat.__copy__(self)->typing.Self",
    "PySide6.QtMultimedia.QCameraFormat.__ne__(self,other:PySide6.QtMultimedia.QCameraFormat)->bool",
    "PySide6.QtMultimedia.QCameraFormat.__eq__(self,other:PySide6.QtMultimedia.QCameraFormat)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QCameraFormat_SignatureByteSize = 236;
static constexpr uint8_t QCameraFormat_SignatureBytes[236] = {
    0x78, 0xda, 0xcd, 0x92, 0x3d, 0x6f, 0xc2, 0x30, 0x10, 0x86, 0x77, 0x7e, 0x09, 0xa9, 0xa8, 0xd5,
    0x2e, 0x1d, 0x2c, 0xb5, 0x0b, 0x12, 0x0b, 0x6a, 0x9a, 0x10, 0xa9, 0xab, 0xe5, 0x36, 0x17, 0x38,
    0xe9, 0xe2, 0x4b, 0x1d, 0x47, 0xc5, 0xfc, 0x7a, 0xa2, 0x84, 0x40, 0xa4, 0xa2, 0x62, 0x98, 0x18,
    0xfd, 0xde, 0x3d, 0xef, 0x7d, 0xf9, 0x59, 0x26, 0x3e, 0xc3, 0x1c, 0x5e, 0x44, 0xea, 0xde, 0x1b,
    0x72, 0x58, 0x42, 0x8e, 0x5a, 0xa4, 0x73, 0x5d, 0x82, 0xd5, 0x0b, 0xb6, 0xa5, 0x76, 0xd3, 0x1a,
    0xa8, 0x98, 0x3d, 0xc8, 0x25, 0xf8, 0x5f, 0xb6, 0xf9, 0x87, 0x21, 0xff, 0x1a, 0xb3, 0x81, 0x99,
    0x85, 0x9a, 0xa9, 0x71, 0xc8, 0x46, 0xa6, 0x19, 0xee, 0xa0, 0x57, 0x2b, 0xdc, 0x02, 0xf5, 0xa4,
    0x4c, 0x3f, 0x5b, 0x6f, 0x5e, 0xd8, 0xd6, 0xad, 0x57, 0x44, 0x72, 0x8a, 0xf6, 0xe9, 0x25, 0x9a,
    0x2e, 0xbe, 0xd2, 0x0e, 0x64, 0x41, 0x7c, 0xd4, 0xf5, 0xf6, 0x9c, 0x1e, 0x4d, 0x9e, 0x82, 0x5b,
    0x66, 0xb7, 0x01, 0x1b, 0x90, 0x7d, 0x3f, 0xb3, 0x5d, 0xee, 0x55, 0x60, 0x1d, 0x37, 0x44, 0xdd,
    0x80, 0xd1, 0xe3, 0xdb, 0x17, 0x33, 0x85, 0x50, 0xe3, 0x8a, 0x03, 0xdb, 0x15, 0x0e, 0x82, 0x47,
    0x63, 0x5c, 0x0d, 0x8f, 0x56, 0x36, 0xb0, 0xe7, 0xa9, 0xff, 0xd6, 0x19, 0x52, 0xe8, 0x74, 0xb1,
    0xbf, 0x75, 0xe6, 0x6c, 0x41, 0x74, 0x77, 0x0c, 0x71, 0x52, 0xea, 0x9b, 0x2b, 0xaf, 0xd4, 0xe0,
    0xe3, 0x7c, 0x85, 0x66, 0x2d, 0xb2, 0xf6, 0x15, 0x86, 0x1b, 0x38, 0xc0, 0xc1, 0x5f, 0xf0, 0x8a,
    0x53, 0x2a, 0x05, 0x3f, 0xb7, 0xda, 0xef, 0x01, 0xfe, 0x18, 0x71, 0x5e
};
#endif

PyTypeObject *init_QCameraFormat(PyObject *module)
{
    if (SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraFormat_IDX].type != nullptr)
        return SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraFormat_IDX].type;

    Shiboken::AutoDecRef Sbk_QCameraFormat_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QCameraFormat_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QCameraFormat",
        "QCameraFormat",
        &Sbk_QCameraFormat_spec,
        &Shiboken::callCppDestructor< ::QCameraFormat >,
        Sbk_QCameraFormat_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QCameraFormat_TypeF(); // references _Sbk_QCameraFormat_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QCameraFormat_SignatureStrings);
#else
    InitSignatureBytes(pyType, QCameraFormat_SignatureBytes, QCameraFormat_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QCameraFormat_PropertyStrings);
    SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraFormat_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QCameraFormat_PythonToCpp_QCameraFormat_PTR,
        is_QCameraFormat_PythonToCpp_QCameraFormat_PTR_Convertible,
        QCameraFormat_PTR_CppToPython_QCameraFormat,
        QCameraFormat_COPY_CppToPython_QCameraFormat);

    Shiboken::Conversions::registerConverterName(converter, "QCameraFormat");
    Shiboken::Conversions::registerConverterName(converter, "QCameraFormat*");
    Shiboken::Conversions::registerConverterName(converter, "QCameraFormat&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QCameraFormat).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QCameraFormat_PythonToCpp_QCameraFormat_COPY,
        is_QCameraFormat_PythonToCpp_QCameraFormat_COPY_Convertible);

    qRegisterMetaType< ::QCameraFormat >("QCameraFormat");

    return pyType;
}
