// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtmultimedia_python.h"

// main header
#include "qimagecapture_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QtGui/qimage.h>
#include <QtMultimedia/qimagecapture.h>
#include <QtMultimedia/qmediacapturesession.h>
#include <QtMultimedia/qmediametadata.h>
#include <QtMultimedia/qvideoframe.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qsize.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QImageCaptureWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QImageCaptureWrapper::QImageCaptureWrapper(::QObject * parent) : QImageCapture(parent)
{
}

void QImageCaptureWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QImageCapture", funcName);
        return;
    }
}

void QImageCaptureWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QImageCapture", funcName);
        return;
    }
}

void QImageCaptureWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QImageCapture", funcName);
        return;
    }
}

void QImageCaptureWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QImageCapture", funcName);
        return;
    }
}

bool QImageCaptureWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QImageCapture", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QImageCapture", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QImageCaptureWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QImageCapture", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QImageCapture", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QImageCaptureWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QImageCapture", funcName);
        return;
    }
}

const QMetaObject *QImageCaptureWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QImageCapture::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QImageCaptureWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QImageCapture::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QImageCaptureWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QImageCaptureWrapper *>(this));
    return QImageCapture::qt_metacast(_clname);
}

QImageCaptureWrapper::~QImageCaptureWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QImageCapture_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QImageCapture >()))
        return -1;

    QImageCaptureWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QImageCapture", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QImageCapture::QImageCapture(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QImageCapture(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QImageCapture(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                // fall through to handle extra keyword signals and properties
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QImageCapture(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QImageCaptureWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QImageCaptureWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QImageCapture >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QImageCaptureFunc_addMetaData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageCapture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QImageCapture::addMetaData(QMediaMetaData)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaMetaData_IDX]), (pyArg)))) {
        overloadId = 0; // addMetaData(QMediaMetaData)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addMetaData", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMediaMetaData cppArg0_local;
        ::QMediaMetaData *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // addMetaData(QMediaMetaData)
            cppSelf->addMetaData(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QImageCaptureFunc_capture(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageCapture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // capture()
        int cppResult = cppSelf->capture();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageCaptureFunc_captureSession(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageCapture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // captureSession()const
        QMediaCaptureSession * cppResult = const_cast<const ::QImageCapture *>(cppSelf)->captureSession();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaCaptureSession_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageCaptureFunc_captureToFile(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageCapture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "captureToFile", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_IDX]);

    if (PyArg_ParseTuple(args, "|O:captureToFile", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QImageCapture::captureToFile(const QString&=)->int
    if (numArgs == 0) {
        overloadId = 0; // captureToFile(QString)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 0; // captureToFile(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "captureToFile", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_location = Shiboken::String::createStaticString("location");
            if (PyDict_Contains(kwds, key_location) != 0) {
                value = PyDict_GetItem(kwds, key_location);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_location);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "captureToFile", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "captureToFile", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_location);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "captureToFile", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_IDX]);
            }
        }
        ::QString cppArg0 = QString();
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // captureToFile(QString)
            int cppResult = cppSelf->captureToFile(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageCaptureFunc_error(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageCapture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // error()const
        QImageCapture::Error cppResult = const_cast<const ::QImageCapture *>(cppSelf)->error();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_Error_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageCaptureFunc_errorString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageCapture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // errorString()const
        QString cppResult = const_cast<const ::QImageCapture *>(cppSelf)->errorString();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageCaptureFunc_fileFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageCapture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // fileFormat()const
        QImageCapture::FileFormat cppResult = const_cast<const ::QImageCapture *>(cppSelf)->fileFormat();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_FileFormat_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageCaptureFunc_fileFormatDescription(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QImageCapture::fileFormatDescription(QImageCapture::FileFormat)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_FileFormat_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // fileFormatDescription(QImageCapture::FileFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fileFormatDescription", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_IDX]);

    // Call function/method
    {
        ::QImageCapture::FileFormat cppArg0{QImageCapture::UnspecifiedFormat};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fileFormatDescription(QImageCapture::FileFormat)
            QString cppResult = ::QImageCapture::fileFormatDescription(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageCaptureFunc_fileFormatName(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QImageCapture::fileFormatName(QImageCapture::FileFormat)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_FileFormat_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // fileFormatName(QImageCapture::FileFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fileFormatName", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_IDX]);

    // Call function/method
    {
        ::QImageCapture::FileFormat cppArg0{QImageCapture::UnspecifiedFormat};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fileFormatName(QImageCapture::FileFormat)
            QString cppResult = ::QImageCapture::fileFormatName(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageCaptureFunc_isAvailable(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageCapture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isAvailable()const
        bool cppResult = const_cast<const ::QImageCapture *>(cppSelf)->isAvailable();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageCaptureFunc_isReadyForCapture(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageCapture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isReadyForCapture()const
        bool cppResult = const_cast<const ::QImageCapture *>(cppSelf)->isReadyForCapture();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageCaptureFunc_metaData(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageCapture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // metaData()const
        QMediaMetaData cppResult = const_cast<const ::QImageCapture *>(cppSelf)->metaData();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaMetaData_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageCaptureFunc_quality(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageCapture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // quality()const
        QImageCapture::Quality cppResult = const_cast<const ::QImageCapture *>(cppSelf)->quality();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_Quality_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageCaptureFunc_resolution(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageCapture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // resolution()const
        QSize cppResult = const_cast<const ::QImageCapture *>(cppSelf)->resolution();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageCaptureFunc_setFileFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageCapture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QImageCapture::setFileFormat(QImageCapture::FileFormat)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_FileFormat_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setFileFormat(QImageCapture::FileFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFileFormat", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_IDX]);

    // Call function/method
    {
        ::QImageCapture::FileFormat cppArg0{QImageCapture::UnspecifiedFormat};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFileFormat(QImageCapture::FileFormat)
            cppSelf->setFileFormat(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QImageCaptureFunc_setMetaData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageCapture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QImageCapture::setMetaData(QMediaMetaData)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaMetaData_IDX]), (pyArg)))) {
        overloadId = 0; // setMetaData(QMediaMetaData)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMetaData", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMediaMetaData cppArg0_local;
        ::QMediaMetaData *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setMetaData(QMediaMetaData)
            cppSelf->setMetaData(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QImageCaptureFunc_setQuality(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageCapture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QImageCapture::setQuality(QImageCapture::Quality)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_Quality_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setQuality(QImageCapture::Quality)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setQuality", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_IDX]);

    // Call function/method
    {
        ::QImageCapture::Quality cppArg0{QImageCapture::VeryLowQuality};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setQuality(QImageCapture::Quality)
            cppSelf->setQuality(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QImageCaptureFunc_setResolution(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageCapture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setResolution", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QImageCapture::setResolution(QSize)
    // 1: QImageCapture::setResolution(int,int)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 1; // setResolution(int,int)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArgs[0])))) {
        overloadId = 0; // setResolution(QSize)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setResolution", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setResolution(const QSize &arg__1)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QSize cppArg0_local;
            ::QSize *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setResolution(QSize)
                cppSelf->setResolution(*cppArg0);
            }
            break;
        }
        case 1: // setResolution(int width, int height)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setResolution(int,int)
                cppSelf->setResolution(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QImageCaptureFunc_supportedFormats(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // supportedFormats()
        QList<QImageCapture::FileFormat> cppResult = ::QImageCapture::supportedFormats();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtMultimediaTypeConverters[SBK_QtMultimedia_QList_QImageCapture_FileFormat_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QImageCapture_PropertyStrings[] = {
    "error:",
    "errorString:",
    "fileFormat:",
    "metaData::",
    "quality:",
    "readyForCapture:isReadyForCapture",
    nullptr // Sentinel
};

static const char *Sbk_QImageCapture_EnumFlagInfo[] = {
    "Error:Enum",
    "FileFormat:Enum",
    "Quality:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QImageCapture_methods[] = {
    {"addMetaData", reinterpret_cast<PyCFunction>(Sbk_QImageCaptureFunc_addMetaData), METH_O, nullptr},
    {"capture", reinterpret_cast<PyCFunction>(Sbk_QImageCaptureFunc_capture), METH_NOARGS, nullptr},
    {"captureSession", reinterpret_cast<PyCFunction>(Sbk_QImageCaptureFunc_captureSession), METH_NOARGS, nullptr},
    {"captureToFile", reinterpret_cast<PyCFunction>(Sbk_QImageCaptureFunc_captureToFile), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"error", reinterpret_cast<PyCFunction>(Sbk_QImageCaptureFunc_error), METH_NOARGS, nullptr},
    {"errorString", reinterpret_cast<PyCFunction>(Sbk_QImageCaptureFunc_errorString), METH_NOARGS, nullptr},
    {"fileFormat", reinterpret_cast<PyCFunction>(Sbk_QImageCaptureFunc_fileFormat), METH_NOARGS, nullptr},
    {"fileFormatDescription", reinterpret_cast<PyCFunction>(Sbk_QImageCaptureFunc_fileFormatDescription), METH_O|METH_STATIC, nullptr},
    {"fileFormatName", reinterpret_cast<PyCFunction>(Sbk_QImageCaptureFunc_fileFormatName), METH_O|METH_STATIC, nullptr},
    {"isAvailable", reinterpret_cast<PyCFunction>(Sbk_QImageCaptureFunc_isAvailable), METH_NOARGS, nullptr},
    {"isReadyForCapture", reinterpret_cast<PyCFunction>(Sbk_QImageCaptureFunc_isReadyForCapture), METH_NOARGS, nullptr},
    {"metaData", reinterpret_cast<PyCFunction>(Sbk_QImageCaptureFunc_metaData), METH_NOARGS, nullptr},
    {"quality", reinterpret_cast<PyCFunction>(Sbk_QImageCaptureFunc_quality), METH_NOARGS, nullptr},
    {"resolution", reinterpret_cast<PyCFunction>(Sbk_QImageCaptureFunc_resolution), METH_NOARGS, nullptr},
    {"setFileFormat", reinterpret_cast<PyCFunction>(Sbk_QImageCaptureFunc_setFileFormat), METH_O, nullptr},
    {"setMetaData", reinterpret_cast<PyCFunction>(Sbk_QImageCaptureFunc_setMetaData), METH_O, nullptr},
    {"setQuality", reinterpret_cast<PyCFunction>(Sbk_QImageCaptureFunc_setQuality), METH_O, nullptr},
    {"setResolution", reinterpret_cast<PyCFunction>(Sbk_QImageCaptureFunc_setResolution), METH_VARARGS, nullptr},
    {"supportedFormats", reinterpret_cast<PyCFunction>(Sbk_QImageCaptureFunc_supportedFormats), METH_NOARGS|METH_STATIC, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QImageCapture_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QImageCapture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QImageCaptureWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QImageCapture_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QImageCapture_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QImageCapture_Type = nullptr;
static PyTypeObject *Sbk_QImageCapture_TypeF(void)
{
    return _Sbk_QImageCapture_Type;
}

static PyType_Slot Sbk_QImageCapture_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QImageCapture_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QImageCapture_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QImageCapture_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QImageCapture_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QImageCapture_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QImageCapture_spec = {
    "2:PySide6.QtMultimedia.QImageCapture",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QImageCapture_slots
};

} //extern "C"

static void *Sbk_QImageCapture_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QImageCapture *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QImageCapture_Error(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QImageCapture::Error>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QImageCapture::Error *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QImageCapture_Error_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_Error_IDX])))
        return Enum_PythonToCpp_QImageCapture_Error;
    return {};
}

static PyObject *QImageCapture_Error_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QImageCapture::Error>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QImageCapture::Error *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_Error_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QImageCapture_Quality(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QImageCapture::Quality>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QImageCapture::Quality *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QImageCapture_Quality_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_Quality_IDX])))
        return Enum_PythonToCpp_QImageCapture_Quality;
    return {};
}

static PyObject *QImageCapture_Quality_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QImageCapture::Quality>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QImageCapture::Quality *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_Quality_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QImageCapture_FileFormat(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QImageCapture::FileFormat>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QImageCapture::FileFormat *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QImageCapture_FileFormat_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_FileFormat_IDX])))
        return Enum_PythonToCpp_QImageCapture_FileFormat;
    return {};
}

static PyObject *QImageCapture_FileFormat_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QImageCapture::FileFormat>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QImageCapture::FileFormat *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_FileFormat_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QImageCapture_PythonToCpp_QImageCapture_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QImageCapture_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QImageCapture_PythonToCpp_QImageCapture_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QImageCapture_TypeF()))
        return QImageCapture_PythonToCpp_QImageCapture_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QImageCapture_PTR_CppToPython_QImageCapture(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QImageCapture *>(const_cast<void *>(cppIn)), Sbk_QImageCapture_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QImageCapture_SignatureStrings[] = {
    "PySide6.QtMultimedia.QImageCapture(self,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,readyForCapture:bool=None,metaData:QMediaMetaData=None,error:QImageCapture.Error=None,errorString:QString=None,fileFormat:QImageCapture.FileFormat=None,quality:QImageCapture.Quality=None)",
    "PySide6.QtMultimedia.QImageCapture.addMetaData(self,metaData:PySide6.QtMultimedia.QMediaMetaData)",
    "PySide6.QtMultimedia.QImageCapture.capture(self)->int",
    "PySide6.QtMultimedia.QImageCapture.captureSession(self)->PySide6.QtMultimedia.QMediaCaptureSession",
    "PySide6.QtMultimedia.QImageCapture.captureToFile(self,location:QString=QString())->int",
    "PySide6.QtMultimedia.QImageCapture.error(self)->PySide6.QtMultimedia.QImageCapture.Error",
    "PySide6.QtMultimedia.QImageCapture.errorString(self)->QString",
    "PySide6.QtMultimedia.QImageCapture.fileFormat(self)->PySide6.QtMultimedia.QImageCapture.FileFormat",
    "PySide6.QtMultimedia.QImageCapture.fileFormatDescription(c:PySide6.QtMultimedia.QImageCapture.FileFormat)->QString",
    "PySide6.QtMultimedia.QImageCapture.fileFormatName(c:PySide6.QtMultimedia.QImageCapture.FileFormat)->QString",
    "PySide6.QtMultimedia.QImageCapture.isAvailable(self)->bool",
    "PySide6.QtMultimedia.QImageCapture.isReadyForCapture(self)->bool",
    "PySide6.QtMultimedia.QImageCapture.metaData(self)->PySide6.QtMultimedia.QMediaMetaData",
    "PySide6.QtMultimedia.QImageCapture.quality(self)->PySide6.QtMultimedia.QImageCapture.Quality",
    "PySide6.QtMultimedia.QImageCapture.resolution(self)->PySide6.QtCore.QSize",
    "PySide6.QtMultimedia.QImageCapture.setFileFormat(self,format:PySide6.QtMultimedia.QImageCapture.FileFormat)",
    "PySide6.QtMultimedia.QImageCapture.setMetaData(self,metaData:PySide6.QtMultimedia.QMediaMetaData)",
    "PySide6.QtMultimedia.QImageCapture.setQuality(self,quality:PySide6.QtMultimedia.QImageCapture.Quality)",
    "1:PySide6.QtMultimedia.QImageCapture.setResolution(self,arg__1:PySide6.QtCore.QSize)",
    "0:PySide6.QtMultimedia.QImageCapture.setResolution(self,width:int,height:int)",
    "PySide6.QtMultimedia.QImageCapture.supportedFormats()->QList[PySide6.QtMultimedia.QImageCapture.FileFormat]",
    nullptr}; // Sentinel
#else
static constexpr size_t QImageCapture_SignatureByteSize = 432;
static constexpr uint8_t QImageCapture_SignatureBytes[432] = {
    0x78, 0xda, 0xb5, 0x54, 0x5d, 0x6f, 0x82, 0x30, 0x14, 0x7d, 0xe7, 0x97, 0xc8, 0xc2, 0xc8, 0x7c,
    0xd9, 0x43, 0x13, 0x97, 0x2c, 0x3a, 0x93, 0x65, 0xf3, 0x03, 0xd9, 0xdb, 0xb2, 0x98, 0x0a, 0x57,
    0xed, 0x52, 0x28, 0x6b, 0x2f, 0x33, 0xec, 0xd7, 0x4f, 0x2c, 0x22, 0x38, 0xe3, 0x5a, 0x13, 0x9f,
    0x0a, 0xbd, 0xbd, 0xe7, 0xdc, 0xcf, 0x33, 0x2d, 0x42, 0x16, 0xc3, 0xbd, 0x1f, 0xe0, 0x28, 0xe7,
    0xc8, 0x12, 0x88, 0x19, 0xf5, 0x83, 0xe7, 0x84, 0xae, 0xa0, 0x4f, 0x33, 0xcc, 0x25, 0x74, 0x14,
    0xf0, 0xa5, 0x97, 0x51, 0x09, 0x29, 0x92, 0x69, 0xfd, 0xbc, 0x2f, 0x24, 0xf8, 0xc1, 0x64, 0xf1,
    0x09, 0x11, 0xf6, 0xd2, 0x9c, 0xf3, 0x0c, 0xa5, 0x77, 0x43, 0x5e, 0xa0, 0xd8, 0x08, 0x19, 0x4f,
    0x52, 0x5e, 0xf4, 0xc6, 0x22, 0x05, 0x4f, 0x02, 0x8d, 0x8b, 0xa1, 0x90, 0x15, 0x1a, 0x59, 0x08,
    0xc1, 0xb5, 0x25, 0x01, 0xa4, 0x03, 0x8a, 0x94, 0x04, 0xa3, 0x92, 0x75, 0x54, 0xfd, 0x6a, 0x23,
    0x48, 0x29, 0x24, 0x69, 0x05, 0xe2, 0x3f, 0x95, 0x77, 0x0d, 0x73, 0x88, 0x92, 0xa5, 0x2b, 0x12,
    0xe8, 0x53, 0x1b, 0x96, 0x8c, 0xc3, 0x96, 0x2d, 0xa1, 0x78, 0xe4, 0x3c, 0xac, 0x0d, 0xfa, 0xe1,
    0x57, 0x4e, 0x39, 0xc3, 0xe2, 0xe8, 0x55, 0xa0, 0x6f, 0x77, 0x4f, 0x5c, 0x67, 0xfa, 0x6f, 0x71,
    0x7c, 0x1a, 0xc7, 0xfb, 0xc0, 0x75, 0xa1, 0xea, 0xac, 0x4e, 0x3b, 0xb7, 0x52, 0x35, 0x62, 0x88,
    0x1a, 0x6d, 0x70, 0x6f, 0x1f, 0x58, 0x8a, 0x16, 0x5e, 0x21, 0x28, 0xc5, 0x44, 0xba, 0x77, 0x3e,
    0x13, 0x53, 0xbf, 0xe5, 0x60, 0x41, 0xf1, 0x26, 0xca, 0xd2, 0xea, 0xe4, 0xb9, 0x88, 0x28, 0x6e,
    0xdd, 0xeb, 0x9e, 0x54, 0x67, 0xc7, 0x35, 0x8f, 0x7c, 0xd7, 0xda, 0xf3, 0x01, 0xff, 0x9d, 0x0a,
    0x63, 0xe0, 0x2a, 0x9e, 0x0a, 0xbe, 0x0a, 0xcf, 0xc4, 0xfb, 0x30, 0x58, 0x16, 0xb1, 0x1d, 0x86,
    0xce, 0x8e, 0x62, 0x00, 0x2a, 0x92, 0x2c, 0x2b, 0x4b, 0xd9, 0x89, 0x88, 0x15, 0xd1, 0xa5, 0x59,
    0x8d, 0x69, 0x02, 0xd7, 0xe5, 0x62, 0xea, 0xf1, 0x9b, 0x32, 0x4e, 0x17, 0xbc, 0x1e, 0xe6, 0x52,
    0x0c, 0xcc, 0x5c, 0x67, 0x6d, 0x19, 0xb1, 0x05, 0x48, 0x9a, 0x3b, 0x7a, 0x7e, 0x11, 0xf6, 0xcb,
    0x69, 0x02, 0x5b, 0x89, 0x88, 0xc5, 0x44, 0x54, 0x02, 0x63, 0x02, 0x2e, 0x41, 0x09, 0x9e, 0xe3,
    0xc9, 0xf5, 0xd5, 0xea, 0x1b, 0xb2, 0x1f, 0x30, 0x41, 0x52, 0x80, 0xc3, 0xf6, 0xf8, 0x7a, 0x4b,
    0xad, 0x91, 0x76, 0xed, 0x36, 0xe4, 0xba, 0xb2, 0x20, 0x6e, 0x19, 0x82, 0x46, 0xdd, 0x6b, 0x25,
    0x37, 0xaf, 0xbe, 0xeb, 0x74, 0x89, 0x19, 0xd1, 0xac, 0xdd, 0x03, 0x8f, 0xca, 0xd5, 0x7c, 0xde,
    0x25, 0xa7, 0x1a, 0xe1, 0x3a, 0x77, 0x17, 0x82, 0x6e, 0x58, 0x8c, 0x6b, 0xb2, 0x95, 0x47, 0x6f,
    0x0d, 0x6c, 0xb5, 0xc6, 0xf2, 0xd3, 0xac, 0x12, 0x79, 0x96, 0x09, 0x89, 0x10, 0xeb, 0xfe, 0xa8,
    0x4e, 0xb9, 0x90, 0xaf, 0x4c, 0xe1, 0xbb, 0x55, 0x5f, 0x3f, 0x9c, 0x5f, 0xb3, 0xb9, 0xf1, 0x81
};
#endif

PyTypeObject *init_QImageCapture(PyObject *module)
{
    if (SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_IDX].type != nullptr)
        return SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_IDX].type;

    Shiboken::AutoDecRef Sbk_QImageCapture_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QImageCapture_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QImageCapture",
        "QImageCapture*",
        &Sbk_QImageCapture_spec,
        &Shiboken::callCppDestructor< QImageCapture >,
        Sbk_QImageCapture_Type_bases.object(),
        0);
    auto *pyType = Sbk_QImageCapture_TypeF(); // references _Sbk_QImageCapture_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QImageCapture_SignatureStrings);
#else
    InitSignatureBytes(pyType, QImageCapture_SignatureBytes, QImageCapture_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QImageCapture_PropertyStrings);
    SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QImageCapture_PythonToCpp_QImageCapture_PTR,
        is_QImageCapture_PythonToCpp_QImageCapture_PTR_Convertible,
        QImageCapture_PTR_CppToPython_QImageCapture);

    Shiboken::Conversions::registerConverterName(converter, "QImageCapture");
    Shiboken::Conversions::registerConverterName(converter, "QImageCapture*");
    Shiboken::Conversions::registerConverterName(converter, "QImageCapture&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QImageCapture).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QImageCaptureWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QImageCapture_TypeF(), &Sbk_QImageCapture_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QImageCapture_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Error'.
    const char *Error_Initializer[] = {
        "NoError",
        "NotReadyError",
        "ResourceError",
        "OutOfSpaceError",
        "NotSupportedFeatureError",
        "FormatError",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Error_InitializerValues[] = {
        uint8_t(QImageCapture::Error::NoError),                  //  0x00  0
        uint8_t(QImageCapture::Error::NotReadyError),            //  0x01  1
        uint8_t(QImageCapture::Error::ResourceError),            //  0x02  2
        uint8_t(QImageCapture::Error::OutOfSpaceError),          //  0x03  3
        uint8_t(QImageCapture::Error::NotSupportedFeatureError), //  0x04  4
        uint8_t(QImageCapture::Error::FormatError)               //  0x05  5
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QImageCapture_TypeF(),
        "2:PySide6.QtMultimedia.QImageCapture.Error",
        Error_Initializer, Error_InitializerValues);
    SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_Error_IDX].type = EType;
    // Register converter for enum 'QImageCapture::Error'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QImageCapture_Error_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QImageCapture_Error,
            is_Enum_PythonToCpp_QImageCapture_Error_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QImageCapture::Error");
        Shiboken::Conversions::registerConverterAlias(converter, "Error");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Error' enum.

    // Initialization of enum 'Quality'.
    const char *Quality_Initializer[] = {
        "VeryLowQuality",
        "LowQuality",
        "NormalQuality",
        "HighQuality",
        "VeryHighQuality",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Quality_InitializerValues[] = {
        uint8_t(QImageCapture::Quality::VeryLowQuality), //  0x00  0
        uint8_t(QImageCapture::Quality::LowQuality),     //  0x01  1
        uint8_t(QImageCapture::Quality::NormalQuality),  //  0x02  2
        uint8_t(QImageCapture::Quality::HighQuality),    //  0x03  3
        uint8_t(QImageCapture::Quality::VeryHighQuality) //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QImageCapture_TypeF(),
        "2:PySide6.QtMultimedia.QImageCapture.Quality",
        Quality_Initializer, Quality_InitializerValues);
    SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_Quality_IDX].type = EType;
    // Register converter for enum 'QImageCapture::Quality'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QImageCapture_Quality_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QImageCapture_Quality,
            is_Enum_PythonToCpp_QImageCapture_Quality_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QImageCapture::Quality");
        Shiboken::Conversions::registerConverterAlias(converter, "Quality");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Quality' enum.

    // Initialization of enum 'FileFormat'.
    const char *FileFormat_Initializer[] = {
        "UnspecifiedFormat",
        "JPEG",
        "PNG",
        "WebP",
        "Tiff",
        "LastFileFormat",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t FileFormat_InitializerValues[] = {
        uint8_t(QImageCapture::FileFormat::UnspecifiedFormat), //  0x00  0
        uint8_t(QImageCapture::FileFormat::JPEG),              //  0x01  1
        uint8_t(QImageCapture::FileFormat::PNG),               //  0x02  2
        uint8_t(QImageCapture::FileFormat::WebP),              //  0x03  3
        uint8_t(QImageCapture::FileFormat::Tiff),              //  0x04  4
        uint8_t(QImageCapture::FileFormat::LastFileFormat)     //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QImageCapture_TypeF(),
        "2:PySide6.QtMultimedia.QImageCapture.FileFormat",
        FileFormat_Initializer, FileFormat_InitializerValues);
    SbkPySide6_QtMultimediaTypeStructs[SBK_QImageCapture_FileFormat_IDX].type = EType;
    // Register converter for enum 'QImageCapture::FileFormat'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QImageCapture_FileFormat_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QImageCapture_FileFormat,
            is_Enum_PythonToCpp_QImageCapture_FileFormat_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QImageCapture::FileFormat");
        Shiboken::Conversions::registerConverterAlias(converter, "FileFormat");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'FileFormat' enum.

    PySide::Signal::registerSignals(pyType, &::QImageCapture::staticMetaObject);
    qRegisterMetaType< ::QImageCapture::Error >("QImageCapture::Error");
    qRegisterMetaType< ::QImageCapture::Quality >("QImageCapture::Quality");
    qRegisterMetaType< ::QImageCapture::FileFormat >("QImageCapture::FileFormat");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QImageCapture::staticMetaObject, sizeof(QImageCaptureWrapper));

    return pyType;
}
