// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtmultimedia_python.h"

// main header
#include "qmediaformat_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtMultimedia/qmediaformat.h>
#include <qmimetype.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QMediaFormat_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QMediaFormat >()))
        return -1;

    ::QMediaFormat *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]);

    if (PyArg_ParseTuple(args, "|O:QMediaFormat", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QMediaFormat::QMediaFormat(QMediaFormat::FileFormat=)
    // 1: QMediaFormat::QMediaFormat(QMediaFormat)
    if (numArgs == 0) {
        overloadId = 0; // QMediaFormat(QMediaFormat::FileFormat)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_FileFormat_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // QMediaFormat(QMediaFormat::FileFormat)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QMediaFormat(QMediaFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QMediaFormat(QMediaFormat::FileFormat format)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_format = Shiboken::String::createStaticString("format");
                if (PyDict_Contains(kwds, key_format) != 0) {
                    value = PyDict_GetItem(kwds, key_format);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_format);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_FileFormat_IDX])))->converter, (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_format);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]);
                }
            }
            ::QMediaFormat::FileFormat cppArg0(QMediaFormat::FileFormat::UnspecifiedFormat);
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QMediaFormat(QMediaFormat::FileFormat)
                cptr = new ::QMediaFormat(cppArg0);
            }
            break;
        }
        case 1: // QMediaFormat(const QMediaFormat &other)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QMediaFormat cppArg0_local;
            ::QMediaFormat *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QMediaFormat(QMediaFormat)
                cptr = new ::QMediaFormat(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QMediaFormat >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QMediaFormatFunc_audioCodec(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // audioCodec()const
        QMediaFormat::AudioCodec cppResult = const_cast<const ::QMediaFormat *>(cppSelf)->audioCodec();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_AudioCodec_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMediaFormatFunc_audioCodecDescription(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QMediaFormat::audioCodecDescription(QMediaFormat::AudioCodec)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_AudioCodec_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // audioCodecDescription(QMediaFormat::AudioCodec)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "audioCodecDescription", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]);

    // Call function/method
    {
        ::QMediaFormat::AudioCodec cppArg0{QMediaFormat::AudioCodec::MP3};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // audioCodecDescription(QMediaFormat::AudioCodec)
            QString cppResult = ::QMediaFormat::audioCodecDescription(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMediaFormatFunc_audioCodecName(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QMediaFormat::audioCodecName(QMediaFormat::AudioCodec)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_AudioCodec_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // audioCodecName(QMediaFormat::AudioCodec)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "audioCodecName", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]);

    // Call function/method
    {
        ::QMediaFormat::AudioCodec cppArg0{QMediaFormat::AudioCodec::MP3};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // audioCodecName(QMediaFormat::AudioCodec)
            QString cppResult = ::QMediaFormat::audioCodecName(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMediaFormatFunc_fileFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // fileFormat()const
        QMediaFormat::FileFormat cppResult = const_cast<const ::QMediaFormat *>(cppSelf)->fileFormat();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_FileFormat_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMediaFormatFunc_fileFormatDescription(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QMediaFormat::fileFormatDescription(QMediaFormat::FileFormat)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_FileFormat_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // fileFormatDescription(QMediaFormat::FileFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fileFormatDescription", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]);

    // Call function/method
    {
        ::QMediaFormat::FileFormat cppArg0{QMediaFormat::WMV};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fileFormatDescription(QMediaFormat::FileFormat)
            QString cppResult = ::QMediaFormat::fileFormatDescription(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMediaFormatFunc_fileFormatName(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QMediaFormat::fileFormatName(QMediaFormat::FileFormat)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_FileFormat_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // fileFormatName(QMediaFormat::FileFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fileFormatName", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]);

    // Call function/method
    {
        ::QMediaFormat::FileFormat cppArg0{QMediaFormat::WMV};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fileFormatName(QMediaFormat::FileFormat)
            QString cppResult = ::QMediaFormat::fileFormatName(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMediaFormatFunc_isSupported(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMediaFormat::isSupported(QMediaFormat::ConversionMode)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_ConversionMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // isSupported(QMediaFormat::ConversionMode)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isSupported", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]);

    // Call function/method
    {
        ::QMediaFormat::ConversionMode cppArg0{QMediaFormat::Encode};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isSupported(QMediaFormat::ConversionMode)const
            bool cppResult = const_cast<const ::QMediaFormat *>(cppSelf)->isSupported(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMediaFormatFunc_mimeType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // mimeType()const
        QMimeType cppResult = const_cast<const ::QMediaFormat *>(cppSelf)->mimeType();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeType_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMediaFormatFunc_resolveForEncoding(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMediaFormat::resolveForEncoding(QMediaFormat::ResolveFlags)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_ResolveFlags_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // resolveForEncoding(QMediaFormat::ResolveFlags)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "resolveForEncoding", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]);

    // Call function/method
    {
        ::QMediaFormat::ResolveFlags cppArg0{QMediaFormat::NoFlags};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // resolveForEncoding(QMediaFormat::ResolveFlags)
            cppSelf->resolveForEncoding(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QMediaFormatFunc_setAudioCodec(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMediaFormat::setAudioCodec(QMediaFormat::AudioCodec)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_AudioCodec_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setAudioCodec(QMediaFormat::AudioCodec)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAudioCodec", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]);

    // Call function/method
    {
        ::QMediaFormat::AudioCodec cppArg0{QMediaFormat::AudioCodec::MP3};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAudioCodec(QMediaFormat::AudioCodec)
            cppSelf->setAudioCodec(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QMediaFormatFunc_setFileFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMediaFormat::setFileFormat(QMediaFormat::FileFormat)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_FileFormat_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setFileFormat(QMediaFormat::FileFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFileFormat", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]);

    // Call function/method
    {
        ::QMediaFormat::FileFormat cppArg0{QMediaFormat::WMV};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFileFormat(QMediaFormat::FileFormat)
            cppSelf->setFileFormat(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QMediaFormatFunc_setVideoCodec(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMediaFormat::setVideoCodec(QMediaFormat::VideoCodec)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_VideoCodec_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setVideoCodec(QMediaFormat::VideoCodec)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setVideoCodec", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]);

    // Call function/method
    {
        ::QMediaFormat::VideoCodec cppArg0{QMediaFormat::VideoCodec::MPEG1};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setVideoCodec(QMediaFormat::VideoCodec)
            cppSelf->setVideoCodec(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QMediaFormatFunc_supportedAudioCodecs(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMediaFormat::supportedAudioCodecs(QMediaFormat::ConversionMode)->QList<QMediaFormat::AudioCodec>
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_ConversionMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // supportedAudioCodecs(QMediaFormat::ConversionMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "supportedAudioCodecs", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]);

    // Call function/method
    {
        ::QMediaFormat::ConversionMode cppArg0{QMediaFormat::Encode};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // supportedAudioCodecs(QMediaFormat::ConversionMode)
            QList<QMediaFormat::AudioCodec> cppResult = cppSelf->supportedAudioCodecs(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtMultimediaTypeConverters[SBK_QtMultimedia_QList_QMediaFormat_AudioCodec_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMediaFormatFunc_supportedFileFormats(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMediaFormat::supportedFileFormats(QMediaFormat::ConversionMode)->QList<QMediaFormat::FileFormat>
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_ConversionMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // supportedFileFormats(QMediaFormat::ConversionMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "supportedFileFormats", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]);

    // Call function/method
    {
        ::QMediaFormat::ConversionMode cppArg0{QMediaFormat::Encode};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // supportedFileFormats(QMediaFormat::ConversionMode)
            QList<QMediaFormat::FileFormat> cppResult = cppSelf->supportedFileFormats(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtMultimediaTypeConverters[SBK_QtMultimedia_QList_QMediaFormat_FileFormat_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMediaFormatFunc_supportedVideoCodecs(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMediaFormat::supportedVideoCodecs(QMediaFormat::ConversionMode)->QList<QMediaFormat::VideoCodec>
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_ConversionMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // supportedVideoCodecs(QMediaFormat::ConversionMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "supportedVideoCodecs", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]);

    // Call function/method
    {
        ::QMediaFormat::ConversionMode cppArg0{QMediaFormat::Encode};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // supportedVideoCodecs(QMediaFormat::ConversionMode)
            QList<QMediaFormat::VideoCodec> cppResult = cppSelf->supportedVideoCodecs(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtMultimediaTypeConverters[SBK_QtMultimedia_QList_QMediaFormat_VideoCodec_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMediaFormatFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMediaFormat::swap(QMediaFormat&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QMediaFormat&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMediaFormat cppArg0_local;
        ::QMediaFormat *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QMediaFormat&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QMediaFormatFunc_videoCodec(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // videoCodec()const
        QMediaFormat::VideoCodec cppResult = const_cast<const ::QMediaFormat *>(cppSelf)->videoCodec();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_VideoCodec_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMediaFormatFunc_videoCodecDescription(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QMediaFormat::videoCodecDescription(QMediaFormat::VideoCodec)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_VideoCodec_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // videoCodecDescription(QMediaFormat::VideoCodec)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "videoCodecDescription", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]);

    // Call function/method
    {
        ::QMediaFormat::VideoCodec cppArg0{QMediaFormat::VideoCodec::MPEG1};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // videoCodecDescription(QMediaFormat::VideoCodec)
            QString cppResult = ::QMediaFormat::videoCodecDescription(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMediaFormatFunc_videoCodecName(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QMediaFormat::videoCodecName(QMediaFormat::VideoCodec)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_VideoCodec_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // videoCodecName(QMediaFormat::VideoCodec)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "videoCodecName", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]);

    // Call function/method
    {
        ::QMediaFormat::VideoCodec cppArg0{QMediaFormat::VideoCodec::MPEG1};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // videoCodecName(QMediaFormat::VideoCodec)
            QString cppResult = ::QMediaFormat::videoCodecName(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMediaFormat__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QMediaFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QMediaFormat_PropertyStrings[] = {
    "audioCodec::",
    "fileFormat::",
    "videoCodec::",
    nullptr // Sentinel
};

static const char *Sbk_QMediaFormat_EnumFlagInfo[] = {
    "AudioCodec:Enum",
    "ConversionMode:Enum",
    "FileFormat:Enum",
    "ResolveFlags:Enum",
    "VideoCodec:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QMediaFormat_methods[] = {
    {"audioCodec", reinterpret_cast<PyCFunction>(Sbk_QMediaFormatFunc_audioCodec), METH_NOARGS, nullptr},
    {"audioCodecDescription", reinterpret_cast<PyCFunction>(Sbk_QMediaFormatFunc_audioCodecDescription), METH_O|METH_STATIC, nullptr},
    {"audioCodecName", reinterpret_cast<PyCFunction>(Sbk_QMediaFormatFunc_audioCodecName), METH_O|METH_STATIC, nullptr},
    {"fileFormat", reinterpret_cast<PyCFunction>(Sbk_QMediaFormatFunc_fileFormat), METH_NOARGS, nullptr},
    {"fileFormatDescription", reinterpret_cast<PyCFunction>(Sbk_QMediaFormatFunc_fileFormatDescription), METH_O|METH_STATIC, nullptr},
    {"fileFormatName", reinterpret_cast<PyCFunction>(Sbk_QMediaFormatFunc_fileFormatName), METH_O|METH_STATIC, nullptr},
    {"isSupported", reinterpret_cast<PyCFunction>(Sbk_QMediaFormatFunc_isSupported), METH_O, nullptr},
    {"mimeType", reinterpret_cast<PyCFunction>(Sbk_QMediaFormatFunc_mimeType), METH_NOARGS, nullptr},
    {"resolveForEncoding", reinterpret_cast<PyCFunction>(Sbk_QMediaFormatFunc_resolveForEncoding), METH_O, nullptr},
    {"setAudioCodec", reinterpret_cast<PyCFunction>(Sbk_QMediaFormatFunc_setAudioCodec), METH_O, nullptr},
    {"setFileFormat", reinterpret_cast<PyCFunction>(Sbk_QMediaFormatFunc_setFileFormat), METH_O, nullptr},
    {"setVideoCodec", reinterpret_cast<PyCFunction>(Sbk_QMediaFormatFunc_setVideoCodec), METH_O, nullptr},
    {"supportedAudioCodecs", reinterpret_cast<PyCFunction>(Sbk_QMediaFormatFunc_supportedAudioCodecs), METH_O, nullptr},
    {"supportedFileFormats", reinterpret_cast<PyCFunction>(Sbk_QMediaFormatFunc_supportedFileFormats), METH_O, nullptr},
    {"supportedVideoCodecs", reinterpret_cast<PyCFunction>(Sbk_QMediaFormatFunc_supportedVideoCodecs), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QMediaFormatFunc_swap), METH_O, nullptr},
    {"videoCodec", reinterpret_cast<PyCFunction>(Sbk_QMediaFormatFunc_videoCodec), METH_NOARGS, nullptr},
    {"videoCodecDescription", reinterpret_cast<PyCFunction>(Sbk_QMediaFormatFunc_videoCodecDescription), METH_O|METH_STATIC, nullptr},
    {"videoCodecName", reinterpret_cast<PyCFunction>(Sbk_QMediaFormatFunc_videoCodecName), METH_O|METH_STATIC, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QMediaFormat__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QMediaFormat_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QMediaFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]), (pyArg)))) {
                // operator!=(const QMediaFormat &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QMediaFormat cppArg0_local;
                ::QMediaFormat *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]), (pyArg)))) {
                // operator==(const QMediaFormat &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QMediaFormat cppArg0_local;
                ::QMediaFormat *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

static PyObject *Sbk_QMediaFormat_get_fmt(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::QMediaFormat::FileFormat cppOut_local = cppSelf->fmt;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_FileFormat_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QMediaFormat_set_fmt(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QMediaFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("fmt");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_FileFormat_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("fmt", "FileFormat");
        return -1;
    }

    auto cppOut_local = cppSelf->fmt;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->fmt = cppOut_local;

    return 0;
}

static PyObject *Sbk_QMediaFormat_get_audio(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::QMediaFormat::AudioCodec cppOut_local = cppSelf->audio;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_AudioCodec_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QMediaFormat_set_audio(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QMediaFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("audio");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_AudioCodec_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("audio", "AudioCodec");
        return -1;
    }

    auto cppOut_local = cppSelf->audio;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->audio = cppOut_local;

    return 0;
}

static PyObject *Sbk_QMediaFormat_get_video(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::QMediaFormat::VideoCodec cppOut_local = cppSelf->video;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_VideoCodec_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QMediaFormat_set_video(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QMediaFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("video");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_VideoCodec_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("video", "VideoCodec");
        return -1;
    }

    auto cppOut_local = cppSelf->video;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->video = cppOut_local;

    return 0;
}

// Getters and Setters for QMediaFormat
static PyGetSetDef Sbk_QMediaFormat_getsetlist[] = {
    {const_cast<char *>("fmt"), Sbk_QMediaFormat_get_fmt, Sbk_QMediaFormat_set_fmt, nullptr, nullptr},
    {const_cast<char *>("audio"), Sbk_QMediaFormat_get_audio, Sbk_QMediaFormat_set_audio, nullptr, nullptr},
    {const_cast<char *>("video"), Sbk_QMediaFormat_get_video, Sbk_QMediaFormat_set_video, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QMediaFormat_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QMediaFormat_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QMediaFormat_Type = nullptr;
static PyTypeObject *Sbk_QMediaFormat_TypeF(void)
{
    return _Sbk_QMediaFormat_Type;
}

static PyType_Slot Sbk_QMediaFormat_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QMediaFormat_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QMediaFormat_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QMediaFormat_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QMediaFormat_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QMediaFormat_getsetlist)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QMediaFormat_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QMediaFormat_spec = {
    "2:PySide6.QtMultimedia.QMediaFormat",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QMediaFormat_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QMediaFormat_FileFormat(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QMediaFormat::FileFormat>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QMediaFormat::FileFormat *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QMediaFormat_FileFormat_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_FileFormat_IDX])))
        return Enum_PythonToCpp_QMediaFormat_FileFormat;
    return {};
}

static PyObject *QMediaFormat_FileFormat_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QMediaFormat::FileFormat>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QMediaFormat::FileFormat *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_FileFormat_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QMediaFormat_AudioCodec(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QMediaFormat::AudioCodec>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QMediaFormat::AudioCodec *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QMediaFormat_AudioCodec_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_AudioCodec_IDX])))
        return Enum_PythonToCpp_QMediaFormat_AudioCodec;
    return {};
}

static PyObject *QMediaFormat_AudioCodec_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QMediaFormat::AudioCodec>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QMediaFormat::AudioCodec *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_AudioCodec_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QMediaFormat_VideoCodec(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QMediaFormat::VideoCodec>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QMediaFormat::VideoCodec *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QMediaFormat_VideoCodec_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_VideoCodec_IDX])))
        return Enum_PythonToCpp_QMediaFormat_VideoCodec;
    return {};
}

static PyObject *QMediaFormat_VideoCodec_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QMediaFormat::VideoCodec>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QMediaFormat::VideoCodec *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_VideoCodec_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QMediaFormat_ConversionMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QMediaFormat::ConversionMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QMediaFormat::ConversionMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QMediaFormat_ConversionMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_ConversionMode_IDX])))
        return Enum_PythonToCpp_QMediaFormat_ConversionMode;
    return {};
}

static PyObject *QMediaFormat_ConversionMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QMediaFormat::ConversionMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QMediaFormat::ConversionMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_ConversionMode_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QMediaFormat_ResolveFlags(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QMediaFormat::ResolveFlags>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QMediaFormat::ResolveFlags *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QMediaFormat_ResolveFlags_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_ResolveFlags_IDX])))
        return Enum_PythonToCpp_QMediaFormat_ResolveFlags;
    return {};
}

static PyObject *QMediaFormat_ResolveFlags_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QMediaFormat::ResolveFlags>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QMediaFormat::ResolveFlags *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_ResolveFlags_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QMediaFormat_PythonToCpp_QMediaFormat_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QMediaFormat_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QMediaFormat_PythonToCpp_QMediaFormat_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QMediaFormat_TypeF()))
        return QMediaFormat_PythonToCpp_QMediaFormat_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QMediaFormat_PTR_CppToPython_QMediaFormat(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QMediaFormat_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QMediaFormat_COPY_CppToPython_QMediaFormat(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QMediaFormat *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QMediaFormat_TypeF(), new ::QMediaFormat(*source), true, true);
}

// Python to C++ copy conversion.
static void QMediaFormat_PythonToCpp_QMediaFormat_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QMediaFormat *>(cppOut) = *reinterpret_cast< ::QMediaFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QMediaFormat_PythonToCpp_QMediaFormat_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QMediaFormat_TypeF()))
        return QMediaFormat_PythonToCpp_QMediaFormat_COPY;
    return {};
}

// Implicit conversions.
static void QMediaFormat_FileFormat_PythonToCpp_QMediaFormat(PyObject *pyIn, void *cppOut)
{
    ::QMediaFormat::FileFormat cppIn{QMediaFormat::WMV};
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_FileFormat_IDX])))->converter, pyIn, &cppIn);
    *reinterpret_cast<::QMediaFormat *>(cppOut) = ::QMediaFormat(cppIn);
}
static PythonToCppFunc is_QMediaFormat_FileFormat_PythonToCpp_QMediaFormat_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_FileFormat_IDX]), pyIn))
        return QMediaFormat_FileFormat_PythonToCpp_QMediaFormat;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QMediaFormat_SignatureStrings[] = {
    "1:PySide6.QtMultimedia.QMediaFormat(self,format:PySide6.QtMultimedia.QMediaFormat.FileFormat=QMediaFormat.FileFormat.UnspecifiedFormat,*:KeywordOnly=None,fileFormat:QMediaFormat.FileFormat=None,audioCodec:QMediaFormat.AudioCodec=None,videoCodec:QMediaFormat.VideoCodec=None)",
    "0:PySide6.QtMultimedia.QMediaFormat(self,other:PySide6.QtMultimedia.QMediaFormat,*:KeywordOnly=None,fileFormat:QMediaFormat.FileFormat=None,audioCodec:QMediaFormat.AudioCodec=None,videoCodec:QMediaFormat.VideoCodec=None)",
    "PySide6.QtMultimedia.QMediaFormat.audioCodec(self)->PySide6.QtMultimedia.QMediaFormat.AudioCodec",
    "PySide6.QtMultimedia.QMediaFormat.audioCodecDescription(codec:PySide6.QtMultimedia.QMediaFormat.AudioCodec)->QString",
    "PySide6.QtMultimedia.QMediaFormat.audioCodecName(codec:PySide6.QtMultimedia.QMediaFormat.AudioCodec)->QString",
    "PySide6.QtMultimedia.QMediaFormat.fileFormat(self)->PySide6.QtMultimedia.QMediaFormat.FileFormat",
    "PySide6.QtMultimedia.QMediaFormat.fileFormatDescription(fileFormat:PySide6.QtMultimedia.QMediaFormat.FileFormat)->QString",
    "PySide6.QtMultimedia.QMediaFormat.fileFormatName(fileFormat:PySide6.QtMultimedia.QMediaFormat.FileFormat)->QString",
    "PySide6.QtMultimedia.QMediaFormat.isSupported(self,mode:PySide6.QtMultimedia.QMediaFormat.ConversionMode)->bool",
    "PySide6.QtMultimedia.QMediaFormat.mimeType(self)->PySide6.QtCore.QMimeType",
    "PySide6.QtMultimedia.QMediaFormat.resolveForEncoding(self,flags:PySide6.QtMultimedia.QMediaFormat.ResolveFlags)",
    "PySide6.QtMultimedia.QMediaFormat.setAudioCodec(self,codec:PySide6.QtMultimedia.QMediaFormat.AudioCodec)",
    "PySide6.QtMultimedia.QMediaFormat.setFileFormat(self,f:PySide6.QtMultimedia.QMediaFormat.FileFormat)",
    "PySide6.QtMultimedia.QMediaFormat.setVideoCodec(self,codec:PySide6.QtMultimedia.QMediaFormat.VideoCodec)",
    "PySide6.QtMultimedia.QMediaFormat.supportedAudioCodecs(self,m:PySide6.QtMultimedia.QMediaFormat.ConversionMode)->QList[PySide6.QtMultimedia.QMediaFormat.AudioCodec]",
    "PySide6.QtMultimedia.QMediaFormat.supportedFileFormats(self,m:PySide6.QtMultimedia.QMediaFormat.ConversionMode)->QList[PySide6.QtMultimedia.QMediaFormat.FileFormat]",
    "PySide6.QtMultimedia.QMediaFormat.supportedVideoCodecs(self,m:PySide6.QtMultimedia.QMediaFormat.ConversionMode)->QList[PySide6.QtMultimedia.QMediaFormat.VideoCodec]",
    "PySide6.QtMultimedia.QMediaFormat.swap(self,other:typing.Union[PySide6.QtMultimedia.QMediaFormat, PySide6.QtMultimedia.QMediaFormat.FileFormat])",
    "PySide6.QtMultimedia.QMediaFormat.videoCodec(self)->PySide6.QtMultimedia.QMediaFormat.VideoCodec",
    "PySide6.QtMultimedia.QMediaFormat.videoCodecDescription(codec:PySide6.QtMultimedia.QMediaFormat.VideoCodec)->QString",
    "PySide6.QtMultimedia.QMediaFormat.videoCodecName(codec:PySide6.QtMultimedia.QMediaFormat.VideoCodec)->QString",
    "PySide6.QtMultimedia.QMediaFormat.__copy__(self)->typing.Self",
    "PySide6.QtMultimedia.QMediaFormat.__ne__(self,other:typing.Union[PySide6.QtMultimedia.QMediaFormat, PySide6.QtMultimedia.QMediaFormat.FileFormat])->bool",
    "PySide6.QtMultimedia.QMediaFormat.__eq__(self,other:typing.Union[PySide6.QtMultimedia.QMediaFormat, PySide6.QtMultimedia.QMediaFormat.FileFormat])->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QMediaFormat_SignatureByteSize = 445;
static constexpr uint8_t QMediaFormat_SignatureBytes[445] = {
    0x78, 0xda, 0xcd, 0x96, 0x4d, 0x4f, 0x83, 0x40, 0x10, 0x86, 0xef, 0xfe, 0x0a, 0x8f, 0xad, 0x41,
    0xa2, 0x17, 0x0f, 0x4d, 0x6a, 0x62, 0xaa, 0xbd, 0x68, 0xab, 0x88, 0x7a, 0x31, 0x86, 0x20, 0x0c,
    0x75, 0x13, 0xd8, 0x5d, 0x77, 0xb7, 0x34, 0xfc, 0x7b, 0xb7, 0x40, 0xbb, 0x10, 0x6d, 0x98, 0x25,
    0x11, 0x3d, 0x95, 0x4e, 0x67, 0x78, 0xe6, 0xe3, 0xdd, 0x9d, 0x9e, 0x4f, 0x1e, 0x0a, 0x9f, 0xc4,
    0x70, 0xe1, 0x7a, 0x6a, 0xb1, 0x4e, 0x15, 0xc9, 0x20, 0x26, 0xa1, 0xeb, 0x2d, 0xb6, 0x1f, 0x73,
    0x26, 0xb2, 0x50, 0x8d, 0x24, 0xa4, 0x89, 0x93, 0x94, 0xcf, 0xdd, 0xde, 0xee, 0x9c, 0xa4, 0x50,
    0x3d, 0x4e, 0x0f, 0xd8, 0xdd, 0x67, 0x2a, 0x39, 0x44, 0x24, 0x21, 0x10, 0x57, 0x16, 0xe7, 0x64,
    0x72, 0x0b, 0xc5, 0x86, 0x89, 0xf8, 0x9e, 0xa6, 0xc5, 0x74, 0xc9, 0x28, 0x38, 0xc9, 0xde, 0x7f,
    0x72, 0xe8, 0xfd, 0xa5, 0x5f, 0xb8, 0x8e, 0x09, 0x9b, 0xb1, 0x18, 0xa2, 0xb6, 0xdf, 0xd5, 0xde,
    0x5e, 0xf9, 0xe5, 0x3a, 0xef, 0x9f, 0xfc, 0x5e, 0xf6, 0xf6, 0xd2, 0x6f, 0x7c, 0x74, 0x86, 0x6d,
    0x09, 0x53, 0x1f, 0x20, 0xba, 0x9d, 0xff, 0x55, 0x71, 0xdd, 0xf3, 0x33, 0xc8, 0xb2, 0xca, 0xf1,
    0xe9, 0x65, 0x77, 0x8c, 0x49, 0xc7, 0x0a, 0x70, 0x0d, 0x32, 0x12, 0x84, 0x2b, 0xc2, 0xe8, 0x28,
    0x2a, 0x93, 0xb7, 0x41, 0xe9, 0xcc, 0x3c, 0x5f, 0x09, 0x42, 0x57, 0x56, 0xd0, 0x65, 0x98, 0xc1,
    0x6f, 0xd3, 0xcc, 0x78, 0xf1, 0x3d, 0x34, 0xa3, 0xb7, 0x02, 0x34, 0x7b, 0xd8, 0x50, 0x95, 0x0d,
    0xaf, 0x67, 0x69, 0x65, 0x23, 0x87, 0x40, 0x12, 0xe9, 0xaf, 0x39, 0x67, 0x42, 0x41, 0x5c, 0x1d,
    0xbc, 0x4c, 0x0f, 0x04, 0x81, 0x9b, 0x31, 0x9a, 0x83, 0x90, 0xba, 0x33, 0x0b, 0x1d, 0xa0, 0x91,
    0xef, 0x8c, 0xa5, 0x08, 0x5e, 0xa6, 0x8d, 0x4f, 0x05, 0x87, 0xef, 0xb3, 0x9b, 0x31, 0x01, 0xda,
    0xb7, 0xfe, 0x1d, 0xf1, 0x2a, 0x01, 0x92, 0xa5, 0xf9, 0xb6, 0xe8, 0x1b, 0xaa, 0x35, 0xa7, 0xeb,
    0xad, 0x6f, 0xd3, 0x34, 0x5c, 0x49, 0x44, 0x09, 0x8f, 0x75, 0xfc, 0xd6, 0x1d, 0x73, 0x78, 0x25,
    0xa8, 0xab, 0xf6, 0xf9, 0x75, 0x7a, 0x48, 0x1d, 0x07, 0x9a, 0xb7, 0x45, 0xee, 0x24, 0x76, 0x0a,
    0xc0, 0x41, 0xcc, 0x05, 0x66, 0x57, 0x8d, 0x89, 0x43, 0x81, 0x76, 0xfa, 0x32, 0x4d, 0x90, 0xb5,
    0xd4, 0xfa, 0xe8, 0xcc, 0xbb, 0x23, 0x52, 0xbd, 0xda, 0xb4, 0xfc, 0xcd, 0x26, 0x49, 0xd3, 0xc4,
    0x21, 0x92, 0x34, 0x34, 0xab, 0x24, 0xcd, 0x00, 0x86, 0x48, 0xd2, 0xd0, 0x50, 0x49, 0x6e, 0x42,
    0xde, 0x5c, 0xe1, 0xaa, 0xe0, 0xfa, 0x64, 0xea, 0xbf, 0x25, 0x1a, 0xdc, 0x0d, 0x73, 0x8e, 0xad,
    0x9a, 0x86, 0xd1, 0x5f, 0xde, 0x56, 0x39, 0x6a, 0x5f, 0x98, 0x92, 0xad, 0x00, 0x7d, 0x76, 0x6e,
    0xe3, 0x30, 0xd9, 0xdc, 0xdb, 0x06, 0x6a, 0xb5, 0x73, 0x7b, 0xd2, 0x82, 0x20, 0x62, 0xbc, 0x08,
    0x82, 0x5d, 0x07, 0xeb, 0xa1, 0xfa, 0xfa, 0x1b, 0x2a, 0x9a, 0x42, 0x1d, 0x3b, 0x88, 0x28, 0xd0,
    0xcb, 0x28, 0x08, 0xe0, 0xf3, 0x0f, 0x12, 0xfb, 0x02, 0xe7, 0xd7, 0x6f, 0x40
};
#endif

PyTypeObject *init_QMediaFormat(PyObject *module)
{
    if (SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX].type != nullptr)
        return SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX].type;

    Shiboken::AutoDecRef Sbk_QMediaFormat_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QMediaFormat_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QMediaFormat",
        "QMediaFormat",
        &Sbk_QMediaFormat_spec,
        &Shiboken::callCppDestructor< ::QMediaFormat >,
        Sbk_QMediaFormat_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QMediaFormat_TypeF(); // references _Sbk_QMediaFormat_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QMediaFormat_SignatureStrings);
#else
    InitSignatureBytes(pyType, QMediaFormat_SignatureBytes, QMediaFormat_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QMediaFormat_PropertyStrings);
    SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QMediaFormat_PythonToCpp_QMediaFormat_PTR,
        is_QMediaFormat_PythonToCpp_QMediaFormat_PTR_Convertible,
        QMediaFormat_PTR_CppToPython_QMediaFormat,
        QMediaFormat_COPY_CppToPython_QMediaFormat);

    Shiboken::Conversions::registerConverterName(converter, "QMediaFormat");
    Shiboken::Conversions::registerConverterName(converter, "QMediaFormat*");
    Shiboken::Conversions::registerConverterName(converter, "QMediaFormat&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QMediaFormat).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QMediaFormat_PythonToCpp_QMediaFormat_COPY,
        is_QMediaFormat_PythonToCpp_QMediaFormat_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QMediaFormat_FileFormat_PythonToCpp_QMediaFormat,
        is_QMediaFormat_FileFormat_PythonToCpp_QMediaFormat_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QMediaFormat_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'FileFormat'.
    const char *FileFormat_Initializer[] = {
        "UnspecifiedFormat",
        "WMV",
        "AVI",
        "Matroska",
        "MPEG4",
        "Ogg",
        "QuickTime",
        "WebM",
        "Mpeg4Audio",
        "AAC",
        "WMA",
        "MP3",
        "FLAC",
        "Wave",
        "LastFileFormat",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t FileFormat_InitializerValues[] = {
        int8_t(QMediaFormat::FileFormat::UnspecifiedFormat), // -0x01 -1
        int8_t(QMediaFormat::FileFormat::WMV),               //  0x00  0
        int8_t(QMediaFormat::FileFormat::AVI),               //  0x01  1
        int8_t(QMediaFormat::FileFormat::Matroska),          //  0x02  2
        int8_t(QMediaFormat::FileFormat::MPEG4),             //  0x03  3
        int8_t(QMediaFormat::FileFormat::Ogg),               //  0x04  4
        int8_t(QMediaFormat::FileFormat::QuickTime),         //  0x05  5
        int8_t(QMediaFormat::FileFormat::WebM),              //  0x06  6
        int8_t(QMediaFormat::FileFormat::Mpeg4Audio),        //  0x07  7
        int8_t(QMediaFormat::FileFormat::AAC),               //  0x08  8
        int8_t(QMediaFormat::FileFormat::WMA),               //  0x09  9
        int8_t(QMediaFormat::FileFormat::MP3),               //  0x0a  10
        int8_t(QMediaFormat::FileFormat::FLAC),              //  0x0b  11
        int8_t(QMediaFormat::FileFormat::Wave),              //  0x0c  12
        int8_t(QMediaFormat::FileFormat::LastFileFormat)     //  0x0c  12
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QMediaFormat_TypeF(),
        "2:PySide6.QtMultimedia.QMediaFormat.FileFormat",
        FileFormat_Initializer, FileFormat_InitializerValues);
    SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_FileFormat_IDX].type = EType;
    // Register converter for enum 'QMediaFormat::FileFormat'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QMediaFormat_FileFormat_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QMediaFormat_FileFormat,
            is_Enum_PythonToCpp_QMediaFormat_FileFormat_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QMediaFormat::FileFormat");
        Shiboken::Conversions::registerConverterAlias(converter, "FileFormat");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'FileFormat' enum.

    // Initialization of enum 'AudioCodec'.
    const char *AudioCodec_Initializer[] = {
        "Unspecified",
        "MP3",
        "AAC",
        "AC3",
        "EAC3",
        "FLAC",
        "DolbyTrueHD",
        "Opus",
        "Vorbis",
        "Wave",
        "WMA",
        "ALAC",
        "LastAudioCodec",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t AudioCodec_InitializerValues[] = {
        int8_t(QMediaFormat::AudioCodec::Unspecified),   // -0x01 -1
        int8_t(QMediaFormat::AudioCodec::MP3),           //  0x00  0
        int8_t(QMediaFormat::AudioCodec::AAC),           //  0x01  1
        int8_t(QMediaFormat::AudioCodec::AC3),           //  0x02  2
        int8_t(QMediaFormat::AudioCodec::EAC3),          //  0x03  3
        int8_t(QMediaFormat::AudioCodec::FLAC),          //  0x04  4
        int8_t(QMediaFormat::AudioCodec::DolbyTrueHD),   //  0x05  5
        int8_t(QMediaFormat::AudioCodec::Opus),          //  0x06  6
        int8_t(QMediaFormat::AudioCodec::Vorbis),        //  0x07  7
        int8_t(QMediaFormat::AudioCodec::Wave),          //  0x08  8
        int8_t(QMediaFormat::AudioCodec::WMA),           //  0x09  9
        int8_t(QMediaFormat::AudioCodec::ALAC),          //  0x0a  10
        int8_t(QMediaFormat::AudioCodec::LastAudioCodec) //  0x0a  10
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QMediaFormat_TypeF(),
        "2:PySide6.QtMultimedia.QMediaFormat.AudioCodec",
        AudioCodec_Initializer, AudioCodec_InitializerValues);
    SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_AudioCodec_IDX].type = EType;
    // Register converter for enum 'QMediaFormat::AudioCodec'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QMediaFormat_AudioCodec_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QMediaFormat_AudioCodec,
            is_Enum_PythonToCpp_QMediaFormat_AudioCodec_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QMediaFormat::AudioCodec");
        Shiboken::Conversions::registerConverterAlias(converter, "AudioCodec");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'AudioCodec' enum.

    // Initialization of enum 'VideoCodec'.
    const char *VideoCodec_Initializer[] = {
        "Unspecified",
        "MPEG1",
        "MPEG2",
        "MPEG4",
        "H264",
        "H265",
        "VP8",
        "VP9",
        "AV1",
        "Theora",
        "WMV",
        "MotionJPEG",
        "LastVideoCodec",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t VideoCodec_InitializerValues[] = {
        int8_t(QMediaFormat::VideoCodec::Unspecified),   // -0x01 -1
        int8_t(QMediaFormat::VideoCodec::MPEG1),         //  0x00  0
        int8_t(QMediaFormat::VideoCodec::MPEG2),         //  0x01  1
        int8_t(QMediaFormat::VideoCodec::MPEG4),         //  0x02  2
        int8_t(QMediaFormat::VideoCodec::H264),          //  0x03  3
        int8_t(QMediaFormat::VideoCodec::H265),          //  0x04  4
        int8_t(QMediaFormat::VideoCodec::VP8),           //  0x05  5
        int8_t(QMediaFormat::VideoCodec::VP9),           //  0x06  6
        int8_t(QMediaFormat::VideoCodec::AV1),           //  0x07  7
        int8_t(QMediaFormat::VideoCodec::Theora),        //  0x08  8
        int8_t(QMediaFormat::VideoCodec::WMV),           //  0x09  9
        int8_t(QMediaFormat::VideoCodec::MotionJPEG),    //  0x0a  10
        int8_t(QMediaFormat::VideoCodec::LastVideoCodec) //  0x0a  10
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QMediaFormat_TypeF(),
        "2:PySide6.QtMultimedia.QMediaFormat.VideoCodec",
        VideoCodec_Initializer, VideoCodec_InitializerValues);
    SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_VideoCodec_IDX].type = EType;
    // Register converter for enum 'QMediaFormat::VideoCodec'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QMediaFormat_VideoCodec_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QMediaFormat_VideoCodec,
            is_Enum_PythonToCpp_QMediaFormat_VideoCodec_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QMediaFormat::VideoCodec");
        Shiboken::Conversions::registerConverterAlias(converter, "VideoCodec");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'VideoCodec' enum.

    // Initialization of enum 'ConversionMode'.
    const char *ConversionMode_Initializer[] = {
        "Encode",
        "Decode",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ConversionMode_InitializerValues[] = {
        uint8_t(QMediaFormat::ConversionMode::Encode), //  0x00  0
        uint8_t(QMediaFormat::ConversionMode::Decode)  //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QMediaFormat_TypeF(),
        "2:PySide6.QtMultimedia.QMediaFormat.ConversionMode",
        ConversionMode_Initializer, ConversionMode_InitializerValues);
    SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_ConversionMode_IDX].type = EType;
    // Register converter for enum 'QMediaFormat::ConversionMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QMediaFormat_ConversionMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QMediaFormat_ConversionMode,
            is_Enum_PythonToCpp_QMediaFormat_ConversionMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QMediaFormat::ConversionMode");
        Shiboken::Conversions::registerConverterAlias(converter, "ConversionMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ConversionMode' enum.

    // Initialization of enum 'ResolveFlags'.
    const char *ResolveFlags_Initializer[] = {
        "NoFlags",
        "RequiresVideo",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ResolveFlags_InitializerValues[] = {
        uint8_t(QMediaFormat::ResolveFlags::NoFlags),      //  0x00  0
        uint8_t(QMediaFormat::ResolveFlags::RequiresVideo) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QMediaFormat_TypeF(),
        "2:PySide6.QtMultimedia.QMediaFormat.ResolveFlags",
        ResolveFlags_Initializer, ResolveFlags_InitializerValues);
    SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_ResolveFlags_IDX].type = EType;
    // Register converter for enum 'QMediaFormat::ResolveFlags'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QMediaFormat_ResolveFlags_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QMediaFormat_ResolveFlags,
            is_Enum_PythonToCpp_QMediaFormat_ResolveFlags_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QMediaFormat::ResolveFlags");
        Shiboken::Conversions::registerConverterAlias(converter, "ResolveFlags");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ResolveFlags' enum.

    qRegisterMetaType< ::QMediaFormat >("QMediaFormat");
    qRegisterMetaType< ::QMediaFormat::FileFormat >("QMediaFormat::FileFormat");
    qRegisterMetaType< ::QMediaFormat::AudioCodec >("QMediaFormat::AudioCodec");
    qRegisterMetaType< ::QMediaFormat::VideoCodec >("QMediaFormat::VideoCodec");
    qRegisterMetaType< ::QMediaFormat::ConversionMode >("QMediaFormat::ConversionMode");
    qRegisterMetaType< ::QMediaFormat::ResolveFlags >("QMediaFormat::ResolveFlags");

    return pyType;
}
