// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtmultimedia_python.h"

// main header
#include "qmediarecorder_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QtMultimedia/qmediacapturesession.h>
#include <QtMultimedia/qmediaformat.h>
#include <QtMultimedia/qmediametadata.h>
#include <QtMultimedia/qmediarecorder.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qiodevice.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qsize.h>
#include <qthread.h>
#include <qurl.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QMediaRecorderWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QMediaRecorderWrapper::QMediaRecorderWrapper(::QObject * parent) : QMediaRecorder(parent)
{
}

void QMediaRecorderWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QMediaRecorder", funcName);
        return;
    }
}

void QMediaRecorderWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QMediaRecorder", funcName);
        return;
    }
}

void QMediaRecorderWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QMediaRecorder", funcName);
        return;
    }
}

void QMediaRecorderWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QMediaRecorder", funcName);
        return;
    }
}

bool QMediaRecorderWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QMediaRecorder", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QMediaRecorder", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QMediaRecorderWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QMediaRecorder", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QMediaRecorder", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QMediaRecorderWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QMediaRecorder", funcName);
        return;
    }
}

const QMetaObject *QMediaRecorderWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QMediaRecorder::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QMediaRecorderWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QMediaRecorder::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QMediaRecorderWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QMediaRecorderWrapper *>(this));
    return QMediaRecorder::qt_metacast(_clname);
}

QMediaRecorderWrapper::~QMediaRecorderWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QMediaRecorder_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QMediaRecorder >()))
        return -1;

    QMediaRecorderWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QMediaRecorder", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QMediaRecorder::QMediaRecorder(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QMediaRecorder(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QMediaRecorder(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                // fall through to handle extra keyword signals and properties
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QMediaRecorder(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QMediaRecorderWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QMediaRecorderWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QMediaRecorder >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QMediaRecorderFunc_actualLocation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaRecorder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // actualLocation()const
        QUrl cppResult = const_cast<const ::QMediaRecorder *>(cppSelf)->actualLocation();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMediaRecorderFunc_addMetaData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaRecorder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMediaRecorder::addMetaData(QMediaMetaData)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaMetaData_IDX]), (pyArg)))) {
        overloadId = 0; // addMetaData(QMediaMetaData)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addMetaData", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMediaMetaData cppArg0_local;
        ::QMediaMetaData *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // addMetaData(QMediaMetaData)
            cppSelf->addMetaData(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QMediaRecorderFunc_audioBitRate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaRecorder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // audioBitRate()const
        int cppResult = const_cast<const ::QMediaRecorder *>(cppSelf)->audioBitRate();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMediaRecorderFunc_audioChannelCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaRecorder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // audioChannelCount()const
        int cppResult = const_cast<const ::QMediaRecorder *>(cppSelf)->audioChannelCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMediaRecorderFunc_audioSampleRate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaRecorder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // audioSampleRate()const
        int cppResult = const_cast<const ::QMediaRecorder *>(cppSelf)->audioSampleRate();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMediaRecorderFunc_autoStop(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaRecorder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // autoStop()const
        bool cppResult = const_cast<const ::QMediaRecorder *>(cppSelf)->autoStop();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMediaRecorderFunc_captureSession(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaRecorder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // captureSession()const
        QMediaCaptureSession * cppResult = const_cast<const ::QMediaRecorder *>(cppSelf)->captureSession();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaCaptureSession_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMediaRecorderFunc_duration(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaRecorder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // duration()const
        qint64 cppResult = const_cast<const ::QMediaRecorder *>(cppSelf)->duration();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMediaRecorderFunc_encodingMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaRecorder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // encodingMode()const
        QMediaRecorder::EncodingMode cppResult = const_cast<const ::QMediaRecorder *>(cppSelf)->encodingMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_EncodingMode_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMediaRecorderFunc_error(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaRecorder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // error()const
        QMediaRecorder::Error cppResult = const_cast<const ::QMediaRecorder *>(cppSelf)->error();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_Error_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMediaRecorderFunc_errorString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaRecorder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // errorString()const
        QString cppResult = const_cast<const ::QMediaRecorder *>(cppSelf)->errorString();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMediaRecorderFunc_isAvailable(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaRecorder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isAvailable()const
        bool cppResult = const_cast<const ::QMediaRecorder *>(cppSelf)->isAvailable();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMediaRecorderFunc_mediaFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaRecorder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // mediaFormat()const
        QMediaFormat cppResult = const_cast<const ::QMediaRecorder *>(cppSelf)->mediaFormat();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMediaRecorderFunc_metaData(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaRecorder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // metaData()const
        QMediaMetaData cppResult = const_cast<const ::QMediaRecorder *>(cppSelf)->metaData();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaMetaData_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMediaRecorderFunc_outputDevice(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaRecorder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // outputDevice()const
        QIODevice * cppResult = const_cast<const ::QMediaRecorder *>(cppSelf)->outputDevice();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMediaRecorderFunc_outputLocation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaRecorder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // outputLocation()const
        QUrl cppResult = const_cast<const ::QMediaRecorder *>(cppSelf)->outputLocation();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMediaRecorderFunc_pause(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaRecorder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pause()
        cppSelf->pause();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QMediaRecorderFunc_quality(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaRecorder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // quality()const
        QMediaRecorder::Quality cppResult = const_cast<const ::QMediaRecorder *>(cppSelf)->quality();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_Quality_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMediaRecorderFunc_record(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaRecorder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // record()
        cppSelf->record();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QMediaRecorderFunc_recorderState(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaRecorder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // recorderState()const
        QMediaRecorder::RecorderState cppResult = const_cast<const ::QMediaRecorder *>(cppSelf)->recorderState();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_RecorderState_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMediaRecorderFunc_setAudioBitRate(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaRecorder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMediaRecorder::setAudioBitRate(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setAudioBitRate(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAudioBitRate", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAudioBitRate(int)
            cppSelf->setAudioBitRate(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QMediaRecorderFunc_setAudioChannelCount(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaRecorder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMediaRecorder::setAudioChannelCount(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setAudioChannelCount(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAudioChannelCount", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAudioChannelCount(int)
            cppSelf->setAudioChannelCount(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QMediaRecorderFunc_setAudioSampleRate(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaRecorder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMediaRecorder::setAudioSampleRate(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setAudioSampleRate(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAudioSampleRate", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAudioSampleRate(int)
            cppSelf->setAudioSampleRate(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QMediaRecorderFunc_setAutoStop(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaRecorder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMediaRecorder::setAutoStop(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAutoStop(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAutoStop", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAutoStop(bool)
            cppSelf->setAutoStop(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QMediaRecorderFunc_setEncodingMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaRecorder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMediaRecorder::setEncodingMode(QMediaRecorder::EncodingMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_EncodingMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setEncodingMode(QMediaRecorder::EncodingMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setEncodingMode", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]);

    // Call function/method
    {
        ::QMediaRecorder::EncodingMode cppArg0{QMediaRecorder::ConstantQualityEncoding};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setEncodingMode(QMediaRecorder::EncodingMode)
            cppSelf->setEncodingMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QMediaRecorderFunc_setMediaFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaRecorder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMediaRecorder::setMediaFormat(QMediaFormat)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaFormat_IDX]), (pyArg)))) {
        overloadId = 0; // setMediaFormat(QMediaFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMediaFormat", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMediaFormat cppArg0_local;
        ::QMediaFormat *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setMediaFormat(QMediaFormat)
            cppSelf->setMediaFormat(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QMediaRecorderFunc_setMetaData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaRecorder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMediaRecorder::setMetaData(QMediaMetaData)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaMetaData_IDX]), (pyArg)))) {
        overloadId = 0; // setMetaData(QMediaMetaData)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMetaData", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMediaMetaData cppArg0_local;
        ::QMediaMetaData *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setMetaData(QMediaMetaData)
            cppSelf->setMetaData(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QMediaRecorderFunc_setOutputDevice(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaRecorder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMediaRecorder::setOutputDevice(QIODevice*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), (pyArg)))) {
        overloadId = 0; // setOutputDevice(QIODevice*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOutputDevice", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QIODevice *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOutputDevice(QIODevice*)
            cppSelf->setOutputDevice(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QMediaRecorderFunc_setOutputLocation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaRecorder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMediaRecorder::setOutputLocation(QUrl)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // setOutputLocation(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOutputLocation", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setOutputLocation(QUrl)
            cppSelf->setOutputLocation(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QMediaRecorderFunc_setQuality(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaRecorder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMediaRecorder::setQuality(QMediaRecorder::Quality)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_Quality_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setQuality(QMediaRecorder::Quality)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setQuality", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]);

    // Call function/method
    {
        ::QMediaRecorder::Quality cppArg0{QMediaRecorder::VeryLowQuality};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setQuality(QMediaRecorder::Quality)
            cppSelf->setQuality(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QMediaRecorderFunc_setVideoBitRate(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaRecorder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMediaRecorder::setVideoBitRate(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setVideoBitRate(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setVideoBitRate", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setVideoBitRate(int)
            cppSelf->setVideoBitRate(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QMediaRecorderFunc_setVideoFrameRate(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaRecorder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMediaRecorder::setVideoFrameRate(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setVideoFrameRate(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setVideoFrameRate", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setVideoFrameRate(qreal)
            cppSelf->setVideoFrameRate(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QMediaRecorderFunc_setVideoResolution(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaRecorder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setVideoResolution", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMediaRecorder::setVideoResolution(QSize)
    // 1: QMediaRecorder::setVideoResolution(int,int)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 1; // setVideoResolution(int,int)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArgs[0])))) {
        overloadId = 0; // setVideoResolution(QSize)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setVideoResolution", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setVideoResolution(const QSize &arg__1)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QSize cppArg0_local;
            ::QSize *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setVideoResolution(QSize)
                cppSelf->setVideoResolution(*cppArg0);
            }
            break;
        }
        case 1: // setVideoResolution(int width, int height)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setVideoResolution(int,int)
                cppSelf->setVideoResolution(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QMediaRecorderFunc_stop(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaRecorder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // stop()
        cppSelf->stop();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QMediaRecorderFunc_videoBitRate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaRecorder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // videoBitRate()const
        int cppResult = const_cast<const ::QMediaRecorder *>(cppSelf)->videoBitRate();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMediaRecorderFunc_videoFrameRate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaRecorder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // videoFrameRate()const
        qreal cppResult = const_cast<const ::QMediaRecorder *>(cppSelf)->videoFrameRate();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMediaRecorderFunc_videoResolution(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaRecorder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // videoResolution()const
        QSize cppResult = const_cast<const ::QMediaRecorder *>(cppSelf)->videoResolution();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QMediaRecorder_PropertyStrings[] = {
    "actualLocation:",
    "audioBitRate::",
    "audioChannelCount::",
    "audioSampleRate::",
    "autoStop::",
    "duration:",
    "encodingMode::",
    "error:",
    "errorString:",
    "mediaFormat::",
    "metaData::",
    "outputLocation::",
    "quality::",
    "recorderState:",
    "videoBitRate::",
    "videoFrameRate::",
    "videoResolution::",
    nullptr // Sentinel
};

static const char *Sbk_QMediaRecorder_EnumFlagInfo[] = {
    "EncodingMode:Enum",
    "Error:Enum",
    "Quality:Enum",
    "RecorderState:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QMediaRecorder_methods[] = {
    {"actualLocation", reinterpret_cast<PyCFunction>(Sbk_QMediaRecorderFunc_actualLocation), METH_NOARGS, nullptr},
    {"addMetaData", reinterpret_cast<PyCFunction>(Sbk_QMediaRecorderFunc_addMetaData), METH_O, nullptr},
    {"audioBitRate", reinterpret_cast<PyCFunction>(Sbk_QMediaRecorderFunc_audioBitRate), METH_NOARGS, nullptr},
    {"audioChannelCount", reinterpret_cast<PyCFunction>(Sbk_QMediaRecorderFunc_audioChannelCount), METH_NOARGS, nullptr},
    {"audioSampleRate", reinterpret_cast<PyCFunction>(Sbk_QMediaRecorderFunc_audioSampleRate), METH_NOARGS, nullptr},
    {"autoStop", reinterpret_cast<PyCFunction>(Sbk_QMediaRecorderFunc_autoStop), METH_NOARGS, nullptr},
    {"captureSession", reinterpret_cast<PyCFunction>(Sbk_QMediaRecorderFunc_captureSession), METH_NOARGS, nullptr},
    {"duration", reinterpret_cast<PyCFunction>(Sbk_QMediaRecorderFunc_duration), METH_NOARGS, nullptr},
    {"encodingMode", reinterpret_cast<PyCFunction>(Sbk_QMediaRecorderFunc_encodingMode), METH_NOARGS, nullptr},
    {"error", reinterpret_cast<PyCFunction>(Sbk_QMediaRecorderFunc_error), METH_NOARGS, nullptr},
    {"errorString", reinterpret_cast<PyCFunction>(Sbk_QMediaRecorderFunc_errorString), METH_NOARGS, nullptr},
    {"isAvailable", reinterpret_cast<PyCFunction>(Sbk_QMediaRecorderFunc_isAvailable), METH_NOARGS, nullptr},
    {"mediaFormat", reinterpret_cast<PyCFunction>(Sbk_QMediaRecorderFunc_mediaFormat), METH_NOARGS, nullptr},
    {"metaData", reinterpret_cast<PyCFunction>(Sbk_QMediaRecorderFunc_metaData), METH_NOARGS, nullptr},
    {"outputDevice", reinterpret_cast<PyCFunction>(Sbk_QMediaRecorderFunc_outputDevice), METH_NOARGS, nullptr},
    {"outputLocation", reinterpret_cast<PyCFunction>(Sbk_QMediaRecorderFunc_outputLocation), METH_NOARGS, nullptr},
    {"pause", reinterpret_cast<PyCFunction>(Sbk_QMediaRecorderFunc_pause), METH_NOARGS, nullptr},
    {"quality", reinterpret_cast<PyCFunction>(Sbk_QMediaRecorderFunc_quality), METH_NOARGS, nullptr},
    {"record", reinterpret_cast<PyCFunction>(Sbk_QMediaRecorderFunc_record), METH_NOARGS, nullptr},
    {"recorderState", reinterpret_cast<PyCFunction>(Sbk_QMediaRecorderFunc_recorderState), METH_NOARGS, nullptr},
    {"setAudioBitRate", reinterpret_cast<PyCFunction>(Sbk_QMediaRecorderFunc_setAudioBitRate), METH_O, nullptr},
    {"setAudioChannelCount", reinterpret_cast<PyCFunction>(Sbk_QMediaRecorderFunc_setAudioChannelCount), METH_O, nullptr},
    {"setAudioSampleRate", reinterpret_cast<PyCFunction>(Sbk_QMediaRecorderFunc_setAudioSampleRate), METH_O, nullptr},
    {"setAutoStop", reinterpret_cast<PyCFunction>(Sbk_QMediaRecorderFunc_setAutoStop), METH_O, nullptr},
    {"setEncodingMode", reinterpret_cast<PyCFunction>(Sbk_QMediaRecorderFunc_setEncodingMode), METH_O, nullptr},
    {"setMediaFormat", reinterpret_cast<PyCFunction>(Sbk_QMediaRecorderFunc_setMediaFormat), METH_O, nullptr},
    {"setMetaData", reinterpret_cast<PyCFunction>(Sbk_QMediaRecorderFunc_setMetaData), METH_O, nullptr},
    {"setOutputDevice", reinterpret_cast<PyCFunction>(Sbk_QMediaRecorderFunc_setOutputDevice), METH_O, nullptr},
    {"setOutputLocation", reinterpret_cast<PyCFunction>(Sbk_QMediaRecorderFunc_setOutputLocation), METH_O, nullptr},
    {"setQuality", reinterpret_cast<PyCFunction>(Sbk_QMediaRecorderFunc_setQuality), METH_O, nullptr},
    {"setVideoBitRate", reinterpret_cast<PyCFunction>(Sbk_QMediaRecorderFunc_setVideoBitRate), METH_O, nullptr},
    {"setVideoFrameRate", reinterpret_cast<PyCFunction>(Sbk_QMediaRecorderFunc_setVideoFrameRate), METH_O, nullptr},
    {"setVideoResolution", reinterpret_cast<PyCFunction>(Sbk_QMediaRecorderFunc_setVideoResolution), METH_VARARGS, nullptr},
    {"stop", reinterpret_cast<PyCFunction>(Sbk_QMediaRecorderFunc_stop), METH_NOARGS, nullptr},
    {"videoBitRate", reinterpret_cast<PyCFunction>(Sbk_QMediaRecorderFunc_videoBitRate), METH_NOARGS, nullptr},
    {"videoFrameRate", reinterpret_cast<PyCFunction>(Sbk_QMediaRecorderFunc_videoFrameRate), METH_NOARGS, nullptr},
    {"videoResolution", reinterpret_cast<PyCFunction>(Sbk_QMediaRecorderFunc_videoResolution), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QMediaRecorder_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QMediaRecorder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QMediaRecorderWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QMediaRecorder_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QMediaRecorder_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QMediaRecorder_Type = nullptr;
static PyTypeObject *Sbk_QMediaRecorder_TypeF(void)
{
    return _Sbk_QMediaRecorder_Type;
}

static PyType_Slot Sbk_QMediaRecorder_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QMediaRecorder_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QMediaRecorder_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QMediaRecorder_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QMediaRecorder_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QMediaRecorder_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QMediaRecorder_spec = {
    "2:PySide6.QtMultimedia.QMediaRecorder",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QMediaRecorder_slots
};

} //extern "C"

static void *Sbk_QMediaRecorder_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QMediaRecorder *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QMediaRecorder_Quality(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QMediaRecorder::Quality>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QMediaRecorder::Quality *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QMediaRecorder_Quality_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_Quality_IDX])))
        return Enum_PythonToCpp_QMediaRecorder_Quality;
    return {};
}

static PyObject *QMediaRecorder_Quality_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QMediaRecorder::Quality>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QMediaRecorder::Quality *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_Quality_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QMediaRecorder_EncodingMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QMediaRecorder::EncodingMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QMediaRecorder::EncodingMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QMediaRecorder_EncodingMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_EncodingMode_IDX])))
        return Enum_PythonToCpp_QMediaRecorder_EncodingMode;
    return {};
}

static PyObject *QMediaRecorder_EncodingMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QMediaRecorder::EncodingMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QMediaRecorder::EncodingMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_EncodingMode_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QMediaRecorder_RecorderState(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QMediaRecorder::RecorderState>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QMediaRecorder::RecorderState *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QMediaRecorder_RecorderState_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_RecorderState_IDX])))
        return Enum_PythonToCpp_QMediaRecorder_RecorderState;
    return {};
}

static PyObject *QMediaRecorder_RecorderState_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QMediaRecorder::RecorderState>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QMediaRecorder::RecorderState *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_RecorderState_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QMediaRecorder_Error(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QMediaRecorder::Error>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QMediaRecorder::Error *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QMediaRecorder_Error_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_Error_IDX])))
        return Enum_PythonToCpp_QMediaRecorder_Error;
    return {};
}

static PyObject *QMediaRecorder_Error_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QMediaRecorder::Error>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QMediaRecorder::Error *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_Error_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QMediaRecorder_PythonToCpp_QMediaRecorder_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QMediaRecorder_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QMediaRecorder_PythonToCpp_QMediaRecorder_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QMediaRecorder_TypeF()))
        return QMediaRecorder_PythonToCpp_QMediaRecorder_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QMediaRecorder_PTR_CppToPython_QMediaRecorder(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QMediaRecorder *>(const_cast<void *>(cppIn)), Sbk_QMediaRecorder_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QMediaRecorder_SignatureStrings[] = {
    "PySide6.QtMultimedia.QMediaRecorder(self,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,recorderState:QMediaRecorder.RecorderState=None,duration:qint64=None,outputLocation:QUrl=None,actualLocation:QUrl=None,metaData:QMediaMetaData=None,error:QMediaRecorder.Error=None,errorString:QString=None,mediaFormat:QMediaFormat=None,quality:QMediaRecorder.Quality=None,encodingMode:QMediaRecorder.EncodingMode=None,videoResolution:QSize=None,videoFrameRate:qreal=None,videoBitRate:int=None,audioBitRate:int=None,audioChannelCount:int=None,audioSampleRate:int=None,autoStop:bool=None)",
    "PySide6.QtMultimedia.QMediaRecorder.actualLocation(self)->PySide6.QtCore.QUrl",
    "PySide6.QtMultimedia.QMediaRecorder.addMetaData(self,metaData:PySide6.QtMultimedia.QMediaMetaData)",
    "PySide6.QtMultimedia.QMediaRecorder.audioBitRate(self)->int",
    "PySide6.QtMultimedia.QMediaRecorder.audioChannelCount(self)->int",
    "PySide6.QtMultimedia.QMediaRecorder.audioSampleRate(self)->int",
    "PySide6.QtMultimedia.QMediaRecorder.autoStop(self)->bool",
    "PySide6.QtMultimedia.QMediaRecorder.captureSession(self)->PySide6.QtMultimedia.QMediaCaptureSession",
    "PySide6.QtMultimedia.QMediaRecorder.duration(self)->qint64",
    "PySide6.QtMultimedia.QMediaRecorder.encodingMode(self)->PySide6.QtMultimedia.QMediaRecorder.EncodingMode",
    "PySide6.QtMultimedia.QMediaRecorder.error(self)->PySide6.QtMultimedia.QMediaRecorder.Error",
    "PySide6.QtMultimedia.QMediaRecorder.errorString(self)->QString",
    "PySide6.QtMultimedia.QMediaRecorder.isAvailable(self)->bool",
    "PySide6.QtMultimedia.QMediaRecorder.mediaFormat(self)->PySide6.QtMultimedia.QMediaFormat",
    "PySide6.QtMultimedia.QMediaRecorder.metaData(self)->PySide6.QtMultimedia.QMediaMetaData",
    "PySide6.QtMultimedia.QMediaRecorder.outputDevice(self)->PySide6.QtCore.QIODevice",
    "PySide6.QtMultimedia.QMediaRecorder.outputLocation(self)->PySide6.QtCore.QUrl",
    "PySide6.QtMultimedia.QMediaRecorder.pause(self)",
    "PySide6.QtMultimedia.QMediaRecorder.quality(self)->PySide6.QtMultimedia.QMediaRecorder.Quality",
    "PySide6.QtMultimedia.QMediaRecorder.record(self)",
    "PySide6.QtMultimedia.QMediaRecorder.recorderState(self)->PySide6.QtMultimedia.QMediaRecorder.RecorderState",
    "PySide6.QtMultimedia.QMediaRecorder.setAudioBitRate(self,bitRate:int)",
    "PySide6.QtMultimedia.QMediaRecorder.setAudioChannelCount(self,channels:int)",
    "PySide6.QtMultimedia.QMediaRecorder.setAudioSampleRate(self,sampleRate:int)",
    "PySide6.QtMultimedia.QMediaRecorder.setAutoStop(self,autoStop:bool)",
    "PySide6.QtMultimedia.QMediaRecorder.setEncodingMode(self,arg__1:PySide6.QtMultimedia.QMediaRecorder.EncodingMode)",
    "PySide6.QtMultimedia.QMediaRecorder.setMediaFormat(self,format:typing.Union[PySide6.QtMultimedia.QMediaFormat, PySide6.QtMultimedia.QMediaFormat.FileFormat])",
    "PySide6.QtMultimedia.QMediaRecorder.setMetaData(self,metaData:PySide6.QtMultimedia.QMediaMetaData)",
    "PySide6.QtMultimedia.QMediaRecorder.setOutputDevice(self,device:PySide6.QtCore.QIODevice)",
    "PySide6.QtMultimedia.QMediaRecorder.setOutputLocation(self,location:typing.Union[PySide6.QtCore.QUrl, QString])",
    "PySide6.QtMultimedia.QMediaRecorder.setQuality(self,quality:PySide6.QtMultimedia.QMediaRecorder.Quality)",
    "PySide6.QtMultimedia.QMediaRecorder.setVideoBitRate(self,bitRate:int)",
    "PySide6.QtMultimedia.QMediaRecorder.setVideoFrameRate(self,frameRate:qreal)",
    "1:PySide6.QtMultimedia.QMediaRecorder.setVideoResolution(self,arg__1:PySide6.QtCore.QSize)",
    "0:PySide6.QtMultimedia.QMediaRecorder.setVideoResolution(self,width:int,height:int)",
    "PySide6.QtMultimedia.QMediaRecorder.stop(self)",
    "PySide6.QtMultimedia.QMediaRecorder.videoBitRate(self)->int",
    "PySide6.QtMultimedia.QMediaRecorder.videoFrameRate(self)->qreal",
    "PySide6.QtMultimedia.QMediaRecorder.videoResolution(self)->PySide6.QtCore.QSize",
    nullptr}; // Sentinel
#else
static constexpr size_t QMediaRecorder_SignatureByteSize = 688;
static constexpr uint8_t QMediaRecorder_SignatureBytes[688] = {
    0x78, 0xda, 0xb5, 0x56, 0x51, 0x8f, 0xda, 0x30, 0x0c, 0x7e, 0xe7, 0x57, 0xdc, 0xe3, 0x98, 0xb2,
    0x6a, 0x93, 0xa6, 0x7b, 0xa8, 0x74, 0x93, 0x6e, 0x1c, 0x48, 0xd3, 0xc6, 0xa0, 0x54, 0x77, 0x2f,
    0xd3, 0x74, 0x0a, 0xad, 0x0f, 0x32, 0x85, 0xa6, 0xa4, 0x2e, 0x27, 0xf6, 0xeb, 0xd7, 0xe2, 0x14,
    0xd2, 0x02, 0x47, 0x72, 0xdb, 0x9e, 0x28, 0xb1, 0xfd, 0xd9, 0xb1, 0xe3, 0xcf, 0x9e, 0x6e, 0x63,
    0x91, 0xc2, 0x75, 0x10, 0xe1, 0xb8, 0x94, 0x28, 0x56, 0x90, 0x0a, 0x1e, 0x44, 0xe3, 0xfa, 0x67,
    0x06, 0x89, 0xd2, 0x29, 0xe8, 0x37, 0x05, 0xc8, 0x27, 0x96, 0x73, 0x0d, 0x19, 0x86, 0xd3, 0xbd,
    0xfe, 0x40, 0x69, 0x08, 0xa2, 0xc9, 0xfc, 0x17, 0x24, 0x78, 0x93, 0x95, 0x52, 0xe6, 0xa8, 0xd9,
    0xdb, 0xf0, 0x2b, 0x6c, 0x9f, 0x2b, 0xb3, 0x49, 0x26, 0xb7, 0x37, 0xdf, 0x55, 0x06, 0x4c, 0x1b,
    0x98, 0x18, 0x39, 0x42, 0xd8, 0x86, 0x0e, 0x66, 0xb6, 0x90, 0xf4, 0xd3, 0x52, 0x73, 0x14, 0x2a,
    0x0b, 0xd7, 0x22, 0xc3, 0xeb, 0x8f, 0x74, 0xa8, 0x4a, 0xcc, 0x4b, 0xfc, 0xa6, 0x12, 0x12, 0x45,
    0xf7, 0x5a, 0x92, 0x80, 0x27, 0x58, 0x72, 0x79, 0x42, 0xb0, 0x02, 0xe4, 0x77, 0x1c, 0xb9, 0xf1,
    0x38, 0x36, 0x7f, 0x49, 0x08, 0x5a, 0x2b, 0xdd, 0x8d, 0x65, 0x58, 0x1f, 0x5a, 0xf2, 0x18, 0xb5,
    0xc8, 0x16, 0x61, 0x44, 0xbf, 0x0d, 0x6a, 0x65, 0x31, 0x52, 0x7a, 0xc5, 0xd1, 0x98, 0xd3, 0x1f,
    0x92, 0xae, 0xab, 0x50, 0x04, 0x6e, 0xbb, 0xc0, 0x11, 0x1d, 0x1b, 0xe8, 0x2c, 0x51, 0x69, 0x85,
    0x37, 0x56, 0xe9, 0x51, 0x36, 0x86, 0x96, 0x8c, 0xb4, 0x37, 0x55, 0xb2, 0xd5, 0x0c, 0x0a, 0x25,
    0x4b, 0xba, 0x5f, 0x2c, 0x7e, 0xdb, 0xa2, 0x91, 0xe6, 0x2b, 0x98, 0xd5, 0x89, 0x5d, 0x6b, 0xe0,
    0xd2, 0x92, 0x7c, 0x16, 0xb8, 0x3b, 0xaf, 0x92, 0x68, 0x32, 0x55, 0xa6, 0xe2, 0xcc, 0xe9, 0x60,
    0xc9, 0xb3, 0x0c, 0xe4, 0x40, 0x95, 0x55, 0x85, 0xdb, 0xa2, 0x98, 0xaf, 0x72, 0x09, 0x5d, 0x1b,
    0x54, 0x31, 0xaa, 0x3c, 0x9c, 0x2b, 0x45, 0x2e, 0xfb, 0xbd, 0xe9, 0xe5, 0x77, 0x14, 0xb4, 0x6b,
    0xb5, 0x7b, 0x56, 0xfd, 0x77, 0x9f, 0xba, 0x2f, 0xaa, 0xaa, 0xa0, 0x1b, 0x5a, 0x9a, 0x36, 0x45,
    0xa5, 0x17, 0xba, 0xaf, 0xf8, 0x0b, 0xd6, 0x8d, 0x85, 0x63, 0xc0, 0x56, 0xca, 0x9a, 0x70, 0xab,
    0x2c, 0xb8, 0xdb, 0xda, 0x89, 0x7d, 0x15, 0xc0, 0x21, 0xfd, 0xfe, 0xe6, 0x54, 0xa4, 0xc6, 0xae,
    0xae, 0x95, 0x93, 0x61, 0xc2, 0x73, 0x2c, 0x35, 0xc4, 0x50, 0x14, 0x27, 0xab, 0x74, 0x64, 0x39,
    0x68, 0x19, 0x38, 0xf9, 0x68, 0x7a, 0xbc, 0x41, 0xa7, 0x56, 0x77, 0x32, 0xb5, 0xfb, 0xc7, 0x21,
    0xb8, 0x93, 0xbd, 0xe5, 0xe6, 0xa8, 0xe6, 0x00, 0x2f, 0x0f, 0xb5, 0x81, 0x3b, 0x34, 0xd1, 0x4a,
    0xe3, 0xc0, 0xb0, 0x8c, 0x93, 0xb9, 0x28, 0x6e, 0x37, 0x5c, 0x48, 0x3e, 0x97, 0xe0, 0x5d, 0x5d,
    0x8b, 0xc0, 0x1c, 0xee, 0x46, 0x8a, 0x8e, 0xc0, 0x56, 0x2f, 0xbe, 0x8c, 0xda, 0x34, 0xa1, 0x13,
    0x2e, 0x31, 0xff, 0x1d, 0x6c, 0x44, 0x02, 0xe7, 0x28, 0xe3, 0xcb, 0x84, 0xe4, 0x1e, 0x80, 0xff,
    0x8a, 0x85, 0x72, 0x5e, 0x16, 0x26, 0x2e, 0x27, 0x7d, 0x33, 0x22, 0x7c, 0xde, 0x95, 0x19, 0x1f,
    0x4e, 0xf0, 0x34, 0x6c, 0x3d, 0xe2, 0x69, 0x4d, 0x67, 0x9f, 0xa8, 0x5a, 0x93, 0xdb, 0xc9, 0x55,
    0x01, 0x78, 0xdb, 0x25, 0x54, 0x36, 0x3f, 0x0c, 0xa4, 0xbe, 0x17, 0xca, 0x11, 0xb5, 0xb2, 0x84,
    0x4e, 0x0a, 0x7f, 0xac, 0x0e, 0xcb, 0xb2, 0xa2, 0x35, 0xf4, 0x3c, 0xb0, 0x2c, 0xca, 0x6d, 0x4f,
    0x49, 0x67, 0x8c, 0x61, 0x97, 0xde, 0x18, 0xd7, 0x8b, 0xc7, 0xc7, 0x0f, 0xa1, 0x2f, 0xc7, 0x39,
    0x7b, 0x1c, 0x77, 0x18, 0x81, 0x3d, 0xd1, 0x7a, 0x83, 0xdb, 0xbc, 0x82, 0x0a, 0xee, 0xb3, 0xaa,
    0x4b, 0x7e, 0x5c, 0xe4, 0x08, 0x76, 0x75, 0x51, 0x25, 0x18, 0x09, 0x09, 0xf4, 0xf9, 0xd3, 0x23,
    0xba, 0xff, 0x3b, 0xe2, 0x2b, 0x17, 0x93, 0x2e, 0xc3, 0xb0, 0x74, 0xf7, 0x1d, 0x9e, 0xa3, 0x19,
    0x4f, 0xe4, 0x16, 0xd5, 0x30, 0xd9, 0xac, 0xaa, 0x67, 0xf2, 0xbb, 0xa7, 0x1f, 0x76, 0x65, 0x66,
    0x82, 0x7b, 0xb2, 0x22, 0x8b, 0x5c, 0xf6, 0xcb, 0xa8, 0x07, 0xc5, 0x38, 0x3b, 0x7a, 0xb0, 0x36,
    0xcc, 0xd7, 0xf7, 0xf1, 0x43, 0x6b, 0x83, 0x35, 0x8f, 0xaf, 0xbd, 0xd0, 0xf6, 0x7b, 0x6e, 0x2f,
    0xbf, 0x41, 0x3b, 0xac, 0xca, 0x67, 0x9a, 0x87, 0xd2, 0x5b, 0x6f, 0xd1, 0xfd, 0xde, 0xfb, 0xbf,
    0x82, 0x7e, 0x16, 0x29, 0x2e, 0xeb, 0xfb, 0xb2, 0x25, 0x88, 0xc5, 0x12, 0x3d, 0xae, 0xbe, 0x5f,
    0xcb, 0x9c, 0xd4, 0x37, 0xdd, 0x64, 0x7b, 0x6c, 0x81, 0x9b, 0xe3, 0x14, 0xd7, 0xeb, 0x56, 0x9d,
    0x5a, 0x77, 0xfb, 0xce, 0xcd, 0x4f, 0x4c, 0xcb, 0x3a, 0x9f, 0xbd, 0x3f, 0x3f, 0x22, 0x40, 0xbf
};
#endif

PyTypeObject *init_QMediaRecorder(PyObject *module)
{
    if (SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX].type != nullptr)
        return SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX].type;

    Shiboken::AutoDecRef Sbk_QMediaRecorder_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QMediaRecorder_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QMediaRecorder",
        "QMediaRecorder*",
        &Sbk_QMediaRecorder_spec,
        &Shiboken::callCppDestructor< QMediaRecorder >,
        Sbk_QMediaRecorder_Type_bases.object(),
        0);
    auto *pyType = Sbk_QMediaRecorder_TypeF(); // references _Sbk_QMediaRecorder_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QMediaRecorder_SignatureStrings);
#else
    InitSignatureBytes(pyType, QMediaRecorder_SignatureBytes, QMediaRecorder_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QMediaRecorder_PropertyStrings);
    SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QMediaRecorder_PythonToCpp_QMediaRecorder_PTR,
        is_QMediaRecorder_PythonToCpp_QMediaRecorder_PTR_Convertible,
        QMediaRecorder_PTR_CppToPython_QMediaRecorder);

    Shiboken::Conversions::registerConverterName(converter, "QMediaRecorder");
    Shiboken::Conversions::registerConverterName(converter, "QMediaRecorder*");
    Shiboken::Conversions::registerConverterName(converter, "QMediaRecorder&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QMediaRecorder).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QMediaRecorderWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QMediaRecorder_TypeF(), &Sbk_QMediaRecorder_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QMediaRecorder_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Quality'.
    const char *Quality_Initializer[] = {
        "VeryLowQuality",
        "LowQuality",
        "NormalQuality",
        "HighQuality",
        "VeryHighQuality",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Quality_InitializerValues[] = {
        uint8_t(QMediaRecorder::Quality::VeryLowQuality), //  0x00  0
        uint8_t(QMediaRecorder::Quality::LowQuality),     //  0x01  1
        uint8_t(QMediaRecorder::Quality::NormalQuality),  //  0x02  2
        uint8_t(QMediaRecorder::Quality::HighQuality),    //  0x03  3
        uint8_t(QMediaRecorder::Quality::VeryHighQuality) //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QMediaRecorder_TypeF(),
        "2:PySide6.QtMultimedia.QMediaRecorder.Quality",
        Quality_Initializer, Quality_InitializerValues);
    SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_Quality_IDX].type = EType;
    // Register converter for enum 'QMediaRecorder::Quality'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QMediaRecorder_Quality_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QMediaRecorder_Quality,
            is_Enum_PythonToCpp_QMediaRecorder_Quality_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QMediaRecorder::Quality");
        Shiboken::Conversions::registerConverterAlias(converter, "Quality");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Quality' enum.

    // Initialization of enum 'EncodingMode'.
    const char *EncodingMode_Initializer[] = {
        "ConstantQualityEncoding",
        "ConstantBitRateEncoding",
        "AverageBitRateEncoding",
        "TwoPassEncoding",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t EncodingMode_InitializerValues[] = {
        uint8_t(QMediaRecorder::EncodingMode::ConstantQualityEncoding), //  0x00  0
        uint8_t(QMediaRecorder::EncodingMode::ConstantBitRateEncoding), //  0x01  1
        uint8_t(QMediaRecorder::EncodingMode::AverageBitRateEncoding),  //  0x02  2
        uint8_t(QMediaRecorder::EncodingMode::TwoPassEncoding)          //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QMediaRecorder_TypeF(),
        "2:PySide6.QtMultimedia.QMediaRecorder.EncodingMode",
        EncodingMode_Initializer, EncodingMode_InitializerValues);
    SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_EncodingMode_IDX].type = EType;
    // Register converter for enum 'QMediaRecorder::EncodingMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QMediaRecorder_EncodingMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QMediaRecorder_EncodingMode,
            is_Enum_PythonToCpp_QMediaRecorder_EncodingMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QMediaRecorder::EncodingMode");
        Shiboken::Conversions::registerConverterAlias(converter, "EncodingMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'EncodingMode' enum.

    // Initialization of enum 'RecorderState'.
    const char *RecorderState_Initializer[] = {
        "StoppedState",
        "RecordingState",
        "PausedState",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t RecorderState_InitializerValues[] = {
        uint8_t(QMediaRecorder::RecorderState::StoppedState),   //  0x00  0
        uint8_t(QMediaRecorder::RecorderState::RecordingState), //  0x01  1
        uint8_t(QMediaRecorder::RecorderState::PausedState)     //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QMediaRecorder_TypeF(),
        "2:PySide6.QtMultimedia.QMediaRecorder.RecorderState",
        RecorderState_Initializer, RecorderState_InitializerValues);
    SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_RecorderState_IDX].type = EType;
    // Register converter for enum 'QMediaRecorder::RecorderState'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QMediaRecorder_RecorderState_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QMediaRecorder_RecorderState,
            is_Enum_PythonToCpp_QMediaRecorder_RecorderState_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QMediaRecorder::RecorderState");
        Shiboken::Conversions::registerConverterAlias(converter, "RecorderState");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'RecorderState' enum.

    // Initialization of enum 'Error'.
    const char *Error_Initializer[] = {
        "NoError",
        "ResourceError",
        "FormatError",
        "OutOfSpaceError",
        "LocationNotWritable",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Error_InitializerValues[] = {
        uint8_t(QMediaRecorder::Error::NoError),            //  0x00  0
        uint8_t(QMediaRecorder::Error::ResourceError),      //  0x01  1
        uint8_t(QMediaRecorder::Error::FormatError),        //  0x02  2
        uint8_t(QMediaRecorder::Error::OutOfSpaceError),    //  0x03  3
        uint8_t(QMediaRecorder::Error::LocationNotWritable) //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QMediaRecorder_TypeF(),
        "2:PySide6.QtMultimedia.QMediaRecorder.Error",
        Error_Initializer, Error_InitializerValues);
    SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaRecorder_Error_IDX].type = EType;
    // Register converter for enum 'QMediaRecorder::Error'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QMediaRecorder_Error_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QMediaRecorder_Error,
            is_Enum_PythonToCpp_QMediaRecorder_Error_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QMediaRecorder::Error");
        Shiboken::Conversions::registerConverterAlias(converter, "Error");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Error' enum.

    PySide::Signal::registerSignals(pyType, &::QMediaRecorder::staticMetaObject);
    qRegisterMetaType< ::QMediaRecorder::Quality >("QMediaRecorder::Quality");
    qRegisterMetaType< ::QMediaRecorder::EncodingMode >("QMediaRecorder::EncodingMode");
    qRegisterMetaType< ::QMediaRecorder::RecorderState >("QMediaRecorder::RecorderState");
    qRegisterMetaType< ::QMediaRecorder::Error >("QMediaRecorder::Error");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QMediaRecorder::staticMetaObject, sizeof(QMediaRecorderWrapper));

    return pyType;
}
