// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtmultimedia_python.h"

// main header
#include "qmediatimerange_interval_wrapper.h"

// Argument includes
#include <QtMultimedia/qmediatimerange.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QMediaTimeRange_Interval_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QMediaTimeRange::Interval >()))
        return -1;

    ::QMediaTimeRange::Interval *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "Interval", 0, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: Interval::Interval()
    // 1: Interval::Interval(QMediaTimeRange::Interval)
    // 2: Interval::Interval(qint64,qint64)
    if (numArgs == 0) {
        overloadId = 0; // Interval()
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[1])))) {
        overloadId = 2; // Interval(qint64,qint64)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaTimeRange_Interval_IDX]), (pyArgs[0])))) {
        overloadId = 1; // Interval(QMediaTimeRange::Interval)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaTimeRange_Interval_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaTimeRange_Interval_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // Interval()
        {

            // Interval()
            cptr = new ::QMediaTimeRange::Interval();
            break;
        }
        case 1: // Interval(const QMediaTimeRange::Interval &Interval)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QMediaTimeRange::Interval cppArg0_local;
            ::QMediaTimeRange::Interval *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // Interval(QMediaTimeRange::Interval)
                cptr = new ::QMediaTimeRange::Interval(*cppArg0);
            }
            break;
        }
        case 2: // Interval(qint64 start, qint64 end)
        {
            qint64 cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qint64 cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // Interval(qint64,qint64)
                cptr = new ::QMediaTimeRange::Interval(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QMediaTimeRange::Interval >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaTimeRange_Interval_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QMediaTimeRange_IntervalFunc_contains(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaTimeRange::Interval *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaTimeRange_Interval_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Interval::contains(qint64)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArg)))) {
        overloadId = 0; // contains(qint64)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "contains", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaTimeRange_Interval_IDX]);

    // Call function/method
    {
        qint64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // contains(qint64)const
            bool cppResult = const_cast<const ::QMediaTimeRange::Interval *>(cppSelf)->contains(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMediaTimeRange_IntervalFunc_end(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaTimeRange::Interval *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaTimeRange_Interval_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // end()const
        qint64 cppResult = const_cast<const ::QMediaTimeRange::Interval *>(cppSelf)->end();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMediaTimeRange_IntervalFunc_isNormal(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaTimeRange::Interval *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaTimeRange_Interval_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isNormal()const
        bool cppResult = const_cast<const ::QMediaTimeRange::Interval *>(cppSelf)->isNormal();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMediaTimeRange_IntervalFunc_normalized(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaTimeRange::Interval *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaTimeRange_Interval_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // normalized()const
        QMediaTimeRange::Interval cppResult = const_cast<const ::QMediaTimeRange::Interval *>(cppSelf)->normalized();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaTimeRange_Interval_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMediaTimeRange_IntervalFunc_start(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaTimeRange::Interval *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaTimeRange_Interval_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // start()const
        qint64 cppResult = const_cast<const ::QMediaTimeRange::Interval *>(cppSelf)->start();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMediaTimeRange_IntervalFunc_translated(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaTimeRange::Interval *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaTimeRange_Interval_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Interval::translated(qint64)const->QMediaTimeRange::Interval
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArg)))) {
        overloadId = 0; // translated(qint64)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "translated", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaTimeRange_Interval_IDX]);

    // Call function/method
    {
        qint64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // translated(qint64)const
            QMediaTimeRange::Interval cppResult = const_cast<const ::QMediaTimeRange::Interval *>(cppSelf)->translated(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaTimeRange_Interval_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMediaTimeRange_Interval__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QMediaTimeRange::Interval *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaTimeRange_Interval_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaTimeRange_Interval_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QMediaTimeRange_Interval_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QMediaTimeRange_Interval_methods[] = {
    {"contains", reinterpret_cast<PyCFunction>(Sbk_QMediaTimeRange_IntervalFunc_contains), METH_O, nullptr},
    {"end", reinterpret_cast<PyCFunction>(Sbk_QMediaTimeRange_IntervalFunc_end), METH_NOARGS, nullptr},
    {"isNormal", reinterpret_cast<PyCFunction>(Sbk_QMediaTimeRange_IntervalFunc_isNormal), METH_NOARGS, nullptr},
    {"normalized", reinterpret_cast<PyCFunction>(Sbk_QMediaTimeRange_IntervalFunc_normalized), METH_NOARGS, nullptr},
    {"start", reinterpret_cast<PyCFunction>(Sbk_QMediaTimeRange_IntervalFunc_start), METH_NOARGS, nullptr},
    {"translated", reinterpret_cast<PyCFunction>(Sbk_QMediaTimeRange_IntervalFunc_translated), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QMediaTimeRange_Interval__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QMediaTimeRange_Interval_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QMediaTimeRange::Interval *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaTimeRange_Interval_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaTimeRange_Interval_IDX]), (pyArg)))) {
                // operator!=(QMediaTimeRange::Interval rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QMediaTimeRange::Interval cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf != (cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaTimeRange_Interval_IDX]), (pyArg)))) {
                // operator==(QMediaTimeRange::Interval rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QMediaTimeRange::Interval cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf == (cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QMediaTimeRange_Interval_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QMediaTimeRange_Interval_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QMediaTimeRange_Interval__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMediaTimeRange::Interval *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaTimeRange_Interval_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QMediaTimeRange_Interval_Type = nullptr;
static PyTypeObject *Sbk_QMediaTimeRange_Interval_TypeF(void)
{
    return _Sbk_QMediaTimeRange_Interval_Type;
}

static PyType_Slot Sbk_QMediaTimeRange_Interval_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QMediaTimeRange_Interval__repr__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QMediaTimeRange_Interval_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QMediaTimeRange_Interval_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QMediaTimeRange_Interval_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QMediaTimeRange_Interval_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QMediaTimeRange_Interval_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QMediaTimeRange_Interval_spec = {
    "2:PySide6.QtMultimedia.QMediaTimeRange.Interval",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QMediaTimeRange_Interval_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void Interval_PythonToCpp_Interval_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QMediaTimeRange_Interval_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_Interval_PythonToCpp_Interval_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QMediaTimeRange_Interval_TypeF()))
        return Interval_PythonToCpp_Interval_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *Interval_PTR_CppToPython_Interval(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QMediaTimeRange_Interval_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *Interval_COPY_CppToPython_Interval(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QMediaTimeRange::Interval *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QMediaTimeRange_Interval_TypeF(), new ::QMediaTimeRange::Interval(*source), true, true);
}

// Python to C++ copy conversion.
static void Interval_PythonToCpp_Interval_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QMediaTimeRange::Interval *>(cppOut) = *reinterpret_cast< ::QMediaTimeRange::Interval *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaTimeRange_Interval_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_Interval_PythonToCpp_Interval_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QMediaTimeRange_Interval_TypeF()))
        return Interval_PythonToCpp_Interval_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QMediaTimeRange_Interval_SignatureStrings[] = {
    "2:PySide6.QtMultimedia.QMediaTimeRange.Interval(self)",
    "1:PySide6.QtMultimedia.QMediaTimeRange.Interval(self,Interval:PySide6.QtMultimedia.QMediaTimeRange.Interval)",
    "0:PySide6.QtMultimedia.QMediaTimeRange.Interval(self,start:qint64,end:qint64)",
    "PySide6.QtMultimedia.QMediaTimeRange.Interval.contains(self,time:qint64)->bool",
    "PySide6.QtMultimedia.QMediaTimeRange.Interval.end(self)->qint64",
    "PySide6.QtMultimedia.QMediaTimeRange.Interval.isNormal(self)->bool",
    "PySide6.QtMultimedia.QMediaTimeRange.Interval.normalized(self)->PySide6.QtMultimedia.QMediaTimeRange.Interval",
    "PySide6.QtMultimedia.QMediaTimeRange.Interval.start(self)->qint64",
    "PySide6.QtMultimedia.QMediaTimeRange.Interval.translated(self,offset:qint64)->PySide6.QtMultimedia.QMediaTimeRange.Interval",
    "PySide6.QtMultimedia.QMediaTimeRange.Interval.__copy__(self)->typing.Self",
    "PySide6.QtMultimedia.QMediaTimeRange.Interval.__ne__(self,rhs:PySide6.QtMultimedia.QMediaTimeRange.Interval)->bool",
    "PySide6.QtMultimedia.QMediaTimeRange.Interval.__eq__(self,rhs:PySide6.QtMultimedia.QMediaTimeRange.Interval)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QMediaTimeRange_Interval_SignatureByteSize = 211;
static constexpr uint8_t QMediaTimeRange_Interval_SignatureBytes[211] = {
    0x78, 0xda, 0xb5, 0x93, 0x3f, 0x0f, 0x82, 0x30, 0x10, 0xc5, 0x77, 0x3e, 0x89, 0x24, 0xd0, 0xa8,
    0x31, 0x0e, 0x0c, 0xec, 0x0e, 0x18, 0xff, 0xed, 0x4d, 0x85, 0x03, 0x9b, 0x94, 0x2b, 0xb6, 0xa7,
    0x09, 0x7e, 0x7a, 0x41, 0xa8, 0xce, 0x85, 0x38, 0xb5, 0x97, 0xdc, 0xfb, 0xdd, 0xbb, 0xbe, 0x74,
    0x9d, 0x1c, 0xda, 0xb3, 0x2c, 0x60, 0xcb, 0x8e, 0x94, 0x3d, 0x14, 0xc9, 0x1a, 0x0a, 0x29, 0xd8,
    0x31, 0xeb, 0x8f, 0x4b, 0x57, 0x9d, 0x04, 0x56, 0xc0, 0x76, 0x48, 0x60, 0x9e, 0x42, 0x2d, 0x2c,
    0xa8, 0x32, 0x0c, 0x56, 0x13, 0x54, 0x91, 0xab, 0xfc, 0xb4, 0x61, 0xb0, 0x9c, 0x32, 0xcc, 0x92,
    0x30, 0x94, 0xdc, 0x25, 0xd2, 0x76, 0x13, 0x01, 0x16, 0xe3, 0x35, 0x0c, 0xbc, 0x58, 0x2c, 0xd7,
    0x48, 0x42, 0xa2, 0x1d, 0xa0, 0x7d, 0xbb, 0x03, 0xc5, 0xe9, 0x55, 0x6b, 0xe5, 0x89, 0xeb, 0x8c,
    0x0c, 0x2f, 0x18, 0xa7, 0x03, 0xc6, 0x53, 0x2f, 0xed, 0x5e, 0x9b, 0xda, 0xc5, 0x30, 0xc9, 0x02,
    0x7e, 0x00, 0xf2, 0x05, 0x5f, 0x27, 0x5e, 0x7a, 0xcf, 0x69, 0x9f, 0x18, 0x66, 0xad, 0x4c, 0x46,
    0xa0, 0x55, 0x82, 0x46, 0xbf, 0x91, 0x2e, 0x4b, 0x0b, 0xf4, 0x4b, 0xe1, 0x9f, 0xee, 0x39, 0xcf,
    0x75, 0xd3, 0x72, 0xee, 0x16, 0xa0, 0xb6, 0x91, 0x58, 0xb1, 0x73, 0x57, 0x79, 0x93, 0x10, 0x46,
    0x4e, 0x64, 0x6e, 0xd6, 0xf3, 0x0b, 0x4c, 0x0a, 0x9a, 0x73, 0xb8, 0xcf, 0x1e, 0xf9, 0x06, 0xbc,
    0x52, 0x7f, 0x31
};
#endif

PyTypeObject *init_QMediaTimeRange_Interval(PyObject *enclosingClass)
{
    if (SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaTimeRange_Interval_IDX].type != nullptr)
        return SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaTimeRange_Interval_IDX].type;

    Shiboken::AutoDecRef Sbk_QMediaTimeRange_Interval_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QMediaTimeRange_Interval_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "Interval",
        "QMediaTimeRange::Interval",
        &Sbk_QMediaTimeRange_Interval_spec,
        &Shiboken::callCppDestructor< ::QMediaTimeRange::Interval >,
        Sbk_QMediaTimeRange_Interval_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass | Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QMediaTimeRange_Interval_TypeF(); // references _Sbk_QMediaTimeRange_Interval_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QMediaTimeRange_Interval_SignatureStrings);
#else
    InitSignatureBytes(pyType, QMediaTimeRange_Interval_SignatureBytes, QMediaTimeRange_Interval_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QMediaTimeRange_Interval_PropertyStrings);
    SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaTimeRange_Interval_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        Interval_PythonToCpp_Interval_PTR,
        is_Interval_PythonToCpp_Interval_PTR_Convertible,
        Interval_PTR_CppToPython_Interval,
        Interval_COPY_CppToPython_Interval);

    Shiboken::Conversions::registerConverterName(converter, "QMediaTimeRange::Interval");
    Shiboken::Conversions::registerConverterName(converter, "QMediaTimeRange::Interval*");
    Shiboken::Conversions::registerConverterName(converter, "QMediaTimeRange::Interval&");
    Shiboken::Conversions::registerConverterAlias(converter, "Interval");
    Shiboken::Conversions::registerConverterAlias(converter, "Interval*");
    Shiboken::Conversions::registerConverterAlias(converter, "Interval&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QMediaTimeRange::Interval).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        Interval_PythonToCpp_Interval_COPY,
        is_Interval_PythonToCpp_Interval_COPY_Convertible);

    qRegisterMetaType< ::QMediaTimeRange::Interval >("Interval");
    qRegisterMetaType< ::QMediaTimeRange::Interval >("QMediaTimeRange::Interval");

    return pyType;
}
