// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtmultimedia_python.h"

// main header
#include "qvideoframe_paintoptions_wrapper.h"

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QVideoFrame_PaintOptions_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QVideoFrame::PaintOptions >()))
        return -1;

    ::QVideoFrame::PaintOptions *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "PaintOptions", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: PaintOptions::PaintOptions()
    // 1: PaintOptions::PaintOptions(QVideoFrame::PaintOptions)
    if (numArgs == 0) {
        overloadId = 0; // PaintOptions()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_PaintOptions_IDX]), (pyArgs[0])))) {
        overloadId = 1; // PaintOptions(QVideoFrame::PaintOptions)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_PaintOptions_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_PaintOptions_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // PaintOptions()
        {

            // PaintOptions()
            cptr = new ::QVideoFrame::PaintOptions();
            break;
        }
        case 1: // PaintOptions(const QVideoFrame::PaintOptions &PaintOptions)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QVideoFrame::PaintOptions cppArg0_local;
            ::QVideoFrame::PaintOptions *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // PaintOptions(QVideoFrame::PaintOptions)
                cptr = new ::QVideoFrame::PaintOptions(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QVideoFrame::PaintOptions >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_PaintOptions_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QVideoFrame_PaintOptions__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QVideoFrame::PaintOptions *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_PaintOptions_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_PaintOptions_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QVideoFrame_PaintOptions_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QVideoFrame_PaintOptions_EnumFlagInfo[] = {
    "PaintFlag:Flag:PaintFlags",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QVideoFrame_PaintOptions_methods[] = {
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QVideoFrame_PaintOptions__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QVideoFrame_PaintOptions_get_backgroundColor(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVideoFrame::PaintOptions *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_PaintOptions_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    if (reinterpret_cast<void *>(&(cppSelf->backgroundColor)) == reinterpret_cast<void *>(cppSelf)) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::Object::findColocatedChild(reinterpret_cast<SbkObject *>(self), Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX])));
        if (pyOut != nullptr) {
            Py_IncRef(pyOut);
            return pyOut;
        }
    } else if (Shiboken::BindingManager::instance().hasWrapper(&(cppSelf->backgroundColor))) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(&(cppSelf->backgroundColor)));
        Py_IncRef(pyOut);
        return pyOut;
    }
    pyOut = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &(cppSelf->backgroundColor), false, true);
    Shiboken::Object::setParent(self, pyOut);
    return pyOut;
}
static int Sbk_QVideoFrame_PaintOptions_set_backgroundColor(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QVideoFrame::PaintOptions *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_PaintOptions_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("backgroundColor");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("backgroundColor", "QColor");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->backgroundColor;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

static PyObject *Sbk_QVideoFrame_PaintOptions_get_aspectRatioMode(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVideoFrame::PaintOptions *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_PaintOptions_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::Qt::AspectRatioMode cppOut_local = cppSelf->aspectRatioMode;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_AspectRatioMode_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QVideoFrame_PaintOptions_set_aspectRatioMode(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QVideoFrame::PaintOptions *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_PaintOptions_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("aspectRatioMode");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_AspectRatioMode_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("aspectRatioMode", "AspectRatioMode");
        return -1;
    }

    auto cppOut_local = cppSelf->aspectRatioMode;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->aspectRatioMode = cppOut_local;

    return 0;
}

static PyObject *Sbk_QVideoFrame_PaintOptions_get_paintFlags(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVideoFrame::PaintOptions *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_PaintOptions_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QFlags_QVideoFrame_PaintOptions_PaintFlag_IDX])))->flagsConverter, &cppSelf->paintFlags);
    return pyOut;
}
static int Sbk_QVideoFrame_PaintOptions_set_paintFlags(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QVideoFrame::PaintOptions *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_PaintOptions_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("paintFlags");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QFlags_QVideoFrame_PaintOptions_PaintFlag_IDX])))->flagsConverter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("paintFlags", "PaintFlags");
        return -1;
    }

    auto cppOut_local = cppSelf->paintFlags;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->paintFlags = cppOut_local;

    return 0;
}

// Getters and Setters for PaintOptions
static PyGetSetDef Sbk_QVideoFrame_PaintOptions_getsetlist[] = {
    {const_cast<char *>("backgroundColor"), Sbk_QVideoFrame_PaintOptions_get_backgroundColor, Sbk_QVideoFrame_PaintOptions_set_backgroundColor, nullptr, nullptr},
    {const_cast<char *>("aspectRatioMode"), Sbk_QVideoFrame_PaintOptions_get_aspectRatioMode, Sbk_QVideoFrame_PaintOptions_set_aspectRatioMode, nullptr, nullptr},
    {const_cast<char *>("paintFlags"), Sbk_QVideoFrame_PaintOptions_get_paintFlags, Sbk_QVideoFrame_PaintOptions_set_paintFlags, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QVideoFrame_PaintOptions_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QVideoFrame_PaintOptions_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QVideoFrame_PaintOptions_Type = nullptr;
static PyTypeObject *Sbk_QVideoFrame_PaintOptions_TypeF(void)
{
    return _Sbk_QVideoFrame_PaintOptions_Type;
}

static PyType_Slot Sbk_QVideoFrame_PaintOptions_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QVideoFrame_PaintOptions_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QVideoFrame_PaintOptions_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QVideoFrame_PaintOptions_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QVideoFrame_PaintOptions_getsetlist)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QVideoFrame_PaintOptions_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QVideoFrame_PaintOptions_spec = {
    "2:PySide6.QtMultimedia.QVideoFrame.PaintOptions",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QVideoFrame_PaintOptions_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QVideoFrame_PaintOptions_PaintFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QVideoFrame::PaintOptions::PaintFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QVideoFrame::PaintOptions::PaintFlag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QVideoFrame_PaintOptions_PaintFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_PaintOptions_PaintFlag_IDX])))
        return Enum_PythonToCpp_QVideoFrame_PaintOptions_PaintFlag;
    return {};
}

static PyObject *QVideoFrame_PaintOptions_PaintFlag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QVideoFrame::PaintOptions::PaintFlag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QVideoFrame::PaintOptions::PaintFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_PaintOptions_PaintFlag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QVideoFrame_PaintOptions_PaintFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QVideoFrame::PaintOptions::PaintFlag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QVideoFrame::PaintOptions::PaintFlag> *>(cppOut) = value;

}

static PyObject *QVideoFrame_PaintOptions_PaintFlag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QVideoFrame::PaintOptions::PaintFlag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_PaintOptions_PaintFlag_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void PaintOptions_PythonToCpp_PaintOptions_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QVideoFrame_PaintOptions_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_PaintOptions_PythonToCpp_PaintOptions_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QVideoFrame_PaintOptions_TypeF()))
        return PaintOptions_PythonToCpp_PaintOptions_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *PaintOptions_PTR_CppToPython_PaintOptions(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QVideoFrame_PaintOptions_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *PaintOptions_COPY_CppToPython_PaintOptions(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QVideoFrame::PaintOptions *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QVideoFrame_PaintOptions_TypeF(), new ::QVideoFrame::PaintOptions(*source), true, true);
}

// Python to C++ copy conversion.
static void PaintOptions_PythonToCpp_PaintOptions_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QVideoFrame::PaintOptions *>(cppOut) = *reinterpret_cast< ::QVideoFrame::PaintOptions *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_PaintOptions_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_PaintOptions_PythonToCpp_PaintOptions_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QVideoFrame_PaintOptions_TypeF()))
        return PaintOptions_PythonToCpp_PaintOptions_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QVideoFrame_PaintOptions_SignatureStrings[] = {
    "1:PySide6.QtMultimedia.QVideoFrame.PaintOptions(self)",
    "0:PySide6.QtMultimedia.QVideoFrame.PaintOptions(self,PaintOptions:PySide6.QtMultimedia.QVideoFrame.PaintOptions)",
    "PySide6.QtMultimedia.QVideoFrame.PaintOptions.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QVideoFrame_PaintOptions_SignatureByteSize = 98;
static constexpr uint8_t QVideoFrame_PaintOptions_SignatureBytes[98] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0xf1, 0x2d,
    0xcd, 0x29, 0xc9, 0xcc, 0x4d, 0x4d, 0xc9, 0x4c, 0xd4, 0x0b, 0x0c, 0x03, 0x8a, 0xe5, 0xbb, 0x15,
    0x25, 0xe6, 0xa6, 0xea, 0x05, 0x24, 0x66, 0xe6, 0x95, 0xf8, 0x17, 0x94, 0x64, 0xe6, 0xe7, 0x15,
    0x6b, 0x14, 0xa7, 0xe6, 0xa4, 0x69, 0x72, 0x19, 0x90, 0xa1, 0x4b, 0x07, 0x59, 0x84, 0x34, 0xfd,
    0x9a, 0x5c, 0x24, 0x29, 0xd7, 0x8b, 0x8f, 0x4f, 0xce, 0x2f, 0xa8, 0x8c, 0x8f, 0x87, 0xb8, 0x56,
    0xd7, 0xae, 0xa4, 0xb2, 0x20, 0x33, 0x2f, 0x5d, 0x2f, 0x18, 0xc8, 0xe3, 0x02, 0x00, 0x94, 0x1d,
    0x58, 0x3a
};
#endif

PyTypeObject *init_QVideoFrame_PaintOptions(PyObject *enclosingClass)
{
    if (SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_PaintOptions_IDX].type != nullptr)
        return SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_PaintOptions_IDX].type;

    Shiboken::AutoDecRef Sbk_QVideoFrame_PaintOptions_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QVideoFrame_PaintOptions_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "PaintOptions",
        "QVideoFrame::PaintOptions",
        &Sbk_QVideoFrame_PaintOptions_spec,
        &Shiboken::callCppDestructor< ::QVideoFrame::PaintOptions >,
        Sbk_QVideoFrame_PaintOptions_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass | Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QVideoFrame_PaintOptions_TypeF(); // references _Sbk_QVideoFrame_PaintOptions_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QVideoFrame_PaintOptions_SignatureStrings);
#else
    InitSignatureBytes(pyType, QVideoFrame_PaintOptions_SignatureBytes, QVideoFrame_PaintOptions_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QVideoFrame_PaintOptions_PropertyStrings);
    SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_PaintOptions_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        PaintOptions_PythonToCpp_PaintOptions_PTR,
        is_PaintOptions_PythonToCpp_PaintOptions_PTR_Convertible,
        PaintOptions_PTR_CppToPython_PaintOptions,
        PaintOptions_COPY_CppToPython_PaintOptions);

    Shiboken::Conversions::registerConverterName(converter, "QVideoFrame::PaintOptions");
    Shiboken::Conversions::registerConverterName(converter, "QVideoFrame::PaintOptions*");
    Shiboken::Conversions::registerConverterName(converter, "QVideoFrame::PaintOptions&");
    Shiboken::Conversions::registerConverterAlias(converter, "PaintOptions");
    Shiboken::Conversions::registerConverterAlias(converter, "PaintOptions*");
    Shiboken::Conversions::registerConverterAlias(converter, "PaintOptions&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QVideoFrame::PaintOptions).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        PaintOptions_PythonToCpp_PaintOptions_COPY,
        is_PaintOptions_PythonToCpp_PaintOptions_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QVideoFrame_PaintOptions_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'PaintFlag'.
    const char *PaintFlag_Initializer[] = {
        "DontDrawSubtitles",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t PaintFlag_InitializerValues[] = {
        uint8_t(QVideoFrame::PaintOptions::PaintFlag::DontDrawSubtitles) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QVideoFrame_PaintOptions_TypeF(),
        "2:PySide6.QtMultimedia.QVideoFrame.PaintOptions.PaintFlag",
        PaintFlag_Initializer, PaintFlag_InitializerValues);
    SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_PaintOptions_PaintFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtMultimediaTypeStructs[SBK_QFlags_QVideoFrame_PaintOptions_PaintFlag_IDX].type =
        EType;
    // Register converter for enum 'QVideoFrame::PaintOptions::PaintFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QVideoFrame_PaintOptions_PaintFlag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QVideoFrame_PaintOptions_PaintFlag,
            is_Enum_PythonToCpp_QVideoFrame_PaintOptions_PaintFlag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QVideoFrame::PaintOptions::PaintFlag");
        Shiboken::Conversions::registerConverterAlias(converter, "PaintOptions::PaintFlag");
        Shiboken::Conversions::registerConverterAlias(converter, "PaintFlag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QVideoFrame_PaintOptions_PaintFlag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QVideoFrame_PaintOptions_PaintFlag,
            is_Enum_PythonToCpp_QVideoFrame_PaintOptions_PaintFlag_Convertible);
        // Register converter for flag 'QFlags<QVideoFrame::PaintOptions::PaintFlag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QVideoFrame::PaintOptions::PaintFlag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QVideoFrame::PaintOptions::PaintFlags");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'PaintFlag' enum/flags.

    qRegisterMetaType< ::QVideoFrame::PaintOptions >("PaintOptions");
    qRegisterMetaType< ::QVideoFrame::PaintOptions >("QVideoFrame::PaintOptions");
    qRegisterMetaType< ::QVideoFrame::PaintOptions::PaintFlag >("PaintOptions::PaintFlag");
    qRegisterMetaType< ::QVideoFrame::PaintOptions::PaintFlag >("QVideoFrame::PaintOptions::PaintFlag");

    return pyType;
}
