// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnetwork_python.h"

// main header
#include "qauthenticator_wrapper.h"

// Argument includes
#include <QHash>
#include <QString>
#include <QtNetwork/qauthenticator.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QAuthenticator_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QAuthenticator >()))
        return -1;

    ::QAuthenticator *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QAuthenticator", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QAuthenticator::QAuthenticator()
    // 1: QAuthenticator::QAuthenticator(QAuthenticator)
    if (numArgs == 0) {
        overloadId = 0; // QAuthenticator()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAuthenticator_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QAuthenticator(QAuthenticator)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAuthenticator_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtNetworkTypeStructs[SBK_QAuthenticator_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QAuthenticator()
        {

            // QAuthenticator()
            cptr = new ::QAuthenticator();
            break;
        }
        case 1: // QAuthenticator(const QAuthenticator &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QAuthenticator cppArg0_local;
            ::QAuthenticator *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QAuthenticator(QAuthenticator)
                cptr = new ::QAuthenticator(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QAuthenticator >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAuthenticator_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QAuthenticatorFunc_isNull(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAuthenticator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAuthenticator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isNull()const
        bool cppResult = const_cast<const ::QAuthenticator *>(cppSelf)->isNull();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAuthenticatorFunc_option(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAuthenticator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAuthenticator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAuthenticator::option(QString)const->QVariant
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // option(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "option", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAuthenticator_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // option(QString)const
            QVariant cppResult = const_cast<const ::QAuthenticator *>(cppSelf)->option(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAuthenticatorFunc_options(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAuthenticator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAuthenticator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // options()const
        QHash<QString,QVariant> cppResult = const_cast<const ::QAuthenticator *>(cppSelf)->options();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QHash_QString_QVariant_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAuthenticatorFunc_password(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAuthenticator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAuthenticator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // password()const
        QString cppResult = const_cast<const ::QAuthenticator *>(cppSelf)->password();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAuthenticatorFunc_realm(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAuthenticator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAuthenticator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // realm()const
        QString cppResult = const_cast<const ::QAuthenticator *>(cppSelf)->realm();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAuthenticatorFunc_setOption(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAuthenticator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAuthenticator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setOption", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAuthenticator::setOption(QString,QVariant)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[1])))) {
        overloadId = 0; // setOption(QString,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setOption", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAuthenticator_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QVariant cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOption(QString,QVariant)
            cppSelf->setOption(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAuthenticatorFunc_setPassword(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAuthenticator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAuthenticator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAuthenticator::setPassword(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setPassword(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPassword", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAuthenticator_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPassword(QString)
            cppSelf->setPassword(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAuthenticatorFunc_setRealm(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAuthenticator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAuthenticator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAuthenticator::setRealm(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setRealm(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRealm", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAuthenticator_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRealm(QString)
            cppSelf->setRealm(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAuthenticatorFunc_setUser(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAuthenticator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAuthenticator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAuthenticator::setUser(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setUser(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUser", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAuthenticator_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setUser(QString)
            cppSelf->setUser(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAuthenticatorFunc_user(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAuthenticator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAuthenticator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // user()const
        QString cppResult = const_cast<const ::QAuthenticator *>(cppSelf)->user();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAuthenticator__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QAuthenticator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAuthenticator_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAuthenticator_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QAuthenticator_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QAuthenticator_methods[] = {
    {"isNull", reinterpret_cast<PyCFunction>(Sbk_QAuthenticatorFunc_isNull), METH_NOARGS, nullptr},
    {"option", reinterpret_cast<PyCFunction>(Sbk_QAuthenticatorFunc_option), METH_O, nullptr},
    {"options", reinterpret_cast<PyCFunction>(Sbk_QAuthenticatorFunc_options), METH_NOARGS, nullptr},
    {"password", reinterpret_cast<PyCFunction>(Sbk_QAuthenticatorFunc_password), METH_NOARGS, nullptr},
    {"realm", reinterpret_cast<PyCFunction>(Sbk_QAuthenticatorFunc_realm), METH_NOARGS, nullptr},
    {"setOption", reinterpret_cast<PyCFunction>(Sbk_QAuthenticatorFunc_setOption), METH_VARARGS, nullptr},
    {"setPassword", reinterpret_cast<PyCFunction>(Sbk_QAuthenticatorFunc_setPassword), METH_O, nullptr},
    {"setRealm", reinterpret_cast<PyCFunction>(Sbk_QAuthenticatorFunc_setRealm), METH_O, nullptr},
    {"setUser", reinterpret_cast<PyCFunction>(Sbk_QAuthenticatorFunc_setUser), METH_O, nullptr},
    {"user", reinterpret_cast<PyCFunction>(Sbk_QAuthenticatorFunc_user), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QAuthenticator__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QAuthenticator___nb_bool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QAuthenticator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAuthenticator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return !cppSelf->isNull() ? 1 : 0;
}

// Rich comparison
static PyObject * Sbk_QAuthenticator_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QAuthenticator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAuthenticator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAuthenticator_IDX]), (pyArg)))) {
                // operator!=(const QAuthenticator &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QAuthenticator cppArg0_local;
                ::QAuthenticator *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAuthenticator_IDX]), (pyArg)))) {
                // operator==(const QAuthenticator &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QAuthenticator cppArg0_local;
                ::QAuthenticator *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QAuthenticator_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QAuthenticator_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QAuthenticator_Type = nullptr;
static PyTypeObject *Sbk_QAuthenticator_TypeF(void)
{
    return _Sbk_QAuthenticator_Type;
}

static PyType_Slot Sbk_QAuthenticator_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QAuthenticator_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QAuthenticator_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QAuthenticator_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QAuthenticator_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QAuthenticator_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_bool,        reinterpret_cast<void *>(Sbk_QAuthenticator___nb_bool)},
    {0, nullptr}
};
static PyType_Spec Sbk_QAuthenticator_spec = {
    "2:PySide6.QtNetwork.QAuthenticator",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QAuthenticator_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAuthenticator_PythonToCpp_QAuthenticator_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QAuthenticator_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAuthenticator_PythonToCpp_QAuthenticator_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QAuthenticator_TypeF()))
        return QAuthenticator_PythonToCpp_QAuthenticator_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAuthenticator_PTR_CppToPython_QAuthenticator(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QAuthenticator_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QAuthenticator_COPY_CppToPython_QAuthenticator(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QAuthenticator *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QAuthenticator_TypeF(), new ::QAuthenticator(*source), true, true);
}

// Python to C++ copy conversion.
static void QAuthenticator_PythonToCpp_QAuthenticator_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QAuthenticator *>(cppOut) = *reinterpret_cast< ::QAuthenticator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAuthenticator_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QAuthenticator_PythonToCpp_QAuthenticator_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QAuthenticator_TypeF()))
        return QAuthenticator_PythonToCpp_QAuthenticator_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QAuthenticator_SignatureStrings[] = {
    "1:PySide6.QtNetwork.QAuthenticator(self)",
    "0:PySide6.QtNetwork.QAuthenticator(self,other:PySide6.QtNetwork.QAuthenticator)",
    "PySide6.QtNetwork.QAuthenticator.isNull(self)->bool",
    "PySide6.QtNetwork.QAuthenticator.option(self,opt:QString)->QVariant",
    "PySide6.QtNetwork.QAuthenticator.options(self)->QHash[QString, QVariant]",
    "PySide6.QtNetwork.QAuthenticator.password(self)->QString",
    "PySide6.QtNetwork.QAuthenticator.realm(self)->QString",
    "PySide6.QtNetwork.QAuthenticator.setOption(self,opt:QString,value:QVariant)",
    "PySide6.QtNetwork.QAuthenticator.setPassword(self,password:QString)",
    "PySide6.QtNetwork.QAuthenticator.setRealm(self,realm:QString)",
    "PySide6.QtNetwork.QAuthenticator.setUser(self,user:QString)",
    "PySide6.QtNetwork.QAuthenticator.user(self)->QString",
    "PySide6.QtNetwork.QAuthenticator.__copy__(self)->typing.Self",
    "PySide6.QtNetwork.QAuthenticator.__ne__(self,other:PySide6.QtNetwork.QAuthenticator)->bool",
    "PySide6.QtNetwork.QAuthenticator.__eq__(self,other:PySide6.QtNetwork.QAuthenticator)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QAuthenticator_SignatureByteSize = 232;
static constexpr uint8_t QAuthenticator_SignatureBytes[232] = {
    0x78, 0xda, 0x9d, 0x93, 0xb1, 0x8e, 0x02, 0x21, 0x10, 0x40, 0x7b, 0xbf, 0xc2, 0xd2, 0x4d, 0xb8,
    0xcd, 0x5d, 0x73, 0xc5, 0x16, 0x26, 0xd7, 0x59, 0xa9, 0xb8, 0x39, 0x1b, 0x63, 0x08, 0xea, 0xe8,
    0x92, 0x43, 0xe0, 0x60, 0xd0, 0xec, 0xdf, 0x4b, 0x74, 0xd9, 0x58, 0x98, 0xc0, 0xda, 0xc1, 0x64,
    0xde, 0x63, 0x66, 0x32, 0x7c, 0x55, 0xcb, 0xb6, 0x16, 0x07, 0xf8, 0x2e, 0x29, 0xce, 0x01, 0xaf,
    0xda, 0xfe, 0x95, 0xf4, 0xc7, 0x63, 0x03, 0x0a, 0xc5, 0x9e, 0xa3, 0xb6, 0x13, 0x07, 0xf2, 0x58,
    0x8c, 0x3e, 0xf3, 0x12, 0x89, 0x0e, 0x11, 0x9b, 0xcc, 0x2d, 0x46, 0xa9, 0x8c, 0x52, 0xb8, 0xb9,
    0x97, 0xf2, 0xf1, 0xfa, 0xc7, 0x74, 0xa7, 0xb5, 0x4c, 0x33, 0xda, 0xa0, 0xd0, 0xaa, 0x2b, 0xc4,
    0x60, 0x45, 0x6b, 0xb4, 0x42, 0x9d, 0x02, 0x4f, 0xd7, 0xdc, 0x0a, 0xae, 0x30, 0xd7, 0xe1, 0xe2,
    0xc3, 0x74, 0xc6, 0x5d, 0xb3, 0xe9, 0x44, 0x64, 0x1c, 0x3d, 0xdb, 0xb4, 0xc8, 0x70, 0xe7, 0x42,
    0xfc, 0xd0, 0x9b, 0x1e, 0x8e, 0x34, 0x68, 0x81, 0xcb, 0xf3, 0x60, 0xca, 0x01, 0x2e, 0x5e, 0xb7,
    0x4f, 0x2e, 0x5c, 0x7a, 0xa8, 0x62, 0xe9, 0x45, 0x96, 0x6b, 0xf9, 0x5c, 0x3d, 0x89, 0xbd, 0xf4,
    0x13, 0xcd, 0x72, 0xac, 0xfa, 0x46, 0xc8, 0xbd, 0xa7, 0x61, 0xf4, 0xaf, 0x83, 0x6e, 0xa7, 0x7c,
    0x38, 0x0d, 0x60, 0x7d, 0x04, 0x87, 0x8c, 0x8f, 0xb1, 0xbd, 0x36, 0x2d, 0x63, 0x11, 0xc4, 0xd6,
    0x04, 0xae, 0xac, 0xc3, 0x2d, 0x07, 0x56, 0xd0, 0xa1, 0xb9, 0x1f, 0x20, 0x77, 0xa5, 0x19, 0x83,
    0xff, 0xf7, 0xd4, 0x37, 0x3f, 0xb6, 0x6b, 0xde
};
#endif

PyTypeObject *init_QAuthenticator(PyObject *module)
{
    if (SbkPySide6_QtNetworkTypeStructs[SBK_QAuthenticator_IDX].type != nullptr)
        return SbkPySide6_QtNetworkTypeStructs[SBK_QAuthenticator_IDX].type;

    Shiboken::AutoDecRef Sbk_QAuthenticator_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QAuthenticator_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QAuthenticator",
        "QAuthenticator",
        &Sbk_QAuthenticator_spec,
        &Shiboken::callCppDestructor< ::QAuthenticator >,
        Sbk_QAuthenticator_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QAuthenticator_TypeF(); // references _Sbk_QAuthenticator_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QAuthenticator_SignatureStrings);
#else
    InitSignatureBytes(pyType, QAuthenticator_SignatureBytes, QAuthenticator_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QAuthenticator_PropertyStrings);
    SbkPySide6_QtNetworkTypeStructs[SBK_QAuthenticator_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAuthenticator_PythonToCpp_QAuthenticator_PTR,
        is_QAuthenticator_PythonToCpp_QAuthenticator_PTR_Convertible,
        QAuthenticator_PTR_CppToPython_QAuthenticator,
        QAuthenticator_COPY_CppToPython_QAuthenticator);

    Shiboken::Conversions::registerConverterName(converter, "QAuthenticator");
    Shiboken::Conversions::registerConverterName(converter, "QAuthenticator*");
    Shiboken::Conversions::registerConverterName(converter, "QAuthenticator&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QAuthenticator).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QAuthenticator_PythonToCpp_QAuthenticator_COPY,
        is_QAuthenticator_PythonToCpp_QAuthenticator_COPY_Convertible);

    qRegisterMetaType< ::QAuthenticator >("QAuthenticator");

    return pyType;
}
