// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnetwork_python.h"

// main header
#include "qdnshostaddressrecord_wrapper.h"

// Argument includes
#include <QString>
#include <QtNetwork/qdnslookup.h>
#include <QtNetwork/qhostaddress.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDnsHostAddressRecord_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QDnsHostAddressRecord >()))
        return -1;

    ::QDnsHostAddressRecord *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QDnsHostAddressRecord", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QDnsHostAddressRecord::QDnsHostAddressRecord()
    // 1: QDnsHostAddressRecord::QDnsHostAddressRecord(QDnsHostAddressRecord)
    if (numArgs == 0) {
        overloadId = 0; // QDnsHostAddressRecord()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsHostAddressRecord_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QDnsHostAddressRecord(QDnsHostAddressRecord)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDnsHostAddressRecord_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtNetworkTypeStructs[SBK_QDnsHostAddressRecord_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QDnsHostAddressRecord()
        {

            // QDnsHostAddressRecord()
            cptr = new ::QDnsHostAddressRecord();
            break;
        }
        case 1: // QDnsHostAddressRecord(const QDnsHostAddressRecord &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QDnsHostAddressRecord cppArg0_local;
            ::QDnsHostAddressRecord *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QDnsHostAddressRecord(QDnsHostAddressRecord)
                cptr = new ::QDnsHostAddressRecord(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QDnsHostAddressRecord >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDnsHostAddressRecord_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QDnsHostAddressRecordFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDnsHostAddressRecord *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsHostAddressRecord_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // name()const
        QString cppResult = const_cast<const ::QDnsHostAddressRecord *>(cppSelf)->name();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDnsHostAddressRecordFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDnsHostAddressRecord *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsHostAddressRecord_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDnsHostAddressRecord::swap(QDnsHostAddressRecord&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsHostAddressRecord_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QDnsHostAddressRecord&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDnsHostAddressRecord_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDnsHostAddressRecord cppArg0_local;
        ::QDnsHostAddressRecord *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QDnsHostAddressRecord&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDnsHostAddressRecordFunc_timeToLive(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDnsHostAddressRecord *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsHostAddressRecord_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // timeToLive()const
        quint32 cppResult = const_cast<const ::QDnsHostAddressRecord *>(cppSelf)->timeToLive();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDnsHostAddressRecordFunc_value(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDnsHostAddressRecord *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsHostAddressRecord_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // value()const
        QHostAddress cppResult = const_cast<const ::QDnsHostAddressRecord *>(cppSelf)->value();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDnsHostAddressRecord__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QDnsHostAddressRecord *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsHostAddressRecord_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsHostAddressRecord_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QDnsHostAddressRecord_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDnsHostAddressRecord_methods[] = {
    {"name", reinterpret_cast<PyCFunction>(Sbk_QDnsHostAddressRecordFunc_name), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QDnsHostAddressRecordFunc_swap), METH_O, nullptr},
    {"timeToLive", reinterpret_cast<PyCFunction>(Sbk_QDnsHostAddressRecordFunc_timeToLive), METH_NOARGS, nullptr},
    {"value", reinterpret_cast<PyCFunction>(Sbk_QDnsHostAddressRecordFunc_value), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QDnsHostAddressRecord__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QDnsHostAddressRecord_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDnsHostAddressRecord_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDnsHostAddressRecord_Type = nullptr;
static PyTypeObject *Sbk_QDnsHostAddressRecord_TypeF(void)
{
    return _Sbk_QDnsHostAddressRecord_Type;
}

static PyType_Slot Sbk_QDnsHostAddressRecord_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDnsHostAddressRecord_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDnsHostAddressRecord_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDnsHostAddressRecord_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDnsHostAddressRecord_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDnsHostAddressRecord_spec = {
    "2:PySide6.QtNetwork.QDnsHostAddressRecord",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDnsHostAddressRecord_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDnsHostAddressRecord_PythonToCpp_QDnsHostAddressRecord_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDnsHostAddressRecord_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDnsHostAddressRecord_PythonToCpp_QDnsHostAddressRecord_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDnsHostAddressRecord_TypeF()))
        return QDnsHostAddressRecord_PythonToCpp_QDnsHostAddressRecord_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDnsHostAddressRecord_PTR_CppToPython_QDnsHostAddressRecord(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QDnsHostAddressRecord_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QDnsHostAddressRecord_COPY_CppToPython_QDnsHostAddressRecord(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QDnsHostAddressRecord *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QDnsHostAddressRecord_TypeF(), new ::QDnsHostAddressRecord(*source), true, true);
}

// Python to C++ copy conversion.
static void QDnsHostAddressRecord_PythonToCpp_QDnsHostAddressRecord_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QDnsHostAddressRecord *>(cppOut) = *reinterpret_cast< ::QDnsHostAddressRecord *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsHostAddressRecord_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QDnsHostAddressRecord_PythonToCpp_QDnsHostAddressRecord_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QDnsHostAddressRecord_TypeF()))
        return QDnsHostAddressRecord_PythonToCpp_QDnsHostAddressRecord_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QDnsHostAddressRecord_SignatureStrings[] = {
    "1:PySide6.QtNetwork.QDnsHostAddressRecord(self)",
    "0:PySide6.QtNetwork.QDnsHostAddressRecord(self,other:PySide6.QtNetwork.QDnsHostAddressRecord)",
    "PySide6.QtNetwork.QDnsHostAddressRecord.name(self)->QString",
    "PySide6.QtNetwork.QDnsHostAddressRecord.swap(self,other:PySide6.QtNetwork.QDnsHostAddressRecord)",
    "PySide6.QtNetwork.QDnsHostAddressRecord.timeToLive(self)->quint32",
    "PySide6.QtNetwork.QDnsHostAddressRecord.value(self)->PySide6.QtNetwork.QHostAddress",
    "PySide6.QtNetwork.QDnsHostAddressRecord.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QDnsHostAddressRecord_SignatureByteSize = 151;
static constexpr uint8_t QDnsHostAddressRecord_SignatureBytes[151] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0xf1, 0x4b,
    0x2d, 0x29, 0xcf, 0x2f, 0xca, 0xd6, 0x0b, 0x74, 0xc9, 0x2b, 0xf6, 0xc8, 0x2f, 0x2e, 0x71, 0x4c,
    0x49, 0x29, 0x4a, 0x2d, 0x2e, 0x0e, 0x4a, 0x4d, 0xce, 0x2f, 0x4a, 0xd1, 0x28, 0x4e, 0xcd, 0x49,
    0xd3, 0xe4, 0x32, 0x20, 0x49, 0xbd, 0x4e, 0x7e, 0x49, 0x46, 0x6a, 0x11, 0xb1, 0x5a, 0x34, 0xb9,
    0x88, 0x54, 0xa8, 0x97, 0x97, 0x98, 0x9b, 0x0a, 0x71, 0x90, 0xae, 0x5d, 0x60, 0x70, 0x49, 0x51,
    0x66, 0x5e, 0x3a, 0xd1, 0x7a, 0x8b, 0xcb, 0x13, 0x0b, 0x68, 0xea, 0xb8, 0x92, 0xcc, 0xdc, 0xd4,
    0x90, 0x7c, 0x9f, 0xcc, 0x32, 0xb8, 0x13, 0x0b, 0x4b, 0x33, 0xf3, 0x4a, 0x8c, 0x8d, 0x88, 0x36,
    0xa1, 0x2c, 0x31, 0xa7, 0x14, 0xae, 0x19, 0x8b, 0x26, 0x24, 0x1d, 0x44, 0x9b, 0x19, 0x1f, 0x9f,
    0x9c, 0x5f, 0x50, 0x19, 0x1f, 0x0f, 0x33, 0xb6, 0xa4, 0xb2, 0x00, 0x18, 0x6a, 0x7a, 0xc1, 0x40,
    0x1e, 0x17, 0x00, 0x75, 0x87, 0xbd, 0x4a
};
#endif

PyTypeObject *init_QDnsHostAddressRecord(PyObject *module)
{
    if (SbkPySide6_QtNetworkTypeStructs[SBK_QDnsHostAddressRecord_IDX].type != nullptr)
        return SbkPySide6_QtNetworkTypeStructs[SBK_QDnsHostAddressRecord_IDX].type;

    Shiboken::AutoDecRef Sbk_QDnsHostAddressRecord_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QDnsHostAddressRecord_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDnsHostAddressRecord",
        "QDnsHostAddressRecord",
        &Sbk_QDnsHostAddressRecord_spec,
        &Shiboken::callCppDestructor< ::QDnsHostAddressRecord >,
        Sbk_QDnsHostAddressRecord_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QDnsHostAddressRecord_TypeF(); // references _Sbk_QDnsHostAddressRecord_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QDnsHostAddressRecord_SignatureStrings);
#else
    InitSignatureBytes(pyType, QDnsHostAddressRecord_SignatureBytes, QDnsHostAddressRecord_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDnsHostAddressRecord_PropertyStrings);
    SbkPySide6_QtNetworkTypeStructs[SBK_QDnsHostAddressRecord_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDnsHostAddressRecord_PythonToCpp_QDnsHostAddressRecord_PTR,
        is_QDnsHostAddressRecord_PythonToCpp_QDnsHostAddressRecord_PTR_Convertible,
        QDnsHostAddressRecord_PTR_CppToPython_QDnsHostAddressRecord,
        QDnsHostAddressRecord_COPY_CppToPython_QDnsHostAddressRecord);

    Shiboken::Conversions::registerConverterName(converter, "QDnsHostAddressRecord");
    Shiboken::Conversions::registerConverterName(converter, "QDnsHostAddressRecord*");
    Shiboken::Conversions::registerConverterName(converter, "QDnsHostAddressRecord&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDnsHostAddressRecord).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QDnsHostAddressRecord_PythonToCpp_QDnsHostAddressRecord_COPY,
        is_QDnsHostAddressRecord_PythonToCpp_QDnsHostAddressRecord_COPY_Convertible);

    qRegisterMetaType< ::QDnsHostAddressRecord >("QDnsHostAddressRecord");

    return pyType;
}
