// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnetwork_python.h"

// main header
#include "qdnslookup_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QtNetwork/qdnslookup.h>
#include <QtNetwork/qhostaddress.h>
#include <QtNetwork/qsslconfiguration.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QDnsLookupWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QDnsLookupWrapper::QDnsLookupWrapper(::QDnsLookup::Type type, const ::QString & name, ::QDnsLookup::Protocol protocol, const ::QHostAddress & nameserver, quint16 port, ::QObject * parent) : QDnsLookup(type, name, protocol, nameserver, port, parent)
{
}

QDnsLookupWrapper::QDnsLookupWrapper(::QDnsLookup::Type type, const ::QString & name, ::QObject * parent) : QDnsLookup(type, name, parent)
{
}

QDnsLookupWrapper::QDnsLookupWrapper(::QDnsLookup::Type type, const ::QString & name, const ::QHostAddress & nameserver, ::QObject * parent) : QDnsLookup(type, name, nameserver, parent)
{
}

QDnsLookupWrapper::QDnsLookupWrapper(::QDnsLookup::Type type, const ::QString & name, const ::QHostAddress & nameserver, quint16 port, ::QObject * parent) : QDnsLookup(type, name, nameserver, port, parent)
{
}

QDnsLookupWrapper::QDnsLookupWrapper(::QObject * parent) : QDnsLookup(parent)
{
}

void QDnsLookupWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QDnsLookup", funcName);
        return;
    }
}

void QDnsLookupWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QDnsLookup", funcName);
        return;
    }
}

void QDnsLookupWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QDnsLookup", funcName);
        return;
    }
}

void QDnsLookupWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QDnsLookup", funcName);
        return;
    }
}

bool QDnsLookupWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QDnsLookup", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QDnsLookup", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QDnsLookupWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QDnsLookup", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QDnsLookup", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QDnsLookupWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QDnsLookup", funcName);
        return;
    }
}

const QMetaObject *QDnsLookupWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QDnsLookup::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QDnsLookupWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QDnsLookup::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QDnsLookupWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QDnsLookupWrapper *>(this));
    return QDnsLookup::qt_metacast(_clname);
}

QDnsLookupWrapper::~QDnsLookupWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDnsLookup_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QDnsLookup >()))
        return -1;

    QDnsLookupWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[6];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OOOOOO:QDnsLookup", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QDnsLookup::QDnsLookup(QDnsLookup::Type,QString,QDnsLookup::Protocol,QHostAddress,quint16=,QObject*=)
    // 1: QDnsLookup::QDnsLookup(QDnsLookup::Type,QString,QObject*=)
    // 2: QDnsLookup::QDnsLookup(QDnsLookup::Type,QString,QHostAddress,QObject*=)
    // 3: QDnsLookup::QDnsLookup(QDnsLookup::Type,QString,QHostAddress,quint16,QObject*=)
    // 4: QDnsLookup::QDnsLookup(QObject*=)
    if (numArgs == 0) {
        overloadId = 4; // QDnsLookup(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 4; // QDnsLookup(QObject*)
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_Type_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 1; // QDnsLookup(QDnsLookup::Type,QString,QObject*)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 2; // QDnsLookup(QDnsLookup::Type,QString,QHostAddress,QObject*)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArgs[3])))) {
                if (numArgs == 4) {
                    overloadId = 3; // QDnsLookup(QDnsLookup::Type,QString,QHostAddress,quint16,QObject*)
                } else if (numArgs >= 5
                    && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[4])))) {
                    overloadId = 3; // QDnsLookup(QDnsLookup::Type,QString,QHostAddress,quint16,QObject*)
                }
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[3])))) {
                overloadId = 2; // QDnsLookup(QDnsLookup::Type,QString,QHostAddress,QObject*)
            }
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[2])))) {
            overloadId = 1; // QDnsLookup(QDnsLookup::Type,QString,QObject*)
        } else if (numArgs >= 4
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_Protocol_IDX])))->converter, (pyArgs[2])))
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), (pyArgs[3])))) {
            if (numArgs == 4) {
                overloadId = 0; // QDnsLookup(QDnsLookup::Type,QString,QDnsLookup::Protocol,QHostAddress,quint16,QObject*)
            } else if (numArgs >= 5
                && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArgs[4])))) {
                if (numArgs == 5) {
                    overloadId = 0; // QDnsLookup(QDnsLookup::Type,QString,QDnsLookup::Protocol,QHostAddress,quint16,QObject*)
                } else if (numArgs >= 6
                    && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[5])))) {
                    overloadId = 0; // QDnsLookup(QDnsLookup::Type,QString,QDnsLookup::Protocol,QHostAddress,quint16,QObject*)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QDnsLookup(QDnsLookup::Type type, const QString &name, QDnsLookup::Protocol protocol, const QHostAddress &nameserver, quint16 port, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_port = Shiboken::String::createStaticString("port");
                if (PyDict_Contains(kwds, key_port) != 0) {
                    value = PyDict_GetItem(kwds, key_port);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_port);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_port);
                }
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[5] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[5] = value;
                        if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[5]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            ::QDnsLookup::Type cppArg0 = static_cast< ::QDnsLookup::Type>(0);
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QDnsLookup::Protocol cppArg2{QDnsLookup::Standard};
            pythonToCpp[2](pyArgs[2], &cppArg2);
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return -1;
            ::QHostAddress cppArg3_local;
            ::QHostAddress *cppArg3 = &cppArg3_local;
            if (pythonToCpp[3].isValue())
                pythonToCpp[3](pyArgs[3], &cppArg3_local);
            else
                pythonToCpp[3](pyArgs[3], &cppArg3);

            quint16 cppArg4 = 0;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);
            if (!Shiboken::Object::isValid(pyArgs[5]))
                return -1;
            ::QObject *cppArg5 = nullptr;
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDnsLookup(QDnsLookup::Type,QString,QDnsLookup::Protocol,QHostAddress,quint16,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QDnsLookupWrapper(cppArg0, cppArg1, cppArg2, *cppArg3, cppArg4, cppArg5);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QDnsLookupWrapper(cppArg0, cppArg1, cppArg2, *cppArg3, cppArg4, cppArg5);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[5], self);
            }
            break;
        }
        case 1: // QDnsLookup(QDnsLookup::Type type, const QString &name, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            ::QDnsLookup::Type cppArg0 = static_cast< ::QDnsLookup::Type>(0);
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return -1;
            ::QObject *cppArg2 = nullptr;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDnsLookup(QDnsLookup::Type,QString,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QDnsLookupWrapper(cppArg0, cppArg1, cppArg2);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QDnsLookupWrapper(cppArg0, cppArg1, cppArg2);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[2], self);
            }
            break;
        }
        case 2: // QDnsLookup(QDnsLookup::Type type, const QString &name, const QHostAddress &nameserver, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            ::QDnsLookup::Type cppArg0 = static_cast< ::QDnsLookup::Type>(0);
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return -1;
            ::QHostAddress cppArg2_local;
            ::QHostAddress *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (!Shiboken::Object::isValid(pyArgs[3]))
                return -1;
            ::QObject *cppArg3 = nullptr;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDnsLookup(QDnsLookup::Type,QString,QHostAddress,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QDnsLookupWrapper(cppArg0, cppArg1, *cppArg2, cppArg3);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QDnsLookupWrapper(cppArg0, cppArg1, *cppArg2, cppArg3);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[3], self);
            }
            break;
        }
        case 3: // QDnsLookup(QDnsLookup::Type type, const QString &name, const QHostAddress &nameserver, quint16 port, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            ::QDnsLookup::Type cppArg0 = static_cast< ::QDnsLookup::Type>(0);
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return -1;
            ::QHostAddress cppArg2_local;
            ::QHostAddress *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);

            quint16 cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return -1;
            ::QObject *cppArg4 = nullptr;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDnsLookup(QDnsLookup::Type,QString,QHostAddress,quint16,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QDnsLookupWrapper(cppArg0, cppArg1, *cppArg2, cppArg3, cppArg4);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QDnsLookupWrapper(cppArg0, cppArg1, *cppArg2, cppArg3, cppArg4);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[4], self);
            }
            break;
        }
        case 4: // QDnsLookup(QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0 = nullptr;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDnsLookup(QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QDnsLookupWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QDnsLookupWrapper(cppArg0);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QDnsLookup >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QDnsLookupFunc_abort(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDnsLookup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // abort()
        cppSelf->abort();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDnsLookupFunc_canonicalNameRecords(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDnsLookup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // canonicalNameRecords()const
        QList<QDnsDomainNameRecord> cppResult = const_cast<const ::QDnsLookup *>(cppSelf)->canonicalNameRecords();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QDnsDomainNameRecord_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDnsLookupFunc_defaultPortForProtocol(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QDnsLookup::defaultPortForProtocol(QDnsLookup::Protocol)->quint16
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_Protocol_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // defaultPortForProtocol(QDnsLookup::Protocol)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "defaultPortForProtocol", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]);

    // Call function/method
    {
        ::QDnsLookup::Protocol cppArg0{QDnsLookup::Standard};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // defaultPortForProtocol(QDnsLookup::Protocol)
            quint16 cppResult = ::QDnsLookup::defaultPortForProtocol(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDnsLookupFunc_error(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDnsLookup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // error()const
        QDnsLookup::Error cppResult = const_cast<const ::QDnsLookup *>(cppSelf)->error();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_Error_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDnsLookupFunc_errorString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDnsLookup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // errorString()const
        QString cppResult = const_cast<const ::QDnsLookup *>(cppSelf)->errorString();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDnsLookupFunc_hostAddressRecords(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDnsLookup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hostAddressRecords()const
        QList<QDnsHostAddressRecord> cppResult = const_cast<const ::QDnsLookup *>(cppSelf)->hostAddressRecords();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QDnsHostAddressRecord_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDnsLookupFunc_isAuthenticData(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDnsLookup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isAuthenticData()const
        bool cppResult = const_cast<const ::QDnsLookup *>(cppSelf)->isAuthenticData();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDnsLookupFunc_isFinished(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDnsLookup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isFinished()const
        bool cppResult = const_cast<const ::QDnsLookup *>(cppSelf)->isFinished();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDnsLookupFunc_isProtocolSupported(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QDnsLookup::isProtocolSupported(QDnsLookup::Protocol)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_Protocol_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // isProtocolSupported(QDnsLookup::Protocol)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isProtocolSupported", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]);

    // Call function/method
    {
        ::QDnsLookup::Protocol cppArg0{QDnsLookup::Standard};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isProtocolSupported(QDnsLookup::Protocol)
            bool cppResult = ::QDnsLookup::isProtocolSupported(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDnsLookupFunc_lookup(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDnsLookup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lookup()
        cppSelf->lookup();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDnsLookupFunc_mailExchangeRecords(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDnsLookup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // mailExchangeRecords()const
        QList<QDnsMailExchangeRecord> cppResult = const_cast<const ::QDnsLookup *>(cppSelf)->mailExchangeRecords();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QDnsMailExchangeRecord_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDnsLookupFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDnsLookup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // name()const
        QString cppResult = const_cast<const ::QDnsLookup *>(cppSelf)->name();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDnsLookupFunc_nameServerRecords(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDnsLookup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // nameServerRecords()const
        QList<QDnsDomainNameRecord> cppResult = const_cast<const ::QDnsLookup *>(cppSelf)->nameServerRecords();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QDnsDomainNameRecord_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDnsLookupFunc_nameserver(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDnsLookup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // nameserver()const
        QHostAddress cppResult = const_cast<const ::QDnsLookup *>(cppSelf)->nameserver();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDnsLookupFunc_nameserverPort(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDnsLookup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // nameserverPort()const
        quint16 cppResult = const_cast<const ::QDnsLookup *>(cppSelf)->nameserverPort();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDnsLookupFunc_nameserverProtocol(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDnsLookup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // nameserverProtocol()const
        QDnsLookup::Protocol cppResult = const_cast<const ::QDnsLookup *>(cppSelf)->nameserverProtocol();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_Protocol_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDnsLookupFunc_pointerRecords(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDnsLookup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pointerRecords()const
        QList<QDnsDomainNameRecord> cppResult = const_cast<const ::QDnsLookup *>(cppSelf)->pointerRecords();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QDnsDomainNameRecord_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDnsLookupFunc_serviceRecords(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDnsLookup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // serviceRecords()const
        QList<QDnsServiceRecord> cppResult = const_cast<const ::QDnsLookup *>(cppSelf)->serviceRecords();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QDnsServiceRecord_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDnsLookupFunc_setName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDnsLookup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDnsLookup::setName(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setName", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setName(QString)
            cppSelf->setName(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDnsLookupFunc_setNameserver(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDnsLookup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setNameserver", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:setNameserver", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDnsLookup::setNameserver(QDnsLookup::Protocol,QHostAddress,quint16=)
    // 1: QDnsLookup::setNameserver(QHostAddress)
    // 2: QDnsLookup::setNameserver(QHostAddress,quint16)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // setNameserver(QHostAddress)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArgs[1])))) {
            overloadId = 2; // setNameserver(QHostAddress,quint16)
        }
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_Protocol_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // setNameserver(QDnsLookup::Protocol,QHostAddress,quint16)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArgs[2])))) {
            overloadId = 0; // setNameserver(QDnsLookup::Protocol,QHostAddress,quint16)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setNameserver", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setNameserver(QDnsLookup::Protocol protocol, const QHostAddress &nameserver, quint16 port)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_port = Shiboken::String::createStaticString("port");
                if (PyDict_Contains(kwds, key_port) != 0) {
                    value = PyDict_GetItem(kwds, key_port);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_port);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "setNameserver", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "setNameserver", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_port);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "setNameserver", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]);
                }
            }
            ::QDnsLookup::Protocol cppArg0{QDnsLookup::Standard};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QHostAddress cppArg1_local;
            ::QHostAddress *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            quint16 cppArg2 = 0;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setNameserver(QDnsLookup::Protocol,QHostAddress,quint16)
                cppSelf->setNameserver(cppArg0, *cppArg1, cppArg2);
            }
            break;
        }
        case 1: // setNameserver(const QHostAddress &nameserver)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setNameserver", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QHostAddress cppArg0_local;
            ::QHostAddress *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setNameserver(QHostAddress)
                cppSelf->setNameserver(*cppArg0);
            }
            break;
        }
        case 2: // setNameserver(const QHostAddress &nameserver, quint16 port)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setNameserver", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QHostAddress cppArg0_local;
            ::QHostAddress *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            quint16 cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setNameserver(QHostAddress,quint16)
                cppSelf->setNameserver(*cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDnsLookupFunc_setNameserverPort(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDnsLookup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDnsLookup::setNameserverPort(quint16)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArg)))) {
        overloadId = 0; // setNameserverPort(quint16)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setNameserverPort", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]);

    // Call function/method
    {
        quint16 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setNameserverPort(quint16)
            cppSelf->setNameserverPort(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDnsLookupFunc_setNameserverProtocol(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDnsLookup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDnsLookup::setNameserverProtocol(QDnsLookup::Protocol)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_Protocol_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setNameserverProtocol(QDnsLookup::Protocol)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setNameserverProtocol", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]);

    // Call function/method
    {
        ::QDnsLookup::Protocol cppArg0{QDnsLookup::Standard};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setNameserverProtocol(QDnsLookup::Protocol)
            cppSelf->setNameserverProtocol(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDnsLookupFunc_setSslConfiguration(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDnsLookup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDnsLookup::setSslConfiguration(QSslConfiguration)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslConfiguration_IDX]), (pyArg)))) {
        overloadId = 0; // setSslConfiguration(QSslConfiguration)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSslConfiguration", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSslConfiguration cppArg0_local;
        ::QSslConfiguration *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setSslConfiguration(QSslConfiguration)
            cppSelf->setSslConfiguration(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDnsLookupFunc_setType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDnsLookup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDnsLookup::setType(QDnsLookup::Type)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_Type_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setType(QDnsLookup::Type)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setType", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]);

    // Call function/method
    {
        ::QDnsLookup::Type cppArg0 = static_cast< ::QDnsLookup::Type>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setType(QDnsLookup::Type)
            cppSelf->setType(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDnsLookupFunc_sslConfiguration(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDnsLookup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sslConfiguration()const
        QSslConfiguration cppResult = const_cast<const ::QDnsLookup *>(cppSelf)->sslConfiguration();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslConfiguration_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDnsLookupFunc_textRecords(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDnsLookup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // textRecords()const
        QList<QDnsTextRecord> cppResult = const_cast<const ::QDnsLookup *>(cppSelf)->textRecords();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QDnsTextRecord_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDnsLookupFunc_tlsAssociationRecords(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDnsLookup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // tlsAssociationRecords()const
        QList<QDnsTlsAssociationRecord> cppResult = const_cast<const ::QDnsLookup *>(cppSelf)->tlsAssociationRecords();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QDnsTlsAssociationRecord_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDnsLookupFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDnsLookup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        QDnsLookup::Type cppResult = const_cast<const ::QDnsLookup *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_Type_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QDnsLookup_PropertyStrings[] = {
    "authenticData:isAuthenticData",
    "error:",
    "errorString:",
    "name::",
    "nameserver::",
    "nameserverPort::",
    "nameserverProtocol::",
    "type::",
    nullptr // Sentinel
};

static const char *Sbk_QDnsLookup_EnumFlagInfo[] = {
    "Error:Enum",
    "Protocol:Enum",
    "Type:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDnsLookup_methods[] = {
    {"abort", reinterpret_cast<PyCFunction>(Sbk_QDnsLookupFunc_abort), METH_NOARGS, nullptr},
    {"canonicalNameRecords", reinterpret_cast<PyCFunction>(Sbk_QDnsLookupFunc_canonicalNameRecords), METH_NOARGS, nullptr},
    {"defaultPortForProtocol", reinterpret_cast<PyCFunction>(Sbk_QDnsLookupFunc_defaultPortForProtocol), METH_O|METH_STATIC, nullptr},
    {"error", reinterpret_cast<PyCFunction>(Sbk_QDnsLookupFunc_error), METH_NOARGS, nullptr},
    {"errorString", reinterpret_cast<PyCFunction>(Sbk_QDnsLookupFunc_errorString), METH_NOARGS, nullptr},
    {"hostAddressRecords", reinterpret_cast<PyCFunction>(Sbk_QDnsLookupFunc_hostAddressRecords), METH_NOARGS, nullptr},
    {"isAuthenticData", reinterpret_cast<PyCFunction>(Sbk_QDnsLookupFunc_isAuthenticData), METH_NOARGS, nullptr},
    {"isFinished", reinterpret_cast<PyCFunction>(Sbk_QDnsLookupFunc_isFinished), METH_NOARGS, nullptr},
    {"isProtocolSupported", reinterpret_cast<PyCFunction>(Sbk_QDnsLookupFunc_isProtocolSupported), METH_O|METH_STATIC, nullptr},
    {"lookup", reinterpret_cast<PyCFunction>(Sbk_QDnsLookupFunc_lookup), METH_NOARGS, nullptr},
    {"mailExchangeRecords", reinterpret_cast<PyCFunction>(Sbk_QDnsLookupFunc_mailExchangeRecords), METH_NOARGS, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_QDnsLookupFunc_name), METH_NOARGS, nullptr},
    {"nameServerRecords", reinterpret_cast<PyCFunction>(Sbk_QDnsLookupFunc_nameServerRecords), METH_NOARGS, nullptr},
    {"nameserver", reinterpret_cast<PyCFunction>(Sbk_QDnsLookupFunc_nameserver), METH_NOARGS, nullptr},
    {"nameserverPort", reinterpret_cast<PyCFunction>(Sbk_QDnsLookupFunc_nameserverPort), METH_NOARGS, nullptr},
    {"nameserverProtocol", reinterpret_cast<PyCFunction>(Sbk_QDnsLookupFunc_nameserverProtocol), METH_NOARGS, nullptr},
    {"pointerRecords", reinterpret_cast<PyCFunction>(Sbk_QDnsLookupFunc_pointerRecords), METH_NOARGS, nullptr},
    {"serviceRecords", reinterpret_cast<PyCFunction>(Sbk_QDnsLookupFunc_serviceRecords), METH_NOARGS, nullptr},
    {"setName", reinterpret_cast<PyCFunction>(Sbk_QDnsLookupFunc_setName), METH_O, nullptr},
    {"setNameserver", reinterpret_cast<PyCFunction>(Sbk_QDnsLookupFunc_setNameserver), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setNameserverPort", reinterpret_cast<PyCFunction>(Sbk_QDnsLookupFunc_setNameserverPort), METH_O, nullptr},
    {"setNameserverProtocol", reinterpret_cast<PyCFunction>(Sbk_QDnsLookupFunc_setNameserverProtocol), METH_O, nullptr},
    {"setSslConfiguration", reinterpret_cast<PyCFunction>(Sbk_QDnsLookupFunc_setSslConfiguration), METH_O, nullptr},
    {"setType", reinterpret_cast<PyCFunction>(Sbk_QDnsLookupFunc_setType), METH_O, nullptr},
    {"sslConfiguration", reinterpret_cast<PyCFunction>(Sbk_QDnsLookupFunc_sslConfiguration), METH_NOARGS, nullptr},
    {"textRecords", reinterpret_cast<PyCFunction>(Sbk_QDnsLookupFunc_textRecords), METH_NOARGS, nullptr},
    {"tlsAssociationRecords", reinterpret_cast<PyCFunction>(Sbk_QDnsLookupFunc_tlsAssociationRecords), METH_NOARGS, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QDnsLookupFunc_type), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QDnsLookup_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QDnsLookup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QDnsLookupWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QDnsLookup_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDnsLookup_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDnsLookup_Type = nullptr;
static PyTypeObject *Sbk_QDnsLookup_TypeF(void)
{
    return _Sbk_QDnsLookup_Type;
}

static PyType_Slot Sbk_QDnsLookup_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QDnsLookup_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDnsLookup_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDnsLookup_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDnsLookup_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDnsLookup_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDnsLookup_spec = {
    "2:PySide6.QtNetwork.QDnsLookup",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDnsLookup_slots
};

} //extern "C"

static void *Sbk_QDnsLookup_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QDnsLookup *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QDnsLookup_Error(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QDnsLookup::Error>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QDnsLookup::Error *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QDnsLookup_Error_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_Error_IDX])))
        return Enum_PythonToCpp_QDnsLookup_Error;
    return {};
}

static PyObject *QDnsLookup_Error_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QDnsLookup::Error>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QDnsLookup::Error *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_Error_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QDnsLookup_Type(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QDnsLookup::Type>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QDnsLookup::Type *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QDnsLookup_Type_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_Type_IDX])))
        return Enum_PythonToCpp_QDnsLookup_Type;
    return {};
}

static PyObject *QDnsLookup_Type_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QDnsLookup::Type>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QDnsLookup::Type *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_Type_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QDnsLookup_Protocol(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QDnsLookup::Protocol>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QDnsLookup::Protocol *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QDnsLookup_Protocol_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_Protocol_IDX])))
        return Enum_PythonToCpp_QDnsLookup_Protocol;
    return {};
}

static PyObject *QDnsLookup_Protocol_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QDnsLookup::Protocol>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QDnsLookup::Protocol *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_Protocol_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDnsLookup_PythonToCpp_QDnsLookup_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDnsLookup_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDnsLookup_PythonToCpp_QDnsLookup_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDnsLookup_TypeF()))
        return QDnsLookup_PythonToCpp_QDnsLookup_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDnsLookup_PTR_CppToPython_QDnsLookup(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QDnsLookup *>(const_cast<void *>(cppIn)), Sbk_QDnsLookup_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QDnsLookup_SignatureStrings[] = {
    "4:PySide6.QtNetwork.QDnsLookup(self,type:PySide6.QtNetwork.QDnsLookup.Type,name:QString,protocol:PySide6.QtNetwork.QDnsLookup.Protocol,nameserver:typing.Union[PySide6.QtNetwork.QHostAddress, PySide6.QtNetwork.QHostAddress.SpecialAddress],port:quint16=0,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,error:QDnsLookup.Error=None,authenticData:bool=None,errorString:QString=None,name:QString=None,type:QDnsLookup.Type=None,nameserver:QHostAddress=None,nameserverPort:quint16=None,nameserverProtocol:QDnsLookup.Protocol=None)",
    "3:PySide6.QtNetwork.QDnsLookup(self,type:PySide6.QtNetwork.QDnsLookup.Type,name:QString,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,error:QDnsLookup.Error=None,authenticData:bool=None,errorString:QString=None,name:QString=None,type:QDnsLookup.Type=None,nameserver:QHostAddress=None,nameserverPort:quint16=None,nameserverProtocol:QDnsLookup.Protocol=None)",
    "2:PySide6.QtNetwork.QDnsLookup(self,type:PySide6.QtNetwork.QDnsLookup.Type,name:QString,nameserver:typing.Union[PySide6.QtNetwork.QHostAddress, PySide6.QtNetwork.QHostAddress.SpecialAddress],parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,error:QDnsLookup.Error=None,authenticData:bool=None,errorString:QString=None,name:QString=None,type:QDnsLookup.Type=None,nameserver:QHostAddress=None,nameserverPort:quint16=None,nameserverProtocol:QDnsLookup.Protocol=None)",
    "1:PySide6.QtNetwork.QDnsLookup(self,type:PySide6.QtNetwork.QDnsLookup.Type,name:QString,nameserver:typing.Union[PySide6.QtNetwork.QHostAddress, PySide6.QtNetwork.QHostAddress.SpecialAddress],port:quint16,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,error:QDnsLookup.Error=None,authenticData:bool=None,errorString:QString=None,name:QString=None,type:QDnsLookup.Type=None,nameserver:QHostAddress=None,nameserverPort:quint16=None,nameserverProtocol:QDnsLookup.Protocol=None)",
    "0:PySide6.QtNetwork.QDnsLookup(self,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,error:QDnsLookup.Error=None,authenticData:bool=None,errorString:QString=None,name:QString=None,type:QDnsLookup.Type=None,nameserver:QHostAddress=None,nameserverPort:quint16=None,nameserverProtocol:QDnsLookup.Protocol=None)",
    "PySide6.QtNetwork.QDnsLookup.abort(self)",
    "PySide6.QtNetwork.QDnsLookup.canonicalNameRecords(self)->QList[PySide6.QtNetwork.QDnsDomainNameRecord]",
    "PySide6.QtNetwork.QDnsLookup.defaultPortForProtocol(protocol:PySide6.QtNetwork.QDnsLookup.Protocol)->quint16",
    "PySide6.QtNetwork.QDnsLookup.error(self)->PySide6.QtNetwork.QDnsLookup.Error",
    "PySide6.QtNetwork.QDnsLookup.errorString(self)->QString",
    "PySide6.QtNetwork.QDnsLookup.hostAddressRecords(self)->QList[PySide6.QtNetwork.QDnsHostAddressRecord]",
    "PySide6.QtNetwork.QDnsLookup.isAuthenticData(self)->bool",
    "PySide6.QtNetwork.QDnsLookup.isFinished(self)->bool",
    "PySide6.QtNetwork.QDnsLookup.isProtocolSupported(protocol:PySide6.QtNetwork.QDnsLookup.Protocol)->bool",
    "PySide6.QtNetwork.QDnsLookup.lookup(self)",
    "PySide6.QtNetwork.QDnsLookup.mailExchangeRecords(self)->QList[PySide6.QtNetwork.QDnsMailExchangeRecord]",
    "PySide6.QtNetwork.QDnsLookup.name(self)->QString",
    "PySide6.QtNetwork.QDnsLookup.nameServerRecords(self)->QList[PySide6.QtNetwork.QDnsDomainNameRecord]",
    "PySide6.QtNetwork.QDnsLookup.nameserver(self)->PySide6.QtNetwork.QHostAddress",
    "PySide6.QtNetwork.QDnsLookup.nameserverPort(self)->quint16",
    "PySide6.QtNetwork.QDnsLookup.nameserverProtocol(self)->PySide6.QtNetwork.QDnsLookup.Protocol",
    "PySide6.QtNetwork.QDnsLookup.pointerRecords(self)->QList[PySide6.QtNetwork.QDnsDomainNameRecord]",
    "PySide6.QtNetwork.QDnsLookup.serviceRecords(self)->QList[PySide6.QtNetwork.QDnsServiceRecord]",
    "PySide6.QtNetwork.QDnsLookup.setName(self,name:QString)",
    "2:PySide6.QtNetwork.QDnsLookup.setNameserver(self,protocol:PySide6.QtNetwork.QDnsLookup.Protocol,nameserver:typing.Union[PySide6.QtNetwork.QHostAddress, PySide6.QtNetwork.QHostAddress.SpecialAddress],port:quint16=0)",
    "1:PySide6.QtNetwork.QDnsLookup.setNameserver(self,nameserver:typing.Union[PySide6.QtNetwork.QHostAddress, PySide6.QtNetwork.QHostAddress.SpecialAddress])",
    "0:PySide6.QtNetwork.QDnsLookup.setNameserver(self,nameserver:typing.Union[PySide6.QtNetwork.QHostAddress, PySide6.QtNetwork.QHostAddress.SpecialAddress],port:quint16)",
    "PySide6.QtNetwork.QDnsLookup.setNameserverPort(self,port:quint16)",
    "PySide6.QtNetwork.QDnsLookup.setNameserverProtocol(self,protocol:PySide6.QtNetwork.QDnsLookup.Protocol)",
    "PySide6.QtNetwork.QDnsLookup.setSslConfiguration(self,sslConfiguration:PySide6.QtNetwork.QSslConfiguration)",
    "PySide6.QtNetwork.QDnsLookup.setType(self,arg__1:PySide6.QtNetwork.QDnsLookup.Type)",
    "PySide6.QtNetwork.QDnsLookup.sslConfiguration(self)->PySide6.QtNetwork.QSslConfiguration",
    "PySide6.QtNetwork.QDnsLookup.textRecords(self)->QList[PySide6.QtNetwork.QDnsTextRecord]",
    "PySide6.QtNetwork.QDnsLookup.tlsAssociationRecords(self)->QList[PySide6.QtNetwork.QDnsTlsAssociationRecord]",
    "PySide6.QtNetwork.QDnsLookup.type(self)->PySide6.QtNetwork.QDnsLookup.Type",
    nullptr}; // Sentinel
#else
static constexpr size_t QDnsLookup_SignatureByteSize = 623;
static constexpr uint8_t QDnsLookup_SignatureBytes[623] = {
    0x78, 0xda, 0xed, 0x57, 0x5d, 0x4f, 0xdb, 0x30, 0x14, 0x7d, 0xef, 0xaf, 0xd8, 0x23, 0x4c, 0x59,
    0x44, 0xb7, 0x89, 0x87, 0x48, 0x9d, 0x54, 0x51, 0x10, 0xd2, 0x58, 0x69, 0x17, 0x78, 0x42, 0x08,
    0xb9, 0x89, 0xdb, 0x7a, 0x18, 0x3b, 0xb3, 0x6f, 0x36, 0xfa, 0xef, 0x67, 0x27, 0x4d, 0x62, 0x82,
    0x67, 0x27, 0x48, 0x05, 0x21, 0xf5, 0x31, 0xf1, 0x3d, 0xf7, 0xe3, 0x9c, 0x7b, 0x6f, 0x9c, 0xaf,
    0xd1, 0x6c, 0x13, 0x93, 0x14, 0x1f, 0x87, 0x73, 0x98, 0x62, 0xf8, 0xcb, 0xc5, 0x7d, 0x38, 0x9f,
    0x30, 0x79, 0xc1, 0xf9, 0x7d, 0x9e, 0x1d, 0x48, 0x4c, 0x97, 0x01, 0x6c, 0x32, 0xec, 0x34, 0x0b,
    0xaf, 0x94, 0x45, 0xc0, 0xd0, 0x03, 0x8e, 0xe6, 0x31, 0x08, 0xc2, 0x56, 0x41, 0x26, 0x38, 0xf0,
    0x84, 0x53, 0x37, 0x6e, 0xb6, 0xb5, 0x2a, 0xb0, 0x12, 0x8b, 0x3f, 0x58, 0x44, 0x2a, 0x9a, 0x72,
    0x10, 0x5e, 0x33, 0xc2, 0xd9, 0x8d, 0x05, 0x7d, 0xce, 0x25, 0x8c, 0xd3, 0x54, 0x60, 0x29, 0x83,
    0x0f, 0xee, 0xf3, 0x30, 0xce, 0x70, 0x42, 0x10, 0xdd, 0x3e, 0xde, 0x06, 0x19, 0x17, 0x10, 0xfd,
    0xce, 0x09, 0x83, 0xe1, 0xf1, 0xe8, 0x28, 0xc8, 0x90, 0xc0, 0x0c, 0x8c, 0x14, 0x4f, 0xb8, 0xc0,
    0xe1, 0xfc, 0x72, 0xf1, 0x0b, 0x27, 0x30, 0x62, 0x39, 0xa5, 0x19, 0x88, 0xe0, 0x63, 0xf4, 0x1d,
    0x6f, 0x94, 0xef, 0xf4, 0x92, 0xd1, 0xcd, 0x68, 0xca, 0x19, 0x0e, 0xb0, 0x10, 0x5c, 0x44, 0x46,
    0x21, 0xa7, 0xfa, 0x45, 0x79, 0x86, 0x72, 0x58, 0x2b, 0xaf, 0x24, 0x99, 0x20, 0x40, 0xd1, 0x82,
    0x73, 0x6a, 0x60, 0x4a, 0x76, 0x2a, 0x96, 0xca, 0x03, 0x93, 0xb7, 0xf2, 0x4d, 0x41, 0x78, 0x8b,
    0xde, 0xc6, 0x76, 0xcb, 0x93, 0x59, 0x68, 0xfb, 0x70, 0x66, 0xd6, 0xd9, 0x3e, 0xab, 0x94, 0xb1,
    0xe8, 0x50, 0xd8, 0x1e, 0x0e, 0xbe, 0xec, 0xaa, 0x29, 0xf6, 0x7c, 0x5b, 0xf9, 0xfe, 0xbc, 0x23,
    0xbe, 0x5f, 0x6b, 0xaa, 0xf6, 0xb2, 0x5a, 0x65, 0x1d, 0xbe, 0x73, 0x59, 0x8d, 0xea, 0xf7, 0x1a,
    0xff, 0x47, 0xe3, 0xa3, 0x0e, 0x1a, 0xef, 0xb9, 0xb3, 0x73, 0xe7, 0x6c, 0x7b, 0xb4, 0x50, 0xce,
    0x0b, 0xfe, 0x3c, 0x86, 0x09, 0x62, 0x9c, 0x91, 0x04, 0xd1, 0xa9, 0x8a, 0xfd, 0x13, 0x27, 0x8a,
    0x41, 0x59, 0xe2, 0x3e, 0x7d, 0x9b, 0x5f, 0x10, 0x09, 0x37, 0x76, 0xf8, 0x84, 0x3f, 0x20, 0xc2,
    0x1a, 0xd0, 0xad, 0x3b, 0x4c, 0x8a, 0x97, 0x28, 0xa7, 0xa0, 0x4b, 0x3e, 0xe3, 0x75, 0x75, 0x07,
    0xfd, 0xee, 0x39, 0x2a, 0xa5, 0x2d, 0x5d, 0xee, 0x60, 0x85, 0x88, 0x55, 0x11, 0x4e, 0xcb, 0xa2,
    0x23, 0x3a, 0x38, 0x2b, 0x75, 0xaf, 0x79, 0x29, 0x1f, 0xdd, 0xb8, 0x75, 0x23, 0x7c, 0x0f, 0x5a,
    0xcf, 0xdb, 0x28, 0x0f, 0xaf, 0x44, 0x8e, 0xcd, 0x4e, 0xae, 0x42, 0xe8, 0x86, 0xf6, 0x01, 0xcf,
    0x08, 0x23, 0x72, 0x8d, 0xd3, 0x3e, 0x98, 0x4a, 0x89, 0x38, 0xcf, 0xf4, 0x7e, 0x53, 0xe0, 0xde,
    0x0a, 0xfa, 0xc3, 0xd0, 0x66, 0xf8, 0x3d, 0xcd, 0xab, 0x5a, 0x90, 0x9e, 0x3e, 0x26, 0x6b, 0xc4,
    0x56, 0x7d, 0x7a, 0xf7, 0xc7, 0x33, 0x98, 0x87, 0x65, 0x3d, 0x97, 0xbd, 0xc4, 0xd7, 0x80, 0xb8,
    0x18, 0xe4, 0xdd, 0x8d, 0x54, 0xb3, 0x2c, 0x1c, 0xad, 0x6e, 0xf4, 0x53, 0x57, 0x6f, 0xb3, 0x7a,
    0x73, 0x74, 0x1c, 0xb7, 0xe7, 0x5b, 0xab, 0xd3, 0xec, 0x55, 0xc6, 0x6e, 0xe7, 0x19, 0x57, 0x19,
    0xec, 0x92, 0x46, 0x9d, 0x39, 0x49, 0xfa, 0xb4, 0x4f, 0x6c, 0x22, 0xbc, 0xde, 0x61, 0x5a, 0x35,
    0xcf, 0x93, 0x6f, 0x88, 0xef, 0xda, 0x5a, 0x21, 0x0d, 0x85, 0xdf, 0xc5, 0x5f, 0xa1, 0xef, 0xde,
    0x66, 0xab, 0xeb, 0x75, 0x12, 0xf5, 0xdd, 0x36, 0xde, 0x2e, 0xb3, 0x27, 0x14, 0x1e, 0x0e, 0xba,
    0x27, 0x59, 0x8f, 0xea, 0xcb, 0x3d, 0x98, 0x13, 0xdb, 0xb3, 0xc1, 0xfc, 0x71, 0x62, 0x49, 0x4f,
    0x38, 0x5b, 0x92, 0x55, 0x2e, 0x10, 0x28, 0xde, 0xca, 0x28, 0xb2, 0xf5, 0xd6, 0x16, 0xad, 0x8d,
    0xf4, 0xc7, 0xd2, 0xd7, 0xaf, 0xd2, 0x3f, 0x12, 0xab, 0xbb, 0xbb, 0xa1, 0xff, 0xb7, 0xc0, 0xe7,
    0xd3, 0x96, 0xbc, 0x7d, 0xa9, 0xb5, 0xb3, 0x75, 0x3b, 0x06, 0xfc, 0x08, 0x3d, 0xd6, 0xcd, 0x55,
    0x6d, 0xee, 0xd9, 0x35, 0x40, 0xe5, 0x58, 0x4a, 0xae, 0x3a, 0x4b, 0xe7, 0xd0, 0x27, 0x82, 0x05,
    0xe8, 0x8b, 0x55, 0xb1, 0xed, 0xdb, 0xf2, 0x9a, 0xe8, 0xc1, 0x3f, 0xe8, 0x2c, 0x1f, 0x52
};
#endif

PyTypeObject *init_QDnsLookup(PyObject *module)
{
    if (SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX].type != nullptr)
        return SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX].type;

    Shiboken::AutoDecRef Sbk_QDnsLookup_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QDnsLookup_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDnsLookup",
        "QDnsLookup*",
        &Sbk_QDnsLookup_spec,
        &Shiboken::callCppDestructor< QDnsLookup >,
        Sbk_QDnsLookup_Type_bases.object(),
        0);
    auto *pyType = Sbk_QDnsLookup_TypeF(); // references _Sbk_QDnsLookup_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QDnsLookup_SignatureStrings);
#else
    InitSignatureBytes(pyType, QDnsLookup_SignatureBytes, QDnsLookup_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDnsLookup_PropertyStrings);
    SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDnsLookup_PythonToCpp_QDnsLookup_PTR,
        is_QDnsLookup_PythonToCpp_QDnsLookup_PTR_Convertible,
        QDnsLookup_PTR_CppToPython_QDnsLookup);

    Shiboken::Conversions::registerConverterName(converter, "QDnsLookup");
    Shiboken::Conversions::registerConverterName(converter, "QDnsLookup*");
    Shiboken::Conversions::registerConverterName(converter, "QDnsLookup&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDnsLookup).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QDnsLookupWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QDnsLookup_TypeF(), &Sbk_QDnsLookup_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QDnsLookup_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Error'.
    const char *Error_Initializer[] = {
        "NoError",
        "ResolverError",
        "OperationCancelledError",
        "InvalidRequestError",
        "InvalidReplyError",
        "ServerFailureError",
        "ServerRefusedError",
        "NotFoundError",
        "TimeoutError",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Error_InitializerValues[] = {
        uint8_t(QDnsLookup::Error::NoError),                 //  0x00  0
        uint8_t(QDnsLookup::Error::ResolverError),           //  0x01  1
        uint8_t(QDnsLookup::Error::OperationCancelledError), //  0x02  2
        uint8_t(QDnsLookup::Error::InvalidRequestError),     //  0x03  3
        uint8_t(QDnsLookup::Error::InvalidReplyError),       //  0x04  4
        uint8_t(QDnsLookup::Error::ServerFailureError),      //  0x05  5
        uint8_t(QDnsLookup::Error::ServerRefusedError),      //  0x06  6
        uint8_t(QDnsLookup::Error::NotFoundError),           //  0x07  7
        uint8_t(QDnsLookup::Error::TimeoutError)             //  0x08  8
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QDnsLookup_TypeF(),
        "2:PySide6.QtNetwork.QDnsLookup.Error",
        Error_Initializer, Error_InitializerValues);
    SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_Error_IDX].type = EType;
    // Register converter for enum 'QDnsLookup::Error'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QDnsLookup_Error_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QDnsLookup_Error,
            is_Enum_PythonToCpp_QDnsLookup_Error_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QDnsLookup::Error");
        Shiboken::Conversions::registerConverterAlias(converter, "Error");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Error' enum.

    // Initialization of enum 'Type'.
    const char *Type_Initializer[] = {
        "A",
        "AAAA",
        "ANY",
        "CNAME",
        "MX",
        "NS",
        "PTR",
        "SRV",
        "TLSA",
        "TXT",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Type_InitializerValues[] = {
        uint8_t(QDnsLookup::Type::A),     //  0x01  1
        uint8_t(QDnsLookup::Type::AAAA),  //  0x1c  28
        uint8_t(QDnsLookup::Type::ANY),   //  0xff  255
        uint8_t(QDnsLookup::Type::CNAME), //  0x05  5
        uint8_t(QDnsLookup::Type::MX),    //  0x0f  15
        uint8_t(QDnsLookup::Type::NS),    //  0x02  2
        uint8_t(QDnsLookup::Type::PTR),   //  0x0c  12
        uint8_t(QDnsLookup::Type::SRV),   //  0x21  33
        uint8_t(QDnsLookup::Type::TLSA),  //  0x34  52
        uint8_t(QDnsLookup::Type::TXT)    //  0x10  16
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QDnsLookup_TypeF(),
        "2:PySide6.QtNetwork.QDnsLookup.Type",
        Type_Initializer, Type_InitializerValues);
    SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_Type_IDX].type = EType;
    // Register converter for enum 'QDnsLookup::Type'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QDnsLookup_Type_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QDnsLookup_Type,
            is_Enum_PythonToCpp_QDnsLookup_Type_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QDnsLookup::Type");
        Shiboken::Conversions::registerConverterAlias(converter, "Type");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Type' enum.

    // Initialization of enum 'Protocol'.
    const char *Protocol_Initializer[] = {
        "Standard",
        "DnsOverTls",
        nullptr};
    // "uint8_t" used instead of "unsigned char"
    constexpr uint8_t Protocol_InitializerValues[] = {
        uint8_t(QDnsLookup::Protocol::Standard),  //  0x00  0
        uint8_t(QDnsLookup::Protocol::DnsOverTls) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QDnsLookup_TypeF(),
        "2:PySide6.QtNetwork.QDnsLookup.Protocol",
        Protocol_Initializer, Protocol_InitializerValues);
    SbkPySide6_QtNetworkTypeStructs[SBK_QDnsLookup_Protocol_IDX].type = EType;
    // Register converter for enum 'QDnsLookup::Protocol'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QDnsLookup_Protocol_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QDnsLookup_Protocol,
            is_Enum_PythonToCpp_QDnsLookup_Protocol_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QDnsLookup::Protocol");
        Shiboken::Conversions::registerConverterAlias(converter, "Protocol");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Protocol' enum.

    PySide::Signal::registerSignals(pyType, &::QDnsLookup::staticMetaObject);
    qRegisterMetaType< ::QDnsLookup::Error >("QDnsLookup::Error");
    qRegisterMetaType< ::QDnsLookup::Type >("QDnsLookup::Type");
    qRegisterMetaType< ::QDnsLookup::Protocol >("QDnsLookup::Protocol");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QDnsLookup::staticMetaObject, sizeof(QDnsLookupWrapper));

    return pyType;
}
