// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnetwork_python.h"

// main header
#include "qdnsmailexchangerecord_wrapper.h"

// Argument includes
#include <QString>
#include <QtNetwork/qdnslookup.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDnsMailExchangeRecord_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QDnsMailExchangeRecord >()))
        return -1;

    ::QDnsMailExchangeRecord *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QDnsMailExchangeRecord", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QDnsMailExchangeRecord::QDnsMailExchangeRecord()
    // 1: QDnsMailExchangeRecord::QDnsMailExchangeRecord(QDnsMailExchangeRecord)
    if (numArgs == 0) {
        overloadId = 0; // QDnsMailExchangeRecord()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsMailExchangeRecord_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QDnsMailExchangeRecord(QDnsMailExchangeRecord)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDnsMailExchangeRecord_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtNetworkTypeStructs[SBK_QDnsMailExchangeRecord_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QDnsMailExchangeRecord()
        {

            // QDnsMailExchangeRecord()
            cptr = new ::QDnsMailExchangeRecord();
            break;
        }
        case 1: // QDnsMailExchangeRecord(const QDnsMailExchangeRecord &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QDnsMailExchangeRecord cppArg0_local;
            ::QDnsMailExchangeRecord *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QDnsMailExchangeRecord(QDnsMailExchangeRecord)
                cptr = new ::QDnsMailExchangeRecord(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QDnsMailExchangeRecord >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDnsMailExchangeRecord_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QDnsMailExchangeRecordFunc_exchange(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDnsMailExchangeRecord *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsMailExchangeRecord_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // exchange()const
        QString cppResult = const_cast<const ::QDnsMailExchangeRecord *>(cppSelf)->exchange();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDnsMailExchangeRecordFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDnsMailExchangeRecord *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsMailExchangeRecord_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // name()const
        QString cppResult = const_cast<const ::QDnsMailExchangeRecord *>(cppSelf)->name();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDnsMailExchangeRecordFunc_preference(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDnsMailExchangeRecord *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsMailExchangeRecord_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // preference()const
        quint16 cppResult = const_cast<const ::QDnsMailExchangeRecord *>(cppSelf)->preference();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDnsMailExchangeRecordFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDnsMailExchangeRecord *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsMailExchangeRecord_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDnsMailExchangeRecord::swap(QDnsMailExchangeRecord&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsMailExchangeRecord_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QDnsMailExchangeRecord&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDnsMailExchangeRecord_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDnsMailExchangeRecord cppArg0_local;
        ::QDnsMailExchangeRecord *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QDnsMailExchangeRecord&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDnsMailExchangeRecordFunc_timeToLive(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDnsMailExchangeRecord *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsMailExchangeRecord_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // timeToLive()const
        quint32 cppResult = const_cast<const ::QDnsMailExchangeRecord *>(cppSelf)->timeToLive();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDnsMailExchangeRecord__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QDnsMailExchangeRecord *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsMailExchangeRecord_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsMailExchangeRecord_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QDnsMailExchangeRecord_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDnsMailExchangeRecord_methods[] = {
    {"exchange", reinterpret_cast<PyCFunction>(Sbk_QDnsMailExchangeRecordFunc_exchange), METH_NOARGS, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_QDnsMailExchangeRecordFunc_name), METH_NOARGS, nullptr},
    {"preference", reinterpret_cast<PyCFunction>(Sbk_QDnsMailExchangeRecordFunc_preference), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QDnsMailExchangeRecordFunc_swap), METH_O, nullptr},
    {"timeToLive", reinterpret_cast<PyCFunction>(Sbk_QDnsMailExchangeRecordFunc_timeToLive), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QDnsMailExchangeRecord__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QDnsMailExchangeRecord_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDnsMailExchangeRecord_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDnsMailExchangeRecord_Type = nullptr;
static PyTypeObject *Sbk_QDnsMailExchangeRecord_TypeF(void)
{
    return _Sbk_QDnsMailExchangeRecord_Type;
}

static PyType_Slot Sbk_QDnsMailExchangeRecord_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDnsMailExchangeRecord_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDnsMailExchangeRecord_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDnsMailExchangeRecord_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDnsMailExchangeRecord_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDnsMailExchangeRecord_spec = {
    "2:PySide6.QtNetwork.QDnsMailExchangeRecord",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDnsMailExchangeRecord_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDnsMailExchangeRecord_PythonToCpp_QDnsMailExchangeRecord_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDnsMailExchangeRecord_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDnsMailExchangeRecord_PythonToCpp_QDnsMailExchangeRecord_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDnsMailExchangeRecord_TypeF()))
        return QDnsMailExchangeRecord_PythonToCpp_QDnsMailExchangeRecord_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDnsMailExchangeRecord_PTR_CppToPython_QDnsMailExchangeRecord(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QDnsMailExchangeRecord_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QDnsMailExchangeRecord_COPY_CppToPython_QDnsMailExchangeRecord(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QDnsMailExchangeRecord *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QDnsMailExchangeRecord_TypeF(), new ::QDnsMailExchangeRecord(*source), true, true);
}

// Python to C++ copy conversion.
static void QDnsMailExchangeRecord_PythonToCpp_QDnsMailExchangeRecord_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QDnsMailExchangeRecord *>(cppOut) = *reinterpret_cast< ::QDnsMailExchangeRecord *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDnsMailExchangeRecord_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QDnsMailExchangeRecord_PythonToCpp_QDnsMailExchangeRecord_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QDnsMailExchangeRecord_TypeF()))
        return QDnsMailExchangeRecord_PythonToCpp_QDnsMailExchangeRecord_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QDnsMailExchangeRecord_SignatureStrings[] = {
    "1:PySide6.QtNetwork.QDnsMailExchangeRecord(self)",
    "0:PySide6.QtNetwork.QDnsMailExchangeRecord(self,other:PySide6.QtNetwork.QDnsMailExchangeRecord)",
    "PySide6.QtNetwork.QDnsMailExchangeRecord.exchange(self)->QString",
    "PySide6.QtNetwork.QDnsMailExchangeRecord.name(self)->QString",
    "PySide6.QtNetwork.QDnsMailExchangeRecord.preference(self)->quint16",
    "PySide6.QtNetwork.QDnsMailExchangeRecord.swap(self,other:PySide6.QtNetwork.QDnsMailExchangeRecord)",
    "PySide6.QtNetwork.QDnsMailExchangeRecord.timeToLive(self)->quint32",
    "PySide6.QtNetwork.QDnsMailExchangeRecord.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QDnsMailExchangeRecord_SignatureByteSize = 159;
static constexpr uint8_t QDnsMailExchangeRecord_SignatureBytes[159] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0xf1, 0x4b,
    0x2d, 0x29, 0xcf, 0x2f, 0xca, 0xd6, 0x0b, 0x74, 0xc9, 0x2b, 0xf6, 0x4d, 0xcc, 0xcc, 0x71, 0xad,
    0x48, 0xce, 0x48, 0xcc, 0x4b, 0x4f, 0x0d, 0x4a, 0x4d, 0xce, 0x2f, 0x4a, 0xd1, 0x28, 0x4e, 0xcd,
    0x49, 0xd3, 0xe4, 0x32, 0x20, 0x4d, 0x83, 0x4e, 0x7e, 0x49, 0x46, 0x6a, 0x11, 0xd1, 0x7a, 0x34,
    0xb9, 0x88, 0x55, 0xa9, 0x97, 0x0a, 0xe5, 0x42, 0xdc, 0xa5, 0x6b, 0x17, 0x18, 0x5c, 0x52, 0x94,
    0x99, 0x97, 0x4e, 0xbc, 0x01, 0x79, 0x89, 0xb9, 0xe4, 0x6b, 0x2e, 0x28, 0x4a, 0x4d, 0x4b, 0x2d,
    0x4a, 0xcd, 0x4b, 0x86, 0x1b, 0x51, 0x58, 0x9a, 0x99, 0x57, 0x62, 0x68, 0x46, 0xbc, 0x11, 0xc5,
    0xe5, 0x89, 0x05, 0x34, 0x0e, 0xa3, 0x92, 0xcc, 0xdc, 0xd4, 0x90, 0x7c, 0x9f, 0xcc, 0x32, 0x54,
    0x57, 0x1a, 0x1b, 0x11, 0x6f, 0x44, 0x7c, 0x7c, 0x72, 0x7e, 0x41, 0x65, 0x7c, 0x3c, 0xcc, 0x80,
    0x92, 0xca, 0x02, 0x60, 0x40, 0xe9, 0x05, 0x03, 0x79, 0x5c, 0x00, 0xc6, 0xd6, 0xd0, 0xa5
};
#endif

PyTypeObject *init_QDnsMailExchangeRecord(PyObject *module)
{
    if (SbkPySide6_QtNetworkTypeStructs[SBK_QDnsMailExchangeRecord_IDX].type != nullptr)
        return SbkPySide6_QtNetworkTypeStructs[SBK_QDnsMailExchangeRecord_IDX].type;

    Shiboken::AutoDecRef Sbk_QDnsMailExchangeRecord_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QDnsMailExchangeRecord_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDnsMailExchangeRecord",
        "QDnsMailExchangeRecord",
        &Sbk_QDnsMailExchangeRecord_spec,
        &Shiboken::callCppDestructor< ::QDnsMailExchangeRecord >,
        Sbk_QDnsMailExchangeRecord_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QDnsMailExchangeRecord_TypeF(); // references _Sbk_QDnsMailExchangeRecord_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QDnsMailExchangeRecord_SignatureStrings);
#else
    InitSignatureBytes(pyType, QDnsMailExchangeRecord_SignatureBytes, QDnsMailExchangeRecord_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDnsMailExchangeRecord_PropertyStrings);
    SbkPySide6_QtNetworkTypeStructs[SBK_QDnsMailExchangeRecord_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDnsMailExchangeRecord_PythonToCpp_QDnsMailExchangeRecord_PTR,
        is_QDnsMailExchangeRecord_PythonToCpp_QDnsMailExchangeRecord_PTR_Convertible,
        QDnsMailExchangeRecord_PTR_CppToPython_QDnsMailExchangeRecord,
        QDnsMailExchangeRecord_COPY_CppToPython_QDnsMailExchangeRecord);

    Shiboken::Conversions::registerConverterName(converter, "QDnsMailExchangeRecord");
    Shiboken::Conversions::registerConverterName(converter, "QDnsMailExchangeRecord*");
    Shiboken::Conversions::registerConverterName(converter, "QDnsMailExchangeRecord&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDnsMailExchangeRecord).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QDnsMailExchangeRecord_PythonToCpp_QDnsMailExchangeRecord_COPY,
        is_QDnsMailExchangeRecord_PythonToCpp_QDnsMailExchangeRecord_COPY_Convertible);

    qRegisterMetaType< ::QDnsMailExchangeRecord >("QDnsMailExchangeRecord");

    return pyType;
}
