// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnetwork_python.h"

// main header
#include "qdtls_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QtNetwork/qdtls.h>
#include <QtNetwork/qhostaddress.h>
#include <QtNetwork/qssl.h>
#include <QtNetwork/qsslcipher.h>
#include <QtNetwork/qsslconfiguration.h>
#include <QtNetwork/qsslerror.h>
#include <QtNetwork/qsslpresharedkeyauthenticator.h>
#include <QtNetwork/qsslsocket.h>
#include <QtNetwork/qudpsocket.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QDtlsWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QDtlsWrapper::QDtlsWrapper(::QSslSocket::SslMode mode, ::QObject * parent) : QDtls(mode, parent)
{
}

void QDtlsWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QDtls", funcName);
        return;
    }
}

void QDtlsWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QDtls", funcName);
        return;
    }
}

void QDtlsWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QDtls", funcName);
        return;
    }
}

void QDtlsWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QDtls", funcName);
        return;
    }
}

bool QDtlsWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QDtls", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QDtls", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QDtlsWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QDtls", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QDtls", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QDtlsWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QDtls", funcName);
        return;
    }
}

const QMetaObject *QDtlsWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QDtls::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QDtlsWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QDtls::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QDtlsWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QDtlsWrapper *>(this));
    return QDtls::qt_metacast(_clname);
}

QDtlsWrapper::~QDtlsWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDtls_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QDtls >()))
        return -1;

    QDtlsWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:QDtls", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QDtls::QDtls(QSslSocket::SslMode,QObject*=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslSocket_SslMode_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // QDtls(QSslSocket::SslMode,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 0; // QDtls(QSslSocket::SslMode,QObject*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                // fall through to handle extra keyword signals and properties
            }
        }
        ::QSslSocket::SslMode cppArg0{QSslSocket::UnencryptedMode};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return -1;
        ::QObject *cppArg1 = nullptr;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QDtls(QSslSocket::SslMode,QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QDtlsWrapper(cppArg0, cppArg1);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QDtlsWrapper(cppArg0, cppArg1);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[1], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QDtls >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QDtlsFunc_abortHandshake(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDtls *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDtls::abortHandshake(QUdpSocket*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QUdpSocket_IDX]), (pyArg)))) {
        overloadId = 0; // abortHandshake(QUdpSocket*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "abortHandshake", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUdpSocket *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // abortHandshake(QUdpSocket*)
            bool cppResult = cppSelf->abortHandshake(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDtlsFunc_cookieGeneratorParameters(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDtls *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cookieGeneratorParameters()const
        QDtlsClientVerifier::GeneratorParameters cppResult = const_cast<const ::QDtls *>(cppSelf)->cookieGeneratorParameters();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDtlsClientVerifier_GeneratorParameters_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDtlsFunc_decryptDatagram(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDtls *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "decryptDatagram", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDtls::decryptDatagram(QUdpSocket*,QByteArray)->QByteArray
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QUdpSocket_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
        overloadId = 0; // decryptDatagram(QUdpSocket*,QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "decryptDatagram", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QUdpSocket *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QByteArray cppArg1_local;
        ::QByteArray *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // decryptDatagram(QUdpSocket*,QByteArray)
            QByteArray cppResult = cppSelf->decryptDatagram(cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDtlsFunc_doHandshake(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDtls *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "doHandshake", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]);

    if (PyArg_ParseTuple(args, "|OO:doHandshake", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDtls::doHandshake(QUdpSocket*,const QByteArray&=)->bool
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QUdpSocket_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // doHandshake(QUdpSocket*,QByteArray)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
            overloadId = 0; // doHandshake(QUdpSocket*,QByteArray)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "doHandshake", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_dgram = Shiboken::String::createStaticString("dgram");
            if (PyDict_Contains(kwds, key_dgram) != 0) {
                value = PyDict_GetItem(kwds, key_dgram);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_dgram);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "doHandshake", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "doHandshake", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_dgram);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "doHandshake", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QUdpSocket *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QByteArray cppArg1_local{};
        ::QByteArray *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1]) {
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // doHandshake(QUdpSocket*,QByteArray)
            bool cppResult = cppSelf->doHandshake(cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDtlsFunc_dtlsConfiguration(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDtls *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // dtlsConfiguration()const
        QSslConfiguration cppResult = const_cast<const ::QDtls *>(cppSelf)->dtlsConfiguration();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslConfiguration_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDtlsFunc_dtlsError(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDtls *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // dtlsError()const
        QDtlsError cppResult = const_cast<const ::QDtls *>(cppSelf)->dtlsError();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDtlsError_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDtlsFunc_dtlsErrorString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDtls *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // dtlsErrorString()const
        QString cppResult = const_cast<const ::QDtls *>(cppSelf)->dtlsErrorString();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDtlsFunc_handleTimeout(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDtls *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDtls::handleTimeout(QUdpSocket*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QUdpSocket_IDX]), (pyArg)))) {
        overloadId = 0; // handleTimeout(QUdpSocket*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "handleTimeout", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUdpSocket *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // handleTimeout(QUdpSocket*)
            bool cppResult = cppSelf->handleTimeout(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDtlsFunc_handshakeState(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDtls *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // handshakeState()const
        QDtls::HandshakeState cppResult = const_cast<const ::QDtls *>(cppSelf)->handshakeState();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_HandshakeState_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDtlsFunc_ignoreVerificationErrors(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDtls *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDtls::ignoreVerificationErrors(QList<QSslError>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QSslError_IDX], (pyArg)))) {
        overloadId = 0; // ignoreVerificationErrors(QList<QSslError>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "ignoreVerificationErrors", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]);

    // Call function/method
    {
        ::QList<QSslError> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // ignoreVerificationErrors(QList<QSslError>)
            cppSelf->ignoreVerificationErrors(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDtlsFunc_isConnectionEncrypted(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDtls *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isConnectionEncrypted()const
        bool cppResult = const_cast<const ::QDtls *>(cppSelf)->isConnectionEncrypted();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDtlsFunc_mtuHint(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDtls *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // mtuHint()const
        quint16 cppResult = const_cast<const ::QDtls *>(cppSelf)->mtuHint();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDtlsFunc_peerAddress(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDtls *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // peerAddress()const
        QHostAddress cppResult = const_cast<const ::QDtls *>(cppSelf)->peerAddress();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDtlsFunc_peerPort(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDtls *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // peerPort()const
        quint16 cppResult = const_cast<const ::QDtls *>(cppSelf)->peerPort();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDtlsFunc_peerVerificationErrors(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDtls *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // peerVerificationErrors()const
        QList<QSslError> cppResult = const_cast<const ::QDtls *>(cppSelf)->peerVerificationErrors();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QSslError_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDtlsFunc_peerVerificationName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDtls *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // peerVerificationName()const
        QString cppResult = const_cast<const ::QDtls *>(cppSelf)->peerVerificationName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDtlsFunc_resumeHandshake(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDtls *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDtls::resumeHandshake(QUdpSocket*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QUdpSocket_IDX]), (pyArg)))) {
        overloadId = 0; // resumeHandshake(QUdpSocket*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "resumeHandshake", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUdpSocket *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // resumeHandshake(QUdpSocket*)
            bool cppResult = cppSelf->resumeHandshake(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDtlsFunc_sessionCipher(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDtls *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sessionCipher()const
        QSslCipher cppResult = const_cast<const ::QDtls *>(cppSelf)->sessionCipher();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslCipher_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDtlsFunc_sessionProtocol(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDtls *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sessionProtocol()const
        QSsl::SslProtocol cppResult = const_cast<const ::QDtls *>(cppSelf)->sessionProtocol();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSsl_SslProtocol_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDtlsFunc_setCookieGeneratorParameters(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDtls *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDtls::setCookieGeneratorParameters(QDtlsClientVerifier::GeneratorParameters)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDtlsClientVerifier_GeneratorParameters_IDX]), (pyArg)))) {
        overloadId = 0; // setCookieGeneratorParameters(QDtlsClientVerifier::GeneratorParameters)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCookieGeneratorParameters", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDtlsClientVerifier::GeneratorParameters cppArg0_local;
        ::QDtlsClientVerifier::GeneratorParameters *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setCookieGeneratorParameters(QDtlsClientVerifier::GeneratorParameters)
            bool cppResult = cppSelf->setCookieGeneratorParameters(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDtlsFunc_setDtlsConfiguration(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDtls *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDtls::setDtlsConfiguration(QSslConfiguration)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslConfiguration_IDX]), (pyArg)))) {
        overloadId = 0; // setDtlsConfiguration(QSslConfiguration)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDtlsConfiguration", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSslConfiguration cppArg0_local;
        ::QSslConfiguration *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setDtlsConfiguration(QSslConfiguration)
            bool cppResult = cppSelf->setDtlsConfiguration(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDtlsFunc_setMtuHint(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDtls *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDtls::setMtuHint(quint16)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArg)))) {
        overloadId = 0; // setMtuHint(quint16)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMtuHint", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]);

    // Call function/method
    {
        quint16 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMtuHint(quint16)
            cppSelf->setMtuHint(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDtlsFunc_setPeer(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDtls *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setPeer", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:setPeer", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDtls::setPeer(QHostAddress,quint16,const QString&=)->bool
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // setPeer(QHostAddress,quint16,QString)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
            overloadId = 0; // setPeer(QHostAddress,quint16,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setPeer", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_verificationName = Shiboken::String::createStaticString("verificationName");
            if (PyDict_Contains(kwds, key_verificationName) != 0) {
                value = PyDict_GetItem(kwds, key_verificationName);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_verificationName);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setPeer", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "setPeer", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_verificationName);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setPeer", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QHostAddress cppArg0_local;
        ::QHostAddress *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        quint16 cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QString cppArg2{};
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPeer(QHostAddress,quint16,QString)
            bool cppResult = cppSelf->setPeer(*cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDtlsFunc_setPeerVerificationName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDtls *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDtls::setPeerVerificationName(QString)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setPeerVerificationName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPeerVerificationName", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPeerVerificationName(QString)
            bool cppResult = cppSelf->setPeerVerificationName(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDtlsFunc_shutdown(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDtls *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDtls::shutdown(QUdpSocket*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QUdpSocket_IDX]), (pyArg)))) {
        overloadId = 0; // shutdown(QUdpSocket*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "shutdown", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUdpSocket *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // shutdown(QUdpSocket*)
            bool cppResult = cppSelf->shutdown(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDtlsFunc_sslMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDtls *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sslMode()const
        QSslSocket::SslMode cppResult = const_cast<const ::QDtls *>(cppSelf)->sslMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslSocket_SslMode_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDtlsFunc_writeDatagramEncrypted(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDtls *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "writeDatagramEncrypted", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDtls::writeDatagramEncrypted(QUdpSocket*,QByteArray)->qint64
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QUdpSocket_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
        overloadId = 0; // writeDatagramEncrypted(QUdpSocket*,QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "writeDatagramEncrypted", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QUdpSocket *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QByteArray cppArg1_local;
        ::QByteArray *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // writeDatagramEncrypted(QUdpSocket*,QByteArray)
            qint64 cppResult = cppSelf->writeDatagramEncrypted(cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QDtls_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QDtls_EnumFlagInfo[] = {
    "HandshakeState:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDtls_methods[] = {
    {"abortHandshake", reinterpret_cast<PyCFunction>(Sbk_QDtlsFunc_abortHandshake), METH_O, nullptr},
    {"cookieGeneratorParameters", reinterpret_cast<PyCFunction>(Sbk_QDtlsFunc_cookieGeneratorParameters), METH_NOARGS, nullptr},
    {"decryptDatagram", reinterpret_cast<PyCFunction>(Sbk_QDtlsFunc_decryptDatagram), METH_VARARGS, nullptr},
    {"doHandshake", reinterpret_cast<PyCFunction>(Sbk_QDtlsFunc_doHandshake), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"dtlsConfiguration", reinterpret_cast<PyCFunction>(Sbk_QDtlsFunc_dtlsConfiguration), METH_NOARGS, nullptr},
    {"dtlsError", reinterpret_cast<PyCFunction>(Sbk_QDtlsFunc_dtlsError), METH_NOARGS, nullptr},
    {"dtlsErrorString", reinterpret_cast<PyCFunction>(Sbk_QDtlsFunc_dtlsErrorString), METH_NOARGS, nullptr},
    {"handleTimeout", reinterpret_cast<PyCFunction>(Sbk_QDtlsFunc_handleTimeout), METH_O, nullptr},
    {"handshakeState", reinterpret_cast<PyCFunction>(Sbk_QDtlsFunc_handshakeState), METH_NOARGS, nullptr},
    {"ignoreVerificationErrors", reinterpret_cast<PyCFunction>(Sbk_QDtlsFunc_ignoreVerificationErrors), METH_O, nullptr},
    {"isConnectionEncrypted", reinterpret_cast<PyCFunction>(Sbk_QDtlsFunc_isConnectionEncrypted), METH_NOARGS, nullptr},
    {"mtuHint", reinterpret_cast<PyCFunction>(Sbk_QDtlsFunc_mtuHint), METH_NOARGS, nullptr},
    {"peerAddress", reinterpret_cast<PyCFunction>(Sbk_QDtlsFunc_peerAddress), METH_NOARGS, nullptr},
    {"peerPort", reinterpret_cast<PyCFunction>(Sbk_QDtlsFunc_peerPort), METH_NOARGS, nullptr},
    {"peerVerificationErrors", reinterpret_cast<PyCFunction>(Sbk_QDtlsFunc_peerVerificationErrors), METH_NOARGS, nullptr},
    {"peerVerificationName", reinterpret_cast<PyCFunction>(Sbk_QDtlsFunc_peerVerificationName), METH_NOARGS, nullptr},
    {"resumeHandshake", reinterpret_cast<PyCFunction>(Sbk_QDtlsFunc_resumeHandshake), METH_O, nullptr},
    {"sessionCipher", reinterpret_cast<PyCFunction>(Sbk_QDtlsFunc_sessionCipher), METH_NOARGS, nullptr},
    {"sessionProtocol", reinterpret_cast<PyCFunction>(Sbk_QDtlsFunc_sessionProtocol), METH_NOARGS, nullptr},
    {"setCookieGeneratorParameters", reinterpret_cast<PyCFunction>(Sbk_QDtlsFunc_setCookieGeneratorParameters), METH_O, nullptr},
    {"setDtlsConfiguration", reinterpret_cast<PyCFunction>(Sbk_QDtlsFunc_setDtlsConfiguration), METH_O, nullptr},
    {"setMtuHint", reinterpret_cast<PyCFunction>(Sbk_QDtlsFunc_setMtuHint), METH_O, nullptr},
    {"setPeer", reinterpret_cast<PyCFunction>(Sbk_QDtlsFunc_setPeer), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setPeerVerificationName", reinterpret_cast<PyCFunction>(Sbk_QDtlsFunc_setPeerVerificationName), METH_O, nullptr},
    {"shutdown", reinterpret_cast<PyCFunction>(Sbk_QDtlsFunc_shutdown), METH_O, nullptr},
    {"sslMode", reinterpret_cast<PyCFunction>(Sbk_QDtlsFunc_sslMode), METH_NOARGS, nullptr},
    {"writeDatagramEncrypted", reinterpret_cast<PyCFunction>(Sbk_QDtlsFunc_writeDatagramEncrypted), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QDtls_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QDtls *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QDtlsWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QDtls_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDtls_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDtls_Type = nullptr;
static PyTypeObject *Sbk_QDtls_TypeF(void)
{
    return _Sbk_QDtls_Type;
}

static PyType_Slot Sbk_QDtls_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QDtls_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDtls_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDtls_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDtls_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDtls_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDtls_spec = {
    "2:PySide6.QtNetwork.QDtls",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDtls_slots
};

} //extern "C"

static void *Sbk_QDtls_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QDtls *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QDtls_HandshakeState(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QDtls::HandshakeState>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QDtls::HandshakeState *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QDtls_HandshakeState_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_HandshakeState_IDX])))
        return Enum_PythonToCpp_QDtls_HandshakeState;
    return {};
}

static PyObject *QDtls_HandshakeState_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QDtls::HandshakeState>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QDtls::HandshakeState *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_HandshakeState_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDtls_PythonToCpp_QDtls_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDtls_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDtls_PythonToCpp_QDtls_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDtls_TypeF()))
        return QDtls_PythonToCpp_QDtls_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDtls_PTR_CppToPython_QDtls(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QDtls *>(const_cast<void *>(cppIn)), Sbk_QDtls_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QDtls_SignatureStrings[] = {
    "PySide6.QtNetwork.QDtls(self,mode:PySide6.QtNetwork.QSslSocket.SslMode,parent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtNetwork.QDtls.abortHandshake(self,socket:PySide6.QtNetwork.QUdpSocket)->bool",
    "PySide6.QtNetwork.QDtls.cookieGeneratorParameters(self)->PySide6.QtNetwork.QDtlsClientVerifier.GeneratorParameters",
    "PySide6.QtNetwork.QDtls.decryptDatagram(self,socket:PySide6.QtNetwork.QUdpSocket,dgram:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtCore.QByteArray",
    "PySide6.QtNetwork.QDtls.doHandshake(self,socket:PySide6.QtNetwork.QUdpSocket,dgram:typing.Union[PySide6.QtCore.QByteArray, char*]={})->bool",
    "PySide6.QtNetwork.QDtls.dtlsConfiguration(self)->PySide6.QtNetwork.QSslConfiguration",
    "PySide6.QtNetwork.QDtls.dtlsError(self)->PySide6.QtNetwork.QDtlsError",
    "PySide6.QtNetwork.QDtls.dtlsErrorString(self)->QString",
    "PySide6.QtNetwork.QDtls.handleTimeout(self,socket:PySide6.QtNetwork.QUdpSocket)->bool",
    "PySide6.QtNetwork.QDtls.handshakeState(self)->PySide6.QtNetwork.QDtls.HandshakeState",
    "PySide6.QtNetwork.QDtls.ignoreVerificationErrors(self,errorsToIgnore:QList[PySide6.QtNetwork.QSslError])",
    "PySide6.QtNetwork.QDtls.isConnectionEncrypted(self)->bool",
    "PySide6.QtNetwork.QDtls.mtuHint(self)->quint16",
    "PySide6.QtNetwork.QDtls.peerAddress(self)->PySide6.QtNetwork.QHostAddress",
    "PySide6.QtNetwork.QDtls.peerPort(self)->quint16",
    "PySide6.QtNetwork.QDtls.peerVerificationErrors(self)->QList[PySide6.QtNetwork.QSslError]",
    "PySide6.QtNetwork.QDtls.peerVerificationName(self)->QString",
    "PySide6.QtNetwork.QDtls.resumeHandshake(self,socket:PySide6.QtNetwork.QUdpSocket)->bool",
    "PySide6.QtNetwork.QDtls.sessionCipher(self)->PySide6.QtNetwork.QSslCipher",
    "PySide6.QtNetwork.QDtls.sessionProtocol(self)->PySide6.QtNetwork.QSsl.SslProtocol",
    "PySide6.QtNetwork.QDtls.setCookieGeneratorParameters(self,params:PySide6.QtNetwork.QDtlsClientVerifier.GeneratorParameters)->bool",
    "PySide6.QtNetwork.QDtls.setDtlsConfiguration(self,configuration:PySide6.QtNetwork.QSslConfiguration)->bool",
    "PySide6.QtNetwork.QDtls.setMtuHint(self,mtuHint:quint16)",
    "PySide6.QtNetwork.QDtls.setPeer(self,address:typing.Union[PySide6.QtNetwork.QHostAddress, PySide6.QtNetwork.QHostAddress.SpecialAddress],port:quint16,verificationName:QString={})->bool",
    "PySide6.QtNetwork.QDtls.setPeerVerificationName(self,name:QString)->bool",
    "PySide6.QtNetwork.QDtls.shutdown(self,socket:PySide6.QtNetwork.QUdpSocket)->bool",
    "PySide6.QtNetwork.QDtls.sslMode(self)->PySide6.QtNetwork.QSslSocket.SslMode",
    "PySide6.QtNetwork.QDtls.writeDatagramEncrypted(self,socket:PySide6.QtNetwork.QUdpSocket,dgram:typing.Union[PySide6.QtCore.QByteArray, char*])->qint64",
    nullptr}; // Sentinel
#else
static constexpr size_t QDtls_SignatureByteSize = 569;
static constexpr uint8_t QDtls_SignatureBytes[569] = {
    0x78, 0xda, 0xb5, 0x56, 0x5d, 0x6b, 0xdb, 0x30, 0x14, 0x7d, 0xef, 0xaf, 0xe8, 0xe3, 0x32, 0x34,
    0xc3, 0x60, 0xe4, 0xc1, 0xd0, 0x41, 0x97, 0x8c, 0x65, 0xb0, 0x76, 0x36, 0x6e, 0xf7, 0x52, 0xf2,
    0xa0, 0x58, 0x37, 0xb1, 0x16, 0x5b, 0x72, 0xaf, 0xaf, 0x17, 0xc2, 0xd8, 0x7f, 0x9f, 0xfc, 0x05,
    0x71, 0x66, 0xc9, 0x6e, 0xc9, 0xde, 0xac, 0xe4, 0xe8, 0x5c, 0xdd, 0x8f, 0x73, 0xa4, 0xe0, 0x18,
    0x49, 0x01, 0x73, 0x2f, 0xa4, 0x7b, 0xa0, 0x83, 0xc6, 0xbd, 0x17, 0x2e, 0x29, 0x2d, 0xde, 0x14,
    0x90, 0x6e, 0x59, 0xa6, 0x05, 0xf8, 0xc1, 0xbf, 0x88, 0xa8, 0x48, 0x23, 0x1d, 0xef, 0x81, 0x3c,
    0xf3, 0x75, 0x67, 0x40, 0x2c, 0xe7, 0x08, 0x8a, 0x4e, 0xb0, 0x0b, 0x8d, 0xe0, 0x85, 0xdf, 0x37,
    0x3f, 0x21, 0xa6, 0x1b, 0x55, 0xa6, 0x69, 0x4e, 0x38, 0xbb, 0x0a, 0x86, 0xa3, 0x79, 0x7c, 0xa3,
    0x91, 0x56, 0x5c, 0x89, 0x22, 0xe1, 0x7b, 0x68, 0x82, 0x17, 0x75, 0x84, 0xa1, 0xf0, 0x8f, 0x22,
    0x6f, 0xc2, 0xcf, 0xde, 0x7d, 0xdc, 0x68, 0x9d, 0x5a, 0x69, 0x63, 0xad, 0xf7, 0x12, 0xbe, 0x80,
    0x02, 0xe4, 0xa4, 0x31, 0xe0, 0xc8, 0x33, 0x20, 0xc0, 0x26, 0x3d, 0xb3, 0xdb, 0xb2, 0x71, 0x91,
    0x4a, 0x93, 0xcd, 0x0f, 0x40, 0xb9, 0x95, 0x80, 0xde, 0x00, 0x81, 0x35, 0xa4, 0x80, 0x18, 0x8f,
    0x39, 0x2d, 0x39, 0xf1, 0x9d, 0x01, 0x4f, 0x4e, 0x85, 0x89, 0x0a, 0xee, 0xd3, 0x31, 0x97, 0x6a,
    0xe7, 0x3d, 0x2a, 0xa9, 0xd5, 0xd3, 0x79, 0x35, 0x3f, 0x1d, 0x09, 0x6e, 0x11, 0xf9, 0x91, 0x5d,
    0xc7, 0x09, 0xc7, 0xb7, 0xeb, 0x5e, 0x06, 0x67, 0x18, 0xfb, 0x09, 0xf5, 0xcb, 0x0b, 0xfd, 0xaa,
    0xd3, 0xdd, 0xfc, 0xfe, 0x33, 0xd6, 0x20, 0x51, 0x15, 0x5b, 0xab, 0xad, 0xdc, 0x95, 0xa6, 0xc0,
    0x86, 0xd5, 0xd1, 0x18, 0x33, 0x6a, 0x3d, 0xa8, 0x93, 0xf4, 0x33, 0xa2, 0xc6, 0x91, 0x2e, 0xd7,
    0x98, 0x71, 0x96, 0x88, 0xd0, 0x24, 0xdd, 0x71, 0x85, 0xcd, 0xd2, 0xba, 0x2d, 0x31, 0xb5, 0x4d,
    0xe1, 0x41, 0x66, 0xa0, 0x4b, 0xba, 0xd8, 0x20, 0x27, 0x5d, 0xc7, 0x22, 0xe2, 0x04, 0x23, 0x79,
    0x79, 0xab, 0x1e, 0xda, 0x4a, 0x2a, 0x77, 0xca, 0x34, 0xae, 0x99, 0xf2, 0xb8, 0x2e, 0x69, 0x9d,
    0x6f, 0xab, 0x7d, 0xa8, 0xbf, 0x1f, 0xf4, 0xd7, 0x1a, 0xe5, 0x87, 0xdf, 0x64, 0x41, 0x4f, 0xc3,
    0x6d, 0xa9, 0xb7, 0xad, 0xed, 0xea, 0x96, 0x55, 0x8f, 0x95, 0x31, 0x82, 0x2a, 0x84, 0xaa, 0xf5,
    0x01, 0xa2, 0x4b, 0xc2, 0x99, 0x77, 0x46, 0xe5, 0x4a, 0x2a, 0xea, 0xb0, 0xcf, 0xa5, 0x59, 0xbc,
    0x9f, 0x5b, 0xe1, 0x39, 0x00, 0xde, 0x0a, 0x81, 0x50, 0xb8, 0x14, 0xbe, 0xd2, 0x05, 0xb5, 0x28,
    0x27, 0x53, 0x60, 0x3c, 0xe9, 0x25, 0x91, 0x2d, 0x95, 0xac, 0x86, 0x66, 0xb4, 0x78, 0x93, 0x89,
    0xef, 0x8d, 0x01, 0x4d, 0x9d, 0x45, 0x93, 0x61, 0x99, 0xc1, 0xe5, 0x6d, 0xb5, 0x30, 0x95, 0x33,
    0x47, 0x59, 0xc8, 0x3c, 0x01, 0x1c, 0x51, 0x6c, 0x8d, 0x19, 0x63, 0x0a, 0x50, 0x93, 0x8e, 0x75,
    0xea, 0xe6, 0xaa, 0x2e, 0x9b, 0x0e, 0xe9, 0x60, 0x34, 0x76, 0xe4, 0x72, 0xfd, 0xea, 0xaa, 0xe2,
    0x59, 0xe1, 0xbf, 0xda, 0xfa, 0xc7, 0xab, 0x43, 0xcb, 0x41, 0x5b, 0x63, 0xf1, 0xe9, 0x4f, 0xfe,
    0x04, 0x8b, 0x9b, 0x10, 0xea, 0xee, 0x44, 0x21, 0xac, 0x95, 0x8b, 0xdf, 0x4e, 0xeb, 0xcc, 0xb5,
    0x31, 0x80, 0xb6, 0x77, 0x8c, 0x37, 0x5a, 0xb0, 0xb9, 0xfb, 0x90, 0x6e, 0xd8, 0xb5, 0xfb, 0x7f,
    0x2f, 0xca, 0x21, 0x96, 0x3c, 0x6d, 0x97, 0x6b, 0x96, 0x1b, 0x2d, 0x75, 0xc7, 0x62, 0xbf, 0xce,
    0xe6, 0xd9, 0x6f, 0x07, 0x79, 0xc2, 0x85, 0xd1, 0x1e, 0x7c, 0x50, 0x11, 0x4c, 0x9d, 0x70, 0x8d,
    0x12, 0x25, 0x25, 0x09, 0x7d, 0x50, 0x97, 0x13, 0x45, 0xf3, 0x12, 0x72, 0x8f, 0x70, 0xff, 0xd5,
    0x64, 0xe5, 0x3a, 0xa0, 0x24, 0xe8, 0x9e, 0x10, 0x7d, 0xc7, 0xfc, 0x9f, 0x6f, 0x89, 0x67, 0xd3,
    0x9e, 0xf9, 0x87, 0xab, 0xbf, 0x1b, 0x31, 0xb2, 0x6b
};
#endif

PyTypeObject *init_QDtls(PyObject *module)
{
    if (SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX].type != nullptr)
        return SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX].type;

    Shiboken::AutoDecRef Sbk_QDtls_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QDtls_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDtls",
        "QDtls*",
        &Sbk_QDtls_spec,
        &Shiboken::callCppDestructor< QDtls >,
        Sbk_QDtls_Type_bases.object(),
        0);
    auto *pyType = Sbk_QDtls_TypeF(); // references _Sbk_QDtls_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QDtls_SignatureStrings);
#else
    InitSignatureBytes(pyType, QDtls_SignatureBytes, QDtls_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDtls_PropertyStrings);
    SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDtls_PythonToCpp_QDtls_PTR,
        is_QDtls_PythonToCpp_QDtls_PTR_Convertible,
        QDtls_PTR_CppToPython_QDtls);

    Shiboken::Conversions::registerConverterName(converter, "QDtls");
    Shiboken::Conversions::registerConverterName(converter, "QDtls*");
    Shiboken::Conversions::registerConverterName(converter, "QDtls&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDtls).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QDtlsWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QDtls_TypeF(), &Sbk_QDtls_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QDtls_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'HandshakeState'.
    const char *HandshakeState_Initializer[] = {
        "HandshakeNotStarted",
        "HandshakeInProgress",
        "PeerVerificationFailed",
        "HandshakeComplete",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t HandshakeState_InitializerValues[] = {
        uint8_t(QDtls::HandshakeState::HandshakeNotStarted),    //  0x00  0
        uint8_t(QDtls::HandshakeState::HandshakeInProgress),    //  0x01  1
        uint8_t(QDtls::HandshakeState::PeerVerificationFailed), //  0x02  2
        uint8_t(QDtls::HandshakeState::HandshakeComplete)       //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QDtls_TypeF(),
        "2:PySide6.QtNetwork.QDtls.HandshakeState",
        HandshakeState_Initializer, HandshakeState_InitializerValues);
    SbkPySide6_QtNetworkTypeStructs[SBK_QDtls_HandshakeState_IDX].type = EType;
    // Register converter for enum 'QDtls::HandshakeState'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QDtls_HandshakeState_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QDtls_HandshakeState,
            is_Enum_PythonToCpp_QDtls_HandshakeState_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QDtls::HandshakeState");
        Shiboken::Conversions::registerConverterAlias(converter, "HandshakeState");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'HandshakeState' enum.

    PySide::Signal::registerSignals(pyType, &::QDtls::staticMetaObject);
    qRegisterMetaType< ::QDtls::HandshakeState >("QDtls::HandshakeState");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QDtls::staticMetaObject, sizeof(QDtlsWrapper));

    return pyType;
}
