// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnetwork_python.h"

// main header
#include "qformdatabuilder_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QtNetwork/qformdatabuilder.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QFormDataBuilder_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QFormDataBuilder >()))
        return -1;

    ::QFormDataBuilder *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtNetworkTypeStructs[SBK_QFormDataBuilder_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QFormDataBuilder()
        cptr = new ::QFormDataBuilder();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QFormDataBuilder >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QFormDataBuilderFunc_part(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFormDataBuilder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFormDataBuilder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFormDataBuilder::part(QAnyStringView)->QFormDataPartBuilder
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // part(QAnyStringView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "part", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QFormDataBuilder_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // part(QAnyStringView)
            QFormDataPartBuilder* cppResult = new QFormDataPartBuilder(cppSelf->part(QAnyStringView(cppArg0)));
            pyResult = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFormDataPartBuilder_IDX]), cppResult, true, true);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFormDataBuilderFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFormDataBuilder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFormDataBuilder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFormDataBuilder::swap(QFormDataBuilder&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFormDataBuilder_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QFormDataBuilder&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QFormDataBuilder_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFormDataBuilder *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QFormDataBuilder&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QFormDataBuilder_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QFormDataBuilder_EnumFlagInfo[] = {
    "Option:Flag:Options",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QFormDataBuilder_methods[] = {
    {"part", reinterpret_cast<PyCFunction>(Sbk_QFormDataBuilderFunc_part), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QFormDataBuilderFunc_swap), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QFormDataBuilder_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QFormDataBuilder_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QFormDataBuilder_Type = nullptr;
static PyTypeObject *Sbk_QFormDataBuilder_TypeF(void)
{
    return _Sbk_QFormDataBuilder_Type;
}

static PyType_Slot Sbk_QFormDataBuilder_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QFormDataBuilder_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QFormDataBuilder_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QFormDataBuilder_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QFormDataBuilder_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QFormDataBuilder_spec = {
    "2:PySide6.QtNetwork.QFormDataBuilder",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QFormDataBuilder_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QFormDataBuilder_Option(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QFormDataBuilder::Option>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QFormDataBuilder::Option *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QFormDataBuilder_Option_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFormDataBuilder_Option_IDX])))
        return Enum_PythonToCpp_QFormDataBuilder_Option;
    return {};
}

static PyObject *QFormDataBuilder_Option_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QFormDataBuilder::Option>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QFormDataBuilder::Option *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFormDataBuilder_Option_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QFormDataBuilder_Option(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QFormDataBuilder::Option>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QFormDataBuilder::Option> *>(cppOut) = value;

}

static PyObject *QFormDataBuilder_Option_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QFormDataBuilder::Option> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFormDataBuilder_Option_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QFormDataBuilder_PythonToCpp_QFormDataBuilder_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QFormDataBuilder_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QFormDataBuilder_PythonToCpp_QFormDataBuilder_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QFormDataBuilder_TypeF()))
        return QFormDataBuilder_PythonToCpp_QFormDataBuilder_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QFormDataBuilder_PTR_CppToPython_QFormDataBuilder(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QFormDataBuilder_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QFormDataBuilder_SignatureStrings[] = {
    "PySide6.QtNetwork.QFormDataBuilder(self)",
    "PySide6.QtNetwork.QFormDataBuilder.part(self,name:QString)->PySide6.QtNetwork.QFormDataPartBuilder",
    "PySide6.QtNetwork.QFormDataBuilder.swap(self,other:PySide6.QtNetwork.QFormDataBuilder)",
    nullptr}; // Sentinel
#else
static constexpr size_t QFormDataBuilder_SignatureByteSize = 101;
static constexpr uint8_t QFormDataBuilder_SignatureBytes[101] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0xf1, 0x4b, 0x2d, 0x29,
    0xcf, 0x2f, 0xca, 0xd6, 0x0b, 0x74, 0xcb, 0x2f, 0xca, 0x75, 0x49, 0x2c, 0x49, 0x74, 0x2a, 0xcd,
    0xcc, 0x49, 0x49, 0x2d, 0xd2, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0xe4, 0x0a, 0x20, 0xa8, 0x50, 0xaf,
    0x20, 0xb1, 0xa8, 0x04, 0xac, 0x5a, 0x27, 0x2f, 0x31, 0x37, 0xd5, 0x2a, 0x30, 0xb8, 0xa4, 0x28,
    0x33, 0x2f, 0x5d, 0x53, 0xd7, 0x0e, 0x8f, 0xde, 0x00, 0xa0, 0x1e, 0xa8, 0x7e, 0x62, 0xac, 0x28,
    0x2e, 0x4f, 0x2c, 0x80, 0x58, 0x91, 0x5f, 0x92, 0x91, 0x5a, 0x64, 0x45, 0x58, 0x8b, 0x26, 0x17,
    0x00, 0xd3, 0xd3, 0x52, 0xc0
};
#endif

PyTypeObject *init_QFormDataBuilder(PyObject *module)
{
    if (SbkPySide6_QtNetworkTypeStructs[SBK_QFormDataBuilder_IDX].type != nullptr)
        return SbkPySide6_QtNetworkTypeStructs[SBK_QFormDataBuilder_IDX].type;

    Shiboken::AutoDecRef Sbk_QFormDataBuilder_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QFormDataBuilder_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QFormDataBuilder",
        "QFormDataBuilder*",
        &Sbk_QFormDataBuilder_spec,
        &Shiboken::callCppDestructor< ::QFormDataBuilder >,
        Sbk_QFormDataBuilder_Type_bases.object(),
        0);
    auto *pyType = Sbk_QFormDataBuilder_TypeF(); // references _Sbk_QFormDataBuilder_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QFormDataBuilder_SignatureStrings);
#else
    InitSignatureBytes(pyType, QFormDataBuilder_SignatureBytes, QFormDataBuilder_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QFormDataBuilder_PropertyStrings);
    SbkPySide6_QtNetworkTypeStructs[SBK_QFormDataBuilder_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QFormDataBuilder_PythonToCpp_QFormDataBuilder_PTR,
        is_QFormDataBuilder_PythonToCpp_QFormDataBuilder_PTR_Convertible,
        QFormDataBuilder_PTR_CppToPython_QFormDataBuilder);

    Shiboken::Conversions::registerConverterName(converter, "QFormDataBuilder");
    Shiboken::Conversions::registerConverterName(converter, "QFormDataBuilder*");
    Shiboken::Conversions::registerConverterName(converter, "QFormDataBuilder&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QFormDataBuilder).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QFormDataBuilder_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Option'.
    const char *Option_Initializer[] = {
        "Default",
        "OmitRfc8187EncodedFilename",
        "UseRfc7578PercentEncodedFilename",
        "PreferLatin1EncodedFilename",
        "StrictRfc7578",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t Option_InitializerValues[] = {
        int8_t(QFormDataBuilder::Option::Default),                          //  0x00  0
        int8_t(QFormDataBuilder::Option::OmitRfc8187EncodedFilename),       //  0x01  1
        int8_t(QFormDataBuilder::Option::UseRfc7578PercentEncodedFilename), //  0x02  2
        int8_t(QFormDataBuilder::Option::PreferLatin1EncodedFilename),      //  0x04  4
        int8_t(QFormDataBuilder::Option::StrictRfc7578)                     //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QFormDataBuilder_TypeF(),
        "2:PySide6.QtNetwork.QFormDataBuilder.Option",
        Option_Initializer, Option_InitializerValues);
    SbkPySide6_QtNetworkTypeStructs[SBK_QFormDataBuilder_Option_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtNetworkTypeStructs[SBK_QFlags_QFormDataBuilder_Option_IDX].type =
        EType;
    // Register converter for enum 'QFormDataBuilder::Option'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QFormDataBuilder_Option_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QFormDataBuilder_Option,
            is_Enum_PythonToCpp_QFormDataBuilder_Option_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QFormDataBuilder::Option");
        Shiboken::Conversions::registerConverterAlias(converter, "Option");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QFormDataBuilder_Option_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QFormDataBuilder_Option,
            is_Enum_PythonToCpp_QFormDataBuilder_Option_Convertible);
        // Register converter for flag 'QFlags<QFormDataBuilder::Option>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QFormDataBuilder::Option>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFormDataBuilder::Options");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'Option' enum/flags.

    qRegisterMetaType< ::QFormDataBuilder *>();
    qRegisterMetaType< ::QFormDataBuilder::Option >("QFormDataBuilder::Option");

    return pyType;
}
