// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnetwork_python.h"

// main header
#include "qformdatapartbuilder_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QtNetwork/qformdatabuilder.h>
#include <QtNetwork/qhttpheaders.h>
#include <qbytearray.h>
#include <qbytearrayview.h>
#include <qiodevice.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QFormDataPartBuilder_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QFormDataPartBuilder >()))
        return -1;

    ::QFormDataPartBuilder *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtNetworkTypeStructs[SBK_QFormDataPartBuilder_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QFormDataPartBuilder()
        cptr = new ::QFormDataPartBuilder();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QFormDataPartBuilder >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QFormDataPartBuilderFunc_setBody(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFormDataPartBuilder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFormDataPartBuilder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setBody", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QFormDataPartBuilder_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:setBody", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QFormDataPartBuilder::setBody(QByteArrayView,QAnyStringView=,QAnyStringView=)->QFormDataPartBuilder
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setBody(QByteArrayView,QAnyStringView,QAnyStringView)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // setBody(QByteArrayView,QAnyStringView,QAnyStringView)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
                overloadId = 0; // setBody(QByteArrayView,QAnyStringView,QAnyStringView)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setBody", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QFormDataPartBuilder_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_fileName = Shiboken::String::createStaticString("fileName");
            if (PyDict_Contains(kwds, key_fileName) != 0) {
                value = PyDict_GetItem(kwds, key_fileName);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_fileName);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setBody", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QFormDataPartBuilder_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QAnyStringView_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "setBody", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QFormDataPartBuilder_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_fileName);
            }
            static PyObject *const key_mimeType = Shiboken::String::createStaticString("mimeType");
            if (PyDict_Contains(kwds, key_mimeType) != 0) {
                value = PyDict_GetItem(kwds, key_mimeType);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_mimeType);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setBody", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QFormDataPartBuilder_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QAnyStringView_IDX], (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "setBody", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QFormDataPartBuilder_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_mimeType);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setBody", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QFormDataPartBuilder_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QByteArray cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1{};
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QString cppArg2{};
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setBody(QByteArrayView,QAnyStringView,QAnyStringView)
            QFormDataPartBuilder* cppResult = new QFormDataPartBuilder(cppSelf->setBody(QByteArrayView(cppArg0), QAnyStringView(cppArg1), QAnyStringView(cppArg2)));
            pyResult = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFormDataPartBuilder_IDX]), cppResult, true, true);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFormDataPartBuilderFunc_setBodyDevice(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFormDataPartBuilder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFormDataPartBuilder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setBodyDevice", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QFormDataPartBuilder_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:setBodyDevice", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QFormDataPartBuilder::setBodyDevice(QIODevice*,QAnyStringView=,QAnyStringView=)->QFormDataPartBuilder
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setBodyDevice(QIODevice*,QAnyStringView,QAnyStringView)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // setBodyDevice(QIODevice*,QAnyStringView,QAnyStringView)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
                overloadId = 0; // setBodyDevice(QIODevice*,QAnyStringView,QAnyStringView)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setBodyDevice", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QFormDataPartBuilder_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_fileName = Shiboken::String::createStaticString("fileName");
            if (PyDict_Contains(kwds, key_fileName) != 0) {
                value = PyDict_GetItem(kwds, key_fileName);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_fileName);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setBodyDevice", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QFormDataPartBuilder_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QAnyStringView_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "setBodyDevice", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QFormDataPartBuilder_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_fileName);
            }
            static PyObject *const key_mimeType = Shiboken::String::createStaticString("mimeType");
            if (PyDict_Contains(kwds, key_mimeType) != 0) {
                value = PyDict_GetItem(kwds, key_mimeType);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_mimeType);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setBodyDevice", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QFormDataPartBuilder_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QAnyStringView_IDX], (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "setBodyDevice", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QFormDataPartBuilder_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_mimeType);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setBodyDevice", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QFormDataPartBuilder_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QIODevice *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1{};
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QString cppArg2{};
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setBodyDevice(QIODevice*,QAnyStringView,QAnyStringView)
            QFormDataPartBuilder* cppResult = new QFormDataPartBuilder(cppSelf->setBodyDevice(cppArg0, QAnyStringView(cppArg1), QAnyStringView(cppArg2)));
            pyResult = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFormDataPartBuilder_IDX]), cppResult, true, true);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFormDataPartBuilderFunc_setHeaders(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFormDataPartBuilder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFormDataPartBuilder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFormDataPartBuilder::setHeaders(QHttpHeaders)->QFormDataPartBuilder
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_IDX]), (pyArg)))) {
        overloadId = 0; // setHeaders(QHttpHeaders)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHeaders", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QFormDataPartBuilder_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QHttpHeaders cppArg0_local;
        ::QHttpHeaders *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setHeaders(QHttpHeaders)
            QFormDataPartBuilder* cppResult = new QFormDataPartBuilder(cppSelf->setHeaders(*cppArg0));
            pyResult = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFormDataPartBuilder_IDX]), cppResult, true, true);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFormDataPartBuilderFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFormDataPartBuilder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFormDataPartBuilder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFormDataPartBuilder::swap(QFormDataPartBuilder&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFormDataPartBuilder_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QFormDataPartBuilder&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QFormDataPartBuilder_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFormDataPartBuilder *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QFormDataPartBuilder&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QFormDataPartBuilder_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QFormDataPartBuilder_methods[] = {
    {"setBody", reinterpret_cast<PyCFunction>(Sbk_QFormDataPartBuilderFunc_setBody), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setBodyDevice", reinterpret_cast<PyCFunction>(Sbk_QFormDataPartBuilderFunc_setBodyDevice), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setHeaders", reinterpret_cast<PyCFunction>(Sbk_QFormDataPartBuilderFunc_setHeaders), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QFormDataPartBuilderFunc_swap), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QFormDataPartBuilder_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QFormDataPartBuilder_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QFormDataPartBuilder_Type = nullptr;
static PyTypeObject *Sbk_QFormDataPartBuilder_TypeF(void)
{
    return _Sbk_QFormDataPartBuilder_Type;
}

static PyType_Slot Sbk_QFormDataPartBuilder_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QFormDataPartBuilder_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QFormDataPartBuilder_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QFormDataPartBuilder_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QFormDataPartBuilder_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QFormDataPartBuilder_spec = {
    "2:PySide6.QtNetwork.QFormDataPartBuilder",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QFormDataPartBuilder_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QFormDataPartBuilder_PythonToCpp_QFormDataPartBuilder_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QFormDataPartBuilder_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QFormDataPartBuilder_PythonToCpp_QFormDataPartBuilder_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QFormDataPartBuilder_TypeF()))
        return QFormDataPartBuilder_PythonToCpp_QFormDataPartBuilder_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QFormDataPartBuilder_PTR_CppToPython_QFormDataPartBuilder(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QFormDataPartBuilder_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QFormDataPartBuilder_SignatureStrings[] = {
    "PySide6.QtNetwork.QFormDataPartBuilder(self)",
    "PySide6.QtNetwork.QFormDataPartBuilder.setBody(self,data:typing.Union[PySide6.QtCore.QByteArray, char*],fileName:QString={},mimeType:QString={})->PySide6.QtNetwork.QFormDataPartBuilder",
    "PySide6.QtNetwork.QFormDataPartBuilder.setBodyDevice(self,body:PySide6.QtCore.QIODevice,fileName:QString={},mimeType:QString={})->PySide6.QtNetwork.QFormDataPartBuilder",
    "PySide6.QtNetwork.QFormDataPartBuilder.setHeaders(self,headers:PySide6.QtNetwork.QHttpHeaders)->PySide6.QtNetwork.QFormDataPartBuilder",
    "PySide6.QtNetwork.QFormDataPartBuilder.swap(self,other:PySide6.QtNetwork.QFormDataPartBuilder)",
    nullptr}; // Sentinel
#else
static constexpr size_t QFormDataPartBuilder_SignatureByteSize = 198;
static constexpr uint8_t QFormDataPartBuilder_SignatureBytes[198] = {
    0x78, 0xda, 0xc5, 0x8e, 0xc1, 0x0a, 0x82, 0x40, 0x10, 0x86, 0xef, 0x3d, 0x45, 0xc7, 0x0c, 0xdb,
    0x63, 0x87, 0x85, 0x82, 0x4c, 0xc2, 0x2e, 0xa6, 0x58, 0xa7, 0xe8, 0xb0, 0xe9, 0x98, 0x4b, 0xea,
    0xca, 0x38, 0x25, 0x4b, 0xf4, 0xee, 0x49, 0x1b, 0x14, 0xd1, 0xc1, 0x20, 0xe8, 0x36, 0xff, 0xcc,
    0xff, 0x0d, 0x5f, 0xa0, 0x23, 0x99, 0xc0, 0x98, 0x85, 0xe4, 0x03, 0x35, 0x0a, 0x8f, 0x2c, 0x5c,
    0x28, 0x2c, 0x5c, 0x41, 0x22, 0x10, 0x48, 0xce, 0x49, 0xe6, 0x09, 0xe0, 0xa0, 0x86, 0x3c, 0xb5,
    0x7a, 0x41, 0xa7, 0x32, 0xab, 0x81, 0x1c, 0x95, 0xe8, 0x3b, 0x64, 0x27, 0xed, 0x91, 0x93, 0xae,
    0x64, 0x79, 0x60, 0x9b, 0x52, 0xaa, 0x72, 0xfb, 0xfc, 0x32, 0x57, 0x08, 0x2c, 0x74, 0x34, 0xc1,
    0x0c, 0x51, 0x68, 0xbb, 0x1f, 0x67, 0x02, 0x87, 0x3b, 0x3b, 0x95, 0x39, 0xf8, 0xa2, 0x00, 0x1e,
    0x46, 0x84, 0x2d, 0x38, 0xb9, 0x5c, 0xed, 0x42, 0x16, 0xb0, 0xd6, 0xd5, 0xeb, 0xce, 0x1a, 0x4d,
    0xbb, 0x19, 0x7d, 0x29, 0xee, 0xc2, 0x59, 0xc6, 0x60, 0xf4, 0xf7, 0x6d, 0xe6, 0xef, 0xc6, 0xcb,
    0x95, 0xa9, 0xfc, 0x53, 0xd4, 0x03, 0xd1, 0x4e, 0xb5, 0xb1, 0xcc, 0x4c, 0xe0, 0x1f, 0x70, 0x8f,
    0xa8, 0x7a, 0x74, 0x7f, 0xaf, 0xd1, 0x88, 0xca, 0x08, 0x28, 0xca, 0x00, 0x79, 0x37, 0xcc, 0xea,
    0xdd, 0x00, 0x38, 0xa5, 0xe7, 0x19
};
#endif

PyTypeObject *init_QFormDataPartBuilder(PyObject *module)
{
    if (SbkPySide6_QtNetworkTypeStructs[SBK_QFormDataPartBuilder_IDX].type != nullptr)
        return SbkPySide6_QtNetworkTypeStructs[SBK_QFormDataPartBuilder_IDX].type;

    Shiboken::AutoDecRef Sbk_QFormDataPartBuilder_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QFormDataPartBuilder_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QFormDataPartBuilder",
        "QFormDataPartBuilder*",
        &Sbk_QFormDataPartBuilder_spec,
        &Shiboken::callCppDestructor< ::QFormDataPartBuilder >,
        Sbk_QFormDataPartBuilder_Type_bases.object(),
        0);
    auto *pyType = Sbk_QFormDataPartBuilder_TypeF(); // references _Sbk_QFormDataPartBuilder_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QFormDataPartBuilder_SignatureStrings);
#else
    InitSignatureBytes(pyType, QFormDataPartBuilder_SignatureBytes, QFormDataPartBuilder_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QFormDataPartBuilder_PropertyStrings);
    SbkPySide6_QtNetworkTypeStructs[SBK_QFormDataPartBuilder_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QFormDataPartBuilder_PythonToCpp_QFormDataPartBuilder_PTR,
        is_QFormDataPartBuilder_PythonToCpp_QFormDataPartBuilder_PTR_Convertible,
        QFormDataPartBuilder_PTR_CppToPython_QFormDataPartBuilder);

    Shiboken::Conversions::registerConverterName(converter, "QFormDataPartBuilder");
    Shiboken::Conversions::registerConverterName(converter, "QFormDataPartBuilder*");
    Shiboken::Conversions::registerConverterName(converter, "QFormDataPartBuilder&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QFormDataPartBuilder).name());

    qRegisterMetaType< ::QFormDataPartBuilder *>();

    return pyType;
}
