// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnetwork_python.h"

// main header
#include "qhostaddress_wrapper.h"

// Argument includes
#include <QString>
#include <QtNetwork/qabstractsocket.h>
#include <QtNetwork/qhostaddress.h>
#include <qdatastream.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <utility>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QHostAddress_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QHostAddress >()))
        return -1;

    ::QHostAddress *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QHostAddress", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QHostAddress::QHostAddress()
    // 1: QHostAddress::QHostAddress(QHostAddress::SpecialAddress)
    // 2: QHostAddress::QHostAddress(QHostAddress)
    // 3: QHostAddress::QHostAddress(QIPv6Address)
    // 4: QHostAddress::QHostAddress(QString)
    // 5: QHostAddress::QHostAddress(quint32)
    if (numArgs == 0) {
        overloadId = 0; // QHostAddress()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 4; // QHostAddress(QString)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QIPv6Address_IDX]), (pyArgs[0])))) {
        overloadId = 3; // QHostAddress(QIPv6Address)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_SpecialAddress_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 1; // QHostAddress(QHostAddress::SpecialAddress)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QHostAddress(QHostAddress)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[0])))) {
        overloadId = 5; // QHostAddress(quint32)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QHostAddress()
        {

            // QHostAddress()
            cptr = new ::QHostAddress();
            break;
        }
        case 1: // QHostAddress(QHostAddress::SpecialAddress address)
        {
            ::QHostAddress::SpecialAddress cppArg0{QHostAddress::Null};
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QHostAddress(QHostAddress::SpecialAddress)
                cptr = new ::QHostAddress(cppArg0);
            }
            break;
        }
        case 2: // QHostAddress(const QHostAddress &copy)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QHostAddress cppArg0_local;
            ::QHostAddress *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QHostAddress(QHostAddress)
                cptr = new ::QHostAddress(*cppArg0);
            }
            break;
        }
        case 3: // QHostAddress(const QIPv6Address &ip6Addr)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QIPv6Address cppArg0_local;
            ::QIPv6Address *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QHostAddress(QIPv6Address)
                cptr = new ::QHostAddress(*cppArg0);
            }
            break;
        }
        case 4: // QHostAddress(const QString &address)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QHostAddress(QString)
                cptr = new ::QHostAddress(cppArg0);
            }
            break;
        }
        case 5: // QHostAddress(quint32 ip4Addr)
        {
            quint32 cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QHostAddress(quint32)
                cptr = new ::QHostAddress(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QHostAddress >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QHostAddressFunc_clear(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHostAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clear()
        cppSelf->clear();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHostAddressFunc_isBroadcast(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHostAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isBroadcast()const
        bool cppResult = const_cast<const ::QHostAddress *>(cppSelf)->isBroadcast();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHostAddressFunc_isEqual(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHostAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "isEqual", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]);

    if (PyArg_ParseTuple(args, "|OO:isEqual", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QHostAddress::isEqual(QHostAddress,QFlags<QHostAddress::ConversionModeFlag>=)const->bool
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // isEqual(QHostAddress,QFlags<QHostAddress::ConversionModeFlag>)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFlags_QHostAddress_ConversionModeFlag_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 0; // isEqual(QHostAddress,QFlags<QHostAddress::ConversionModeFlag>)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "isEqual", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
            if (PyDict_Contains(kwds, key_mode) != 0) {
                value = PyDict_GetItem(kwds, key_mode);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_mode);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "isEqual", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFlags_QHostAddress_ConversionModeFlag_IDX])))->flagsConverter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "isEqual", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_mode);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "isEqual", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QHostAddress cppArg0_local;
        ::QHostAddress *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QFlags<QHostAddress::ConversionModeFlag> cppArg1(QHostAddress::ConversionModeFlag::TolerantConversion);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isEqual(QHostAddress,QFlags<QHostAddress::ConversionModeFlag>)const
            bool cppResult = const_cast<const ::QHostAddress *>(cppSelf)->isEqual(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHostAddressFunc_isGlobal(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHostAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isGlobal()const
        bool cppResult = const_cast<const ::QHostAddress *>(cppSelf)->isGlobal();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHostAddressFunc_isInSubnet(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHostAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "isInSubnet", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QHostAddress::isInSubnet(QHostAddress,int)const->bool
    // 1: QHostAddress::isInSubnet(std::pair<QHostAddress,int>)const->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // isInSubnet(QHostAddress,int)const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_std_pair_QHostAddress_int_IDX], (pyArgs[0])))) {
        overloadId = 1; // isInSubnet(std::pair<QHostAddress,int>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "isInSubnet", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // isInSubnet(const QHostAddress &subnet, int netmask) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QHostAddress cppArg0_local;
            ::QHostAddress *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // isInSubnet(QHostAddress,int)const
                bool cppResult = const_cast<const ::QHostAddress *>(cppSelf)->isInSubnet(*cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // isInSubnet(const std::pair<QHostAddress,int> &subnet) const
        {
            std::pair<QHostAddress,int> cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // isInSubnet(std::pair<QHostAddress,int>)const
                bool cppResult = const_cast<const ::QHostAddress *>(cppSelf)->isInSubnet(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHostAddressFunc_isLinkLocal(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHostAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isLinkLocal()const
        bool cppResult = const_cast<const ::QHostAddress *>(cppSelf)->isLinkLocal();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHostAddressFunc_isLoopback(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHostAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isLoopback()const
        bool cppResult = const_cast<const ::QHostAddress *>(cppSelf)->isLoopback();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHostAddressFunc_isMulticast(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHostAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isMulticast()const
        bool cppResult = const_cast<const ::QHostAddress *>(cppSelf)->isMulticast();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHostAddressFunc_isNull(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHostAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isNull()const
        bool cppResult = const_cast<const ::QHostAddress *>(cppSelf)->isNull();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHostAddressFunc_isPrivateUse(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHostAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isPrivateUse()const
        bool cppResult = const_cast<const ::QHostAddress *>(cppSelf)->isPrivateUse();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHostAddressFunc_isSiteLocal(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHostAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isSiteLocal()const
        bool cppResult = const_cast<const ::QHostAddress *>(cppSelf)->isSiteLocal();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHostAddressFunc_isUniqueLocalUnicast(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHostAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isUniqueLocalUnicast()const
        bool cppResult = const_cast<const ::QHostAddress *>(cppSelf)->isUniqueLocalUnicast();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHostAddressFunc_parseSubnet(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QHostAddress::parseSubnet(QString)->std::pair<QHostAddress,int>
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // parseSubnet(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "parseSubnet", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // parseSubnet(QString)
            std::pair<QHostAddress,int> cppResult = ::QHostAddress::parseSubnet(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_std_pair_QHostAddress_int_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHostAddressFunc_protocol(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHostAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // protocol()const
        QAbstractSocket::NetworkLayerProtocol cppResult = const_cast<const ::QHostAddress *>(cppSelf)->protocol();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_NetworkLayerProtocol_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHostAddressFunc_scopeId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHostAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // scopeId()const
        QString cppResult = const_cast<const ::QHostAddress *>(cppSelf)->scopeId();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHostAddressFunc_setAddress(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHostAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHostAddress::setAddress(QHostAddress::SpecialAddress)
    // 1: QHostAddress::setAddress(QIPv6Address)
    // 2: QHostAddress::setAddress(QString)->bool
    // 3: QHostAddress::setAddress(quint32)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 2; // setAddress(QString)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QIPv6Address_IDX]), (pyArg)))) {
        overloadId = 1; // setAddress(QIPv6Address)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_SpecialAddress_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setAddress(QHostAddress::SpecialAddress)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArg)))) {
        overloadId = 3; // setAddress(quint32)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAddress", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setAddress(QHostAddress::SpecialAddress address)
        {
            ::QHostAddress::SpecialAddress cppArg0{QHostAddress::Null};
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setAddress(QHostAddress::SpecialAddress)
                cppSelf->setAddress(cppArg0);
                pyResult = Py_None;
                Py_INCREF(Py_None);
            }
            break;
        }
        case 1: // setAddress(const QIPv6Address &ip6Addr)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QIPv6Address cppArg0_local;
            ::QIPv6Address *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setAddress(QIPv6Address)
                cppSelf->setAddress(*cppArg0);
                pyResult = Py_None;
                Py_INCREF(Py_None);
            }
            break;
        }
        case 2: // setAddress(const QString &address)
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setAddress(QString)
                bool cppResult = cppSelf->setAddress(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 3: // setAddress(quint32 ip4Addr)
        {
            quint32 cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setAddress(quint32)
                cppSelf->setAddress(cppArg0);
                pyResult = Py_None;
                Py_INCREF(Py_None);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHostAddressFunc_setScopeId(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHostAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHostAddress::setScopeId(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setScopeId(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setScopeId", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setScopeId(QString)
            cppSelf->setScopeId(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHostAddressFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHostAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHostAddress::swap(QHostAddress&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QHostAddress&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QHostAddress cppArg0_local;
        ::QHostAddress *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QHostAddress&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHostAddressFunc_toIPv4Address(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHostAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "toIPv4Address", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]);

    if (PyArg_ParseTuple(args, "|O:toIPv4Address", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QHostAddress::toIPv4Address(bool*=)const->quint32
    if (numArgs == 0) {
        overloadId = 0; // toIPv4Address(bool*)const
    } else if (numArgs >= 1
        && PyBool_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))) {
        overloadId = 0; // toIPv4Address(bool*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "toIPv4Address", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_ok = Shiboken::String::createStaticString("ok");
            if (PyDict_Contains(kwds, key_ok) != 0) {
                value = PyDict_GetItem(kwds, key_ok);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_ok);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "toIPv4Address", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "toIPv4Address", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_ok);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "toIPv4Address", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]);
            }
        }
        bool *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toIPv4Address(bool*)const
            quint32 cppResult = const_cast<const ::QHostAddress *>(cppSelf)->toIPv4Address(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHostAddressFunc_toIPv6Address(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHostAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toIPv6Address()const
        QIPv6Address cppResult = const_cast<const ::QHostAddress *>(cppSelf)->toIPv6Address();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QIPv6Address_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHostAddressFunc_toString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHostAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toString()const
        QString cppResult = const_cast<const ::QHostAddress *>(cppSelf)->toString();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHostAddress__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QHostAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QHostAddress_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QHostAddress_EnumFlagInfo[] = {
    "ConversionModeFlag:Flag:ConversionMode",
    "SpecialAddress:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QHostAddress_methods[] = {
    {"clear", reinterpret_cast<PyCFunction>(Sbk_QHostAddressFunc_clear), METH_NOARGS, nullptr},
    {"isBroadcast", reinterpret_cast<PyCFunction>(Sbk_QHostAddressFunc_isBroadcast), METH_NOARGS, nullptr},
    {"isEqual", reinterpret_cast<PyCFunction>(Sbk_QHostAddressFunc_isEqual), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"isGlobal", reinterpret_cast<PyCFunction>(Sbk_QHostAddressFunc_isGlobal), METH_NOARGS, nullptr},
    {"isInSubnet", reinterpret_cast<PyCFunction>(Sbk_QHostAddressFunc_isInSubnet), METH_VARARGS, nullptr},
    {"isLinkLocal", reinterpret_cast<PyCFunction>(Sbk_QHostAddressFunc_isLinkLocal), METH_NOARGS, nullptr},
    {"isLoopback", reinterpret_cast<PyCFunction>(Sbk_QHostAddressFunc_isLoopback), METH_NOARGS, nullptr},
    {"isMulticast", reinterpret_cast<PyCFunction>(Sbk_QHostAddressFunc_isMulticast), METH_NOARGS, nullptr},
    {"isNull", reinterpret_cast<PyCFunction>(Sbk_QHostAddressFunc_isNull), METH_NOARGS, nullptr},
    {"isPrivateUse", reinterpret_cast<PyCFunction>(Sbk_QHostAddressFunc_isPrivateUse), METH_NOARGS, nullptr},
    {"isSiteLocal", reinterpret_cast<PyCFunction>(Sbk_QHostAddressFunc_isSiteLocal), METH_NOARGS, nullptr},
    {"isUniqueLocalUnicast", reinterpret_cast<PyCFunction>(Sbk_QHostAddressFunc_isUniqueLocalUnicast), METH_NOARGS, nullptr},
    {"parseSubnet", reinterpret_cast<PyCFunction>(Sbk_QHostAddressFunc_parseSubnet), METH_O|METH_STATIC, nullptr},
    {"protocol", reinterpret_cast<PyCFunction>(Sbk_QHostAddressFunc_protocol), METH_NOARGS, nullptr},
    {"scopeId", reinterpret_cast<PyCFunction>(Sbk_QHostAddressFunc_scopeId), METH_NOARGS, nullptr},
    {"setAddress", reinterpret_cast<PyCFunction>(Sbk_QHostAddressFunc_setAddress), METH_O, nullptr},
    {"setScopeId", reinterpret_cast<PyCFunction>(Sbk_QHostAddressFunc_setScopeId), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QHostAddressFunc_swap), METH_O, nullptr},
    {"toIPv4Address", reinterpret_cast<PyCFunction>(Sbk_QHostAddressFunc_toIPv4Address), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toIPv6Address", reinterpret_cast<PyCFunction>(Sbk_QHostAddressFunc_toIPv6Address), METH_NOARGS, nullptr},
    {"toString", reinterpret_cast<PyCFunction>(Sbk_QHostAddressFunc_toString), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QHostAddress__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QHostAddress___nb_bool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QHostAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return !cppSelf->isNull() ? 1 : 0;
}

static PyObject *Sbk_QHostAddressFunc___lshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHostAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rlshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QHostAddress::operator<<(QDataStream&)->QDataStream&
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // operator<<(QDataStream&,QHostAddress)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator<<", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator<<(QDataStream&,QHostAddress) [reverse operator]
                QDataStream & cppResult = (*cppArg0) << (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHostAddressFunc___rshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHostAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rrshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QHostAddress::operator>>(QDataStream&)->QDataStream&
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // operator>>(QDataStream&,QHostAddress&)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator>>", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator>>(QDataStream&,QHostAddress&) [reverse operator]
                QDataStream & cppResult = (*cppArg0) >> (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

// Rich comparison
static PyObject * Sbk_QHostAddress_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QHostAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_SpecialAddress_IDX])))->converter, (pyArg)))) {
                // operator!=(QHostAddress::SpecialAddress lhs)
                ::QHostAddress::SpecialAddress cppArg0{QHostAddress::Null};
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf != (cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_SpecialAddress_IDX])))->converter, (pyArg)))) {
                // operator!=(QHostAddress::SpecialAddress address) const
                ::QHostAddress::SpecialAddress cppArg0{QHostAddress::Null};
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf != (cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), (pyArg)))) {
                // operator!=(const QHostAddress &address) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QHostAddress cppArg0_local;
                ::QHostAddress *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_SpecialAddress_IDX])))->converter, (pyArg)))) {
                // operator==(QHostAddress::SpecialAddress lhs)
                ::QHostAddress::SpecialAddress cppArg0{QHostAddress::Null};
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf == (cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_SpecialAddress_IDX])))->converter, (pyArg)))) {
                // operator==(QHostAddress::SpecialAddress address) const
                ::QHostAddress::SpecialAddress cppArg0{QHostAddress::Null};
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf == (cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), (pyArg)))) {
                // operator==(const QHostAddress &address) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QHostAddress cppArg0_local;
                ::QHostAddress *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static Py_hash_t Sbk_QHostAddress_HashFunc(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHostAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return Py_hash_t(qHash(*cppSelf));
}

static int Sbk_QHostAddress_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QHostAddress_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QHostAddress__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHostAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QHostAddress_Type = nullptr;
static PyTypeObject *Sbk_QHostAddress_TypeF(void)
{
    return _Sbk_QHostAddress_Type;
}

static PyType_Slot Sbk_QHostAddress_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QHostAddress__repr__)},
    {Py_tp_hash,        reinterpret_cast<void *>(&Sbk_QHostAddress_HashFunc)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QHostAddress_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QHostAddress_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QHostAddress_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QHostAddress_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QHostAddress_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_bool,        reinterpret_cast<void *>(Sbk_QHostAddress___nb_bool)},
    {Py_nb_lshift,      reinterpret_cast<void *>(Sbk_QHostAddressFunc___lshift__)},
    {Py_nb_rshift,      reinterpret_cast<void *>(Sbk_QHostAddressFunc___rshift__)},
    {0, nullptr}
};
static PyType_Spec Sbk_QHostAddress_spec = {
    "2:PySide6.QtNetwork.QHostAddress",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QHostAddress_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QHostAddress_SpecialAddress(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QHostAddress::SpecialAddress>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QHostAddress::SpecialAddress *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QHostAddress_SpecialAddress_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_SpecialAddress_IDX])))
        return Enum_PythonToCpp_QHostAddress_SpecialAddress;
    return {};
}

static PyObject *QHostAddress_SpecialAddress_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QHostAddress::SpecialAddress>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QHostAddress::SpecialAddress *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_SpecialAddress_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QHostAddress_ConversionModeFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QHostAddress::ConversionModeFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QHostAddress::ConversionModeFlag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QHostAddress_ConversionModeFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_ConversionModeFlag_IDX])))
        return Enum_PythonToCpp_QHostAddress_ConversionModeFlag;
    return {};
}

static PyObject *QHostAddress_ConversionModeFlag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QHostAddress::ConversionModeFlag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QHostAddress::ConversionModeFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_ConversionModeFlag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QHostAddress_ConversionModeFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QHostAddress::ConversionModeFlag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QHostAddress::ConversionModeFlag> *>(cppOut) = value;

}

static PyObject *QHostAddress_ConversionModeFlag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QHostAddress::ConversionModeFlag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_ConversionModeFlag_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QHostAddress_PythonToCpp_QHostAddress_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QHostAddress_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QHostAddress_PythonToCpp_QHostAddress_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QHostAddress_TypeF()))
        return QHostAddress_PythonToCpp_QHostAddress_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QHostAddress_PTR_CppToPython_QHostAddress(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QHostAddress_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QHostAddress_COPY_CppToPython_QHostAddress(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QHostAddress *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QHostAddress_TypeF(), new ::QHostAddress(*source), true, true);
}

// Python to C++ copy conversion.
static void QHostAddress_PythonToCpp_QHostAddress_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QHostAddress *>(cppOut) = *reinterpret_cast< ::QHostAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QHostAddress_PythonToCpp_QHostAddress_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QHostAddress_TypeF()))
        return QHostAddress_PythonToCpp_QHostAddress_COPY;
    return {};
}

// Implicit conversions.
static void QHostAddress_SpecialAddress_PythonToCpp_QHostAddress(PyObject *pyIn, void *cppOut)
{
    ::QHostAddress::SpecialAddress cppIn{QHostAddress::Null};
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_SpecialAddress_IDX])))->converter, pyIn, &cppIn);
    *reinterpret_cast<::QHostAddress *>(cppOut) = ::QHostAddress(cppIn);
}
static PythonToCppFunc is_QHostAddress_SpecialAddress_PythonToCpp_QHostAddress_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_SpecialAddress_IDX]), pyIn))
        return QHostAddress_SpecialAddress_PythonToCpp_QHostAddress;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QHostAddress_SignatureStrings[] = {
    "5:PySide6.QtNetwork.QHostAddress(self)",
    "4:PySide6.QtNetwork.QHostAddress(self,address:PySide6.QtNetwork.QHostAddress.SpecialAddress)",
    "3:PySide6.QtNetwork.QHostAddress(self,copy:PySide6.QtNetwork.QHostAddress)",
    "2:PySide6.QtNetwork.QHostAddress(self,ip6Addr:PySide6.QtNetwork.QIPv6Address)",
    "1:PySide6.QtNetwork.QHostAddress(self,address:QString)",
    "0:PySide6.QtNetwork.QHostAddress(self,ip4Addr:quint32)",
    "PySide6.QtNetwork.QHostAddress.clear(self)",
    "PySide6.QtNetwork.QHostAddress.isBroadcast(self)->bool",
    "PySide6.QtNetwork.QHostAddress.isEqual(self,address:typing.Union[PySide6.QtNetwork.QHostAddress, PySide6.QtNetwork.QHostAddress.SpecialAddress],mode:PySide6.QtNetwork.QHostAddress.ConversionModeFlag=QHostAddress.ConversionModeFlag.TolerantConversion)->bool",
    "PySide6.QtNetwork.QHostAddress.isGlobal(self)->bool",
    "1:PySide6.QtNetwork.QHostAddress.isInSubnet(self,subnet:typing.Union[PySide6.QtNetwork.QHostAddress, PySide6.QtNetwork.QHostAddress.SpecialAddress],netmask:int)->bool",
    "0:PySide6.QtNetwork.QHostAddress.isInSubnet(self,subnet:std.pair[PySide6.QtNetwork.QHostAddress, int])->bool",
    "PySide6.QtNetwork.QHostAddress.isLinkLocal(self)->bool",
    "PySide6.QtNetwork.QHostAddress.isLoopback(self)->bool",
    "PySide6.QtNetwork.QHostAddress.isMulticast(self)->bool",
    "PySide6.QtNetwork.QHostAddress.isNull(self)->bool",
    "PySide6.QtNetwork.QHostAddress.isPrivateUse(self)->bool",
    "PySide6.QtNetwork.QHostAddress.isSiteLocal(self)->bool",
    "PySide6.QtNetwork.QHostAddress.isUniqueLocalUnicast(self)->bool",
    "PySide6.QtNetwork.QHostAddress.parseSubnet(subnet:QString)->std.pair[PySide6.QtNetwork.QHostAddress, int]",
    "PySide6.QtNetwork.QHostAddress.protocol(self)->PySide6.QtNetwork.QAbstractSocket.NetworkLayerProtocol",
    "PySide6.QtNetwork.QHostAddress.scopeId(self)->QString",
    "3:PySide6.QtNetwork.QHostAddress.setAddress(self,address:PySide6.QtNetwork.QHostAddress.SpecialAddress)",
    "2:PySide6.QtNetwork.QHostAddress.setAddress(self,ip6Addr:PySide6.QtNetwork.QIPv6Address)",
    "1:PySide6.QtNetwork.QHostAddress.setAddress(self,address:QString)->bool",
    "0:PySide6.QtNetwork.QHostAddress.setAddress(self,ip4Addr:quint32)",
    "PySide6.QtNetwork.QHostAddress.setScopeId(self,id:QString)",
    "PySide6.QtNetwork.QHostAddress.swap(self,other:typing.Union[PySide6.QtNetwork.QHostAddress, PySide6.QtNetwork.QHostAddress.SpecialAddress])",
    "PySide6.QtNetwork.QHostAddress.toIPv4Address(self,ok:bool*=nullptr)->quint32",
    "PySide6.QtNetwork.QHostAddress.toIPv6Address(self)->PySide6.QtNetwork.QIPv6Address",
    "PySide6.QtNetwork.QHostAddress.toString(self)->QString",
    "PySide6.QtNetwork.QHostAddress.__copy__(self)->typing.Self",
    "PySide6.QtNetwork.QHostAddress.__lshift__(self,arg__1:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "PySide6.QtNetwork.QHostAddress.__rshift__(self,arg__1:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "2:PySide6.QtNetwork.QHostAddress.__ne__(self,address:PySide6.QtNetwork.QHostAddress.SpecialAddress)->bool",
    "1:PySide6.QtNetwork.QHostAddress.__ne__(self,lhs:PySide6.QtNetwork.QHostAddress.SpecialAddress)->bool",
    "0:PySide6.QtNetwork.QHostAddress.__ne__(self,address:typing.Union[PySide6.QtNetwork.QHostAddress, PySide6.QtNetwork.QHostAddress.SpecialAddress])->bool",
    "2:PySide6.QtNetwork.QHostAddress.__eq__(self,address:PySide6.QtNetwork.QHostAddress.SpecialAddress)->bool",
    "1:PySide6.QtNetwork.QHostAddress.__eq__(self,lhs:PySide6.QtNetwork.QHostAddress.SpecialAddress)->bool",
    "0:PySide6.QtNetwork.QHostAddress.__eq__(self,address:typing.Union[PySide6.QtNetwork.QHostAddress, PySide6.QtNetwork.QHostAddress.SpecialAddress])->bool",
    "PySide6.QtNetwork.QHostAddress.__hash__(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t QHostAddress_SignatureByteSize = 577;
static constexpr uint8_t QHostAddress_SignatureBytes[577] = {
    0x78, 0xda, 0xbd, 0x56, 0x4d, 0x6f, 0xdb, 0x30, 0x0c, 0xbd, 0xfb, 0x57, 0xec, 0xb8, 0x0c, 0xae,
    0x91, 0xa5, 0x59, 0x0e, 0x01, 0x5a, 0xa0, 0xeb, 0xbe, 0x02, 0xa4, 0x45, 0x02, 0xaf, 0xa7, 0xa1,
    0x30, 0x18, 0x9b, 0x4d, 0x04, 0x2b, 0xa2, 0x23, 0xd1, 0x2d, 0xf2, 0xef, 0xa7, 0xd4, 0x76, 0xbe,
    0x9a, 0x4d, 0x76, 0x90, 0xf4, 0x66, 0x59, 0x7c, 0x7c, 0xe4, 0x23, 0x25, 0xea, 0x4b, 0x7f, 0xb4,
    0x0c, 0x45, 0x82, 0xbd, 0x60, 0xcc, 0xf7, 0xc8, 0x2f, 0xa4, 0xd3, 0x60, 0xfc, 0x8b, 0x0c, 0xdf,
    0x24, 0x89, 0x46, 0x63, 0x3e, 0x1a, 0x94, 0x4f, 0x2d, 0xaf, 0x5b, 0xc7, 0xcc, 0x87, 0x62, 0xe1,
    0xb0, 0x0d, 0xc2, 0x0c, 0x63, 0x01, 0xb2, 0x5c, 0xb6, 0xbc, 0xcb, 0x5a, 0xce, 0x63, 0xca, 0x96,
    0x0e, 0xc3, 0x96, 0xd7, 0xa9, 0xe5, 0x4a, 0x64, 0xbd, 0xd5, 0xfa, 0x90, 0xed, 0x60, 0xf4, 0xdc,
    0x5b, 0x7b, 0xfb, 0xdc, 0x28, 0xeb, 0x71, 0xc8, 0x5a, 0xa8, 0x69, 0xcb, 0x6b, 0xd7, 0x0c, 0xa2,
    0xfb, 0x1a, 0xc4, 0x22, 0x17, 0x8a, 0x2f, 0x3b, 0x2d, 0xcf, 0xa1, 0x5a, 0x2c, 0x11, 0x74, 0x59,
    0x0e, 0x87, 0xa9, 0x30, 0x5f, 0x35, 0x41, 0x12, 0x83, 0xe1, 0x02, 0x70, 0x71, 0x3d, 0x21, 0x92,
    0x6e, 0xd8, 0xf7, 0x45, 0x0e, 0x72, 0x37, 0x2b, 0x5e, 0x66, 0x36, 0xa9, 0xe0, 0x41, 0x09, 0x52,
    0x7f, 0xfe, 0xef, 0xc0, 0xff, 0xd0, 0xa8, 0xf0, 0x8f, 0xfe, 0x9c, 0x12, 0x74, 0x35, 0xcb, 0x2d,
    0xa9, 0x67, 0xd4, 0xc6, 0xb2, 0xdf, 0x59, 0xeb, 0x1f, 0x12, 0xa6, 0x57, 0x8e, 0xfd, 0xe0, 0x37,
    0x49, 0xd4, 0xa0, 0x78, 0xb3, 0x55, 0x5b, 0x80, 0x9f, 0x92, 0x26, 0xa5, 0x02, 0x15, 0xc6, 0xd5,
    0x04, 0x16, 0x35, 0x50, 0x61, 0x3e, 0x51, 0x58, 0x88, 0xed, 0x9b, 0xd7, 0xef, 0xb3, 0x0a, 0x67,
    0xfd, 0xcf, 0xc1, 0xa4, 0x7d, 0xdb, 0x39, 0x55, 0x98, 0xed, 0x23, 0xc3, 0x34, 0x9c, 0x04, 0x19,
    0x08, 0xed, 0x0c, 0xd1, 0x72, 0x3d, 0xd6, 0xd6, 0x71, 0x28, 0x54, 0x3a, 0xa4, 0x78, 0x4f, 0x4a,
    0x37, 0x8c, 0x28, 0x9b, 0x40, 0x9c, 0x36, 0x43, 0xdd, 0xe5, 0x92, 0x45, 0xf3, 0x66, 0xbf, 0xcf,
    0x65, 0xc3, 0xf0, 0x46, 0x5a, 0x3c, 0x03, 0xe3, 0x83, 0xc1, 0x66, 0xb8, 0x50, 0x30, 0x1e, 0xa1,
    0x86, 0x6d, 0x9d, 0x45, 0x5e, 0x00, 0xed, 0x67, 0xd3, 0x04, 0x33, 0xd0, 0x06, 0xab, 0x82, 0x17,
    0xb5, 0xae, 0x6e, 0xa8, 0x8b, 0xeb, 0x46, 0x55, 0x77, 0x32, 0x69, 0x62, 0x8a, 0x69, 0x9d, 0xdd,
    0x01, 0xf3, 0x9b, 0x89, 0x61, 0x0d, 0x31, 0x87, 0x14, 0xa7, 0xc8, 0x41, 0xf9, 0x7f, 0x08, 0x4b,
    0xd4, 0xa3, 0x12, 0xed, 0x62, 0x31, 0x76, 0x00, 0xe0, 0x20, 0xa9, 0x48, 0xca, 0x5c, 0x9c, 0xc3,
    0x23, 0x30, 0x78, 0x92, 0x21, 0xd5, 0x69, 0xca, 0x73, 0xaa, 0x21, 0xf3, 0xcf, 0x04, 0x36, 0xd5,
    0xac, 0x77, 0x01, 0xbc, 0x0d, 0xb0, 0xd9, 0x00, 0xb2, 0xf8, 0x70, 0xab, 0x06, 0xbe, 0x48, 0x36,
    0x23, 0xcf, 0x05, 0x7d, 0x81, 0xac, 0x00, 0x11, 0xcf, 0x50, 0x9f, 0xf3, 0x6e, 0x74, 0xc6, 0xc2,
    0x64, 0xe5, 0xef, 0xee, 0x28, 0x41, 0x69, 0x7f, 0x25, 0xe1, 0xa7, 0x2b, 0x65, 0xaf, 0x84, 0x8c,
    0xb5, 0x95, 0xb4, 0x14, 0xa5, 0x96, 0xb3, 0xde, 0xce, 0x5b, 0xe9, 0x60, 0xff, 0x6f, 0x59, 0xb9,
    0x5d, 0x16, 0xa2, 0xee, 0x37, 0xba, 0x03, 0x16, 0x45, 0xab, 0x07, 0x52, 0x14, 0x55, 0xb0, 0x52,
    0xe2, 0xd0, 0xae, 0xdc, 0x50, 0x69, 0x66, 0xe2, 0x89, 0x4b, 0xb0, 0x0f, 0x7a, 0x1a, 0x45, 0xdb,
    0x6d, 0x79, 0x4b, 0x1a, 0x83, 0xf1, 0x37, 0x60, 0xb0, 0xb1, 0x20, 0xcc, 0x77, 0x72, 0xdc, 0xdf,
    0x74, 0xb3, 0xe9, 0x53, 0xb2, 0x39, 0xcf, 0x65, 0x14, 0x29, 0x5c, 0x73, 0x1d, 0x75, 0xf6, 0xeb,
    0x3e, 0x04, 0xb6, 0x99, 0xe4, 0xec, 0x48, 0x96, 0xf6, 0x31, 0xf9, 0x9c, 0xf3, 0x3c, 0x95, 0x71,
    0xd5, 0xd0, 0x19, 0x17, 0xef, 0xa5, 0xf3, 0x86, 0xe9, 0x9c, 0x3a, 0xbf, 0xcd, 0xe7, 0x1d, 0x74,
    0x76, 0x46, 0x35, 0x03, 0x33, 0xdb, 0x1c, 0x73, 0x7b, 0x4b, 0x79, 0x7f, 0x01, 0x53, 0x8a, 0x02,
    0xb7
};
#endif

PyTypeObject *init_QHostAddress(PyObject *module)
{
    if (SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX].type != nullptr)
        return SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX].type;

    Shiboken::AutoDecRef Sbk_QHostAddress_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QHostAddress_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QHostAddress",
        "QHostAddress",
        &Sbk_QHostAddress_spec,
        &Shiboken::callCppDestructor< ::QHostAddress >,
        Sbk_QHostAddress_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QHostAddress_TypeF(); // references _Sbk_QHostAddress_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QHostAddress_SignatureStrings);
#else
    InitSignatureBytes(pyType, QHostAddress_SignatureBytes, QHostAddress_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QHostAddress_PropertyStrings);
    SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QHostAddress_PythonToCpp_QHostAddress_PTR,
        is_QHostAddress_PythonToCpp_QHostAddress_PTR_Convertible,
        QHostAddress_PTR_CppToPython_QHostAddress,
        QHostAddress_COPY_CppToPython_QHostAddress);

    Shiboken::Conversions::registerConverterName(converter, "QHostAddress");
    Shiboken::Conversions::registerConverterName(converter, "QHostAddress*");
    Shiboken::Conversions::registerConverterName(converter, "QHostAddress&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QHostAddress).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QHostAddress_PythonToCpp_QHostAddress_COPY,
        is_QHostAddress_PythonToCpp_QHostAddress_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QHostAddress_SpecialAddress_PythonToCpp_QHostAddress,
        is_QHostAddress_SpecialAddress_PythonToCpp_QHostAddress_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QHostAddress_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'SpecialAddress'.
    const char *SpecialAddress_Initializer[] = {
        "Null",
        "Broadcast",
        "LocalHost",
        "LocalHostIPv6",
        "Any",
        "AnyIPv6",
        "AnyIPv4",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t SpecialAddress_InitializerValues[] = {
        uint8_t(QHostAddress::SpecialAddress::Null),          //  0x00  0
        uint8_t(QHostAddress::SpecialAddress::Broadcast),     //  0x01  1
        uint8_t(QHostAddress::SpecialAddress::LocalHost),     //  0x02  2
        uint8_t(QHostAddress::SpecialAddress::LocalHostIPv6), //  0x03  3
        uint8_t(QHostAddress::SpecialAddress::Any),           //  0x04  4
        uint8_t(QHostAddress::SpecialAddress::AnyIPv6),       //  0x05  5
        uint8_t(QHostAddress::SpecialAddress::AnyIPv4)        //  0x06  6
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QHostAddress_TypeF(),
        "2:PySide6.QtNetwork.QHostAddress.SpecialAddress",
        SpecialAddress_Initializer, SpecialAddress_InitializerValues);
    SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_SpecialAddress_IDX].type = EType;
    // Register converter for enum 'QHostAddress::SpecialAddress'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QHostAddress_SpecialAddress_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QHostAddress_SpecialAddress,
            is_Enum_PythonToCpp_QHostAddress_SpecialAddress_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QHostAddress::SpecialAddress");
        Shiboken::Conversions::registerConverterAlias(converter, "SpecialAddress");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'SpecialAddress' enum.

    // Initialization of enum 'ConversionModeFlag'.
    const char *ConversionModeFlag_Initializer[] = {
        "ConvertV4MappedToIPv4",
        "ConvertV4CompatToIPv4",
        "ConvertUnspecifiedAddress",
        "ConvertLocalHost",
        "TolerantConversion",
        "StrictConversion",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ConversionModeFlag_InitializerValues[] = {
        uint8_t(QHostAddress::ConversionModeFlag::ConvertV4MappedToIPv4),     //  0x01  1
        uint8_t(QHostAddress::ConversionModeFlag::ConvertV4CompatToIPv4),     //  0x02  2
        uint8_t(QHostAddress::ConversionModeFlag::ConvertUnspecifiedAddress), //  0x04  4
        uint8_t(QHostAddress::ConversionModeFlag::ConvertLocalHost),          //  0x08  8
        uint8_t(QHostAddress::ConversionModeFlag::TolerantConversion),        //  0xff  255
        uint8_t(QHostAddress::ConversionModeFlag::StrictConversion)           //  0x00  0
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QHostAddress_TypeF(),
        "2:PySide6.QtNetwork.QHostAddress.ConversionModeFlag",
        ConversionModeFlag_Initializer, ConversionModeFlag_InitializerValues);
    SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_ConversionModeFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtNetworkTypeStructs[SBK_QFlags_QHostAddress_ConversionModeFlag_IDX].type =
        EType;
    // Register converter for enum 'QHostAddress::ConversionModeFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QHostAddress_ConversionModeFlag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QHostAddress_ConversionModeFlag,
            is_Enum_PythonToCpp_QHostAddress_ConversionModeFlag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QHostAddress::ConversionModeFlag");
        Shiboken::Conversions::registerConverterAlias(converter, "ConversionModeFlag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QHostAddress_ConversionModeFlag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QHostAddress_ConversionModeFlag,
            is_Enum_PythonToCpp_QHostAddress_ConversionModeFlag_Convertible);
        // Register converter for flag 'QFlags<QHostAddress::ConversionModeFlag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QHostAddress::ConversionModeFlag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QHostAddress::ConversionMode");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'ConversionModeFlag' enum/flags.

    qRegisterMetaType< ::QHostAddress >("QHostAddress");
    qRegisterMetaType< ::QHostAddress::SpecialAddress >("QHostAddress::SpecialAddress");
    qRegisterMetaType< ::QHostAddress::ConversionModeFlag >("QHostAddress::ConversionModeFlag");

    return pyType;
}

PyTypeObject *init_QHostAddressStaticFields(PyObject *module)
{
    auto *obType = PyObject_GetAttrString(module, "QHostAddress");
    auto *type = reinterpret_cast<PyTypeObject *>(obType);
    Shiboken::AutoDecRef dict(PepType_GetDict(type));
    PyDict_SetItemString(dict, "IPv4Protocol",
                         Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_NetworkLayerProtocol_IDX])))->converter, &QHostAddress::IPv4Protocol));
    PyDict_SetItemString(dict, "IPv6Protocol",
                         Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_NetworkLayerProtocol_IDX])))->converter, &QHostAddress::IPv6Protocol));
    PyDict_SetItemString(dict, "AnyIPProtocol",
                         Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_NetworkLayerProtocol_IDX])))->converter, &QHostAddress::AnyIPProtocol));
    PyDict_SetItemString(dict, "UnknownNetworkLayerProtocol",
                         Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_NetworkLayerProtocol_IDX])))->converter, &QHostAddress::UnknownNetworkLayerProtocol));
    return type;
}
