// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnetwork_python.h"

// main header
#include "qhostinfo_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtNetwork/qhostaddress.h>
#include <QtNetwork/qhostinfo.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Begin code injection
// ========================================================================
// START of custom code block [file: ../glue/qtnetwork.cpp (qhostinfo-lookuphost-functor)]
struct QHostInfoFunctor : public Shiboken::PyObjectHolder
{
public:
    using Shiboken::PyObjectHolder::PyObjectHolder;

    void operator()(const QHostInfo &hostInfo);
};

void QHostInfoFunctor::operator()(const QHostInfo &hostInfo)
{
    Shiboken::GilState state;
    Shiboken::AutoDecRef arglist(PyTuple_New(1));
    auto *pyHostInfo = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostInfo_IDX]), &hostInfo);
    PyTuple_SetItem(arglist.object(), 0, pyHostInfo);
    Shiboken::AutoDecRef ret(PyObject_CallObject(object(), arglist));
    release(); // single shot
}
// END of custom code block [file: ../glue/qtnetwork.cpp (qhostinfo-lookuphost-functor)]
// ========================================================================
// End of code injection



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QHostInfo_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QHostInfo >()))
        return -1;

    ::QHostInfo *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHostInfo_IDX]);

    if (PyArg_ParseTuple(args, "|O:QHostInfo", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QHostInfo::QHostInfo(QHostInfo)
    // 1: QHostInfo::QHostInfo(int=)
    if (numArgs == 0) {
        overloadId = 1; // QHostInfo(int)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 1; // QHostInfo(int)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostInfo_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QHostInfo(QHostInfo)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHostInfo_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtNetworkTypeStructs[SBK_QHostInfo_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QHostInfo(const QHostInfo &d)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHostInfo_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QHostInfo cppArg0_local;
            ::QHostInfo *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QHostInfo(QHostInfo)
                cptr = new ::QHostInfo(*cppArg0);
            }
            break;
        }
        case 1: // QHostInfo(int lookupId)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_lookupId = Shiboken::String::createStaticString("lookupId");
                if (PyDict_Contains(kwds, key_lookupId) != 0) {
                    value = PyDict_GetItem(kwds, key_lookupId);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_lookupId);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHostInfo_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHostInfo_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_lookupId);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHostInfo_IDX]);
                }
            }
            int cppArg0 = -1;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QHostInfo(int)
                cptr = new ::QHostInfo(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QHostInfo >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHostInfo_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QHostInfoFunc_abortHostLookup(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QHostInfo::abortHostLookup(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // abortHostLookup(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "abortHostLookup", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHostInfo_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // abortHostLookup(int)
            ::QHostInfo::abortHostLookup(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHostInfoFunc_addresses(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHostInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // addresses()const
        QList<QHostAddress> cppResult = const_cast<const ::QHostInfo *>(cppSelf)->addresses();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QHostAddress_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHostInfoFunc_error(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHostInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // error()const
        QHostInfo::HostInfoError cppResult = const_cast<const ::QHostInfo *>(cppSelf)->error();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostInfo_HostInfoError_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHostInfoFunc_errorString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHostInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // errorString()const
        QString cppResult = const_cast<const ::QHostInfo *>(cppSelf)->errorString();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHostInfoFunc_fromName(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QHostInfo::fromName(QString)->QHostInfo
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // fromName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fromName", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHostInfo_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromName(QString)
            QHostInfo cppResult = ::QHostInfo::fromName(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostInfo_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHostInfoFunc_hostName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHostInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hostName()const
        QString cppResult = const_cast<const ::QHostInfo *>(cppSelf)->hostName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHostInfoFunc_localDomainName(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // localDomainName()
        QString cppResult = ::QHostInfo::localDomainName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHostInfoFunc_localHostName(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // localHostName()
        QString cppResult = ::QHostInfo::localHostName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHostInfoFunc_lookupHost(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    if (!Shiboken::Object::isValid(self))
        return {};
    ::QHostInfo *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (self)
        cppSelf = reinterpret_cast< ::QHostInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "lookupHost", 2, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QHostInfo::lookupHost(QString,PyCallable)
    // 1: static QHostInfo::lookupHost(QString,const QObject*,const char*)->int
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))
            && Shiboken::String::check(pyArgs[2]) && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[2])))) {
            overloadId = 1; // lookupHost(QString,const QObject*,const char*)
        } else if (numArgs == 2
            && PyCallable_Check(pyArgs[1])) {
            overloadId = 0; // lookupHost(QString,PyCallable)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "lookupHost", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHostInfo_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // lookupHost(const QString &name, PyCallable callable)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)

            if (Shiboken::Errors::occurred() == nullptr) {
                // lookupHost(QString,PyCallable)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtnetwork.cpp (qhostinfo-lookuphost-callable)]
                cppSelf->lookupHost(cppArg0, QHostInfoFunctor(pyArgs[2-1]));
                // END of custom code block [file: ../glue/qtnetwork.cpp (qhostinfo-lookuphost-callable)]
                // ========================================================================
                // End of code injection

                pyResult = Py_None;
                Py_INCREF(Py_None);
            }
            break;
        }
        case 1: // lookupHost(const QString &name, const QObject *receiver, const char *member)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QObject *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            const char* cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // lookupHost(QString,const QObject*,const char*)
                int cppResult = ::QHostInfo::lookupHost(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHostInfoFunc_lookupId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHostInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lookupId()const
        int cppResult = const_cast<const ::QHostInfo *>(cppSelf)->lookupId();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHostInfoFunc_setAddresses(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHostInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHostInfo::setAddresses(QList<QHostAddress>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QHostAddress_IDX], (pyArg)))) {
        overloadId = 0; // setAddresses(QList<QHostAddress>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAddresses", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHostInfo_IDX]);

    // Call function/method
    {
        ::QList<QHostAddress> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAddresses(QList<QHostAddress>)
            cppSelf->setAddresses(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHostInfoFunc_setError(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHostInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHostInfo::setError(QHostInfo::HostInfoError)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostInfo_HostInfoError_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setError(QHostInfo::HostInfoError)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setError", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHostInfo_IDX]);

    // Call function/method
    {
        ::QHostInfo::HostInfoError cppArg0{QHostInfo::NoError};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setError(QHostInfo::HostInfoError)
            cppSelf->setError(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHostInfoFunc_setErrorString(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHostInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHostInfo::setErrorString(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setErrorString(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setErrorString", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHostInfo_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setErrorString(QString)
            cppSelf->setErrorString(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHostInfoFunc_setHostName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHostInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHostInfo::setHostName(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setHostName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHostName", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHostInfo_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHostName(QString)
            cppSelf->setHostName(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHostInfoFunc_setLookupId(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHostInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHostInfo::setLookupId(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setLookupId(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLookupId", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHostInfo_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLookupId(int)
            cppSelf->setLookupId(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHostInfoFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHostInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHostInfo::swap(QHostInfo&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostInfo_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QHostInfo&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHostInfo_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QHostInfo cppArg0_local;
        ::QHostInfo *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QHostInfo&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHostInfo__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QHostInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostInfo_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyMethodDef Sbk_QHostInfoMethod_lookupHost = {"lookupHost", reinterpret_cast<PyCFunction>(Sbk_QHostInfoFunc_lookupHost), METH_VARARGS|METH_STATIC, nullptr};


static const char *Sbk_QHostInfo_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QHostInfo_EnumFlagInfo[] = {
    "HostInfoError:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QHostInfo_methods[] = {
    {"abortHostLookup", reinterpret_cast<PyCFunction>(Sbk_QHostInfoFunc_abortHostLookup), METH_O|METH_STATIC, nullptr},
    {"addresses", reinterpret_cast<PyCFunction>(Sbk_QHostInfoFunc_addresses), METH_NOARGS, nullptr},
    {"error", reinterpret_cast<PyCFunction>(Sbk_QHostInfoFunc_error), METH_NOARGS, nullptr},
    {"errorString", reinterpret_cast<PyCFunction>(Sbk_QHostInfoFunc_errorString), METH_NOARGS, nullptr},
    {"fromName", reinterpret_cast<PyCFunction>(Sbk_QHostInfoFunc_fromName), METH_O|METH_STATIC, nullptr},
    {"hostName", reinterpret_cast<PyCFunction>(Sbk_QHostInfoFunc_hostName), METH_NOARGS, nullptr},
    {"localDomainName", reinterpret_cast<PyCFunction>(Sbk_QHostInfoFunc_localDomainName), METH_NOARGS|METH_STATIC, nullptr},
    {"localHostName", reinterpret_cast<PyCFunction>(Sbk_QHostInfoFunc_localHostName), METH_NOARGS|METH_STATIC, nullptr},
    {"lookupHost", reinterpret_cast<PyCFunction>(Sbk_QHostInfoFunc_lookupHost), METH_VARARGS|METH_STATIC, nullptr},
    {"lookupId", reinterpret_cast<PyCFunction>(Sbk_QHostInfoFunc_lookupId), METH_NOARGS, nullptr},
    {"setAddresses", reinterpret_cast<PyCFunction>(Sbk_QHostInfoFunc_setAddresses), METH_O, nullptr},
    {"setError", reinterpret_cast<PyCFunction>(Sbk_QHostInfoFunc_setError), METH_O, nullptr},
    {"setErrorString", reinterpret_cast<PyCFunction>(Sbk_QHostInfoFunc_setErrorString), METH_O, nullptr},
    {"setHostName", reinterpret_cast<PyCFunction>(Sbk_QHostInfoFunc_setHostName), METH_O, nullptr},
    {"setLookupId", reinterpret_cast<PyCFunction>(Sbk_QHostInfoFunc_setLookupId), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QHostInfoFunc_swap), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QHostInfo__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QHostInfo_getattro(PyObject *self, PyObject *name)
{
    PySide::Feature::Select(self);
    // Search the method in the instance dict
    auto *ob_dict = SbkObject_GetDict_NoRef(self);
    if (auto *meth = PyDict_GetItem(ob_dict, name)) {
        Py_INCREF(meth);
        return meth;
    }
    // Search the method in the type dict
    if (Shiboken::Object::isUserType(self)) {
        Shiboken::AutoDecRef tmp(_Pep_PrivateMangle(self, name));
        Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
        if (auto *meth = PyDict_GetItem(tpDict.object(), tmp)) {
            if (std::strcmp(Py_TYPE(meth)->tp_name, "compiled_function") == 0) {
                auto descrGetFunc = reinterpret_cast<descrgetfunc>(PepType_GetSlot(Py_TYPE(meth), Py_tp_descr_get));
                ;
                return descrGetFunc(meth, self, nullptr);
            }
            return PyFunction_Check(meth) ? PyMethod_New(meth, self)
                                          : PyObject_GenericGetAttr(self, name);
        }
    }
    static PyMethodDef non_static_Sbk_QHostInfoMethod_lookupHost = {
        Sbk_QHostInfoMethod_lookupHost.ml_name,
        Sbk_QHostInfoMethod_lookupHost.ml_meth,
        Sbk_QHostInfoMethod_lookupHost.ml_flags & (~METH_STATIC),
        Sbk_QHostInfoMethod_lookupHost.ml_doc,
    };
    if (Shiboken::String::compare(name, "lookupHost") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_QHostInfoMethod_lookupHost, self, 0);
    return PyObject_GenericGetAttr(self, name);
}

} // extern "C"

static int Sbk_QHostInfo_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QHostInfo_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QHostInfo_Type = nullptr;
static PyTypeObject *Sbk_QHostInfo_TypeF(void)
{
    return _Sbk_QHostInfo_Type;
}

static PyType_Slot Sbk_QHostInfo_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_getattro,    reinterpret_cast<void *>(Sbk_QHostInfo_getattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QHostInfo_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QHostInfo_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QHostInfo_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QHostInfo_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QHostInfo_spec = {
    "2:PySide6.QtNetwork.QHostInfo",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QHostInfo_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QHostInfo_HostInfoError(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QHostInfo::HostInfoError>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QHostInfo::HostInfoError *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QHostInfo_HostInfoError_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostInfo_HostInfoError_IDX])))
        return Enum_PythonToCpp_QHostInfo_HostInfoError;
    return {};
}

static PyObject *QHostInfo_HostInfoError_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QHostInfo::HostInfoError>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QHostInfo::HostInfoError *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostInfo_HostInfoError_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QHostInfo_PythonToCpp_QHostInfo_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QHostInfo_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QHostInfo_PythonToCpp_QHostInfo_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QHostInfo_TypeF()))
        return QHostInfo_PythonToCpp_QHostInfo_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QHostInfo_PTR_CppToPython_QHostInfo(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QHostInfo_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QHostInfo_COPY_CppToPython_QHostInfo(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QHostInfo *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QHostInfo_TypeF(), new ::QHostInfo(*source), true, true);
}

// Python to C++ copy conversion.
static void QHostInfo_PythonToCpp_QHostInfo_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QHostInfo *>(cppOut) = *reinterpret_cast< ::QHostInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostInfo_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QHostInfo_PythonToCpp_QHostInfo_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QHostInfo_TypeF()))
        return QHostInfo_PythonToCpp_QHostInfo_COPY;
    return {};
}

// Implicit conversions.
static void int_PythonToCpp_QHostInfo(PyObject *pyIn, void *cppOut)
{
    int cppIn;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyIn, &cppIn);
    *reinterpret_cast<::QHostInfo *>(cppOut) = ::QHostInfo(cppIn);
}
static PythonToCppFunc is_int_PythonToCpp_QHostInfo_Convertible(PyObject *pyIn)
{
    if (PyLong_Check(pyIn))
        return int_PythonToCpp_QHostInfo;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QHostInfo_SignatureStrings[] = {
    "1:PySide6.QtNetwork.QHostInfo(self,d:PySide6.QtNetwork.QHostInfo)",
    "0:PySide6.QtNetwork.QHostInfo(self,lookupId:int=-1)",
    "PySide6.QtNetwork.QHostInfo.abortHostLookup(lookupId:int)",
    "PySide6.QtNetwork.QHostInfo.addresses(self)->QList[PySide6.QtNetwork.QHostAddress]",
    "PySide6.QtNetwork.QHostInfo.error(self)->PySide6.QtNetwork.QHostInfo.HostInfoError",
    "PySide6.QtNetwork.QHostInfo.errorString(self)->QString",
    "PySide6.QtNetwork.QHostInfo.fromName(name:QString)->PySide6.QtNetwork.QHostInfo",
    "PySide6.QtNetwork.QHostInfo.hostName(self)->QString",
    "PySide6.QtNetwork.QHostInfo.localDomainName()->QString",
    "PySide6.QtNetwork.QHostInfo.localHostName()->QString",
    "1:PySide6.QtNetwork.QHostInfo.lookupHost(self,name:QString,callable:PyCallable)",
    "0:PySide6.QtNetwork.QHostInfo.lookupHost(name:QString,receiver:PySide6.QtCore.QObject,member:char*)->int",
    "PySide6.QtNetwork.QHostInfo.lookupId(self)->int",
    "PySide6.QtNetwork.QHostInfo.setAddresses(self,addresses:QList[PySide6.QtNetwork.QHostAddress])",
    "PySide6.QtNetwork.QHostInfo.setError(self,error:PySide6.QtNetwork.QHostInfo.HostInfoError)",
    "PySide6.QtNetwork.QHostInfo.setErrorString(self,errorString:QString)",
    "PySide6.QtNetwork.QHostInfo.setHostName(self,name:QString)",
    "PySide6.QtNetwork.QHostInfo.setLookupId(self,id:int)",
    "PySide6.QtNetwork.QHostInfo.swap(self,other:typing.Union[PySide6.QtNetwork.QHostInfo, int])",
    "PySide6.QtNetwork.QHostInfo.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QHostInfo_SignatureByteSize = 347;
static constexpr uint8_t QHostInfo_SignatureBytes[347] = {
    0x78, 0xda, 0x95, 0x94, 0xcf, 0x6b, 0x83, 0x30, 0x14, 0xc7, 0xef, 0xfe, 0x15, 0x3b, 0xd6, 0x91,
    0xca, 0xbc, 0xec, 0x20, 0x6c, 0x30, 0xba, 0x42, 0x85, 0xd2, 0x4d, 0xca, 0x4e, 0x65, 0x48, 0xd4,
    0xe7, 0x9a, 0x55, 0xf3, 0x24, 0xc9, 0x56, 0xfa, 0xdf, 0x2f, 0xfe, 0x24, 0x3d, 0x2c, 0xb1, 0x17,
    0xc9, 0xc3, 0xf7, 0xf9, 0x24, 0xe6, 0x7d, 0x31, 0x8c, 0xde, 0x2f, 0x7b, 0x56, 0xc0, 0x63, 0x90,
    0xa8, 0x1d, 0xa8, 0x33, 0x8a, 0x53, 0x90, 0x6c, 0x50, 0xaa, 0x98, 0x97, 0xb8, 0x90, 0x50, 0x95,
    0xa4, 0xb0, 0xb5, 0xf8, 0xde, 0x83, 0xdb, 0x50, 0x21, 0x9e, 0x7e, 0x9a, 0xb8, 0x88, 0x18, 0x57,
    0x4f, 0xcb, 0xd0, 0xf7, 0x2c, 0x44, 0x40, 0x33, 0x14, 0xaa, 0xad, 0xb6, 0x1d, 0xb5, 0x30, 0x61,
    0x07, 0x59, 0x14, 0x02, 0xa4, 0x04, 0xd9, 0xed, 0xea, 0x2f, 0x9f, 0x93, 0x2d, 0x93, 0xea, 0xf0,
    0x0f, 0xf2, 0xd2, 0x77, 0x7f, 0x5a, 0x95, 0x20, 0x04, 0x8a, 0x51, 0x67, 0x6b, 0x1c, 0x17, 0xeb,
    0x16, 0x70, 0x2b, 0xf7, 0x4a, 0x30, 0xfe, 0x35, 0x9d, 0xb3, 0x2f, 0xad, 0x58, 0x29, 0xb0, 0xde,
    0xd1, 0x1a, 0x16, 0x5c, 0x3f, 0xa2, 0x81, 0xb0, 0x1f, 0xca, 0xea, 0x3b, 0xea, 0x45, 0xe7, 0xbb,
    0xe1, 0x0c, 0x15, 0xe6, 0xb4, 0x7a, 0xc5, 0x9a, 0x32, 0xde, 0xa1, 0xb7, 0x60, 0x9b, 0x71, 0x3f,
    0x03, 0x0a, 0x23, 0x3b, 0xd6, 0x0e, 0xbe, 0x2d, 0xfb, 0x14, 0x99, 0x1f, 0x4e, 0xb4, 0xb1, 0xa2,
    0x59, 0x05, 0xda, 0xb0, 0x1a, 0x96, 0x8e, 0x28, 0x9a, 0xbe, 0x2b, 0x95, 0x80, 0x1c, 0xd8, 0x2f,
    0x08, 0x03, 0x5e, 0xa1, 0x80, 0x20, 0x79, 0xcb, 0xbe, 0x21, 0x57, 0xa4, 0x86, 0x3a, 0xd3, 0x6f,
    0xf3, 0x23, 0x15, 0xf7, 0xfa, 0xf0, 0x3a, 0x86, 0x9e, 0x7b, 0x9b, 0xb8, 0x18, 0x2f, 0xd6, 0xd5,
    0x2f, 0x61, 0x8c, 0xe2, 0x10, 0x5c, 0x32, 0xe5, 0x38, 0x9a, 0x15, 0x60, 0xdf, 0xa5, 0x5f, 0x4f,
    0x21, 0x26, 0x5d, 0xf8, 0xa2, 0xd9, 0x41, 0x9e, 0xa7, 0x36, 0xc2, 0x4c, 0x8c, 0x74, 0x4f, 0x21,
    0x75, 0x49, 0x36, 0x66, 0x14, 0xaf, 0xc6, 0xec, 0x44, 0xb7, 0xe6, 0x65, 0x13, 0x36, 0xe3, 0x27,
    0x21, 0xcf, 0xb4, 0xe9, 0xbb, 0x51, 0x1d, 0xf5, 0x58, 0xd5, 0xa5, 0xd1, 0x1b, 0x05, 0x1f, 0x9c,
    0x21, 0x3f, 0x58, 0x40, 0x72, 0xa7, 0xd5, 0x8e, 0xbb, 0x4e, 0xd3, 0x1c, 0x9b, 0x4b, 0x9a, 0x8e,
    0xa3, 0x1f, 0xdc, 0x7b, 0x5d, 0x79, 0x7f, 0x75, 0xf1, 0xf6, 0xfb
};
#endif

PyTypeObject *init_QHostInfo(PyObject *module)
{
    if (SbkPySide6_QtNetworkTypeStructs[SBK_QHostInfo_IDX].type != nullptr)
        return SbkPySide6_QtNetworkTypeStructs[SBK_QHostInfo_IDX].type;

    Shiboken::AutoDecRef Sbk_QHostInfo_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QHostInfo_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QHostInfo",
        "QHostInfo",
        &Sbk_QHostInfo_spec,
        &Shiboken::callCppDestructor< ::QHostInfo >,
        Sbk_QHostInfo_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QHostInfo_TypeF(); // references _Sbk_QHostInfo_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QHostInfo_SignatureStrings);
#else
    InitSignatureBytes(pyType, QHostInfo_SignatureBytes, QHostInfo_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QHostInfo_PropertyStrings);
    SbkPySide6_QtNetworkTypeStructs[SBK_QHostInfo_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QHostInfo_PythonToCpp_QHostInfo_PTR,
        is_QHostInfo_PythonToCpp_QHostInfo_PTR_Convertible,
        QHostInfo_PTR_CppToPython_QHostInfo,
        QHostInfo_COPY_CppToPython_QHostInfo);

    Shiboken::Conversions::registerConverterName(converter, "QHostInfo");
    Shiboken::Conversions::registerConverterName(converter, "QHostInfo*");
    Shiboken::Conversions::registerConverterName(converter, "QHostInfo&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QHostInfo).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QHostInfo_PythonToCpp_QHostInfo_COPY,
        is_QHostInfo_PythonToCpp_QHostInfo_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        int_PythonToCpp_QHostInfo,
        is_int_PythonToCpp_QHostInfo_Convertible);


    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QHostInfo_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'HostInfoError'.
    const char *HostInfoError_Initializer[] = {
        "NoError",
        "HostNotFound",
        "UnknownError",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t HostInfoError_InitializerValues[] = {
        uint8_t(QHostInfo::HostInfoError::NoError),      //  0x00  0
        uint8_t(QHostInfo::HostInfoError::HostNotFound), //  0x01  1
        uint8_t(QHostInfo::HostInfoError::UnknownError)  //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QHostInfo_TypeF(),
        "2:PySide6.QtNetwork.QHostInfo.HostInfoError",
        HostInfoError_Initializer, HostInfoError_InitializerValues);
    SbkPySide6_QtNetworkTypeStructs[SBK_QHostInfo_HostInfoError_IDX].type = EType;
    // Register converter for enum 'QHostInfo::HostInfoError'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QHostInfo_HostInfoError_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QHostInfo_HostInfoError,
            is_Enum_PythonToCpp_QHostInfo_HostInfoError_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QHostInfo::HostInfoError");
        Shiboken::Conversions::registerConverterAlias(converter, "HostInfoError");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'HostInfoError' enum.


    qRegisterMetaType< ::QHostInfo >("QHostInfo");
    qRegisterMetaType< ::QHostInfo::HostInfoError >("QHostInfo::HostInfoError");

    return pyType;
}

