// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnetwork_python.h"

// main header
#include "qhstspolicy_wrapper.h"

// Argument includes
#include <QString>
#include <QtNetwork/qhstspolicy.h>
#include <qdatetime.h>
#include <qurl.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QHstsPolicy_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QHstsPolicy >()))
        return -1;

    ::QHstsPolicy *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_IDX]);
    if (numArgs == 2)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:QHstsPolicy", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QHstsPolicy::QHstsPolicy()
    // 1: QHstsPolicy::QHstsPolicy(QDateTime,QFlags<QHstsPolicy::PolicyFlag>,QString,QUrl::ParsingMode=)
    // 2: QHstsPolicy::QHstsPolicy(QHstsPolicy)
    if (numArgs == 0) {
        overloadId = 0; // QHstsPolicy()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QHstsPolicy(QHstsPolicy)
    } else if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFlags_QHstsPolicy_PolicyFlag_IDX])))->flagsConverter, (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 1; // QHstsPolicy(QDateTime,QFlags<QHstsPolicy::PolicyFlag>,QString,QUrl::ParsingMode)
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_ParsingMode_IDX])))->converter, (pyArgs[3])))) {
            overloadId = 1; // QHstsPolicy(QDateTime,QFlags<QHstsPolicy::PolicyFlag>,QString,QUrl::ParsingMode)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QHstsPolicy()
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_IDX]);
            }

            // QHstsPolicy()
            cptr = new ::QHstsPolicy();
            break;
        }
        case 1: // QHstsPolicy(const QDateTime &expiry, QFlags<QHstsPolicy::PolicyFlag> flags, const QString &host, QUrl::ParsingMode mode)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
                if (PyDict_Contains(kwds, key_mode) != 0) {
                    value = PyDict_GetItem(kwds, key_mode);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_mode);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_ParsingMode_IDX])))->converter, (pyArgs[3]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_mode);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QDateTime cppArg0_local;
            ::QDateTime *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QFlags<QHstsPolicy::PolicyFlag> cppArg1 = QFlags<QHstsPolicy::PolicyFlag>(0);
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QUrl::ParsingMode cppArg3(QUrl::DecodedMode);
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QHstsPolicy(QDateTime,QFlags<QHstsPolicy::PolicyFlag>,QString,QUrl::ParsingMode)
                cptr = new ::QHstsPolicy(*cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
        case 2: // QHstsPolicy(const QHstsPolicy &rhs)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QHstsPolicy cppArg0_local;
            ::QHstsPolicy *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QHstsPolicy(QHstsPolicy)
                cptr = new ::QHstsPolicy(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QHstsPolicy >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QHstsPolicyFunc_expiry(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHstsPolicy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // expiry()const
        QDateTime cppResult = const_cast<const ::QHstsPolicy *>(cppSelf)->expiry();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHstsPolicyFunc_host(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHstsPolicy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "host", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_IDX]);

    if (PyArg_ParseTuple(args, "|O:host", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QHstsPolicy::host(QFlags<QUrl::ComponentFormattingOption>=)const->QString
    if (numArgs == 0) {
        overloadId = 0; // host(QFlags<QUrl::ComponentFormattingOption>)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_ComponentFormattingOption_IDX])))->flagsConverter, (pyArgs[0])))) {
        overloadId = 0; // host(QFlags<QUrl::ComponentFormattingOption>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "host", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_options = Shiboken::String::createStaticString("options");
            if (PyDict_Contains(kwds, key_options) != 0) {
                value = PyDict_GetItem(kwds, key_options);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_options);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "host", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_ComponentFormattingOption_IDX])))->flagsConverter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "host", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_options);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "host", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_IDX]);
            }
        }
        ::QFlags<QUrl::ComponentFormattingOption> cppArg0(QUrl::FullyDecoded);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // host(QFlags<QUrl::ComponentFormattingOption>)const
            QString cppResult = const_cast<const ::QHstsPolicy *>(cppSelf)->host(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHstsPolicyFunc_includesSubDomains(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHstsPolicy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // includesSubDomains()const
        bool cppResult = const_cast<const ::QHstsPolicy *>(cppSelf)->includesSubDomains();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHstsPolicyFunc_isExpired(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHstsPolicy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isExpired()const
        bool cppResult = const_cast<const ::QHstsPolicy *>(cppSelf)->isExpired();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHstsPolicyFunc_setExpiry(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHstsPolicy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHstsPolicy::setExpiry(QDateTime)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // setExpiry(QDateTime)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setExpiry", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setExpiry(QDateTime)
            cppSelf->setExpiry(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHstsPolicyFunc_setHost(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHstsPolicy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setHost", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setHost", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QHstsPolicy::setHost(QString,QUrl::ParsingMode=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setHost(QString,QUrl::ParsingMode)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_ParsingMode_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // setHost(QString,QUrl::ParsingMode)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setHost", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
            if (PyDict_Contains(kwds, key_mode) != 0) {
                value = PyDict_GetItem(kwds, key_mode);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_mode);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setHost", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_ParsingMode_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "setHost", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_mode);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setHost", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QUrl::ParsingMode cppArg1(QUrl::DecodedMode);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHost(QString,QUrl::ParsingMode)
            cppSelf->setHost(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHstsPolicyFunc_setIncludesSubDomains(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHstsPolicy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHstsPolicy::setIncludesSubDomains(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setIncludesSubDomains(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setIncludesSubDomains", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setIncludesSubDomains(bool)
            cppSelf->setIncludesSubDomains(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHstsPolicyFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHstsPolicy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHstsPolicy::swap(QHstsPolicy&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QHstsPolicy&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QHstsPolicy cppArg0_local;
        ::QHstsPolicy *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QHstsPolicy&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHstsPolicy__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QHstsPolicy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QHstsPolicy_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QHstsPolicy_EnumFlagInfo[] = {
    "PolicyFlag:Flag:PolicyFlags",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QHstsPolicy_methods[] = {
    {"expiry", reinterpret_cast<PyCFunction>(Sbk_QHstsPolicyFunc_expiry), METH_NOARGS, nullptr},
    {"host", reinterpret_cast<PyCFunction>(Sbk_QHstsPolicyFunc_host), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"includesSubDomains", reinterpret_cast<PyCFunction>(Sbk_QHstsPolicyFunc_includesSubDomains), METH_NOARGS, nullptr},
    {"isExpired", reinterpret_cast<PyCFunction>(Sbk_QHstsPolicyFunc_isExpired), METH_NOARGS, nullptr},
    {"setExpiry", reinterpret_cast<PyCFunction>(Sbk_QHstsPolicyFunc_setExpiry), METH_O, nullptr},
    {"setHost", reinterpret_cast<PyCFunction>(Sbk_QHstsPolicyFunc_setHost), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setIncludesSubDomains", reinterpret_cast<PyCFunction>(Sbk_QHstsPolicyFunc_setIncludesSubDomains), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QHstsPolicyFunc_swap), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QHstsPolicy__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QHstsPolicy_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QHstsPolicy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_IDX]), (pyArg)))) {
                // operator!=(const QHstsPolicy &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QHstsPolicy cppArg0_local;
                ::QHstsPolicy *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_IDX]), (pyArg)))) {
                // operator==(const QHstsPolicy &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QHstsPolicy cppArg0_local;
                ::QHstsPolicy *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QHstsPolicy_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QHstsPolicy_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QHstsPolicy_Type = nullptr;
static PyTypeObject *Sbk_QHstsPolicy_TypeF(void)
{
    return _Sbk_QHstsPolicy_Type;
}

static PyType_Slot Sbk_QHstsPolicy_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QHstsPolicy_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QHstsPolicy_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QHstsPolicy_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QHstsPolicy_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QHstsPolicy_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QHstsPolicy_spec = {
    "2:PySide6.QtNetwork.QHstsPolicy",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QHstsPolicy_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QHstsPolicy_PolicyFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QHstsPolicy::PolicyFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QHstsPolicy::PolicyFlag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QHstsPolicy_PolicyFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_PolicyFlag_IDX])))
        return Enum_PythonToCpp_QHstsPolicy_PolicyFlag;
    return {};
}

static PyObject *QHstsPolicy_PolicyFlag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QHstsPolicy::PolicyFlag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QHstsPolicy::PolicyFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_PolicyFlag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QHstsPolicy_PolicyFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QHstsPolicy::PolicyFlag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QHstsPolicy::PolicyFlag> *>(cppOut) = value;

}

static PyObject *QHstsPolicy_PolicyFlag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QHstsPolicy::PolicyFlag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_PolicyFlag_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QHstsPolicy_PythonToCpp_QHstsPolicy_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QHstsPolicy_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QHstsPolicy_PythonToCpp_QHstsPolicy_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QHstsPolicy_TypeF()))
        return QHstsPolicy_PythonToCpp_QHstsPolicy_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QHstsPolicy_PTR_CppToPython_QHstsPolicy(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QHstsPolicy_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QHstsPolicy_COPY_CppToPython_QHstsPolicy(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QHstsPolicy *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QHstsPolicy_TypeF(), new ::QHstsPolicy(*source), true, true);
}

// Python to C++ copy conversion.
static void QHstsPolicy_PythonToCpp_QHstsPolicy_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QHstsPolicy *>(cppOut) = *reinterpret_cast< ::QHstsPolicy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QHstsPolicy_PythonToCpp_QHstsPolicy_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QHstsPolicy_TypeF()))
        return QHstsPolicy_PythonToCpp_QHstsPolicy_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QHstsPolicy_SignatureStrings[] = {
    "2:PySide6.QtNetwork.QHstsPolicy(self)",
    "1:PySide6.QtNetwork.QHstsPolicy(self,expiry:PySide6.QtCore.QDateTime,flags:PySide6.QtNetwork.QHstsPolicy.PolicyFlag,host:QString,mode:PySide6.QtCore.QUrl.ParsingMode=QUrl.DecodedMode)",
    "0:PySide6.QtNetwork.QHstsPolicy(self,rhs:PySide6.QtNetwork.QHstsPolicy)",
    "PySide6.QtNetwork.QHstsPolicy.expiry(self)->PySide6.QtCore.QDateTime",
    "PySide6.QtNetwork.QHstsPolicy.host(self,options:PySide6.QtCore.QUrl.ComponentFormattingOption=QUrl.FullyDecoded)->QString",
    "PySide6.QtNetwork.QHstsPolicy.includesSubDomains(self)->bool",
    "PySide6.QtNetwork.QHstsPolicy.isExpired(self)->bool",
    "PySide6.QtNetwork.QHstsPolicy.setExpiry(self,expiry:PySide6.QtCore.QDateTime)",
    "PySide6.QtNetwork.QHstsPolicy.setHost(self,host:QString,mode:PySide6.QtCore.QUrl.ParsingMode=QUrl.DecodedMode)",
    "PySide6.QtNetwork.QHstsPolicy.setIncludesSubDomains(self,include:bool)",
    "PySide6.QtNetwork.QHstsPolicy.swap(self,other:PySide6.QtNetwork.QHstsPolicy)",
    "PySide6.QtNetwork.QHstsPolicy.__copy__(self)->typing.Self",
    "PySide6.QtNetwork.QHstsPolicy.__ne__(self,rhs:PySide6.QtNetwork.QHstsPolicy)->bool",
    "PySide6.QtNetwork.QHstsPolicy.__eq__(self,rhs:PySide6.QtNetwork.QHstsPolicy)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QHstsPolicy_SignatureByteSize = 301;
static constexpr uint8_t QHstsPolicy_SignatureBytes[301] = {
    0x78, 0xda, 0xad, 0x53, 0xc1, 0x52, 0x83, 0x30, 0x10, 0xbd, 0xf3, 0x25, 0x32, 0x83, 0x19, 0xf5,
    0xe0, 0x81, 0x19, 0xbd, 0x94, 0x76, 0xea, 0x41, 0x85, 0x41, 0xcf, 0x19, 0x0a, 0xdb, 0x92, 0x31,
    0x64, 0x31, 0x59, 0xa6, 0xe6, 0xef, 0x0d, 0x85, 0xaa, 0x33, 0xb6, 0x0d, 0x1d, 0x3d, 0x11, 0x92,
    0xb7, 0x2f, 0xef, 0xbd, 0xdd, 0xdc, 0xc4, 0xa9, 0xcd, 0x45, 0x05, 0xb7, 0x2c, 0xa3, 0x27, 0xa0,
    0x2d, 0xea, 0x37, 0x96, 0x2d, 0x0d, 0x99, 0x14, 0xa5, 0x28, 0xed, 0x85, 0x01, 0xb9, 0x0e, 0x83,
    0xeb, 0x09, 0xa8, 0x08, 0x3e, 0x5a, 0xa1, 0xed, 0x0f, 0xe4, 0x0c, 0x35, 0xb0, 0x2c, 0x29, 0x08,
    0x5e, 0x44, 0x03, 0xd1, 0x5a, 0x16, 0x1b, 0x73, 0x9a, 0x88, 0x0d, 0x9f, 0x85, 0x43, 0x46, 0x35,
    0x1a, 0x8a, 0xb3, 0x9c, 0xb4, 0x50, 0x9b, 0xa8, 0xc1, 0x0a, 0x7e, 0x31, 0xbf, 0x6a, 0xc9, 0xd2,
    0x42, 0x1b, 0x07, 0x78, 0x74, 0xe7, 0x77, 0xbb, 0x8d, 0x04, 0x4a, 0xb7, 0xae, 0xfa, 0x8d, 0x30,
    0xb8, 0x9a, 0xa2, 0x5b, 0xd7, 0x1e, 0x55, 0x61, 0x70, 0x5a, 0xf4, 0x60, 0x7c, 0x88, 0xea, 0xf2,
    0xfe, 0x98, 0x7f, 0x0f, 0x49, 0x6f, 0x77, 0xd0, 0x83, 0x2d, 0x09, 0x54, 0xe6, 0xa0, 0xdd, 0x19,
    0x36, 0x2d, 0x2a, 0x50, 0xb4, 0x40, 0xdd, 0x14, 0x44, 0xce, 0xfa, 0xf3, 0x0e, 0x3e, 0x98, 0x5f,
    0x74, 0x52, 0xda, 0x31, 0x01, 0x27, 0x65, 0x4c, 0xcf, 0x73, 0xb3, 0x50, 0xa5, 0xec, 0x2a, 0x30,
    0x79, 0xb7, 0x4a, 0xb0, 0x29, 0x84, 0x32, 0x7b, 0x2b, 0x2b, 0x44, 0xe9, 0x2b, 0x36, 0xf3, 0xde,
    0x3d, 0x54, 0x67, 0xd4, 0x18, 0xa0, 0xf9, 0x77, 0x64, 0xbe, 0xb9, 0x09, 0xfd, 0x6c, 0xcb, 0xaf,
    0xec, 0xfe, 0x63, 0x68, 0xbc, 0xd7, 0x3d, 0x1c, 0x0e, 0x2c, 0x1a, 0x83, 0x8c, 0xfb, 0x08, 0xbc,
    0x34, 0xdb, 0xa2, 0x1d, 0xdb, 0x4d, 0x35, 0xe8, 0xbf, 0x0d, 0x20, 0xe7, 0x25, 0xb6, 0x96, 0xf3,
    0x7d, 0x0f, 0xc8, 0xb6, 0xce, 0x1e, 0xcb, 0xdd, 0x9f, 0xb7, 0x52, 0xc1, 0x58, 0x37, 0xe1, 0x1d,
    0x4c, 0xea, 0x2e, 0xe7, 0xf0, 0x7e, 0x36, 0xe5, 0x27, 0xee, 0x3a, 0xa7, 0x01
};
#endif

PyTypeObject *init_QHstsPolicy(PyObject *module)
{
    if (SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_IDX].type != nullptr)
        return SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_IDX].type;

    Shiboken::AutoDecRef Sbk_QHstsPolicy_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QHstsPolicy_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QHstsPolicy",
        "QHstsPolicy",
        &Sbk_QHstsPolicy_spec,
        &Shiboken::callCppDestructor< ::QHstsPolicy >,
        Sbk_QHstsPolicy_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QHstsPolicy_TypeF(); // references _Sbk_QHstsPolicy_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QHstsPolicy_SignatureStrings);
#else
    InitSignatureBytes(pyType, QHstsPolicy_SignatureBytes, QHstsPolicy_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QHstsPolicy_PropertyStrings);
    SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QHstsPolicy_PythonToCpp_QHstsPolicy_PTR,
        is_QHstsPolicy_PythonToCpp_QHstsPolicy_PTR_Convertible,
        QHstsPolicy_PTR_CppToPython_QHstsPolicy,
        QHstsPolicy_COPY_CppToPython_QHstsPolicy);

    Shiboken::Conversions::registerConverterName(converter, "QHstsPolicy");
    Shiboken::Conversions::registerConverterName(converter, "QHstsPolicy*");
    Shiboken::Conversions::registerConverterName(converter, "QHstsPolicy&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QHstsPolicy).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QHstsPolicy_PythonToCpp_QHstsPolicy_COPY,
        is_QHstsPolicy_PythonToCpp_QHstsPolicy_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QHstsPolicy_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'PolicyFlag'.
    const char *PolicyFlag_Initializer[] = {
        "IncludeSubDomains",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t PolicyFlag_InitializerValues[] = {
        uint8_t(QHstsPolicy::PolicyFlag::IncludeSubDomains) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QHstsPolicy_TypeF(),
        "2:PySide6.QtNetwork.QHstsPolicy.PolicyFlag",
        PolicyFlag_Initializer, PolicyFlag_InitializerValues);
    SbkPySide6_QtNetworkTypeStructs[SBK_QHstsPolicy_PolicyFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtNetworkTypeStructs[SBK_QFlags_QHstsPolicy_PolicyFlag_IDX].type =
        EType;
    // Register converter for enum 'QHstsPolicy::PolicyFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QHstsPolicy_PolicyFlag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QHstsPolicy_PolicyFlag,
            is_Enum_PythonToCpp_QHstsPolicy_PolicyFlag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QHstsPolicy::PolicyFlag");
        Shiboken::Conversions::registerConverterAlias(converter, "PolicyFlag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QHstsPolicy_PolicyFlag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QHstsPolicy_PolicyFlag,
            is_Enum_PythonToCpp_QHstsPolicy_PolicyFlag_Convertible);
        // Register converter for flag 'QFlags<QHstsPolicy::PolicyFlag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QHstsPolicy::PolicyFlag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QHstsPolicy::PolicyFlags");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'PolicyFlag' enum/flags.

    qRegisterMetaType< ::QHstsPolicy >("QHstsPolicy");
    qRegisterMetaType< ::QHstsPolicy::PolicyFlag >("QHstsPolicy::PolicyFlag");

    return pyType;
}
