// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnetwork_python.h"

// main header
#include "qhttp2configuration_wrapper.h"

// Argument includes
#include <QtNetwork/qhttp2configuration.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QHttp2Configuration_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QHttp2Configuration >()))
        return -1;

    ::QHttp2Configuration *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QHttp2Configuration", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QHttp2Configuration::QHttp2Configuration()
    // 1: QHttp2Configuration::QHttp2Configuration(QHttp2Configuration)
    if (numArgs == 0) {
        overloadId = 0; // QHttp2Configuration()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QHttp2Configuration(QHttp2Configuration)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QHttp2Configuration()
        {

            // QHttp2Configuration()
            cptr = new ::QHttp2Configuration();
            break;
        }
        case 1: // QHttp2Configuration(const QHttp2Configuration &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QHttp2Configuration cppArg0_local;
            ::QHttp2Configuration *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QHttp2Configuration(QHttp2Configuration)
                cptr = new ::QHttp2Configuration(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QHttp2Configuration >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QHttp2ConfigurationFunc_huffmanCompressionEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttp2Configuration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // huffmanCompressionEnabled()const
        bool cppResult = const_cast<const ::QHttp2Configuration *>(cppSelf)->huffmanCompressionEnabled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttp2ConfigurationFunc_maxFrameSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttp2Configuration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maxFrameSize()const
        unsigned int cppResult = const_cast<const ::QHttp2Configuration *>(cppSelf)->maxFrameSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttp2ConfigurationFunc_serverPushEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttp2Configuration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // serverPushEnabled()const
        bool cppResult = const_cast<const ::QHttp2Configuration *>(cppSelf)->serverPushEnabled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttp2ConfigurationFunc_sessionReceiveWindowSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttp2Configuration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sessionReceiveWindowSize()const
        unsigned int cppResult = const_cast<const ::QHttp2Configuration *>(cppSelf)->sessionReceiveWindowSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttp2ConfigurationFunc_setHuffmanCompressionEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttp2Configuration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHttp2Configuration::setHuffmanCompressionEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setHuffmanCompressionEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHuffmanCompressionEnabled", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHuffmanCompressionEnabled(bool)
            cppSelf->setHuffmanCompressionEnabled(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHttp2ConfigurationFunc_setMaxFrameSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttp2Configuration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHttp2Configuration::setMaxFrameSize(uint)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // setMaxFrameSize(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMaxFrameSize", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMaxFrameSize(uint)
            bool cppResult = cppSelf->setMaxFrameSize(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttp2ConfigurationFunc_setServerPushEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttp2Configuration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHttp2Configuration::setServerPushEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setServerPushEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setServerPushEnabled", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setServerPushEnabled(bool)
            cppSelf->setServerPushEnabled(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHttp2ConfigurationFunc_setSessionReceiveWindowSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttp2Configuration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHttp2Configuration::setSessionReceiveWindowSize(uint)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // setSessionReceiveWindowSize(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSessionReceiveWindowSize", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSessionReceiveWindowSize(uint)
            bool cppResult = cppSelf->setSessionReceiveWindowSize(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttp2ConfigurationFunc_setStreamReceiveWindowSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttp2Configuration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHttp2Configuration::setStreamReceiveWindowSize(uint)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // setStreamReceiveWindowSize(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStreamReceiveWindowSize", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStreamReceiveWindowSize(uint)
            bool cppResult = cppSelf->setStreamReceiveWindowSize(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttp2ConfigurationFunc_streamReceiveWindowSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttp2Configuration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // streamReceiveWindowSize()const
        unsigned int cppResult = const_cast<const ::QHttp2Configuration *>(cppSelf)->streamReceiveWindowSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttp2ConfigurationFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttp2Configuration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHttp2Configuration::swap(QHttp2Configuration&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QHttp2Configuration&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QHttp2Configuration cppArg0_local;
        ::QHttp2Configuration *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QHttp2Configuration&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHttp2Configuration__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QHttp2Configuration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QHttp2Configuration_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QHttp2Configuration_methods[] = {
    {"huffmanCompressionEnabled", reinterpret_cast<PyCFunction>(Sbk_QHttp2ConfigurationFunc_huffmanCompressionEnabled), METH_NOARGS, nullptr},
    {"maxFrameSize", reinterpret_cast<PyCFunction>(Sbk_QHttp2ConfigurationFunc_maxFrameSize), METH_NOARGS, nullptr},
    {"serverPushEnabled", reinterpret_cast<PyCFunction>(Sbk_QHttp2ConfigurationFunc_serverPushEnabled), METH_NOARGS, nullptr},
    {"sessionReceiveWindowSize", reinterpret_cast<PyCFunction>(Sbk_QHttp2ConfigurationFunc_sessionReceiveWindowSize), METH_NOARGS, nullptr},
    {"setHuffmanCompressionEnabled", reinterpret_cast<PyCFunction>(Sbk_QHttp2ConfigurationFunc_setHuffmanCompressionEnabled), METH_O, nullptr},
    {"setMaxFrameSize", reinterpret_cast<PyCFunction>(Sbk_QHttp2ConfigurationFunc_setMaxFrameSize), METH_O, nullptr},
    {"setServerPushEnabled", reinterpret_cast<PyCFunction>(Sbk_QHttp2ConfigurationFunc_setServerPushEnabled), METH_O, nullptr},
    {"setSessionReceiveWindowSize", reinterpret_cast<PyCFunction>(Sbk_QHttp2ConfigurationFunc_setSessionReceiveWindowSize), METH_O, nullptr},
    {"setStreamReceiveWindowSize", reinterpret_cast<PyCFunction>(Sbk_QHttp2ConfigurationFunc_setStreamReceiveWindowSize), METH_O, nullptr},
    {"streamReceiveWindowSize", reinterpret_cast<PyCFunction>(Sbk_QHttp2ConfigurationFunc_streamReceiveWindowSize), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QHttp2ConfigurationFunc_swap), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QHttp2Configuration__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QHttp2Configuration_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QHttp2Configuration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]), (pyArg)))) {
                // operator!=(const QHttp2Configuration &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QHttp2Configuration cppArg0_local;
                ::QHttp2Configuration *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]), (pyArg)))) {
                // operator==(const QHttp2Configuration &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QHttp2Configuration cppArg0_local;
                ::QHttp2Configuration *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QHttp2Configuration_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QHttp2Configuration_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QHttp2Configuration_Type = nullptr;
static PyTypeObject *Sbk_QHttp2Configuration_TypeF(void)
{
    return _Sbk_QHttp2Configuration_Type;
}

static PyType_Slot Sbk_QHttp2Configuration_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QHttp2Configuration_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QHttp2Configuration_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QHttp2Configuration_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QHttp2Configuration_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QHttp2Configuration_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QHttp2Configuration_spec = {
    "2:PySide6.QtNetwork.QHttp2Configuration",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QHttp2Configuration_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QHttp2Configuration_PythonToCpp_QHttp2Configuration_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QHttp2Configuration_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QHttp2Configuration_PythonToCpp_QHttp2Configuration_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QHttp2Configuration_TypeF()))
        return QHttp2Configuration_PythonToCpp_QHttp2Configuration_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QHttp2Configuration_PTR_CppToPython_QHttp2Configuration(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QHttp2Configuration_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QHttp2Configuration_COPY_CppToPython_QHttp2Configuration(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QHttp2Configuration *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QHttp2Configuration_TypeF(), new ::QHttp2Configuration(*source), true, true);
}

// Python to C++ copy conversion.
static void QHttp2Configuration_PythonToCpp_QHttp2Configuration_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QHttp2Configuration *>(cppOut) = *reinterpret_cast< ::QHttp2Configuration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QHttp2Configuration_PythonToCpp_QHttp2Configuration_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QHttp2Configuration_TypeF()))
        return QHttp2Configuration_PythonToCpp_QHttp2Configuration_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QHttp2Configuration_SignatureStrings[] = {
    "1:PySide6.QtNetwork.QHttp2Configuration(self)",
    "0:PySide6.QtNetwork.QHttp2Configuration(self,other:PySide6.QtNetwork.QHttp2Configuration)",
    "PySide6.QtNetwork.QHttp2Configuration.huffmanCompressionEnabled(self)->bool",
    "PySide6.QtNetwork.QHttp2Configuration.maxFrameSize(self)->unsigned int",
    "PySide6.QtNetwork.QHttp2Configuration.serverPushEnabled(self)->bool",
    "PySide6.QtNetwork.QHttp2Configuration.sessionReceiveWindowSize(self)->unsigned int",
    "PySide6.QtNetwork.QHttp2Configuration.setHuffmanCompressionEnabled(self,enable:bool)",
    "PySide6.QtNetwork.QHttp2Configuration.setMaxFrameSize(self,size:unsigned int)->bool",
    "PySide6.QtNetwork.QHttp2Configuration.setServerPushEnabled(self,enable:bool)",
    "PySide6.QtNetwork.QHttp2Configuration.setSessionReceiveWindowSize(self,size:unsigned int)->bool",
    "PySide6.QtNetwork.QHttp2Configuration.setStreamReceiveWindowSize(self,size:unsigned int)->bool",
    "PySide6.QtNetwork.QHttp2Configuration.streamReceiveWindowSize(self)->unsigned int",
    "PySide6.QtNetwork.QHttp2Configuration.swap(self,other:PySide6.QtNetwork.QHttp2Configuration)",
    "PySide6.QtNetwork.QHttp2Configuration.__copy__(self)->typing.Self",
    "PySide6.QtNetwork.QHttp2Configuration.__ne__(self,rhs:PySide6.QtNetwork.QHttp2Configuration)->bool",
    "PySide6.QtNetwork.QHttp2Configuration.__eq__(self,rhs:PySide6.QtNetwork.QHttp2Configuration)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QHttp2Configuration_SignatureByteSize = 254;
static constexpr uint8_t QHttp2Configuration_SignatureBytes[254] = {
    0x78, 0xda, 0xb5, 0x93, 0x31, 0x4f, 0xc3, 0x30, 0x10, 0x85, 0xf7, 0xfe, 0x8a, 0x8e, 0x44, 0x0a,
    0x11, 0x30, 0x74, 0xc8, 0xc0, 0x52, 0x51, 0x75, 0x69, 0xd5, 0xe2, 0x81, 0xd1, 0x72, 0x9b, 0x4b,
    0x72, 0x22, 0x3e, 0x1b, 0xfb, 0xd2, 0x10, 0x7e, 0x3d, 0x81, 0x52, 0x09, 0x21, 0x14, 0x39, 0x69,
    0xbb, 0xf9, 0xac, 0x7b, 0xcf, 0xdf, 0x3d, 0x9d, 0xef, 0xd3, 0x4d, 0x2b, 0x30, 0x83, 0x59, 0xb2,
    0xe5, 0x35, 0x70, 0x63, 0xdc, 0x6b, 0xb2, 0x5d, 0x32, 0xdb, 0x87, 0xb9, 0xa1, 0x1c, 0x8b, 0xda,
    0x29, 0x46, 0x43, 0x37, 0x1e, 0xaa, 0x3c, 0x9a, 0xdc, 0x0d, 0xe8, 0x8e, 0x0d, 0x97, 0xe0, 0xc2,
    0x04, 0xd1, 0x24, 0xa8, 0x2d, 0x29, 0xeb, 0x3c, 0xd7, 0x8a, 0xe6, 0x46, 0x5b, 0x07, 0xde, 0x77,
    0x57, 0x4f, 0xa4, 0x76, 0x15, 0x64, 0x47, 0xbe, 0xdb, 0xc7, 0x9d, 0x31, 0x55, 0xa0, 0x97, 0x56,
    0xef, 0x0b, 0xa7, 0x34, 0x08, 0xfc, 0x80, 0x93, 0xbc, 0x26, 0x8f, 0x05, 0x41, 0x36, 0x45, 0xe2,
    0x40, 0x1b, 0x0f, 0xee, 0x00, 0x6e, 0x53, 0xfb, 0x72, 0x3c, 0x8a, 0x3f, 0xce, 0xf2, 0x0c, 0x7b,
    0xc0, 0x03, 0xbc, 0x20, 0x65, 0xa6, 0x39, 0x1b, 0x8b, 0x97, 0xbd, 0x61, 0xc5, 0xf0, 0x5d, 0xa4,
    0x5f, 0x98, 0x51, 0xb8, 0xe9, 0xea, 0x6f, 0x6a, 0xb1, 0xef, 0x4e, 0xe9, 0x6f, 0xc2, 0xa1, 0xb3,
    0xb3, 0xf8, 0x37, 0xc2, 0x91, 0x80, 0xa2, 0x2f, 0xcb, 0x4b, 0xc0, 0xb2, 0x03, 0xa5, 0xaf, 0x64,
    0xdf, 0xe3, 0x3d, 0x72, 0x0d, 0x1a, 0x65, 0xaf, 0xf6, 0x1b, 0xa5, 0xdc, 0x1b, 0xdb, 0x4a, 0x79,
    0xe2, 0xe3, 0xd6, 0x22, 0x15, 0x89, 0xe8, 0xaa, 0x60, 0x07, 0x82, 0x1f, 0x7d, 0xec, 0x4a, 0x1f,
    0x88, 0x37, 0x28, 0x53, 0x29, 0xe1, 0x6d, 0xf4, 0x13, 0x9f, 0x03, 0x99, 0xe7, 0x23
};
#endif

PyTypeObject *init_QHttp2Configuration(PyObject *module)
{
    if (SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX].type != nullptr)
        return SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX].type;

    Shiboken::AutoDecRef Sbk_QHttp2Configuration_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QHttp2Configuration_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QHttp2Configuration",
        "QHttp2Configuration",
        &Sbk_QHttp2Configuration_spec,
        &Shiboken::callCppDestructor< ::QHttp2Configuration >,
        Sbk_QHttp2Configuration_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QHttp2Configuration_TypeF(); // references _Sbk_QHttp2Configuration_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QHttp2Configuration_SignatureStrings);
#else
    InitSignatureBytes(pyType, QHttp2Configuration_SignatureBytes, QHttp2Configuration_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QHttp2Configuration_PropertyStrings);
    SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QHttp2Configuration_PythonToCpp_QHttp2Configuration_PTR,
        is_QHttp2Configuration_PythonToCpp_QHttp2Configuration_PTR_Convertible,
        QHttp2Configuration_PTR_CppToPython_QHttp2Configuration,
        QHttp2Configuration_COPY_CppToPython_QHttp2Configuration);

    Shiboken::Conversions::registerConverterName(converter, "QHttp2Configuration");
    Shiboken::Conversions::registerConverterName(converter, "QHttp2Configuration*");
    Shiboken::Conversions::registerConverterName(converter, "QHttp2Configuration&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QHttp2Configuration).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QHttp2Configuration_PythonToCpp_QHttp2Configuration_COPY,
        is_QHttp2Configuration_PythonToCpp_QHttp2Configuration_COPY_Convertible);

    qRegisterMetaType< ::QHttp2Configuration >("QHttp2Configuration");

    return pyType;
}
