// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnetwork_python.h"

// main header
#include "qnetworkcachemetadata_wrapper.h"

// Argument includes
#include <QHash>
#include <QList>
#include <QtNetwork/qabstractnetworkcache.h>
#include <QtNetwork/qhttpheaders.h>
#include <QtNetwork/qnetworkrequest.h>
#include <qbytearray.h>
#include <qdatastream.h>
#include <qdatetime.h>
#include <qurl.h>
#include <qvariant.h>
#include <utility>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QNetworkCacheMetaData_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QNetworkCacheMetaData >()))
        return -1;

    ::QNetworkCacheMetaData *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QNetworkCacheMetaData", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QNetworkCacheMetaData::QNetworkCacheMetaData()
    // 1: QNetworkCacheMetaData::QNetworkCacheMetaData(QNetworkCacheMetaData)
    if (numArgs == 0) {
        overloadId = 0; // QNetworkCacheMetaData()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCacheMetaData_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QNetworkCacheMetaData(QNetworkCacheMetaData)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCacheMetaData_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCacheMetaData_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QNetworkCacheMetaData()
        {

            // QNetworkCacheMetaData()
            cptr = new ::QNetworkCacheMetaData();
            break;
        }
        case 1: // QNetworkCacheMetaData(const QNetworkCacheMetaData &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QNetworkCacheMetaData cppArg0_local;
            ::QNetworkCacheMetaData *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QNetworkCacheMetaData(QNetworkCacheMetaData)
                cptr = new ::QNetworkCacheMetaData(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QNetworkCacheMetaData >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCacheMetaData_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QNetworkCacheMetaDataFunc_attributes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkCacheMetaData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCacheMetaData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // attributes()const
        QHash<QNetworkRequest::Attribute,QVariant> cppResult = const_cast<const ::QNetworkCacheMetaData *>(cppSelf)->attributes();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QHash_QNetworkRequest_Attribute_QVariant_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkCacheMetaDataFunc_expirationDate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkCacheMetaData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCacheMetaData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // expirationDate()const
        QDateTime cppResult = const_cast<const ::QNetworkCacheMetaData *>(cppSelf)->expirationDate();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkCacheMetaDataFunc_headers(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkCacheMetaData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCacheMetaData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // headers()const
        QHttpHeaders cppResult = const_cast<const ::QNetworkCacheMetaData *>(cppSelf)->headers();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkCacheMetaDataFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkCacheMetaData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCacheMetaData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QNetworkCacheMetaData *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkCacheMetaDataFunc_lastModified(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkCacheMetaData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCacheMetaData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lastModified()const
        QDateTime cppResult = const_cast<const ::QNetworkCacheMetaData *>(cppSelf)->lastModified();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkCacheMetaDataFunc_rawHeaders(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkCacheMetaData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCacheMetaData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rawHeaders()const
        QList<std::pair<QByteArray,QByteArray>> cppResult = const_cast<const ::QNetworkCacheMetaData *>(cppSelf)->rawHeaders();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_std_pair_QByteArray_QByteArray_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkCacheMetaDataFunc_saveToDisk(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkCacheMetaData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCacheMetaData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // saveToDisk()const
        bool cppResult = const_cast<const ::QNetworkCacheMetaData *>(cppSelf)->saveToDisk();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkCacheMetaDataFunc_setAttributes(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkCacheMetaData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCacheMetaData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkCacheMetaData::setAttributes(QHash<QNetworkRequest::Attribute,QVariant>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QHash_QNetworkRequest_Attribute_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // setAttributes(QHash<QNetworkRequest::Attribute,QVariant>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAttributes", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCacheMetaData_IDX]);

    // Call function/method
    {
        ::QHash<QNetworkRequest::Attribute,QVariant> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAttributes(QHash<QNetworkRequest::Attribute,QVariant>)
            cppSelf->setAttributes(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkCacheMetaDataFunc_setExpirationDate(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkCacheMetaData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCacheMetaData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkCacheMetaData::setExpirationDate(QDateTime)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // setExpirationDate(QDateTime)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setExpirationDate", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCacheMetaData_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setExpirationDate(QDateTime)
            cppSelf->setExpirationDate(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkCacheMetaDataFunc_setHeaders(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkCacheMetaData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCacheMetaData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkCacheMetaData::setHeaders(QHttpHeaders)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_IDX]), (pyArg)))) {
        overloadId = 0; // setHeaders(QHttpHeaders)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHeaders", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCacheMetaData_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QHttpHeaders cppArg0_local;
        ::QHttpHeaders *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setHeaders(QHttpHeaders)
            cppSelf->setHeaders(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkCacheMetaDataFunc_setLastModified(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkCacheMetaData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCacheMetaData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkCacheMetaData::setLastModified(QDateTime)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // setLastModified(QDateTime)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLastModified", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCacheMetaData_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setLastModified(QDateTime)
            cppSelf->setLastModified(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkCacheMetaDataFunc_setRawHeaders(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkCacheMetaData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCacheMetaData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkCacheMetaData::setRawHeaders(QList<std::pair<QByteArray,QByteArray>>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_std_pair_QByteArray_QByteArray_IDX], (pyArg)))) {
        overloadId = 0; // setRawHeaders(QList<std::pair<QByteArray,QByteArray>>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRawHeaders", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCacheMetaData_IDX]);

    // Call function/method
    {
        ::QList<std::pair<QByteArray,QByteArray>> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRawHeaders(QList<std::pair<QByteArray,QByteArray>>)
            cppSelf->setRawHeaders(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkCacheMetaDataFunc_setSaveToDisk(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkCacheMetaData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCacheMetaData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkCacheMetaData::setSaveToDisk(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setSaveToDisk(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSaveToDisk", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCacheMetaData_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSaveToDisk(bool)
            cppSelf->setSaveToDisk(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkCacheMetaDataFunc_setUrl(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkCacheMetaData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCacheMetaData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkCacheMetaData::setUrl(QUrl)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // setUrl(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUrl", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCacheMetaData_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setUrl(QUrl)
            cppSelf->setUrl(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkCacheMetaDataFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkCacheMetaData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCacheMetaData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkCacheMetaData::swap(QNetworkCacheMetaData&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCacheMetaData_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QNetworkCacheMetaData&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCacheMetaData_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QNetworkCacheMetaData cppArg0_local;
        ::QNetworkCacheMetaData *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QNetworkCacheMetaData&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkCacheMetaDataFunc_url(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkCacheMetaData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCacheMetaData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // url()const
        QUrl cppResult = const_cast<const ::QNetworkCacheMetaData *>(cppSelf)->url();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkCacheMetaData__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QNetworkCacheMetaData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCacheMetaData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCacheMetaData_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QNetworkCacheMetaData_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QNetworkCacheMetaData_methods[] = {
    {"attributes", reinterpret_cast<PyCFunction>(Sbk_QNetworkCacheMetaDataFunc_attributes), METH_NOARGS, nullptr},
    {"expirationDate", reinterpret_cast<PyCFunction>(Sbk_QNetworkCacheMetaDataFunc_expirationDate), METH_NOARGS, nullptr},
    {"headers", reinterpret_cast<PyCFunction>(Sbk_QNetworkCacheMetaDataFunc_headers), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QNetworkCacheMetaDataFunc_isValid), METH_NOARGS, nullptr},
    {"lastModified", reinterpret_cast<PyCFunction>(Sbk_QNetworkCacheMetaDataFunc_lastModified), METH_NOARGS, nullptr},
    {"rawHeaders", reinterpret_cast<PyCFunction>(Sbk_QNetworkCacheMetaDataFunc_rawHeaders), METH_NOARGS, nullptr},
    {"saveToDisk", reinterpret_cast<PyCFunction>(Sbk_QNetworkCacheMetaDataFunc_saveToDisk), METH_NOARGS, nullptr},
    {"setAttributes", reinterpret_cast<PyCFunction>(Sbk_QNetworkCacheMetaDataFunc_setAttributes), METH_O, nullptr},
    {"setExpirationDate", reinterpret_cast<PyCFunction>(Sbk_QNetworkCacheMetaDataFunc_setExpirationDate), METH_O, nullptr},
    {"setHeaders", reinterpret_cast<PyCFunction>(Sbk_QNetworkCacheMetaDataFunc_setHeaders), METH_O, nullptr},
    {"setLastModified", reinterpret_cast<PyCFunction>(Sbk_QNetworkCacheMetaDataFunc_setLastModified), METH_O, nullptr},
    {"setRawHeaders", reinterpret_cast<PyCFunction>(Sbk_QNetworkCacheMetaDataFunc_setRawHeaders), METH_O, nullptr},
    {"setSaveToDisk", reinterpret_cast<PyCFunction>(Sbk_QNetworkCacheMetaDataFunc_setSaveToDisk), METH_O, nullptr},
    {"setUrl", reinterpret_cast<PyCFunction>(Sbk_QNetworkCacheMetaDataFunc_setUrl), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QNetworkCacheMetaDataFunc_swap), METH_O, nullptr},
    {"url", reinterpret_cast<PyCFunction>(Sbk_QNetworkCacheMetaDataFunc_url), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QNetworkCacheMetaData__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QNetworkCacheMetaDataFunc___lshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCacheMetaData_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCacheMetaData_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkCacheMetaData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCacheMetaData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rlshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QNetworkCacheMetaData::operator<<(QDataStream&)->QDataStream&
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // operator<<(QDataStream&,QNetworkCacheMetaData)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator<<", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCacheMetaData_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator<<(QDataStream&,QNetworkCacheMetaData) [reverse operator]
                QDataStream & cppResult = (*cppArg0) << (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkCacheMetaDataFunc___rshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCacheMetaData_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCacheMetaData_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkCacheMetaData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCacheMetaData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rrshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QNetworkCacheMetaData::operator>>(QDataStream&)->QDataStream&
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // operator>>(QDataStream&,QNetworkCacheMetaData&)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator>>", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCacheMetaData_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator>>(QDataStream&,QNetworkCacheMetaData&) [reverse operator]
                QDataStream & cppResult = (*cppArg0) >> (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

// Rich comparison
static PyObject * Sbk_QNetworkCacheMetaData_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QNetworkCacheMetaData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCacheMetaData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCacheMetaData_IDX]), (pyArg)))) {
                // operator!=(const QNetworkCacheMetaData &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QNetworkCacheMetaData cppArg0_local;
                ::QNetworkCacheMetaData *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCacheMetaData_IDX]), (pyArg)))) {
                // operator==(const QNetworkCacheMetaData &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QNetworkCacheMetaData cppArg0_local;
                ::QNetworkCacheMetaData *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QNetworkCacheMetaData_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QNetworkCacheMetaData_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QNetworkCacheMetaData_Type = nullptr;
static PyTypeObject *Sbk_QNetworkCacheMetaData_TypeF(void)
{
    return _Sbk_QNetworkCacheMetaData_Type;
}

static PyType_Slot Sbk_QNetworkCacheMetaData_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QNetworkCacheMetaData_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QNetworkCacheMetaData_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QNetworkCacheMetaData_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QNetworkCacheMetaData_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QNetworkCacheMetaData_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_lshift,      reinterpret_cast<void *>(Sbk_QNetworkCacheMetaDataFunc___lshift__)},
    {Py_nb_rshift,      reinterpret_cast<void *>(Sbk_QNetworkCacheMetaDataFunc___rshift__)},
    {0, nullptr}
};
static PyType_Spec Sbk_QNetworkCacheMetaData_spec = {
    "2:PySide6.QtNetwork.QNetworkCacheMetaData",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QNetworkCacheMetaData_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QNetworkCacheMetaData_PythonToCpp_QNetworkCacheMetaData_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QNetworkCacheMetaData_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QNetworkCacheMetaData_PythonToCpp_QNetworkCacheMetaData_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QNetworkCacheMetaData_TypeF()))
        return QNetworkCacheMetaData_PythonToCpp_QNetworkCacheMetaData_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QNetworkCacheMetaData_PTR_CppToPython_QNetworkCacheMetaData(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QNetworkCacheMetaData_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QNetworkCacheMetaData_COPY_CppToPython_QNetworkCacheMetaData(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QNetworkCacheMetaData *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QNetworkCacheMetaData_TypeF(), new ::QNetworkCacheMetaData(*source), true, true);
}

// Python to C++ copy conversion.
static void QNetworkCacheMetaData_PythonToCpp_QNetworkCacheMetaData_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QNetworkCacheMetaData *>(cppOut) = *reinterpret_cast< ::QNetworkCacheMetaData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCacheMetaData_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QNetworkCacheMetaData_PythonToCpp_QNetworkCacheMetaData_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QNetworkCacheMetaData_TypeF()))
        return QNetworkCacheMetaData_PythonToCpp_QNetworkCacheMetaData_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QNetworkCacheMetaData_SignatureStrings[] = {
    "1:PySide6.QtNetwork.QNetworkCacheMetaData(self)",
    "0:PySide6.QtNetwork.QNetworkCacheMetaData(self,other:PySide6.QtNetwork.QNetworkCacheMetaData)",
    "PySide6.QtNetwork.QNetworkCacheMetaData.attributes(self)->QHash[PySide6.QtNetwork.QNetworkRequest.Attribute, QVariant]",
    "PySide6.QtNetwork.QNetworkCacheMetaData.expirationDate(self)->PySide6.QtCore.QDateTime",
    "PySide6.QtNetwork.QNetworkCacheMetaData.headers(self)->PySide6.QtNetwork.QHttpHeaders",
    "PySide6.QtNetwork.QNetworkCacheMetaData.isValid(self)->bool",
    "PySide6.QtNetwork.QNetworkCacheMetaData.lastModified(self)->PySide6.QtCore.QDateTime",
    "PySide6.QtNetwork.QNetworkCacheMetaData.rawHeaders(self)->QList[std.pair[PySide6.QtCore.QByteArray, PySide6.QtCore.QByteArray]]",
    "PySide6.QtNetwork.QNetworkCacheMetaData.saveToDisk(self)->bool",
    "PySide6.QtNetwork.QNetworkCacheMetaData.setAttributes(self,attributes:QHash[PySide6.QtNetwork.QNetworkRequest.Attribute, QVariant])",
    "PySide6.QtNetwork.QNetworkCacheMetaData.setExpirationDate(self,dateTime:PySide6.QtCore.QDateTime)",
    "PySide6.QtNetwork.QNetworkCacheMetaData.setHeaders(self,headers:PySide6.QtNetwork.QHttpHeaders)",
    "PySide6.QtNetwork.QNetworkCacheMetaData.setLastModified(self,dateTime:PySide6.QtCore.QDateTime)",
    "PySide6.QtNetwork.QNetworkCacheMetaData.setRawHeaders(self,headers:QList[std.pair[PySide6.QtCore.QByteArray, PySide6.QtCore.QByteArray]])",
    "PySide6.QtNetwork.QNetworkCacheMetaData.setSaveToDisk(self,allow:bool)",
    "PySide6.QtNetwork.QNetworkCacheMetaData.setUrl(self,url:typing.Union[PySide6.QtCore.QUrl, QString])",
    "PySide6.QtNetwork.QNetworkCacheMetaData.swap(self,other:PySide6.QtNetwork.QNetworkCacheMetaData)",
    "PySide6.QtNetwork.QNetworkCacheMetaData.url(self)->PySide6.QtCore.QUrl",
    "PySide6.QtNetwork.QNetworkCacheMetaData.__copy__(self)->typing.Self",
    "PySide6.QtNetwork.QNetworkCacheMetaData.__lshift__(self,arg__1:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "PySide6.QtNetwork.QNetworkCacheMetaData.__rshift__(self,arg__1:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "PySide6.QtNetwork.QNetworkCacheMetaData.__ne__(self,other:PySide6.QtNetwork.QNetworkCacheMetaData)->bool",
    "PySide6.QtNetwork.QNetworkCacheMetaData.__eq__(self,other:PySide6.QtNetwork.QNetworkCacheMetaData)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QNetworkCacheMetaData_SignatureByteSize = 403;
static constexpr uint8_t QNetworkCacheMetaData_SignatureBytes[403] = {
    0x78, 0xda, 0xc5, 0x94, 0x4d, 0x6f, 0xc2, 0x30, 0x0c, 0x86, 0xef, 0xfc, 0x0a, 0x8e, 0x43, 0xea,
    0xaa, 0x71, 0xd9, 0xa1, 0x87, 0x49, 0x6c, 0x4c, 0xea, 0x01, 0xa6, 0x95, 0x02, 0x17, 0x84, 0x22,
    0x43, 0x0d, 0x8d, 0x08, 0x4d, 0x49, 0xdc, 0x75, 0xfd, 0xf7, 0x2b, 0xa2, 0x85, 0x95, 0x8f, 0xa9,
    0x19, 0x4c, 0xbb, 0x25, 0x8a, 0xfd, 0xbe, 0x76, 0xfc, 0xc8, 0x6d, 0xe7, 0x3d, 0xf3, 0x79, 0x80,
    0x8f, 0xb6, 0x47, 0x6f, 0x48, 0xa9, 0x54, 0x2b, 0xdb, 0x2b, 0x0e, 0x2f, 0x30, 0x0f, 0xb1, 0x8f,
    0x04, 0x5d, 0x20, 0xb8, 0xd3, 0x28, 0x16, 0xad, 0xc6, 0x83, 0x51, 0xbc, 0x25, 0x29, 0x44, 0x55,
    0x37, 0xa5, 0xd5, 0xa8, 0x19, 0x68, 0x03, 0x91, 0xe2, 0xb3, 0x84, 0x50, 0xef, 0xca, 0xba, 0x7f,
    0xf2, 0x5c, 0xd0, 0xe1, 0xe4, 0x72, 0xfe, 0x00, 0x37, 0x09, 0x6a, 0xb2, 0x3b, 0x65, 0xa6, 0xd5,
    0xf4, 0xc6, 0xa0, 0x38, 0x44, 0x34, 0xad, 0x6d, 0x8b, 0x9f, 0x31, 0x57, 0x40, 0x5c, 0x46, 0xf9,
    0x15, 0x4b, 0xeb, 0x43, 0xf6, 0x8b, 0x54, 0x68, 0x7b, 0xdb, 0xb7, 0x21, 0x5f, 0x63, 0x6d, 0xd9,
    0x10, 0x21, 0x40, 0xa5, 0x4f, 0xf5, 0xf6, 0x69, 0x2e, 0x51, 0xec, 0xee, 0xa2, 0x6a, 0xab, 0x72,
    0x3d, 0x06, 0xc1, 0x83, 0x52, 0x75, 0x26, 0xa5, 0xa8, 0x9d, 0x2b, 0x40, 0x53, 0x5f, 0x06, 0x7c,
    0xc1, 0x31, 0xb8, 0x59, 0x9b, 0x0a, 0x52, 0xb7, 0xda, 0xa9, 0xd7, 0xe3, 0x9a, 0x26, 0x9a, 0x02,
    0x3b, 0x06, 0xae, 0x26, 0xc7, 0x0e, 0xcf, 0x19, 0x61, 0x47, 0x29, 0xc8, 0xac, 0xe6, 0xc5, 0xa7,
    0x69, 0xfd, 0xe9, 0x69, 0xf8, 0xc0, 0xa1, 0xec, 0x72, 0xbd, 0xfa, 0xd5, 0x9f, 0x68, 0xa4, 0x4e,
    0x15, 0x3b, 0xeb, 0x80, 0xa1, 0x73, 0x0d, 0x7f, 0x2d, 0x93, 0x1a, 0x5e, 0x4f, 0x19, 0xb4, 0x82,
    0x62, 0x14, 0xce, 0xa5, 0x19, 0x19, 0x39, 0x7c, 0x1f, 0x92, 0x55, 0xb0, 0xe9, 0xfc, 0x0c, 0xa5,
    0x91, 0x7e, 0xef, 0x18, 0xae, 0x1b, 0xd7, 0x3f, 0xa8, 0x72, 0xb6, 0x6f, 0xe1, 0x26, 0xb4, 0x19,
    0x55, 0xe2, 0x57, 0x89, 0xb3, 0x40, 0x08, 0x99, 0x3a, 0x5b, 0xea, 0x8c, 0x64, 0x46, 0x4a, 0xec,
    0xf2, 0x13, 0x25, 0x1c, 0xca, 0x62, 0x1e, 0x2d, 0xed, 0x51, 0x94, 0x13, 0x70, 0xd2, 0x43, 0x1e,
    0x99, 0x73, 0xe5, 0xe7, 0x88, 0x45, 0x4b, 0x93, 0x52, 0x53, 0x88, 0xff, 0x74, 0x5f, 0x27, 0x45,
    0x07, 0x67, 0xd6, 0x48, 0x5e, 0x72, 0x6d, 0x19, 0xc6, 0xe6, 0x32, 0xce, 0x18, 0x2b, 0xb5, 0x8a,
    0xbf, 0xf0, 0xf3, 0x9b, 0x81, 0x86, 0xd0, 0x21, 0x5f, 0x50, 0xa1, 0x62, 0x81, 0x5a, 0x32, 0xd6,
    0x3e, 0x47, 0x1e, 0xe4, 0xff, 0x88, 0xb0, 0x3e, 0xbf, 0xfa, 0x8a, 0x47, 0x03, 0x5b, 0xf5, 0x3f,
    0xb6, 0x11, 0x96, 0x96, 0x66, 0xb3, 0x35, 0xdc, 0x8e, 0x8c, 0xe1, 0xe6, 0x2a, 0xa3, 0x2f, 0x86,
    0x3b, 0x1b, 0xff
};
#endif

PyTypeObject *init_QNetworkCacheMetaData(PyObject *module)
{
    if (SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCacheMetaData_IDX].type != nullptr)
        return SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCacheMetaData_IDX].type;

    Shiboken::AutoDecRef Sbk_QNetworkCacheMetaData_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QNetworkCacheMetaData_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QNetworkCacheMetaData",
        "QNetworkCacheMetaData",
        &Sbk_QNetworkCacheMetaData_spec,
        &Shiboken::callCppDestructor< ::QNetworkCacheMetaData >,
        Sbk_QNetworkCacheMetaData_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QNetworkCacheMetaData_TypeF(); // references _Sbk_QNetworkCacheMetaData_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QNetworkCacheMetaData_SignatureStrings);
#else
    InitSignatureBytes(pyType, QNetworkCacheMetaData_SignatureBytes, QNetworkCacheMetaData_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QNetworkCacheMetaData_PropertyStrings);
    SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCacheMetaData_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QNetworkCacheMetaData_PythonToCpp_QNetworkCacheMetaData_PTR,
        is_QNetworkCacheMetaData_PythonToCpp_QNetworkCacheMetaData_PTR_Convertible,
        QNetworkCacheMetaData_PTR_CppToPython_QNetworkCacheMetaData,
        QNetworkCacheMetaData_COPY_CppToPython_QNetworkCacheMetaData);

    Shiboken::Conversions::registerConverterName(converter, "QNetworkCacheMetaData");
    Shiboken::Conversions::registerConverterName(converter, "QNetworkCacheMetaData*");
    Shiboken::Conversions::registerConverterName(converter, "QNetworkCacheMetaData&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QNetworkCacheMetaData).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QNetworkCacheMetaData_PythonToCpp_QNetworkCacheMetaData_COPY,
        is_QNetworkCacheMetaData_PythonToCpp_QNetworkCacheMetaData_COPY_Convertible);

    qRegisterMetaType< ::QNetworkCacheMetaData >("QNetworkCacheMetaData");

    return pyType;
}
