// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnetwork_python.h"

// main header
#include "qnetworkdatagram_wrapper.h"

// Argument includes
#include <QtNetwork/qhostaddress.h>
#include <QtNetwork/qnetworkdatagram.h>
#include <qbytearray.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QNetworkDatagram_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QNetworkDatagram >()))
        return -1;

    ::QNetworkDatagram *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:QNetworkDatagram", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QNetworkDatagram::QNetworkDatagram()
    // 1: QNetworkDatagram::QNetworkDatagram(QByteArray,const QHostAddress&=,quint16=)
    // 2: QNetworkDatagram::QNetworkDatagram(QNetworkDatagram)
    if (numArgs == 0) {
        overloadId = 0; // QNetworkDatagram()
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QNetworkDatagram(QByteArray,QHostAddress,quint16)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 1; // QNetworkDatagram(QByteArray,QHostAddress,quint16)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArgs[2])))) {
                overloadId = 1; // QNetworkDatagram(QByteArray,QHostAddress,quint16)
            }
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QNetworkDatagram(QNetworkDatagram)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QNetworkDatagram()
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX]);
            }

            // QNetworkDatagram()
            cptr = new ::QNetworkDatagram();
            break;
        }
        case 1: // QNetworkDatagram(const QByteArray &data, const QHostAddress &destinationAddress, quint16 port)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_destinationAddress = Shiboken::String::createStaticString("destinationAddress");
                if (PyDict_Contains(kwds, key_destinationAddress) != 0) {
                    value = PyDict_GetItem(kwds, key_destinationAddress);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_destinationAddress);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_destinationAddress);
                }
                static PyObject *const key_port = Shiboken::String::createStaticString("port");
                if (PyDict_Contains(kwds, key_port) != 0) {
                    value = PyDict_GetItem(kwds, key_port);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_port);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_port);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QHostAddress cppArg1_local = QHostAddress();
            ::QHostAddress *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1]) {
                if (pythonToCpp[1].isValue())
                    pythonToCpp[1](pyArgs[1], &cppArg1_local);
                else
                    pythonToCpp[1](pyArgs[1], &cppArg1);
                }
            quint16 cppArg2 = 0;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QNetworkDatagram(QByteArray,QHostAddress,quint16)
                cptr = new ::QNetworkDatagram(*cppArg0, *cppArg1, cppArg2);
            }
            break;
        }
        case 2: // QNetworkDatagram(const QNetworkDatagram &other)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QNetworkDatagram cppArg0_local;
            ::QNetworkDatagram *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QNetworkDatagram(QNetworkDatagram)
                cptr = new ::QNetworkDatagram(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QNetworkDatagram >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QNetworkDatagramFunc_clear(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkDatagram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clear()
        cppSelf->clear();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkDatagramFunc_data(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkDatagram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // data()const
        QByteArray cppResult = const_cast<const ::QNetworkDatagram *>(cppSelf)->data();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkDatagramFunc_destinationAddress(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkDatagram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // destinationAddress()const
        QHostAddress cppResult = const_cast<const ::QNetworkDatagram *>(cppSelf)->destinationAddress();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkDatagramFunc_destinationPort(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkDatagram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // destinationPort()const
        int cppResult = const_cast<const ::QNetworkDatagram *>(cppSelf)->destinationPort();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkDatagramFunc_hopLimit(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkDatagram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hopLimit()const
        int cppResult = const_cast<const ::QNetworkDatagram *>(cppSelf)->hopLimit();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkDatagramFunc_interfaceIndex(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkDatagram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // interfaceIndex()const
        uint cppResult = const_cast<const ::QNetworkDatagram *>(cppSelf)->interfaceIndex();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkDatagramFunc_isNull(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkDatagram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isNull()const
        bool cppResult = const_cast<const ::QNetworkDatagram *>(cppSelf)->isNull();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkDatagramFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkDatagram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QNetworkDatagram *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkDatagramFunc_makeReply(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkDatagram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkDatagram::makeReply(QByteArray)->QNetworkDatagram
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // makeReply(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "makeReply", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // makeReply(QByteArray)
            QNetworkDatagram cppResult = cppSelf->makeReply(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkDatagramFunc_senderAddress(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkDatagram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // senderAddress()const
        QHostAddress cppResult = const_cast<const ::QNetworkDatagram *>(cppSelf)->senderAddress();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkDatagramFunc_senderPort(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkDatagram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // senderPort()const
        int cppResult = const_cast<const ::QNetworkDatagram *>(cppSelf)->senderPort();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkDatagramFunc_setData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkDatagram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkDatagram::setData(QByteArray)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // setData(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setData", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setData(QByteArray)
            cppSelf->setData(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkDatagramFunc_setDestination(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkDatagram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setDestination", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QNetworkDatagram::setDestination(QHostAddress,quint16)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArgs[1])))) {
        overloadId = 0; // setDestination(QHostAddress,quint16)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setDestination", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QHostAddress cppArg0_local;
        ::QHostAddress *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        quint16 cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDestination(QHostAddress,quint16)
            cppSelf->setDestination(*cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkDatagramFunc_setHopLimit(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkDatagram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkDatagram::setHopLimit(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setHopLimit(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHopLimit", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHopLimit(int)
            cppSelf->setHopLimit(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkDatagramFunc_setInterfaceIndex(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkDatagram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkDatagram::setInterfaceIndex(uint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArg)))) {
        overloadId = 0; // setInterfaceIndex(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setInterfaceIndex", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX]);

    // Call function/method
    {
        uint cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setInterfaceIndex(uint)
            cppSelf->setInterfaceIndex(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkDatagramFunc_setSender(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkDatagram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setSender", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setSender", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QNetworkDatagram::setSender(QHostAddress,quint16=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setSender(QHostAddress,quint16)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArgs[1])))) {
            overloadId = 0; // setSender(QHostAddress,quint16)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setSender", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_port = Shiboken::String::createStaticString("port");
            if (PyDict_Contains(kwds, key_port) != 0) {
                value = PyDict_GetItem(kwds, key_port);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_port);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setSender", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "setSender", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_port);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setSender", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QHostAddress cppArg0_local;
        ::QHostAddress *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        quint16 cppArg1 = 0;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSender(QHostAddress,quint16)
            cppSelf->setSender(*cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkDatagramFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkDatagram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkDatagram::swap(QNetworkDatagram&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QNetworkDatagram&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QNetworkDatagram cppArg0_local;
        ::QNetworkDatagram *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QNetworkDatagram&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkDatagram__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QNetworkDatagram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QNetworkDatagram_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QNetworkDatagram_methods[] = {
    {"clear", reinterpret_cast<PyCFunction>(Sbk_QNetworkDatagramFunc_clear), METH_NOARGS, nullptr},
    {"data", reinterpret_cast<PyCFunction>(Sbk_QNetworkDatagramFunc_data), METH_NOARGS, nullptr},
    {"destinationAddress", reinterpret_cast<PyCFunction>(Sbk_QNetworkDatagramFunc_destinationAddress), METH_NOARGS, nullptr},
    {"destinationPort", reinterpret_cast<PyCFunction>(Sbk_QNetworkDatagramFunc_destinationPort), METH_NOARGS, nullptr},
    {"hopLimit", reinterpret_cast<PyCFunction>(Sbk_QNetworkDatagramFunc_hopLimit), METH_NOARGS, nullptr},
    {"interfaceIndex", reinterpret_cast<PyCFunction>(Sbk_QNetworkDatagramFunc_interfaceIndex), METH_NOARGS, nullptr},
    {"isNull", reinterpret_cast<PyCFunction>(Sbk_QNetworkDatagramFunc_isNull), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QNetworkDatagramFunc_isValid), METH_NOARGS, nullptr},
    {"makeReply", reinterpret_cast<PyCFunction>(Sbk_QNetworkDatagramFunc_makeReply), METH_O, nullptr},
    {"senderAddress", reinterpret_cast<PyCFunction>(Sbk_QNetworkDatagramFunc_senderAddress), METH_NOARGS, nullptr},
    {"senderPort", reinterpret_cast<PyCFunction>(Sbk_QNetworkDatagramFunc_senderPort), METH_NOARGS, nullptr},
    {"setData", reinterpret_cast<PyCFunction>(Sbk_QNetworkDatagramFunc_setData), METH_O, nullptr},
    {"setDestination", reinterpret_cast<PyCFunction>(Sbk_QNetworkDatagramFunc_setDestination), METH_VARARGS, nullptr},
    {"setHopLimit", reinterpret_cast<PyCFunction>(Sbk_QNetworkDatagramFunc_setHopLimit), METH_O, nullptr},
    {"setInterfaceIndex", reinterpret_cast<PyCFunction>(Sbk_QNetworkDatagramFunc_setInterfaceIndex), METH_O, nullptr},
    {"setSender", reinterpret_cast<PyCFunction>(Sbk_QNetworkDatagramFunc_setSender), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QNetworkDatagramFunc_swap), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QNetworkDatagram__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QNetworkDatagram___nb_bool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QNetworkDatagram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return !cppSelf->isNull() ? 1 : 0;
}

} // extern "C"

static int Sbk_QNetworkDatagram_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QNetworkDatagram_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QNetworkDatagram_Type = nullptr;
static PyTypeObject *Sbk_QNetworkDatagram_TypeF(void)
{
    return _Sbk_QNetworkDatagram_Type;
}

static PyType_Slot Sbk_QNetworkDatagram_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QNetworkDatagram_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QNetworkDatagram_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QNetworkDatagram_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QNetworkDatagram_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_bool,        reinterpret_cast<void *>(Sbk_QNetworkDatagram___nb_bool)},
    {0, nullptr}
};
static PyType_Spec Sbk_QNetworkDatagram_spec = {
    "2:PySide6.QtNetwork.QNetworkDatagram",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QNetworkDatagram_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QNetworkDatagram_PythonToCpp_QNetworkDatagram_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QNetworkDatagram_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QNetworkDatagram_PythonToCpp_QNetworkDatagram_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QNetworkDatagram_TypeF()))
        return QNetworkDatagram_PythonToCpp_QNetworkDatagram_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QNetworkDatagram_PTR_CppToPython_QNetworkDatagram(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QNetworkDatagram_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QNetworkDatagram_COPY_CppToPython_QNetworkDatagram(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QNetworkDatagram *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QNetworkDatagram_TypeF(), new ::QNetworkDatagram(*source), true, true);
}

// Python to C++ copy conversion.
static void QNetworkDatagram_PythonToCpp_QNetworkDatagram_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QNetworkDatagram *>(cppOut) = *reinterpret_cast< ::QNetworkDatagram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QNetworkDatagram_PythonToCpp_QNetworkDatagram_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QNetworkDatagram_TypeF()))
        return QNetworkDatagram_PythonToCpp_QNetworkDatagram_COPY;
    return {};
}

// Implicit conversions.
static void PySide6_QtCore_constQByteArrayREF_PythonToCpp_QNetworkDatagram(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QNetworkDatagram *>(cppOut) = ::QNetworkDatagram( *reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(pyIn))));
}
static PythonToCppFunc is_PySide6_QtCore_constQByteArrayREF_PythonToCpp_QNetworkDatagram_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), pyIn))
        return PySide6_QtCore_constQByteArrayREF_PythonToCpp_QNetworkDatagram;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QNetworkDatagram_SignatureStrings[] = {
    "2:PySide6.QtNetwork.QNetworkDatagram(self)",
    "1:PySide6.QtNetwork.QNetworkDatagram(self,data:typing.Union[PySide6.QtCore.QByteArray, char*],destinationAddress:typing.Union[PySide6.QtNetwork.QHostAddress, PySide6.QtNetwork.QHostAddress.SpecialAddress]=QHostAddress(),port:quint16=0)",
    "0:PySide6.QtNetwork.QNetworkDatagram(self,other:PySide6.QtNetwork.QNetworkDatagram)",
    "PySide6.QtNetwork.QNetworkDatagram.clear(self)",
    "PySide6.QtNetwork.QNetworkDatagram.data(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtNetwork.QNetworkDatagram.destinationAddress(self)->PySide6.QtNetwork.QHostAddress",
    "PySide6.QtNetwork.QNetworkDatagram.destinationPort(self)->int",
    "PySide6.QtNetwork.QNetworkDatagram.hopLimit(self)->int",
    "PySide6.QtNetwork.QNetworkDatagram.interfaceIndex(self)->uint",
    "PySide6.QtNetwork.QNetworkDatagram.isNull(self)->bool",
    "PySide6.QtNetwork.QNetworkDatagram.isValid(self)->bool",
    "PySide6.QtNetwork.QNetworkDatagram.makeReply(self,payload:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtNetwork.QNetworkDatagram",
    "PySide6.QtNetwork.QNetworkDatagram.senderAddress(self)->PySide6.QtNetwork.QHostAddress",
    "PySide6.QtNetwork.QNetworkDatagram.senderPort(self)->int",
    "PySide6.QtNetwork.QNetworkDatagram.setData(self,data:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "PySide6.QtNetwork.QNetworkDatagram.setDestination(self,address:typing.Union[PySide6.QtNetwork.QHostAddress, PySide6.QtNetwork.QHostAddress.SpecialAddress],port:quint16)",
    "PySide6.QtNetwork.QNetworkDatagram.setHopLimit(self,count:int)",
    "PySide6.QtNetwork.QNetworkDatagram.setInterfaceIndex(self,index:uint)",
    "PySide6.QtNetwork.QNetworkDatagram.setSender(self,address:typing.Union[PySide6.QtNetwork.QHostAddress, PySide6.QtNetwork.QHostAddress.SpecialAddress],port:quint16=0)",
    "PySide6.QtNetwork.QNetworkDatagram.swap(self,other:typing.Union[PySide6.QtNetwork.QNetworkDatagram, PySide6.QtCore.QByteArray])",
    "PySide6.QtNetwork.QNetworkDatagram.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QNetworkDatagram_SignatureByteSize = 374;
static constexpr uint8_t QNetworkDatagram_SignatureBytes[374] = {
    0x78, 0xda, 0xc5, 0x54, 0x5d, 0x4f, 0xc2, 0x30, 0x14, 0x7d, 0xdf, 0xaf, 0xe0, 0x91, 0x99, 0xb9,
    0x80, 0x0f, 0x3c, 0x2c, 0xc1, 0x04, 0xe5, 0x01, 0x12, 0x43, 0xc0, 0x45, 0x5f, 0x0c, 0x59, 0xae,
    0xeb, 0x05, 0x1a, 0xca, 0x5a, 0xdb, 0x2e, 0xb8, 0x7f, 0x6f, 0xe7, 0x36, 0x99, 0x7c, 0x48, 0x47,
    0x34, 0xbe, 0xb5, 0xe9, 0x39, 0xe7, 0xde, 0x9e, 0x9e, 0xde, 0x9b, 0x60, 0x9a, 0x85, 0x94, 0x60,
    0xcf, 0x9f, 0xe9, 0x09, 0xea, 0x2d, 0x97, 0x6b, 0x7f, 0x56, 0x2e, 0x86, 0xa0, 0x61, 0x29, 0x61,
    0xd3, 0x56, 0xc8, 0x16, 0xae, 0xd3, 0xb5, 0x85, 0x7a, 0xc4, 0xec, 0x02, 0x9d, 0x09, 0x9a, 0x2c,
    0xfd, 0xa7, 0x84, 0xf2, 0xe4, 0x65, 0xc7, 0xbc, 0xe7, 0x12, 0xfd, 0xd9, 0x5d, 0xa6, 0x71, 0x20,
    0x25, 0x64, 0x5e, 0x2b, 0x5e, 0x81, 0xbc, 0x9a, 0x7b, 0x04, 0x95, 0xa6, 0x09, 0x68, 0x83, 0x1e,
    0x10, 0x22, 0x51, 0xa9, 0x53, 0x0a, 0x5f, 0xb5, 0x47, 0x5c, 0xe9, 0x12, 0xeb, 0xb5, 0x7e, 0x3e,
    0xf7, 0x43, 0x81, 0x31, 0x05, 0x56, 0x6e, 0xe7, 0xfd, 0xfa, 0x61, 0xdb, 0xf5, 0x04, 0x97, 0x3a,
    0x78, 0x4b, 0x69, 0xa2, 0xbb, 0xbd, 0x7e, 0xc7, 0x75, 0x3a, 0xd6, 0x77, 0xe5, 0x7a, 0x85, 0xd2,
    0x02, 0xed, 0x3a, 0xe7, 0x31, 0x7e, 0xcc, 0x10, 0x64, 0x69, 0xb7, 0x05, 0x3c, 0xf7, 0xb9, 0x40,
    0x5f, 0xdf, 0x9e, 0x74, 0xd8, 0x4a, 0xe8, 0xc0, 0xfc, 0x43, 0xd9, 0x63, 0xb6, 0x36, 0xd4, 0x9e,
    0x1a, 0x97, 0x2b, 0x61, 0x63, 0xb5, 0x0d, 0x7b, 0xc5, 0xc5, 0x03, 0xdd, 0xd0, 0xa6, 0x34, 0x03,
    0x43, 0xb9, 0x80, 0x18, 0xc7, 0x09, 0xc1, 0xf7, 0x8a, 0x9c, 0xda, 0xb2, 0xd5, 0x24, 0x65, 0xac,
    0x62, 0xbd, 0x72, 0xce, 0xec, 0x58, 0xcf, 0xc0, 0x28, 0x69, 0x4a, 0xdb, 0xc0, 0x1a, 0x1f, 0x51,
    0xb0, 0xac, 0xc8, 0x93, 0x80, 0x8c, 0x71, 0x20, 0x0d, 0xbf, 0xcf, 0xf1, 0x97, 0xda, 0x2b, 0x65,
    0xd3, 0x8d, 0x42, 0x63, 0x98, 0xfc, 0xf5, 0x10, 0x14, 0xb2, 0x17, 0xbc, 0xbf, 0x42, 0x3d, 0xac,
    0x52, 0x7e, 0xc9, 0x5c, 0x71, 0x6d, 0x8b, 0xec, 0x52, 0x5a, 0xd4, 0x82, 0xbf, 0x1f, 0x42, 0xdf,
    0xa6, 0x8e, 0x6d, 0xa3, 0xa3, 0xfa, 0x87, 0xf0, 0x62, 0x9e, 0x26, 0x3a, 0x30, 0x02, 0xb6, 0xf4,
    0xf1, 0xe1, 0xc7, 0xf0, 0x68, 0xbe, 0x0c, 0xd2, 0x06, 0x2a, 0xe1, 0xe7, 0x73, 0xfe, 0x8f, 0x51,
    0xf9, 0x78, 0xb6, 0xe9, 0x72, 0x0b, 0xa2, 0x3e, 0xa1, 0xcf, 0xb5, 0xb7, 0xc7, 0xaf, 0xb7, 0xb8,
    0x17, 0x2d, 0xbb, 0x4c, 0x45, 0x51, 0xcc, 0x45, 0x16, 0x45, 0x55, 0xde, 0xcb, 0xfa, 0xa1, 0xd9,
    0x39, 0x1f, 0x24, 0x86, 0xbe, 0x14
};
#endif

PyTypeObject *init_QNetworkDatagram(PyObject *module)
{
    if (SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX].type != nullptr)
        return SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX].type;

    Shiboken::AutoDecRef Sbk_QNetworkDatagram_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QNetworkDatagram_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QNetworkDatagram",
        "QNetworkDatagram",
        &Sbk_QNetworkDatagram_spec,
        &Shiboken::callCppDestructor< ::QNetworkDatagram >,
        Sbk_QNetworkDatagram_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QNetworkDatagram_TypeF(); // references _Sbk_QNetworkDatagram_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QNetworkDatagram_SignatureStrings);
#else
    InitSignatureBytes(pyType, QNetworkDatagram_SignatureBytes, QNetworkDatagram_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QNetworkDatagram_PropertyStrings);
    SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkDatagram_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QNetworkDatagram_PythonToCpp_QNetworkDatagram_PTR,
        is_QNetworkDatagram_PythonToCpp_QNetworkDatagram_PTR_Convertible,
        QNetworkDatagram_PTR_CppToPython_QNetworkDatagram,
        QNetworkDatagram_COPY_CppToPython_QNetworkDatagram);

    Shiboken::Conversions::registerConverterName(converter, "QNetworkDatagram");
    Shiboken::Conversions::registerConverterName(converter, "QNetworkDatagram*");
    Shiboken::Conversions::registerConverterName(converter, "QNetworkDatagram&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QNetworkDatagram).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QNetworkDatagram_PythonToCpp_QNetworkDatagram_COPY,
        is_QNetworkDatagram_PythonToCpp_QNetworkDatagram_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        PySide6_QtCore_constQByteArrayREF_PythonToCpp_QNetworkDatagram,
        is_PySide6_QtCore_constQByteArrayREF_PythonToCpp_QNetworkDatagram_Convertible);

    qRegisterMetaType< ::QNetworkDatagram >("QNetworkDatagram");

    return pyType;
}
