// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnetwork_python.h"

// main header
#include "qnetworkinformation_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QStringList>
#include <QStringView>
#include <QtNetwork/qnetworkinformation.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QNetworkInformationFunc_availableBackends(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // availableBackends()
        QStringList cppResult = ::QNetworkInformation::availableBackends();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInformationFunc_backendName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkInformation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // backendName()const
        QString cppResult = const_cast<const ::QNetworkInformation *>(cppSelf)->backendName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInformationFunc_instance(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // instance()
        QNetworkInformation * cppResult = ::QNetworkInformation::instance();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInformationFunc_isBehindCaptivePortal(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkInformation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isBehindCaptivePortal()const
        bool cppResult = const_cast<const ::QNetworkInformation *>(cppSelf)->isBehindCaptivePortal();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInformationFunc_isMetered(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkInformation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isMetered()const
        bool cppResult = const_cast<const ::QNetworkInformation *>(cppSelf)->isMetered();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInformationFunc_load(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QNetworkInformation::load(QFlags<QNetworkInformation::Feature>)->bool
    // 1: static QNetworkInformation::load(QStringView)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 1; // load(QStringView)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFlags_QNetworkInformation_Feature_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // load(QFlags<QNetworkInformation::Feature>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "load", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // load(QFlags<QNetworkInformation::Feature> features)
        {
            Shiboken::Warnings::warnDeprecated("QNetworkInformation", "load(QFlags<QNetworkInformation.Feature> features)");
            if (Shiboken::Errors::occurred() != nullptr)
                return {};
            ::QFlags<QNetworkInformation::Feature> cppArg0 = QFlags<QNetworkInformation::Feature>(0);
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // load(QFlags<QNetworkInformation::Feature>)
                bool cppResult = ::QNetworkInformation::load(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // load(QStringView backend)
        {
            Shiboken::Warnings::warnDeprecated("QNetworkInformation", "load(QStringView backend)");
            if (Shiboken::Errors::occurred() != nullptr)
                return {};
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // load(QStringView)
                bool cppResult = ::QNetworkInformation::load(QStringView(cppArg0));
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInformationFunc_loadBackendByFeatures(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QNetworkInformation::loadBackendByFeatures(QFlags<QNetworkInformation::Feature>)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFlags_QNetworkInformation_Feature_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // loadBackendByFeatures(QFlags<QNetworkInformation::Feature>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "loadBackendByFeatures", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_IDX]);

    // Call function/method
    {
        ::QFlags<QNetworkInformation::Feature> cppArg0 = QFlags<QNetworkInformation::Feature>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // loadBackendByFeatures(QFlags<QNetworkInformation::Feature>)
            bool cppResult = ::QNetworkInformation::loadBackendByFeatures(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInformationFunc_loadBackendByName(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QNetworkInformation::loadBackendByName(QStringView)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // loadBackendByName(QStringView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "loadBackendByName", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // loadBackendByName(QStringView)
            bool cppResult = ::QNetworkInformation::loadBackendByName(QStringView(cppArg0));
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInformationFunc_loadDefaultBackend(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // loadDefaultBackend()
        bool cppResult = ::QNetworkInformation::loadDefaultBackend();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInformationFunc_reachability(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkInformation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // reachability()const
        QNetworkInformation::Reachability cppResult = const_cast<const ::QNetworkInformation *>(cppSelf)->reachability();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_Reachability_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInformationFunc_supportedFeatures(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkInformation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // supportedFeatures()const
        QFlags<QNetworkInformation::Feature> cppResult = const_cast<const ::QNetworkInformation *>(cppSelf)->supportedFeatures();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFlags_QNetworkInformation_Feature_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInformationFunc_supports(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkInformation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkInformation::supports(QFlags<QNetworkInformation::Feature>)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFlags_QNetworkInformation_Feature_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // supports(QFlags<QNetworkInformation::Feature>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "supports", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_IDX]);

    // Call function/method
    {
        ::QFlags<QNetworkInformation::Feature> cppArg0 = QFlags<QNetworkInformation::Feature>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // supports(QFlags<QNetworkInformation::Feature>)const
            bool cppResult = const_cast<const ::QNetworkInformation *>(cppSelf)->supports(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInformationFunc_transportMedium(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkInformation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // transportMedium()const
        QNetworkInformation::TransportMedium cppResult = const_cast<const ::QNetworkInformation *>(cppSelf)->transportMedium();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_TransportMedium_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QNetworkInformation_PropertyStrings[] = {
    "isBehindCaptivePortal:",
    "isMetered:",
    "reachability:",
    "transportMedium:",
    nullptr // Sentinel
};

static const char *Sbk_QNetworkInformation_EnumFlagInfo[] = {
    "Feature:Flag:Features",
    "Reachability:Enum",
    "TransportMedium:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QNetworkInformation_methods[] = {
    {"availableBackends", reinterpret_cast<PyCFunction>(Sbk_QNetworkInformationFunc_availableBackends), METH_NOARGS|METH_STATIC, nullptr},
    {"backendName", reinterpret_cast<PyCFunction>(Sbk_QNetworkInformationFunc_backendName), METH_NOARGS, nullptr},
    {"instance", reinterpret_cast<PyCFunction>(Sbk_QNetworkInformationFunc_instance), METH_NOARGS|METH_STATIC, nullptr},
    {"isBehindCaptivePortal", reinterpret_cast<PyCFunction>(Sbk_QNetworkInformationFunc_isBehindCaptivePortal), METH_NOARGS, nullptr},
    {"isMetered", reinterpret_cast<PyCFunction>(Sbk_QNetworkInformationFunc_isMetered), METH_NOARGS, nullptr},
    {"load", reinterpret_cast<PyCFunction>(Sbk_QNetworkInformationFunc_load), METH_O|METH_STATIC, nullptr},
    {"loadBackendByFeatures", reinterpret_cast<PyCFunction>(Sbk_QNetworkInformationFunc_loadBackendByFeatures), METH_O|METH_STATIC, nullptr},
    {"loadBackendByName", reinterpret_cast<PyCFunction>(Sbk_QNetworkInformationFunc_loadBackendByName), METH_O|METH_STATIC, nullptr},
    {"loadDefaultBackend", reinterpret_cast<PyCFunction>(Sbk_QNetworkInformationFunc_loadDefaultBackend), METH_NOARGS|METH_STATIC, nullptr},
    {"reachability", reinterpret_cast<PyCFunction>(Sbk_QNetworkInformationFunc_reachability), METH_NOARGS, nullptr},
    {"supportedFeatures", reinterpret_cast<PyCFunction>(Sbk_QNetworkInformationFunc_supportedFeatures), METH_NOARGS, nullptr},
    {"supports", reinterpret_cast<PyCFunction>(Sbk_QNetworkInformationFunc_supports), METH_O, nullptr},
    {"transportMedium", reinterpret_cast<PyCFunction>(Sbk_QNetworkInformationFunc_transportMedium), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QNetworkInformation_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QNetworkInformation_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QNetworkInformation_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QNetworkInformation_Type = nullptr;
static PyTypeObject *Sbk_QNetworkInformation_TypeF(void)
{
    return _Sbk_QNetworkInformation_Type;
}

static PyType_Slot Sbk_QNetworkInformation_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(SbkDeallocWrapperWithPrivateDtor)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QNetworkInformation_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QNetworkInformation_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QNetworkInformation_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QNetworkInformation_methods)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QNetworkInformation_spec = {
    "2:PySide6.QtNetwork.QNetworkInformation",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QNetworkInformation_slots
};

} //extern "C"

static void *Sbk_QNetworkInformation_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QNetworkInformation *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QNetworkInformation_Reachability(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QNetworkInformation::Reachability>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QNetworkInformation::Reachability *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QNetworkInformation_Reachability_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_Reachability_IDX])))
        return Enum_PythonToCpp_QNetworkInformation_Reachability;
    return {};
}

static PyObject *QNetworkInformation_Reachability_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QNetworkInformation::Reachability>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QNetworkInformation::Reachability *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_Reachability_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QNetworkInformation_TransportMedium(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QNetworkInformation::TransportMedium>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QNetworkInformation::TransportMedium *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QNetworkInformation_TransportMedium_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_TransportMedium_IDX])))
        return Enum_PythonToCpp_QNetworkInformation_TransportMedium;
    return {};
}

static PyObject *QNetworkInformation_TransportMedium_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QNetworkInformation::TransportMedium>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QNetworkInformation::TransportMedium *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_TransportMedium_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QNetworkInformation_Feature(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QNetworkInformation::Feature>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QNetworkInformation::Feature *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QNetworkInformation_Feature_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_Feature_IDX])))
        return Enum_PythonToCpp_QNetworkInformation_Feature;
    return {};
}

static PyObject *QNetworkInformation_Feature_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QNetworkInformation::Feature>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QNetworkInformation::Feature *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_Feature_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QNetworkInformation_Feature(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QNetworkInformation::Feature>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QNetworkInformation::Feature> *>(cppOut) = value;

}

static PyObject *QNetworkInformation_Feature_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QNetworkInformation::Feature> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_Feature_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QNetworkInformation_PythonToCpp_QNetworkInformation_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QNetworkInformation_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QNetworkInformation_PythonToCpp_QNetworkInformation_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QNetworkInformation_TypeF()))
        return QNetworkInformation_PythonToCpp_QNetworkInformation_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QNetworkInformation_PTR_CppToPython_QNetworkInformation(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QNetworkInformation *>(const_cast<void *>(cppIn)), Sbk_QNetworkInformation_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QNetworkInformation_SignatureStrings[] = {
    "PySide6.QtNetwork.QNetworkInformation.availableBackends()->QStringList",
    "PySide6.QtNetwork.QNetworkInformation.backendName(self)->QString",
    "PySide6.QtNetwork.QNetworkInformation.instance()->PySide6.QtNetwork.QNetworkInformation",
    "PySide6.QtNetwork.QNetworkInformation.isBehindCaptivePortal(self)->bool",
    "PySide6.QtNetwork.QNetworkInformation.isMetered(self)->bool",
    "1:PySide6.QtNetwork.QNetworkInformation.load(features:PySide6.QtNetwork.QNetworkInformation.Feature)->bool",
    "0:PySide6.QtNetwork.QNetworkInformation.load(backend:QString)->bool",
    "PySide6.QtNetwork.QNetworkInformation.loadBackendByFeatures(features:PySide6.QtNetwork.QNetworkInformation.Feature)->bool",
    "PySide6.QtNetwork.QNetworkInformation.loadBackendByName(backend:QString)->bool",
    "PySide6.QtNetwork.QNetworkInformation.loadDefaultBackend()->bool",
    "PySide6.QtNetwork.QNetworkInformation.reachability(self)->PySide6.QtNetwork.QNetworkInformation.Reachability",
    "PySide6.QtNetwork.QNetworkInformation.supportedFeatures(self)->PySide6.QtNetwork.QNetworkInformation.Feature",
    "PySide6.QtNetwork.QNetworkInformation.supports(self,features:PySide6.QtNetwork.QNetworkInformation.Feature)->bool",
    "PySide6.QtNetwork.QNetworkInformation.transportMedium(self)->PySide6.QtNetwork.QNetworkInformation.TransportMedium",
    nullptr}; // Sentinel
#else
static constexpr size_t QNetworkInformation_SignatureByteSize = 255;
static constexpr uint8_t QNetworkInformation_SignatureBytes[255] = {
    0x78, 0xda, 0xbd, 0x92, 0xb1, 0x4e, 0xc3, 0x40, 0x0c, 0x86, 0xf7, 0x3e, 0x49, 0x90, 0x20, 0x82,
    0x85, 0xa1, 0x03, 0x43, 0x40, 0x48, 0x48, 0xb4, 0x4a, 0x28, 0x2f, 0xe0, 0xe4, 0x1c, 0x6a, 0xf5,
    0x72, 0x17, 0x9d, 0x9d, 0xa2, 0xbc, 0x3d, 0x84, 0x5c, 0x80, 0x6e, 0x3e, 0x2a, 0xb1, 0x65, 0xc8,
    0xf7, 0x7f, 0xf6, 0xfd, 0x2e, 0xc7, 0x1d, 0x19, 0xbc, 0xcd, 0x2b, 0xd9, 0xa2, 0xbc, 0xfb, 0x70,
    0xc8, 0xab, 0xf8, 0xf1, 0xe4, 0x5a, 0x1f, 0x3a, 0x10, 0xf2, 0x2e, 0x87, 0x23, 0x90, 0x85, 0xda,
    0x62, 0x01, 0xcd, 0x01, 0x9d, 0xe1, 0xec, 0xe2, 0xea, 0xae, 0xda, 0x49, 0x20, 0xf7, 0xf6, 0x4c,
    0x2c, 0xab, 0x52, 0x15, 0x53, 0xcf, 0xf4, 0x16, 0x3a, 0xcc, 0x18, 0x6d, 0xfb, 0x13, 0xa2, 0x0c,
    0x20, 0xc7, 0x02, 0xae, 0xc1, 0x49, 0xaf, 0x22, 0xb4, 0xb9, 0x5c, 0xe0, 0x9e, 0x9c, 0xb9, 0x87,
    0x5e, 0xe8, 0x88, 0xa5, 0x0f, 0x02, 0x76, 0x19, 0xb1, 0xf6, 0xde, 0xaa, 0x73, 0x36, 0x28, 0x18,
    0xd0, 0x9c, 0xb0, 0x37, 0x6b, 0x1d, 0x6d, 0x3d, 0x98, 0xac, 0x45, 0x90, 0x21, 0x20, 0x2b, 0x99,
    0xc7, 0xf9, 0xf7, 0x45, 0x75, 0x9d, 0xa2, 0x8a, 0x75, 0xac, 0x63, 0x07, 0x69, 0xab, 0x4e, 0x09,
    0xf1, 0x1a, 0x8a, 0x31, 0x4e, 0xc1, 0x67, 0x4e, 0xff, 0x07, 0xf3, 0xd7, 0x2d, 0x9d, 0xbd, 0xc8,
    0x03, 0xb6, 0x30, 0x58, 0x89, 0xa9, 0x59, 0x5a, 0x40, 0x40, 0x68, 0xf6, 0x50, 0x93, 0x25, 0x19,
    0x97, 0xde, 0x75, 0xe4, 0xcb, 0x2f, 0x52, 0x29, 0xe3, 0xa1, 0xef, 0x3f, 0xaf, 0x13, 0xcd, 0xf7,
    0x93, 0x27, 0x19, 0x23, 0x95, 0x26, 0x9b, 0x1d, 0x97, 0xff, 0xd1, 0xad, 0x04, 0x70, 0x3c, 0x39,
    0x37, 0x68, 0x68, 0xe8, 0xd2, 0x96, 0x7b, 0x3d, 0x85, 0x57, 0x1f, 0xdf, 0x6b, 0xd2, 0x34
};
#endif

PyTypeObject *init_QNetworkInformation(PyObject *module)
{
    if (SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_IDX].type != nullptr)
        return SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_IDX].type;

    Shiboken::AutoDecRef Sbk_QNetworkInformation_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QNetworkInformation_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QNetworkInformation",
        "QNetworkInformation*",
        &Sbk_QNetworkInformation_spec,
        nullptr,
        Sbk_QNetworkInformation_Type_bases.object(),
        0);
    auto *pyType = Sbk_QNetworkInformation_TypeF(); // references _Sbk_QNetworkInformation_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QNetworkInformation_SignatureStrings);
#else
    InitSignatureBytes(pyType, QNetworkInformation_SignatureBytes, QNetworkInformation_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QNetworkInformation_PropertyStrings);
    SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QNetworkInformation_PythonToCpp_QNetworkInformation_PTR,
        is_QNetworkInformation_PythonToCpp_QNetworkInformation_PTR_Convertible,
        QNetworkInformation_PTR_CppToPython_QNetworkInformation);

    Shiboken::Conversions::registerConverterName(converter, "QNetworkInformation");
    Shiboken::Conversions::registerConverterName(converter, "QNetworkInformation*");
    Shiboken::Conversions::registerConverterName(converter, "QNetworkInformation&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QNetworkInformation).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QNetworkInformation_TypeF(), &Sbk_QNetworkInformation_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QNetworkInformation_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Reachability'.
    const char *Reachability_Initializer[] = {
        "Unknown",
        "Disconnected",
        "Local",
        "Site",
        "Online",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t Reachability_InitializerValues[] = {
        int8_t(QNetworkInformation::Reachability::Unknown),      //  0x00  0
        int8_t(QNetworkInformation::Reachability::Disconnected), //  0x01  1
        int8_t(QNetworkInformation::Reachability::Local),        //  0x02  2
        int8_t(QNetworkInformation::Reachability::Site),         //  0x03  3
        int8_t(QNetworkInformation::Reachability::Online)        //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QNetworkInformation_TypeF(),
        "2:PySide6.QtNetwork.QNetworkInformation.Reachability",
        Reachability_Initializer, Reachability_InitializerValues);
    SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_Reachability_IDX].type = EType;
    // Register converter for enum 'QNetworkInformation::Reachability'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QNetworkInformation_Reachability_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QNetworkInformation_Reachability,
            is_Enum_PythonToCpp_QNetworkInformation_Reachability_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QNetworkInformation::Reachability");
        Shiboken::Conversions::registerConverterAlias(converter, "Reachability");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Reachability' enum.

    // Initialization of enum 'TransportMedium'.
    const char *TransportMedium_Initializer[] = {
        "Unknown",
        "Ethernet",
        "Cellular",
        "WiFi",
        "Bluetooth",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t TransportMedium_InitializerValues[] = {
        int8_t(QNetworkInformation::TransportMedium::Unknown),  //  0x00  0
        int8_t(QNetworkInformation::TransportMedium::Ethernet), //  0x01  1
        int8_t(QNetworkInformation::TransportMedium::Cellular), //  0x02  2
        int8_t(QNetworkInformation::TransportMedium::WiFi),     //  0x03  3
        int8_t(QNetworkInformation::TransportMedium::Bluetooth) //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QNetworkInformation_TypeF(),
        "2:PySide6.QtNetwork.QNetworkInformation.TransportMedium",
        TransportMedium_Initializer, TransportMedium_InitializerValues);
    SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_TransportMedium_IDX].type = EType;
    // Register converter for enum 'QNetworkInformation::TransportMedium'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QNetworkInformation_TransportMedium_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QNetworkInformation_TransportMedium,
            is_Enum_PythonToCpp_QNetworkInformation_TransportMedium_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QNetworkInformation::TransportMedium");
        Shiboken::Conversions::registerConverterAlias(converter, "TransportMedium");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'TransportMedium' enum.

    // Initialization of enum 'Feature'.
    const char *Feature_Initializer[] = {
        "Reachability",
        "CaptivePortal",
        "TransportMedium",
        "Metered",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t Feature_InitializerValues[] = {
        int8_t(QNetworkInformation::Feature::Reachability),    //  0x01  1
        int8_t(QNetworkInformation::Feature::CaptivePortal),   //  0x02  2
        int8_t(QNetworkInformation::Feature::TransportMedium), //  0x04  4
        int8_t(QNetworkInformation::Feature::Metered)          //  0x08  8
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QNetworkInformation_TypeF(),
        "2:PySide6.QtNetwork.QNetworkInformation.Feature",
        Feature_Initializer, Feature_InitializerValues);
    SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_Feature_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtNetworkTypeStructs[SBK_QFlags_QNetworkInformation_Feature_IDX].type =
        EType;
    // Register converter for enum 'QNetworkInformation::Feature'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QNetworkInformation_Feature_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QNetworkInformation_Feature,
            is_Enum_PythonToCpp_QNetworkInformation_Feature_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QNetworkInformation::Feature");
        Shiboken::Conversions::registerConverterAlias(converter, "Feature");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QNetworkInformation_Feature_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QNetworkInformation_Feature,
            is_Enum_PythonToCpp_QNetworkInformation_Feature_Convertible);
        // Register converter for flag 'QFlags<QNetworkInformation::Feature>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QNetworkInformation::Feature>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QNetworkInformation::Features");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'Feature' enum/flags.

    PySide::Signal::registerSignals(pyType, &::QNetworkInformation::staticMetaObject);
    qRegisterMetaType< ::QNetworkInformation::Reachability >("QNetworkInformation::Reachability");
    qRegisterMetaType< ::QNetworkInformation::TransportMedium >("QNetworkInformation::TransportMedium");
    qRegisterMetaType< ::QNetworkInformation::Feature >("QNetworkInformation::Feature");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QNetworkInformation::staticMetaObject, sizeof(::QNetworkInformation));

    return pyType;
}
