// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnetwork_python.h"

// main header
#include "qnetworkinterface_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtNetwork/qhostaddress.h>
#include <QtNetwork/qnetworkinterface.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QNetworkInterface_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QNetworkInterface >()))
        return -1;

    ::QNetworkInterface *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QNetworkInterface", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QNetworkInterface::QNetworkInterface()
    // 1: QNetworkInterface::QNetworkInterface(QNetworkInterface)
    if (numArgs == 0) {
        overloadId = 0; // QNetworkInterface()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QNetworkInterface(QNetworkInterface)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QNetworkInterface()
        {

            // QNetworkInterface()
            cptr = new ::QNetworkInterface();
            break;
        }
        case 1: // QNetworkInterface(const QNetworkInterface &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QNetworkInterface cppArg0_local;
            ::QNetworkInterface *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QNetworkInterface(QNetworkInterface)
                cptr = new ::QNetworkInterface(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QNetworkInterface >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QNetworkInterfaceFunc_addressEntries(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // addressEntries()const
        QList<QNetworkAddressEntry> cppResult = const_cast<const ::QNetworkInterface *>(cppSelf)->addressEntries();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QNetworkAddressEntry_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInterfaceFunc_allAddresses(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // allAddresses()
        QList<QHostAddress> cppResult = ::QNetworkInterface::allAddresses();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QHostAddress_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInterfaceFunc_allInterfaces(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // allInterfaces()
        QList<QNetworkInterface> cppResult = ::QNetworkInterface::allInterfaces();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QNetworkInterface_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInterfaceFunc_flags(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // flags()const
        QFlags<QNetworkInterface::InterfaceFlag> cppResult = const_cast<const ::QNetworkInterface *>(cppSelf)->flags();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFlags_QNetworkInterface_InterfaceFlag_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInterfaceFunc_hardwareAddress(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hardwareAddress()const
        QString cppResult = const_cast<const ::QNetworkInterface *>(cppSelf)->hardwareAddress();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInterfaceFunc_humanReadableName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // humanReadableName()const
        QString cppResult = const_cast<const ::QNetworkInterface *>(cppSelf)->humanReadableName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInterfaceFunc_index(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // index()const
        int cppResult = const_cast<const ::QNetworkInterface *>(cppSelf)->index();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInterfaceFunc_interfaceFromIndex(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QNetworkInterface::interfaceFromIndex(int)->QNetworkInterface
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // interfaceFromIndex(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "interfaceFromIndex", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // interfaceFromIndex(int)
            QNetworkInterface cppResult = ::QNetworkInterface::interfaceFromIndex(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInterfaceFunc_interfaceFromName(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QNetworkInterface::interfaceFromName(QString)->QNetworkInterface
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // interfaceFromName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "interfaceFromName", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // interfaceFromName(QString)
            QNetworkInterface cppResult = ::QNetworkInterface::interfaceFromName(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInterfaceFunc_interfaceIndexFromName(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QNetworkInterface::interfaceIndexFromName(QString)->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // interfaceIndexFromName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "interfaceIndexFromName", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // interfaceIndexFromName(QString)
            int cppResult = ::QNetworkInterface::interfaceIndexFromName(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInterfaceFunc_interfaceNameFromIndex(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QNetworkInterface::interfaceNameFromIndex(int)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // interfaceNameFromIndex(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "interfaceNameFromIndex", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // interfaceNameFromIndex(int)
            QString cppResult = ::QNetworkInterface::interfaceNameFromIndex(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInterfaceFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QNetworkInterface *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInterfaceFunc_maximumTransmissionUnit(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maximumTransmissionUnit()const
        int cppResult = const_cast<const ::QNetworkInterface *>(cppSelf)->maximumTransmissionUnit();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInterfaceFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // name()const
        QString cppResult = const_cast<const ::QNetworkInterface *>(cppSelf)->name();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInterfaceFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkInterface::swap(QNetworkInterface&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QNetworkInterface&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QNetworkInterface cppArg0_local;
        ::QNetworkInterface *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QNetworkInterface&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkInterfaceFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        QNetworkInterface::InterfaceType cppResult = const_cast<const ::QNetworkInterface *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_InterfaceType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInterface__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QNetworkInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QNetworkInterface_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QNetworkInterface_EnumFlagInfo[] = {
    "InterfaceFlag:Flag:InterfaceFlags",
    "InterfaceType:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QNetworkInterface_methods[] = {
    {"addressEntries", reinterpret_cast<PyCFunction>(Sbk_QNetworkInterfaceFunc_addressEntries), METH_NOARGS, nullptr},
    {"allAddresses", reinterpret_cast<PyCFunction>(Sbk_QNetworkInterfaceFunc_allAddresses), METH_NOARGS|METH_STATIC, nullptr},
    {"allInterfaces", reinterpret_cast<PyCFunction>(Sbk_QNetworkInterfaceFunc_allInterfaces), METH_NOARGS|METH_STATIC, nullptr},
    {"flags", reinterpret_cast<PyCFunction>(Sbk_QNetworkInterfaceFunc_flags), METH_NOARGS, nullptr},
    {"hardwareAddress", reinterpret_cast<PyCFunction>(Sbk_QNetworkInterfaceFunc_hardwareAddress), METH_NOARGS, nullptr},
    {"humanReadableName", reinterpret_cast<PyCFunction>(Sbk_QNetworkInterfaceFunc_humanReadableName), METH_NOARGS, nullptr},
    {"index", reinterpret_cast<PyCFunction>(Sbk_QNetworkInterfaceFunc_index), METH_NOARGS, nullptr},
    {"interfaceFromIndex", reinterpret_cast<PyCFunction>(Sbk_QNetworkInterfaceFunc_interfaceFromIndex), METH_O|METH_STATIC, nullptr},
    {"interfaceFromName", reinterpret_cast<PyCFunction>(Sbk_QNetworkInterfaceFunc_interfaceFromName), METH_O|METH_STATIC, nullptr},
    {"interfaceIndexFromName", reinterpret_cast<PyCFunction>(Sbk_QNetworkInterfaceFunc_interfaceIndexFromName), METH_O|METH_STATIC, nullptr},
    {"interfaceNameFromIndex", reinterpret_cast<PyCFunction>(Sbk_QNetworkInterfaceFunc_interfaceNameFromIndex), METH_O|METH_STATIC, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QNetworkInterfaceFunc_isValid), METH_NOARGS, nullptr},
    {"maximumTransmissionUnit", reinterpret_cast<PyCFunction>(Sbk_QNetworkInterfaceFunc_maximumTransmissionUnit), METH_NOARGS, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_QNetworkInterfaceFunc_name), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QNetworkInterfaceFunc_swap), METH_O, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QNetworkInterfaceFunc_type), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QNetworkInterface__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QNetworkInterface_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QNetworkInterface_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QNetworkInterface__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QNetworkInterface_Type = nullptr;
static PyTypeObject *Sbk_QNetworkInterface_TypeF(void)
{
    return _Sbk_QNetworkInterface_Type;
}

static PyType_Slot Sbk_QNetworkInterface_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QNetworkInterface__repr__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QNetworkInterface_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QNetworkInterface_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QNetworkInterface_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QNetworkInterface_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QNetworkInterface_spec = {
    "2:PySide6.QtNetwork.QNetworkInterface",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QNetworkInterface_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QNetworkInterface_InterfaceFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QNetworkInterface::InterfaceFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QNetworkInterface::InterfaceFlag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QNetworkInterface_InterfaceFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_InterfaceFlag_IDX])))
        return Enum_PythonToCpp_QNetworkInterface_InterfaceFlag;
    return {};
}

static PyObject *QNetworkInterface_InterfaceFlag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QNetworkInterface::InterfaceFlag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QNetworkInterface::InterfaceFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_InterfaceFlag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QNetworkInterface_InterfaceFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QNetworkInterface::InterfaceFlag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QNetworkInterface::InterfaceFlag> *>(cppOut) = value;

}

static PyObject *QNetworkInterface_InterfaceFlag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QNetworkInterface::InterfaceFlag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_InterfaceFlag_IDX]), flags.toInt());

}

static void Enum_PythonToCpp_QNetworkInterface_InterfaceType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QNetworkInterface::InterfaceType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QNetworkInterface::InterfaceType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QNetworkInterface_InterfaceType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_InterfaceType_IDX])))
        return Enum_PythonToCpp_QNetworkInterface_InterfaceType;
    return {};
}

static PyObject *QNetworkInterface_InterfaceType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QNetworkInterface::InterfaceType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QNetworkInterface::InterfaceType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_InterfaceType_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QNetworkInterface_PythonToCpp_QNetworkInterface_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QNetworkInterface_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QNetworkInterface_PythonToCpp_QNetworkInterface_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QNetworkInterface_TypeF()))
        return QNetworkInterface_PythonToCpp_QNetworkInterface_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QNetworkInterface_PTR_CppToPython_QNetworkInterface(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QNetworkInterface_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QNetworkInterface_COPY_CppToPython_QNetworkInterface(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QNetworkInterface *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QNetworkInterface_TypeF(), new ::QNetworkInterface(*source), true, true);
}

// Python to C++ copy conversion.
static void QNetworkInterface_PythonToCpp_QNetworkInterface_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QNetworkInterface *>(cppOut) = *reinterpret_cast< ::QNetworkInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QNetworkInterface_PythonToCpp_QNetworkInterface_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QNetworkInterface_TypeF()))
        return QNetworkInterface_PythonToCpp_QNetworkInterface_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QNetworkInterface_SignatureStrings[] = {
    "1:PySide6.QtNetwork.QNetworkInterface(self)",
    "0:PySide6.QtNetwork.QNetworkInterface(self,other:PySide6.QtNetwork.QNetworkInterface)",
    "PySide6.QtNetwork.QNetworkInterface.addressEntries(self)->QList[PySide6.QtNetwork.QNetworkAddressEntry]",
    "PySide6.QtNetwork.QNetworkInterface.allAddresses()->QList[PySide6.QtNetwork.QHostAddress]",
    "PySide6.QtNetwork.QNetworkInterface.allInterfaces()->QList[PySide6.QtNetwork.QNetworkInterface]",
    "PySide6.QtNetwork.QNetworkInterface.flags(self)->PySide6.QtNetwork.QNetworkInterface.InterfaceFlag",
    "PySide6.QtNetwork.QNetworkInterface.hardwareAddress(self)->QString",
    "PySide6.QtNetwork.QNetworkInterface.humanReadableName(self)->QString",
    "PySide6.QtNetwork.QNetworkInterface.index(self)->int",
    "PySide6.QtNetwork.QNetworkInterface.interfaceFromIndex(index:int)->PySide6.QtNetwork.QNetworkInterface",
    "PySide6.QtNetwork.QNetworkInterface.interfaceFromName(name:QString)->PySide6.QtNetwork.QNetworkInterface",
    "PySide6.QtNetwork.QNetworkInterface.interfaceIndexFromName(name:QString)->int",
    "PySide6.QtNetwork.QNetworkInterface.interfaceNameFromIndex(index:int)->QString",
    "PySide6.QtNetwork.QNetworkInterface.isValid(self)->bool",
    "PySide6.QtNetwork.QNetworkInterface.maximumTransmissionUnit(self)->int",
    "PySide6.QtNetwork.QNetworkInterface.name(self)->QString",
    "PySide6.QtNetwork.QNetworkInterface.swap(self,other:PySide6.QtNetwork.QNetworkInterface)",
    "PySide6.QtNetwork.QNetworkInterface.type(self)->PySide6.QtNetwork.QNetworkInterface.InterfaceType",
    "PySide6.QtNetwork.QNetworkInterface.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QNetworkInterface_SignatureByteSize = 295;
static constexpr uint8_t QNetworkInterface_SignatureBytes[295] = {
    0x78, 0xda, 0xb5, 0x94, 0x41, 0x4b, 0xc3, 0x40, 0x10, 0x85, 0xef, 0xf9, 0x25, 0x16, 0x34, 0xe8,
    0xc5, 0x43, 0x0e, 0x82, 0x07, 0xc5, 0x82, 0x14, 0x63, 0xaa, 0x17, 0x91, 0x30, 0xed, 0x4e, 0xec,
    0xe2, 0xee, 0x6c, 0xd8, 0xd9, 0xd2, 0xe6, 0xdf, 0xbb, 0xc6, 0x24, 0x82, 0xd8, 0x32, 0x09, 0xf4,
    0x12, 0x76, 0xc9, 0xbc, 0xf7, 0xe5, 0xcd, 0xec, 0xe6, 0x2a, 0x7b, 0x6a, 0x0a, 0xad, 0xf0, 0x3a,
    0xcd, 0xc3, 0x02, 0xc3, 0xce, 0xf9, 0xcf, 0x34, 0xef, 0x16, 0x73, 0x0a, 0xe8, 0x2b, 0x58, 0xe3,
    0x19, 0xa3, 0xa9, 0x66, 0xc9, 0xa5, 0xb8, 0xf6, 0xdc, 0x85, 0x0d, 0x7a, 0x49, 0xf9, 0x2c, 0x11,
    0x14, 0xa5, 0xa0, 0x94, 0x47, 0xe6, 0x3b, 0x0a, 0x5e, 0x23, 0xff, 0x7c, 0xce, 0xc5, 0x4d, 0xfe,
    0xa8, 0x39, 0xbc, 0x1d, 0xd6, 0xdf, 0xfe, 0xaa, 0x9a, 0x77, 0x19, 0xc7, 0x98, 0x4e, 0x14, 0x29,
    0xc7, 0x08, 0x0f, 0x8e, 0x43, 0x57, 0x29, 0x76, 0x1e, 0x36, 0xc7, 0xad, 0xff, 0x4a, 0x65, 0xfe,
    0x95, 0x81, 0x8f, 0xa1, 0x31, 0x12, 0xc1, 0xb0, 0xba, 0x8f, 0x4a, 0x11, 0x62, 0x03, 0x5e, 0xed,
    0xc0, 0x63, 0x97, 0x7b, 0x98, 0x42, 0x11, 0x87, 0x42, 0x42, 0x8b, 0xad, 0x05, 0x7a, 0x46, 0x50,
    0xb0, 0x32, 0xb8, 0x00, 0x8b, 0x53, 0x4c, 0x34, 0x29, 0xdc, 0xf7, 0x42, 0x4d, 0x41, 0x28, 0xea,
    0xe3, 0x7a, 0x67, 0xe7, 0xad, 0x43, 0xeb, 0x93, 0xc5, 0x17, 0xb2, 0x8e, 0x8d, 0xc7, 0xb4, 0x01,
    0x29, 0x3e, 0xb2, 0x2e, 0xde, 0x29, 0x40, 0x6d, 0x96, 0x43, 0xb4, 0xd1, 0xdd, 0xf9, 0x36, 0xf9,
    0xbf, 0x43, 0xa3, 0x26, 0xc4, 0xaf, 0x60, 0xb4, 0xea, 0x67, 0xb4, 0x72, 0xce, 0x88, 0x74, 0x16,
    0xf6, 0xda, 0x6e, 0xed, 0xd2, 0x03, 0xb1, 0xd5, 0xcc, 0xda, 0xd1, 0x0b, 0xe9, 0x30, 0x76, 0xd6,
    0x34, 0xf1, 0x60, 0xf1, 0x0e, 0xea, 0x93, 0xfc, 0xbe, 0x42, 0x53, 0xe3, 0xa4, 0xbb, 0xb9, 0x8c,
    0x42, 0x11, 0xa1, 0x2c, 0xd7, 0xae, 0x6e, 0xca, 0xb2, 0xa7, 0x44, 0x62, 0x4c, 0x9d, 0x16, 0x71,
    0x97, 0x7c, 0x01, 0xeb, 0x3d, 0x2e, 0x51
};
#endif

PyTypeObject *init_QNetworkInterface(PyObject *module)
{
    if (SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX].type != nullptr)
        return SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX].type;

    Shiboken::AutoDecRef Sbk_QNetworkInterface_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QNetworkInterface_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QNetworkInterface",
        "QNetworkInterface",
        &Sbk_QNetworkInterface_spec,
        &Shiboken::callCppDestructor< ::QNetworkInterface >,
        Sbk_QNetworkInterface_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QNetworkInterface_TypeF(); // references _Sbk_QNetworkInterface_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QNetworkInterface_SignatureStrings);
#else
    InitSignatureBytes(pyType, QNetworkInterface_SignatureBytes, QNetworkInterface_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QNetworkInterface_PropertyStrings);
    SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QNetworkInterface_PythonToCpp_QNetworkInterface_PTR,
        is_QNetworkInterface_PythonToCpp_QNetworkInterface_PTR_Convertible,
        QNetworkInterface_PTR_CppToPython_QNetworkInterface,
        QNetworkInterface_COPY_CppToPython_QNetworkInterface);

    Shiboken::Conversions::registerConverterName(converter, "QNetworkInterface");
    Shiboken::Conversions::registerConverterName(converter, "QNetworkInterface*");
    Shiboken::Conversions::registerConverterName(converter, "QNetworkInterface&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QNetworkInterface).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QNetworkInterface_PythonToCpp_QNetworkInterface_COPY,
        is_QNetworkInterface_PythonToCpp_QNetworkInterface_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QNetworkInterface_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'InterfaceFlag'.
    const char *InterfaceFlag_Initializer[] = {
        "IsUp",
        "IsRunning",
        "CanBroadcast",
        "IsLoopBack",
        "IsPointToPoint",
        "CanMulticast",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t InterfaceFlag_InitializerValues[] = {
        uint8_t(QNetworkInterface::InterfaceFlag::IsUp),           //  0x01  1
        uint8_t(QNetworkInterface::InterfaceFlag::IsRunning),      //  0x02  2
        uint8_t(QNetworkInterface::InterfaceFlag::CanBroadcast),   //  0x04  4
        uint8_t(QNetworkInterface::InterfaceFlag::IsLoopBack),     //  0x08  8
        uint8_t(QNetworkInterface::InterfaceFlag::IsPointToPoint), //  0x10  16
        uint8_t(QNetworkInterface::InterfaceFlag::CanMulticast)    //  0x20  32
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QNetworkInterface_TypeF(),
        "2:PySide6.QtNetwork.QNetworkInterface.InterfaceFlag",
        InterfaceFlag_Initializer, InterfaceFlag_InitializerValues);
    SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_InterfaceFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtNetworkTypeStructs[SBK_QFlags_QNetworkInterface_InterfaceFlag_IDX].type =
        EType;
    // Register converter for enum 'QNetworkInterface::InterfaceFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QNetworkInterface_InterfaceFlag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QNetworkInterface_InterfaceFlag,
            is_Enum_PythonToCpp_QNetworkInterface_InterfaceFlag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QNetworkInterface::InterfaceFlag");
        Shiboken::Conversions::registerConverterAlias(converter, "InterfaceFlag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QNetworkInterface_InterfaceFlag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QNetworkInterface_InterfaceFlag,
            is_Enum_PythonToCpp_QNetworkInterface_InterfaceFlag_Convertible);
        // Register converter for flag 'QFlags<QNetworkInterface::InterfaceFlag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QNetworkInterface::InterfaceFlag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QNetworkInterface::InterfaceFlags");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'InterfaceFlag' enum/flags.

    // Initialization of enum 'InterfaceType'.
    const char *InterfaceType_Initializer[] = {
        "Loopback",
        "Virtual",
        "Ethernet",
        "Slip",
        "CanBus",
        "Ppp",
        "Fddi",
        "Wifi",
        "Ieee80211",
        "Phonet",
        "Ieee802154",
        "SixLoWPAN",
        "Ieee80216",
        "Ieee1394",
        "Unknown",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t InterfaceType_InitializerValues[] = {
        uint8_t(QNetworkInterface::InterfaceType::Loopback),   //  0x01  1
        uint8_t(QNetworkInterface::InterfaceType::Virtual),    //  0x02  2
        uint8_t(QNetworkInterface::InterfaceType::Ethernet),   //  0x03  3
        uint8_t(QNetworkInterface::InterfaceType::Slip),       //  0x04  4
        uint8_t(QNetworkInterface::InterfaceType::CanBus),     //  0x05  5
        uint8_t(QNetworkInterface::InterfaceType::Ppp),        //  0x06  6
        uint8_t(QNetworkInterface::InterfaceType::Fddi),       //  0x07  7
        uint8_t(QNetworkInterface::InterfaceType::Wifi),       //  0x08  8
        uint8_t(QNetworkInterface::InterfaceType::Ieee80211),  //  0x08  8
        uint8_t(QNetworkInterface::InterfaceType::Phonet),     //  0x09  9
        uint8_t(QNetworkInterface::InterfaceType::Ieee802154), //  0x0a  10
        uint8_t(QNetworkInterface::InterfaceType::SixLoWPAN),  //  0x0b  11
        uint8_t(QNetworkInterface::InterfaceType::Ieee80216),  //  0x0c  12
        uint8_t(QNetworkInterface::InterfaceType::Ieee1394),   //  0x0d  13
        uint8_t(QNetworkInterface::InterfaceType::Unknown)     //  0x00  0
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QNetworkInterface_TypeF(),
        "2:PySide6.QtNetwork.QNetworkInterface.InterfaceType",
        InterfaceType_Initializer, InterfaceType_InitializerValues);
    SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_InterfaceType_IDX].type = EType;
    // Register converter for enum 'QNetworkInterface::InterfaceType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QNetworkInterface_InterfaceType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QNetworkInterface_InterfaceType,
            is_Enum_PythonToCpp_QNetworkInterface_InterfaceType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QNetworkInterface::InterfaceType");
        Shiboken::Conversions::registerConverterAlias(converter, "InterfaceType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'InterfaceType' enum.

    qRegisterMetaType< ::QNetworkInterface >("QNetworkInterface");
    qRegisterMetaType< ::QNetworkInterface::InterfaceFlag >("QNetworkInterface::InterfaceFlag");
    qRegisterMetaType< ::QNetworkInterface::InterfaceType >("QNetworkInterface::InterfaceType");

    return pyType;
}
