// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnetwork_python.h"

// main header
#include "qnetworkrequest_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QtNetwork/qhttp1configuration.h>
#include <QtNetwork/qhttp2configuration.h>
#include <QtNetwork/qhttpheaders.h>
#include <QtNetwork/qnetworkrequest.h>
#include <QtNetwork/qsslconfiguration.h>
#include <qbytearray.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qurl.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QNetworkRequest_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QNetworkRequest >()))
        return -1;

    ::QNetworkRequest *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QNetworkRequest", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QNetworkRequest::QNetworkRequest()
    // 1: QNetworkRequest::QNetworkRequest(QNetworkRequest)
    // 2: QNetworkRequest::QNetworkRequest(QUrl)
    if (numArgs == 0) {
        overloadId = 0; // QNetworkRequest()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QNetworkRequest(QUrl)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QNetworkRequest(QNetworkRequest)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QNetworkRequest()
        {

            // QNetworkRequest()
            cptr = new ::QNetworkRequest();
            break;
        }
        case 1: // QNetworkRequest(const QNetworkRequest &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QNetworkRequest cppArg0_local;
            ::QNetworkRequest *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QNetworkRequest(QNetworkRequest)
                cptr = new ::QNetworkRequest(*cppArg0);
            }
            break;
        }
        case 2: // QNetworkRequest(const QUrl &url)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QUrl cppArg0_local;
            ::QUrl *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QNetworkRequest(QUrl)
                cptr = new ::QNetworkRequest(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QNetworkRequest >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QNetworkRequestFunc_attribute(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "attribute", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]);

    if (PyArg_ParseTuple(args, "|OO:attribute", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QNetworkRequest::attribute(QNetworkRequest::Attribute,const QVariant&=)const->QVariant
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_Attribute_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // attribute(QNetworkRequest::Attribute,QVariant)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[1])))) {
            overloadId = 0; // attribute(QNetworkRequest::Attribute,QVariant)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "attribute", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_defaultValue = Shiboken::String::createStaticString("defaultValue");
            if (PyDict_Contains(kwds, key_defaultValue) != 0) {
                value = PyDict_GetItem(kwds, key_defaultValue);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_defaultValue);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "attribute", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "attribute", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_defaultValue);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "attribute", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]);
            }
        }
        ::QNetworkRequest::Attribute cppArg0{QNetworkRequest::HttpStatusCodeAttribute};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QVariant cppArg1 = QVariant();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // attribute(QNetworkRequest::Attribute,QVariant)const
            QVariant cppResult = const_cast<const ::QNetworkRequest *>(cppSelf)->attribute(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkRequestFunc_decompressedSafetyCheckThreshold(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // decompressedSafetyCheckThreshold()const
        qint64 cppResult = const_cast<const ::QNetworkRequest *>(cppSelf)->decompressedSafetyCheckThreshold();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkRequestFunc_hasRawHeader(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkRequest::hasRawHeader(QAnyStringView)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // hasRawHeader(QAnyStringView)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "hasRawHeader", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // hasRawHeader(QAnyStringView)const
            bool cppResult = const_cast<const ::QNetworkRequest *>(cppSelf)->hasRawHeader(QAnyStringView(cppArg0));
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkRequestFunc_header(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkRequest::header(QNetworkRequest::KnownHeaders)const->QVariant
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_KnownHeaders_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // header(QNetworkRequest::KnownHeaders)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "header", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]);

    // Call function/method
    {
        ::QNetworkRequest::KnownHeaders cppArg0{QNetworkRequest::ContentTypeHeader};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // header(QNetworkRequest::KnownHeaders)const
            QVariant cppResult = const_cast<const ::QNetworkRequest *>(cppSelf)->header(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkRequestFunc_headers(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // headers()const
        QHttpHeaders cppResult = const_cast<const ::QNetworkRequest *>(cppSelf)->headers();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkRequestFunc_http1Configuration(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // http1Configuration()const
        QHttp1Configuration cppResult = const_cast<const ::QNetworkRequest *>(cppSelf)->http1Configuration();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp1Configuration_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkRequestFunc_http2Configuration(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // http2Configuration()const
        QHttp2Configuration cppResult = const_cast<const ::QNetworkRequest *>(cppSelf)->http2Configuration();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkRequestFunc_maximumRedirectsAllowed(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maximumRedirectsAllowed()const
        int cppResult = const_cast<const ::QNetworkRequest *>(cppSelf)->maximumRedirectsAllowed();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkRequestFunc_originatingObject(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // originatingObject()const
        QObject * cppResult = const_cast<const ::QNetworkRequest *>(cppSelf)->originatingObject();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkRequestFunc_peerVerifyName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // peerVerifyName()const
        QString cppResult = const_cast<const ::QNetworkRequest *>(cppSelf)->peerVerifyName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkRequestFunc_priority(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // priority()const
        QNetworkRequest::Priority cppResult = const_cast<const ::QNetworkRequest *>(cppSelf)->priority();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_Priority_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkRequestFunc_rawHeader(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkRequest::rawHeader(QAnyStringView)const->QByteArray
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // rawHeader(QAnyStringView)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "rawHeader", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // rawHeader(QAnyStringView)const
            QByteArray cppResult = const_cast<const ::QNetworkRequest *>(cppSelf)->rawHeader(QAnyStringView(cppArg0));
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkRequestFunc_rawHeaderList(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rawHeaderList()const
        QList<QByteArray> cppResult = const_cast<const ::QNetworkRequest *>(cppSelf)->rawHeaderList();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QByteArray_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkRequestFunc_setAttribute(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setAttribute", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QNetworkRequest::setAttribute(QNetworkRequest::Attribute,QVariant)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_Attribute_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[1])))) {
        overloadId = 0; // setAttribute(QNetworkRequest::Attribute,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setAttribute", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]);

    // Call function/method
    {
        ::QNetworkRequest::Attribute cppArg0{QNetworkRequest::HttpStatusCodeAttribute};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QVariant cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAttribute(QNetworkRequest::Attribute,QVariant)
            cppSelf->setAttribute(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkRequestFunc_setDecompressedSafetyCheckThreshold(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkRequest::setDecompressedSafetyCheckThreshold(qint64)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArg)))) {
        overloadId = 0; // setDecompressedSafetyCheckThreshold(qint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDecompressedSafetyCheckThreshold", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]);

    // Call function/method
    {
        qint64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDecompressedSafetyCheckThreshold(qint64)
            cppSelf->setDecompressedSafetyCheckThreshold(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkRequestFunc_setHeader(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setHeader", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QNetworkRequest::setHeader(QNetworkRequest::KnownHeaders,QVariant)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_KnownHeaders_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[1])))) {
        overloadId = 0; // setHeader(QNetworkRequest::KnownHeaders,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setHeader", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]);

    // Call function/method
    {
        ::QNetworkRequest::KnownHeaders cppArg0{QNetworkRequest::ContentTypeHeader};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QVariant cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHeader(QNetworkRequest::KnownHeaders,QVariant)
            cppSelf->setHeader(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkRequestFunc_setHeaders(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkRequest::setHeaders(QHttpHeaders)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_IDX]), (pyArg)))) {
        overloadId = 0; // setHeaders(QHttpHeaders)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHeaders", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QHttpHeaders cppArg0_local;
        ::QHttpHeaders *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setHeaders(QHttpHeaders)
            cppSelf->setHeaders(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkRequestFunc_setHttp1Configuration(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkRequest::setHttp1Configuration(QHttp1Configuration)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp1Configuration_IDX]), (pyArg)))) {
        overloadId = 0; // setHttp1Configuration(QHttp1Configuration)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHttp1Configuration", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QHttp1Configuration cppArg0_local;
        ::QHttp1Configuration *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setHttp1Configuration(QHttp1Configuration)
            cppSelf->setHttp1Configuration(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkRequestFunc_setHttp2Configuration(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkRequest::setHttp2Configuration(QHttp2Configuration)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]), (pyArg)))) {
        overloadId = 0; // setHttp2Configuration(QHttp2Configuration)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHttp2Configuration", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QHttp2Configuration cppArg0_local;
        ::QHttp2Configuration *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setHttp2Configuration(QHttp2Configuration)
            cppSelf->setHttp2Configuration(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkRequestFunc_setMaximumRedirectsAllowed(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkRequest::setMaximumRedirectsAllowed(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setMaximumRedirectsAllowed(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMaximumRedirectsAllowed", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMaximumRedirectsAllowed(int)
            cppSelf->setMaximumRedirectsAllowed(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkRequestFunc_setOriginatingObject(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkRequest::setOriginatingObject(QObject*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArg)))) {
        overloadId = 0; // setOriginatingObject(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOriginatingObject", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QObject *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOriginatingObject(QObject*)
            cppSelf->setOriginatingObject(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkRequestFunc_setPeerVerifyName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkRequest::setPeerVerifyName(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setPeerVerifyName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPeerVerifyName", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPeerVerifyName(QString)
            cppSelf->setPeerVerifyName(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkRequestFunc_setPriority(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkRequest::setPriority(QNetworkRequest::Priority)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_Priority_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setPriority(QNetworkRequest::Priority)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPriority", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]);

    // Call function/method
    {
        ::QNetworkRequest::Priority cppArg0 = static_cast< ::QNetworkRequest::Priority>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPriority(QNetworkRequest::Priority)
            cppSelf->setPriority(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkRequestFunc_setRawHeader(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setRawHeader", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QNetworkRequest::setRawHeader(QByteArray,QByteArray)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
        overloadId = 0; // setRawHeader(QByteArray,QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setRawHeader", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QByteArray cppArg1_local;
        ::QByteArray *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setRawHeader(QByteArray,QByteArray)
            cppSelf->setRawHeader(*cppArg0, *cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkRequestFunc_setSslConfiguration(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkRequest::setSslConfiguration(QSslConfiguration)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslConfiguration_IDX]), (pyArg)))) {
        overloadId = 0; // setSslConfiguration(QSslConfiguration)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSslConfiguration", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSslConfiguration cppArg0_local;
        ::QSslConfiguration *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setSslConfiguration(QSslConfiguration)
            cppSelf->setSslConfiguration(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkRequestFunc_setTransferTimeout(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkRequest::setTransferTimeout(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setTransferTimeout(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTransferTimeout", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTransferTimeout(int)
            cppSelf->setTransferTimeout(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkRequestFunc_setUrl(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkRequest::setUrl(QUrl)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // setUrl(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUrl", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setUrl(QUrl)
            cppSelf->setUrl(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkRequestFunc_sslConfiguration(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sslConfiguration()const
        QSslConfiguration cppResult = const_cast<const ::QNetworkRequest *>(cppSelf)->sslConfiguration();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslConfiguration_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkRequestFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkRequest::swap(QNetworkRequest&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QNetworkRequest&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QNetworkRequest cppArg0_local;
        ::QNetworkRequest *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QNetworkRequest&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkRequestFunc_transferTimeout(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // transferTimeout()const
        int cppResult = const_cast<const ::QNetworkRequest *>(cppSelf)->transferTimeout();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkRequestFunc_url(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // url()const
        QUrl cppResult = const_cast<const ::QNetworkRequest *>(cppSelf)->url();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkRequest__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QNetworkRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QNetworkRequest_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QNetworkRequest_EnumFlagInfo[] = {
    "Attribute:Enum",
    "CacheLoadControl:Enum",
    "KnownHeaders:Enum",
    "LoadControl:Enum",
    "Priority:Enum",
    "RedirectPolicy:Enum",
    "TransferTimeoutConstant:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QNetworkRequest_methods[] = {
    {"attribute", reinterpret_cast<PyCFunction>(Sbk_QNetworkRequestFunc_attribute), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"decompressedSafetyCheckThreshold", reinterpret_cast<PyCFunction>(Sbk_QNetworkRequestFunc_decompressedSafetyCheckThreshold), METH_NOARGS, nullptr},
    {"hasRawHeader", reinterpret_cast<PyCFunction>(Sbk_QNetworkRequestFunc_hasRawHeader), METH_O, nullptr},
    {"header", reinterpret_cast<PyCFunction>(Sbk_QNetworkRequestFunc_header), METH_O, nullptr},
    {"headers", reinterpret_cast<PyCFunction>(Sbk_QNetworkRequestFunc_headers), METH_NOARGS, nullptr},
    {"http1Configuration", reinterpret_cast<PyCFunction>(Sbk_QNetworkRequestFunc_http1Configuration), METH_NOARGS, nullptr},
    {"http2Configuration", reinterpret_cast<PyCFunction>(Sbk_QNetworkRequestFunc_http2Configuration), METH_NOARGS, nullptr},
    {"maximumRedirectsAllowed", reinterpret_cast<PyCFunction>(Sbk_QNetworkRequestFunc_maximumRedirectsAllowed), METH_NOARGS, nullptr},
    {"originatingObject", reinterpret_cast<PyCFunction>(Sbk_QNetworkRequestFunc_originatingObject), METH_NOARGS, nullptr},
    {"peerVerifyName", reinterpret_cast<PyCFunction>(Sbk_QNetworkRequestFunc_peerVerifyName), METH_NOARGS, nullptr},
    {"priority", reinterpret_cast<PyCFunction>(Sbk_QNetworkRequestFunc_priority), METH_NOARGS, nullptr},
    {"rawHeader", reinterpret_cast<PyCFunction>(Sbk_QNetworkRequestFunc_rawHeader), METH_O, nullptr},
    {"rawHeaderList", reinterpret_cast<PyCFunction>(Sbk_QNetworkRequestFunc_rawHeaderList), METH_NOARGS, nullptr},
    {"setAttribute", reinterpret_cast<PyCFunction>(Sbk_QNetworkRequestFunc_setAttribute), METH_VARARGS, nullptr},
    {"setDecompressedSafetyCheckThreshold", reinterpret_cast<PyCFunction>(Sbk_QNetworkRequestFunc_setDecompressedSafetyCheckThreshold), METH_O, nullptr},
    {"setHeader", reinterpret_cast<PyCFunction>(Sbk_QNetworkRequestFunc_setHeader), METH_VARARGS, nullptr},
    {"setHeaders", reinterpret_cast<PyCFunction>(Sbk_QNetworkRequestFunc_setHeaders), METH_O, nullptr},
    {"setHttp1Configuration", reinterpret_cast<PyCFunction>(Sbk_QNetworkRequestFunc_setHttp1Configuration), METH_O, nullptr},
    {"setHttp2Configuration", reinterpret_cast<PyCFunction>(Sbk_QNetworkRequestFunc_setHttp2Configuration), METH_O, nullptr},
    {"setMaximumRedirectsAllowed", reinterpret_cast<PyCFunction>(Sbk_QNetworkRequestFunc_setMaximumRedirectsAllowed), METH_O, nullptr},
    {"setOriginatingObject", reinterpret_cast<PyCFunction>(Sbk_QNetworkRequestFunc_setOriginatingObject), METH_O, nullptr},
    {"setPeerVerifyName", reinterpret_cast<PyCFunction>(Sbk_QNetworkRequestFunc_setPeerVerifyName), METH_O, nullptr},
    {"setPriority", reinterpret_cast<PyCFunction>(Sbk_QNetworkRequestFunc_setPriority), METH_O, nullptr},
    {"setRawHeader", reinterpret_cast<PyCFunction>(Sbk_QNetworkRequestFunc_setRawHeader), METH_VARARGS, nullptr},
    {"setSslConfiguration", reinterpret_cast<PyCFunction>(Sbk_QNetworkRequestFunc_setSslConfiguration), METH_O, nullptr},
    {"setTransferTimeout", reinterpret_cast<PyCFunction>(Sbk_QNetworkRequestFunc_setTransferTimeout), METH_O, nullptr},
    {"setUrl", reinterpret_cast<PyCFunction>(Sbk_QNetworkRequestFunc_setUrl), METH_O, nullptr},
    {"sslConfiguration", reinterpret_cast<PyCFunction>(Sbk_QNetworkRequestFunc_sslConfiguration), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QNetworkRequestFunc_swap), METH_O, nullptr},
    {"transferTimeout", reinterpret_cast<PyCFunction>(Sbk_QNetworkRequestFunc_transferTimeout), METH_NOARGS, nullptr},
    {"url", reinterpret_cast<PyCFunction>(Sbk_QNetworkRequestFunc_url), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QNetworkRequest__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QNetworkRequest_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QNetworkRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), (pyArg)))) {
                // operator!=(const QNetworkRequest &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QNetworkRequest cppArg0_local;
                ::QNetworkRequest *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), (pyArg)))) {
                // operator==(const QNetworkRequest &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QNetworkRequest cppArg0_local;
                ::QNetworkRequest *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QNetworkRequest_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QNetworkRequest_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QNetworkRequest_Type = nullptr;
static PyTypeObject *Sbk_QNetworkRequest_TypeF(void)
{
    return _Sbk_QNetworkRequest_Type;
}

static PyType_Slot Sbk_QNetworkRequest_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QNetworkRequest_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QNetworkRequest_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QNetworkRequest_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QNetworkRequest_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QNetworkRequest_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QNetworkRequest_spec = {
    "2:PySide6.QtNetwork.QNetworkRequest",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QNetworkRequest_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QNetworkRequest_KnownHeaders(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QNetworkRequest::KnownHeaders>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QNetworkRequest::KnownHeaders *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QNetworkRequest_KnownHeaders_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_KnownHeaders_IDX])))
        return Enum_PythonToCpp_QNetworkRequest_KnownHeaders;
    return {};
}

static PyObject *QNetworkRequest_KnownHeaders_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QNetworkRequest::KnownHeaders>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QNetworkRequest::KnownHeaders *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_KnownHeaders_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QNetworkRequest_Attribute(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QNetworkRequest::Attribute>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QNetworkRequest::Attribute *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QNetworkRequest_Attribute_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_Attribute_IDX])))
        return Enum_PythonToCpp_QNetworkRequest_Attribute;
    return {};
}

static PyObject *QNetworkRequest_Attribute_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QNetworkRequest::Attribute>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QNetworkRequest::Attribute *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_Attribute_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QNetworkRequest_CacheLoadControl(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QNetworkRequest::CacheLoadControl>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QNetworkRequest::CacheLoadControl *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QNetworkRequest_CacheLoadControl_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_CacheLoadControl_IDX])))
        return Enum_PythonToCpp_QNetworkRequest_CacheLoadControl;
    return {};
}

static PyObject *QNetworkRequest_CacheLoadControl_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QNetworkRequest::CacheLoadControl>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QNetworkRequest::CacheLoadControl *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_CacheLoadControl_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QNetworkRequest_LoadControl(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QNetworkRequest::LoadControl>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QNetworkRequest::LoadControl *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QNetworkRequest_LoadControl_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_LoadControl_IDX])))
        return Enum_PythonToCpp_QNetworkRequest_LoadControl;
    return {};
}

static PyObject *QNetworkRequest_LoadControl_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QNetworkRequest::LoadControl>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QNetworkRequest::LoadControl *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_LoadControl_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QNetworkRequest_Priority(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QNetworkRequest::Priority>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QNetworkRequest::Priority *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QNetworkRequest_Priority_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_Priority_IDX])))
        return Enum_PythonToCpp_QNetworkRequest_Priority;
    return {};
}

static PyObject *QNetworkRequest_Priority_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QNetworkRequest::Priority>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QNetworkRequest::Priority *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_Priority_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QNetworkRequest_RedirectPolicy(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QNetworkRequest::RedirectPolicy>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QNetworkRequest::RedirectPolicy *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QNetworkRequest_RedirectPolicy_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_RedirectPolicy_IDX])))
        return Enum_PythonToCpp_QNetworkRequest_RedirectPolicy;
    return {};
}

static PyObject *QNetworkRequest_RedirectPolicy_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QNetworkRequest::RedirectPolicy>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QNetworkRequest::RedirectPolicy *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_RedirectPolicy_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QNetworkRequest_TransferTimeoutConstant(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QNetworkRequest::TransferTimeoutConstant>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QNetworkRequest::TransferTimeoutConstant *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QNetworkRequest_TransferTimeoutConstant_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_TransferTimeoutConstant_IDX])))
        return Enum_PythonToCpp_QNetworkRequest_TransferTimeoutConstant;
    return {};
}

static PyObject *QNetworkRequest_TransferTimeoutConstant_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QNetworkRequest::TransferTimeoutConstant>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QNetworkRequest::TransferTimeoutConstant *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_TransferTimeoutConstant_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QNetworkRequest_PythonToCpp_QNetworkRequest_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QNetworkRequest_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QNetworkRequest_PythonToCpp_QNetworkRequest_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QNetworkRequest_TypeF()))
        return QNetworkRequest_PythonToCpp_QNetworkRequest_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QNetworkRequest_PTR_CppToPython_QNetworkRequest(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QNetworkRequest_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QNetworkRequest_COPY_CppToPython_QNetworkRequest(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QNetworkRequest *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QNetworkRequest_TypeF(), new ::QNetworkRequest(*source), true, true);
}

// Python to C++ copy conversion.
static void QNetworkRequest_PythonToCpp_QNetworkRequest_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QNetworkRequest *>(cppOut) = *reinterpret_cast< ::QNetworkRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QNetworkRequest_PythonToCpp_QNetworkRequest_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QNetworkRequest_TypeF()))
        return QNetworkRequest_PythonToCpp_QNetworkRequest_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QNetworkRequest_SignatureStrings[] = {
    "2:PySide6.QtNetwork.QNetworkRequest(self)",
    "1:PySide6.QtNetwork.QNetworkRequest(self,other:PySide6.QtNetwork.QNetworkRequest)",
    "0:PySide6.QtNetwork.QNetworkRequest(self,url:typing.Union[PySide6.QtCore.QUrl, QString])",
    "PySide6.QtNetwork.QNetworkRequest.attribute(self,code:PySide6.QtNetwork.QNetworkRequest.Attribute,defaultValue:QVariant=QVariant())->QVariant",
    "PySide6.QtNetwork.QNetworkRequest.decompressedSafetyCheckThreshold(self)->qint64",
    "PySide6.QtNetwork.QNetworkRequest.hasRawHeader(self,headerName:QString)->bool",
    "PySide6.QtNetwork.QNetworkRequest.header(self,header:PySide6.QtNetwork.QNetworkRequest.KnownHeaders)->QVariant",
    "PySide6.QtNetwork.QNetworkRequest.headers(self)->PySide6.QtNetwork.QHttpHeaders",
    "PySide6.QtNetwork.QNetworkRequest.http1Configuration(self)->PySide6.QtNetwork.QHttp1Configuration",
    "PySide6.QtNetwork.QNetworkRequest.http2Configuration(self)->PySide6.QtNetwork.QHttp2Configuration",
    "PySide6.QtNetwork.QNetworkRequest.maximumRedirectsAllowed(self)->int",
    "PySide6.QtNetwork.QNetworkRequest.originatingObject(self)->PySide6.QtCore.QObject",
    "PySide6.QtNetwork.QNetworkRequest.peerVerifyName(self)->QString",
    "PySide6.QtNetwork.QNetworkRequest.priority(self)->PySide6.QtNetwork.QNetworkRequest.Priority",
    "PySide6.QtNetwork.QNetworkRequest.rawHeader(self,headerName:QString)->PySide6.QtCore.QByteArray",
    "PySide6.QtNetwork.QNetworkRequest.rawHeaderList(self)->QList[PySide6.QtCore.QByteArray]",
    "PySide6.QtNetwork.QNetworkRequest.setAttribute(self,code:PySide6.QtNetwork.QNetworkRequest.Attribute,value:QVariant)",
    "PySide6.QtNetwork.QNetworkRequest.setDecompressedSafetyCheckThreshold(self,threshold:qint64)",
    "PySide6.QtNetwork.QNetworkRequest.setHeader(self,header:PySide6.QtNetwork.QNetworkRequest.KnownHeaders,value:QVariant)",
    "PySide6.QtNetwork.QNetworkRequest.setHeaders(self,newHeaders:PySide6.QtNetwork.QHttpHeaders)",
    "PySide6.QtNetwork.QNetworkRequest.setHttp1Configuration(self,configuration:PySide6.QtNetwork.QHttp1Configuration)",
    "PySide6.QtNetwork.QNetworkRequest.setHttp2Configuration(self,configuration:PySide6.QtNetwork.QHttp2Configuration)",
    "PySide6.QtNetwork.QNetworkRequest.setMaximumRedirectsAllowed(self,maximumRedirectsAllowed:int)",
    "PySide6.QtNetwork.QNetworkRequest.setOriginatingObject(self,object:PySide6.QtCore.QObject)",
    "PySide6.QtNetwork.QNetworkRequest.setPeerVerifyName(self,peerName:QString)",
    "PySide6.QtNetwork.QNetworkRequest.setPriority(self,priority:PySide6.QtNetwork.QNetworkRequest.Priority)",
    "PySide6.QtNetwork.QNetworkRequest.setRawHeader(self,headerName:typing.Union[PySide6.QtCore.QByteArray, char*],value:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "PySide6.QtNetwork.QNetworkRequest.setSslConfiguration(self,configuration:PySide6.QtNetwork.QSslConfiguration)",
    "PySide6.QtNetwork.QNetworkRequest.setTransferTimeout(self,timeout:int)",
    "PySide6.QtNetwork.QNetworkRequest.setUrl(self,url:typing.Union[PySide6.QtCore.QUrl, QString])",
    "PySide6.QtNetwork.QNetworkRequest.sslConfiguration(self)->PySide6.QtNetwork.QSslConfiguration",
    "PySide6.QtNetwork.QNetworkRequest.swap(self,other:PySide6.QtNetwork.QNetworkRequest)",
    "PySide6.QtNetwork.QNetworkRequest.transferTimeout(self)->int",
    "PySide6.QtNetwork.QNetworkRequest.url(self)->PySide6.QtCore.QUrl",
    "PySide6.QtNetwork.QNetworkRequest.__copy__(self)->typing.Self",
    "PySide6.QtNetwork.QNetworkRequest.__ne__(self,other:PySide6.QtNetwork.QNetworkRequest)->bool",
    "PySide6.QtNetwork.QNetworkRequest.__eq__(self,other:PySide6.QtNetwork.QNetworkRequest)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QNetworkRequest_SignatureByteSize = 600;
static constexpr uint8_t QNetworkRequest_SignatureBytes[600] = {
    0x78, 0xda, 0xb5, 0x96, 0xdf, 0x6f, 0x9b, 0x30, 0x10, 0xc7, 0xdf, 0xf3, 0x57, 0xf4, 0xb1, 0x4c,
    0x14, 0xad, 0xd1, 0xd4, 0x07, 0xa4, 0x55, 0xca, 0xd2, 0x87, 0x48, 0xdb, 0xda, 0x90, 0xa4, 0x79,
    0xa9, 0x22, 0xe4, 0xc0, 0x11, 0xbc, 0x82, 0x4d, 0xec, 0x63, 0x19, 0xff, 0xfd, 0x9c, 0x02, 0x69,
    0x7e, 0x90, 0xe4, 0x48, 0xd5, 0x37, 0x1b, 0xee, 0x3e, 0x77, 0x3e, 0x9f, 0xbf, 0x76, 0xd7, 0x1d,
    0x16, 0x63, 0x1e, 0xc2, 0x9d, 0xe3, 0xe1, 0x23, 0xe0, 0x4a, 0xaa, 0x57, 0xc7, 0xab, 0x06, 0x23,
    0x58, 0xe6, 0xa0, 0xf1, 0x5a, 0x43, 0x12, 0x59, 0x9d, 0x5b, 0xa2, 0xa5, 0x2d, 0x31, 0x06, 0x75,
    0xde, 0xd8, 0xea, 0x7c, 0xa5, 0x12, 0x73, 0x95, 0xb8, 0x58, 0x64, 0x5c, 0x2c, 0x9c, 0x67, 0xc1,
    0xa5, 0x78, 0x79, 0xf7, 0xeb, 0x4b, 0x05, 0x8e, 0xf7, 0xac, 0x12, 0xfb, 0xca, 0x1b, 0xa3, 0x32,
    0x26, 0x33, 0xab, 0x73, 0x16, 0xeb, 0x30, 0x34, 0xb6, 0xf3, 0x1c, 0xa1, 0x0c, 0x10, 0xc8, 0x10,
    0xce, 0x27, 0xe3, 0xf4, 0x6a, 0x2f, 0x3b, 0x84, 0x88, 0xe5, 0x09, 0x4e, 0x59, 0x92, 0x83, 0xeb,
    0x4d, 0x99, 0xe2, 0x4c, 0xe0, 0xf7, 0x7a, 0x70, 0x6d, 0x59, 0x37, 0xf7, 0xf5, 0x84, 0x90, 0x4d,
    0x08, 0x81, 0x4c, 0x33, 0x05, 0x5a, 0x43, 0x38, 0x66, 0x11, 0x60, 0xd1, 0x8f, 0x21, 0x78, 0x9d,
    0xc4, 0xe6, 0x53, 0x2c, 0x93, 0xb0, 0xdc, 0x81, 0x9b, 0xfb, 0x25, 0x17, 0x78, 0xf7, 0x8d, 0x00,
    0x8c, 0x99, 0x1e, 0xb1, 0xd5, 0x00, 0x58, 0x08, 0xaa, 0x5c, 0x61, 0xfc, 0x36, 0x7e, 0x64, 0xa9,
    0x49, 0xb7, 0xac, 0x93, 0xe1, 0xcd, 0xa5, 0x4c, 0x28, 0xb4, 0x03, 0x0e, 0xa1, 0x56, 0x3f, 0x85,
    0x5c, 0x89, 0x32, 0x03, 0xdd, 0xae, 0x1a, 0x65, 0x08, 0x5d, 0x2f, 0xba, 0xc1, 0x61, 0x80, 0x98,
    0x55, 0x68, 0x0a, 0xcf, 0x58, 0xdf, 0xf6, 0xa5, 0x88, 0xf8, 0x22, 0x57, 0x0c, 0x4d, 0xff, 0x9c,
    0x41, 0xef, 0x1a, 0x13, 0x23, 0x74, 0xdb, 0x44, 0xe8, 0xb6, 0x8d, 0x90, 0xb2, 0x7f, 0x3c, 0xcd,
    0xd3, 0x11, 0x84, 0x5c, 0x41, 0x80, 0xba, 0x97, 0x24, 0x72, 0x05, 0x9b, 0xc6, 0xe0, 0xa4, 0xc2,
    0x4a, 0xc5, 0x17, 0x5c, 0x98, 0x90, 0x62, 0xf1, 0x34, 0xff, 0x63, 0x30, 0x87, 0x59, 0x96, 0xc7,
    0xa9, 0xfc, 0x4b, 0x20, 0x66, 0x00, 0x6a, 0x0a, 0x8a, 0x47, 0xc5, 0xba, 0xb3, 0x6a, 0x5c, 0xd5,
    0x60, 0x14, 0x7f, 0xc5, 0x4d, 0x52, 0x58, 0x9c, 0x28, 0xd7, 0x9e, 0xc7, 0xb0, 0xf2, 0x20, 0xc0,
    0x15, 0xe1, 0x04, 0xec, 0xaf, 0xfc, 0x47, 0x81, 0xd0, 0x53, 0x8a, 0xb5, 0xe2, 0xff, 0xe2, 0x7a,
    0x53, 0x4a, 0x6f, 0x3d, 0x79, 0x39, 0x8a, 0x9d, 0x11, 0xb8, 0x1a, 0xb0, 0xf7, 0x41, 0x79, 0xfa,
    0xbb, 0xa3, 0x4b, 0x16, 0x2d, 0xe8, 0x03, 0x45, 0x85, 0x6c, 0xac, 0xa7, 0x6e, 0xa9, 0x46, 0x44,
    0xf8, 0xe0, 0xa3, 0x1a, 0x72, 0xd9, 0x9a, 0x06, 0x5b, 0x5a, 0x62, 0x0b, 0xa8, 0x36, 0x4c, 0xbb,
    0xa7, 0x45, 0x85, 0x0a, 0x6f, 0x16, 0x16, 0xb3, 0x5d, 0x5b, 0x9f, 0x5c, 0x92, 0xc8, 0xb4, 0x88,
    0xd8, 0xbd, 0x34, 0x62, 0xf7, 0x92, 0x88, 0xbf, 0x4f, 0x08, 0x8f, 0x7d, 0x44, 0x95, 0x5c, 0x4e,
    0xde, 0x9f, 0xa7, 0x46, 0x49, 0xb2, 0xe5, 0xdb, 0xd8, 0x6d, 0xd6, 0x25, 0x22, 0x7a, 0x78, 0xa8,
    0x4d, 0xf6, 0x5a, 0xaf, 0x76, 0x14, 0x80, 0x88, 0xda, 0x96, 0x29, 0xbb, 0x16, 0x2d, 0x97, 0xae,
    0x56, 0xc4, 0x38, 0xc7, 0xef, 0xec, 0x93, 0xaf, 0x9f, 0x8d, 0xba, 0xd8, 0x57, 0x41, 0xcc, 0xd4,
    0x97, 0x59, 0x75, 0x56, 0xda, 0x39, 0x11, 0x73, 0x1c, 0xeb, 0xe4, 0x92, 0x06, 0xdc, 0x77, 0x23,
    0x46, 0x9b, 0x28, 0x26, 0x74, 0x04, 0x6a, 0xc2, 0x53, 0x90, 0x79, 0xd5, 0x1d, 0x58, 0x4e, 0x5a,
    0xb4, 0x99, 0x79, 0x1f, 0x7e, 0xd6, 0x4b, 0x52, 0x37, 0xd5, 0xa3, 0xf9, 0x2a, 0xdb, 0xaf, 0x01,
    0x85, 0xbe, 0x62, 0x59, 0xcb, 0x57, 0xf5, 0x79, 0x28, 0x36, 0x14, 0x95, 0xfc, 0x88, 0xc8, 0xab,
    0x52, 0x36, 0x5c, 0x9e, 0xa6, 0x76, 0x04, 0x80, 0xef, 0x07, 0x32, 0x2b, 0x7c, 0xbf, 0xa6, 0x54,
    0xdb, 0x31, 0x36, 0x33, 0x92, 0xb7, 0x80, 0xca, 0x97, 0x5c, 0x12, 0xf2, 0x43, 0xd7, 0xf7, 0x61,
    0x79, 0x21, 0xfc, 0x3f, 0x94, 0xa5, 0xf4, 0x84
};
#endif

PyTypeObject *init_QNetworkRequest(PyObject *module)
{
    if (SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX].type != nullptr)
        return SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX].type;

    Shiboken::AutoDecRef Sbk_QNetworkRequest_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QNetworkRequest_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QNetworkRequest",
        "QNetworkRequest",
        &Sbk_QNetworkRequest_spec,
        &Shiboken::callCppDestructor< ::QNetworkRequest >,
        Sbk_QNetworkRequest_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QNetworkRequest_TypeF(); // references _Sbk_QNetworkRequest_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QNetworkRequest_SignatureStrings);
#else
    InitSignatureBytes(pyType, QNetworkRequest_SignatureBytes, QNetworkRequest_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QNetworkRequest_PropertyStrings);
    SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QNetworkRequest_PythonToCpp_QNetworkRequest_PTR,
        is_QNetworkRequest_PythonToCpp_QNetworkRequest_PTR_Convertible,
        QNetworkRequest_PTR_CppToPython_QNetworkRequest,
        QNetworkRequest_COPY_CppToPython_QNetworkRequest);

    Shiboken::Conversions::registerConverterName(converter, "QNetworkRequest");
    Shiboken::Conversions::registerConverterName(converter, "QNetworkRequest*");
    Shiboken::Conversions::registerConverterName(converter, "QNetworkRequest&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QNetworkRequest).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QNetworkRequest_PythonToCpp_QNetworkRequest_COPY,
        is_QNetworkRequest_PythonToCpp_QNetworkRequest_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QNetworkRequest_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'KnownHeaders'.
    const char *KnownHeaders_Initializer[] = {
        "ContentTypeHeader",
        "ContentLengthHeader",
        "LocationHeader",
        "LastModifiedHeader",
        "CookieHeader",
        "SetCookieHeader",
        "ContentDispositionHeader",
        "UserAgentHeader",
        "ServerHeader",
        "IfModifiedSinceHeader",
        "ETagHeader",
        "IfMatchHeader",
        "IfNoneMatchHeader",
        "NumKnownHeaders",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t KnownHeaders_InitializerValues[] = {
        uint8_t(QNetworkRequest::KnownHeaders::ContentTypeHeader),        //  0x00  0
        uint8_t(QNetworkRequest::KnownHeaders::ContentLengthHeader),      //  0x01  1
        uint8_t(QNetworkRequest::KnownHeaders::LocationHeader),           //  0x02  2
        uint8_t(QNetworkRequest::KnownHeaders::LastModifiedHeader),       //  0x03  3
        uint8_t(QNetworkRequest::KnownHeaders::CookieHeader),             //  0x04  4
        uint8_t(QNetworkRequest::KnownHeaders::SetCookieHeader),          //  0x05  5
        uint8_t(QNetworkRequest::KnownHeaders::ContentDispositionHeader), //  0x06  6
        uint8_t(QNetworkRequest::KnownHeaders::UserAgentHeader),          //  0x07  7
        uint8_t(QNetworkRequest::KnownHeaders::ServerHeader),             //  0x08  8
        uint8_t(QNetworkRequest::KnownHeaders::IfModifiedSinceHeader),    //  0x09  9
        uint8_t(QNetworkRequest::KnownHeaders::ETagHeader),               //  0x0a  10
        uint8_t(QNetworkRequest::KnownHeaders::IfMatchHeader),            //  0x0b  11
        uint8_t(QNetworkRequest::KnownHeaders::IfNoneMatchHeader),        //  0x0c  12
        uint8_t(QNetworkRequest::KnownHeaders::NumKnownHeaders)           //  0x0d  13
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QNetworkRequest_TypeF(),
        "2:PySide6.QtNetwork.QNetworkRequest.KnownHeaders",
        KnownHeaders_Initializer, KnownHeaders_InitializerValues);
    SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_KnownHeaders_IDX].type = EType;
    // Register converter for enum 'QNetworkRequest::KnownHeaders'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QNetworkRequest_KnownHeaders_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QNetworkRequest_KnownHeaders,
            is_Enum_PythonToCpp_QNetworkRequest_KnownHeaders_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QNetworkRequest::KnownHeaders");
        Shiboken::Conversions::registerConverterAlias(converter, "KnownHeaders");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'KnownHeaders' enum.

    // Initialization of enum 'Attribute'.
    const char *Attribute_Initializer[] = {
        "HttpStatusCodeAttribute",
        "HttpReasonPhraseAttribute",
        "RedirectionTargetAttribute",
        "ConnectionEncryptedAttribute",
        "CacheLoadControlAttribute",
        "CacheSaveControlAttribute",
        "SourceIsFromCacheAttribute",
        "DoNotBufferUploadDataAttribute",
        "HttpPipeliningAllowedAttribute",
        "HttpPipeliningWasUsedAttribute",
        "CustomVerbAttribute",
        "CookieLoadControlAttribute",
        "AuthenticationReuseAttribute",
        "CookieSaveControlAttribute",
        "MaximumDownloadBufferSizeAttribute",
        "DownloadBufferAttribute",
        "SynchronousRequestAttribute",
        "BackgroundRequestAttribute",
        "EmitAllUploadProgressSignalsAttribute",
        "Http2AllowedAttribute",
        "Http2WasUsedAttribute",
        "OriginalContentLengthAttribute",
        "RedirectPolicyAttribute",
        "Http2DirectAttribute",
        "ResourceTypeAttribute",
        "AutoDeleteReplyOnFinishAttribute",
        "ConnectionCacheExpiryTimeoutSecondsAttribute",
        "Http2CleartextAllowedAttribute",
        "UseCredentialsAttribute",
        "FullLocalServerNameAttribute",
        "User",
        "UserMax",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t Attribute_InitializerValues[] = {
        uint16_t(QNetworkRequest::Attribute::HttpStatusCodeAttribute),                      //  0x0000  0
        uint16_t(QNetworkRequest::Attribute::HttpReasonPhraseAttribute),                    //  0x0001  1
        uint16_t(QNetworkRequest::Attribute::RedirectionTargetAttribute),                   //  0x0002  2
        uint16_t(QNetworkRequest::Attribute::ConnectionEncryptedAttribute),                 //  0x0003  3
        uint16_t(QNetworkRequest::Attribute::CacheLoadControlAttribute),                    //  0x0004  4
        uint16_t(QNetworkRequest::Attribute::CacheSaveControlAttribute),                    //  0x0005  5
        uint16_t(QNetworkRequest::Attribute::SourceIsFromCacheAttribute),                   //  0x0006  6
        uint16_t(QNetworkRequest::Attribute::DoNotBufferUploadDataAttribute),               //  0x0007  7
        uint16_t(QNetworkRequest::Attribute::HttpPipeliningAllowedAttribute),               //  0x0008  8
        uint16_t(QNetworkRequest::Attribute::HttpPipeliningWasUsedAttribute),               //  0x0009  9
        uint16_t(QNetworkRequest::Attribute::CustomVerbAttribute),                          //  0x000a  10
        uint16_t(QNetworkRequest::Attribute::CookieLoadControlAttribute),                   //  0x000b  11
        uint16_t(QNetworkRequest::Attribute::AuthenticationReuseAttribute),                 //  0x000c  12
        uint16_t(QNetworkRequest::Attribute::CookieSaveControlAttribute),                   //  0x000d  13
        uint16_t(QNetworkRequest::Attribute::MaximumDownloadBufferSizeAttribute),           //  0x000e  14
        uint16_t(QNetworkRequest::Attribute::DownloadBufferAttribute),                      //  0x000f  15
        uint16_t(QNetworkRequest::Attribute::SynchronousRequestAttribute),                  //  0x0010  16
        uint16_t(QNetworkRequest::Attribute::BackgroundRequestAttribute),                   //  0x0011  17
        uint16_t(QNetworkRequest::Attribute::EmitAllUploadProgressSignalsAttribute),        //  0x0012  18
        uint16_t(QNetworkRequest::Attribute::Http2AllowedAttribute),                        //  0x0013  19
        uint16_t(QNetworkRequest::Attribute::Http2WasUsedAttribute),                        //  0x0014  20
        uint16_t(QNetworkRequest::Attribute::OriginalContentLengthAttribute),               //  0x0015  21
        uint16_t(QNetworkRequest::Attribute::RedirectPolicyAttribute),                      //  0x0016  22
        uint16_t(QNetworkRequest::Attribute::Http2DirectAttribute),                         //  0x0017  23
        uint16_t(QNetworkRequest::Attribute::ResourceTypeAttribute),                        //  0x0018  24
        uint16_t(QNetworkRequest::Attribute::AutoDeleteReplyOnFinishAttribute),             //  0x0019  25
        uint16_t(QNetworkRequest::Attribute::ConnectionCacheExpiryTimeoutSecondsAttribute), //  0x001a  26
        uint16_t(QNetworkRequest::Attribute::Http2CleartextAllowedAttribute),               //  0x001b  27
        uint16_t(QNetworkRequest::Attribute::UseCredentialsAttribute),                      //  0x001c  28
        uint16_t(QNetworkRequest::Attribute::FullLocalServerNameAttribute),                 //  0x001d  29
        uint16_t(QNetworkRequest::Attribute::User),                                         //  0x03e8  1000
        uint16_t(QNetworkRequest::Attribute::UserMax)                                       //  0x7fff  32767
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QNetworkRequest_TypeF(),
        "2:PySide6.QtNetwork.QNetworkRequest.Attribute",
        Attribute_Initializer, Attribute_InitializerValues);
    SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_Attribute_IDX].type = EType;
    // Register converter for enum 'QNetworkRequest::Attribute'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QNetworkRequest_Attribute_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QNetworkRequest_Attribute,
            is_Enum_PythonToCpp_QNetworkRequest_Attribute_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QNetworkRequest::Attribute");
        Shiboken::Conversions::registerConverterAlias(converter, "Attribute");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Attribute' enum.

    // Initialization of enum 'CacheLoadControl'.
    const char *CacheLoadControl_Initializer[] = {
        "AlwaysNetwork",
        "PreferNetwork",
        "PreferCache",
        "AlwaysCache",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t CacheLoadControl_InitializerValues[] = {
        uint8_t(QNetworkRequest::CacheLoadControl::AlwaysNetwork), //  0x00  0
        uint8_t(QNetworkRequest::CacheLoadControl::PreferNetwork), //  0x01  1
        uint8_t(QNetworkRequest::CacheLoadControl::PreferCache),   //  0x02  2
        uint8_t(QNetworkRequest::CacheLoadControl::AlwaysCache)    //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QNetworkRequest_TypeF(),
        "2:PySide6.QtNetwork.QNetworkRequest.CacheLoadControl",
        CacheLoadControl_Initializer, CacheLoadControl_InitializerValues);
    SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_CacheLoadControl_IDX].type = EType;
    // Register converter for enum 'QNetworkRequest::CacheLoadControl'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QNetworkRequest_CacheLoadControl_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QNetworkRequest_CacheLoadControl,
            is_Enum_PythonToCpp_QNetworkRequest_CacheLoadControl_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QNetworkRequest::CacheLoadControl");
        Shiboken::Conversions::registerConverterAlias(converter, "CacheLoadControl");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'CacheLoadControl' enum.

    // Initialization of enum 'LoadControl'.
    const char *LoadControl_Initializer[] = {
        "Automatic",
        "Manual",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t LoadControl_InitializerValues[] = {
        uint8_t(QNetworkRequest::LoadControl::Automatic), //  0x00  0
        uint8_t(QNetworkRequest::LoadControl::Manual)     //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QNetworkRequest_TypeF(),
        "2:PySide6.QtNetwork.QNetworkRequest.LoadControl",
        LoadControl_Initializer, LoadControl_InitializerValues);
    SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_LoadControl_IDX].type = EType;
    // Register converter for enum 'QNetworkRequest::LoadControl'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QNetworkRequest_LoadControl_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QNetworkRequest_LoadControl,
            is_Enum_PythonToCpp_QNetworkRequest_LoadControl_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QNetworkRequest::LoadControl");
        Shiboken::Conversions::registerConverterAlias(converter, "LoadControl");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'LoadControl' enum.

    // Initialization of enum 'Priority'.
    const char *Priority_Initializer[] = {
        "HighPriority",
        "NormalPriority",
        "LowPriority",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Priority_InitializerValues[] = {
        uint8_t(QNetworkRequest::Priority::HighPriority),   //  0x01  1
        uint8_t(QNetworkRequest::Priority::NormalPriority), //  0x03  3
        uint8_t(QNetworkRequest::Priority::LowPriority)     //  0x05  5
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QNetworkRequest_TypeF(),
        "2:PySide6.QtNetwork.QNetworkRequest.Priority",
        Priority_Initializer, Priority_InitializerValues);
    SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_Priority_IDX].type = EType;
    // Register converter for enum 'QNetworkRequest::Priority'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QNetworkRequest_Priority_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QNetworkRequest_Priority,
            is_Enum_PythonToCpp_QNetworkRequest_Priority_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QNetworkRequest::Priority");
        Shiboken::Conversions::registerConverterAlias(converter, "Priority");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Priority' enum.

    // Initialization of enum 'RedirectPolicy'.
    const char *RedirectPolicy_Initializer[] = {
        "ManualRedirectPolicy",
        "NoLessSafeRedirectPolicy",
        "SameOriginRedirectPolicy",
        "UserVerifiedRedirectPolicy",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t RedirectPolicy_InitializerValues[] = {
        uint8_t(QNetworkRequest::RedirectPolicy::ManualRedirectPolicy),      //  0x00  0
        uint8_t(QNetworkRequest::RedirectPolicy::NoLessSafeRedirectPolicy),  //  0x01  1
        uint8_t(QNetworkRequest::RedirectPolicy::SameOriginRedirectPolicy),  //  0x02  2
        uint8_t(QNetworkRequest::RedirectPolicy::UserVerifiedRedirectPolicy) //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QNetworkRequest_TypeF(),
        "2:PySide6.QtNetwork.QNetworkRequest.RedirectPolicy",
        RedirectPolicy_Initializer, RedirectPolicy_InitializerValues);
    SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_RedirectPolicy_IDX].type = EType;
    // Register converter for enum 'QNetworkRequest::RedirectPolicy'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QNetworkRequest_RedirectPolicy_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QNetworkRequest_RedirectPolicy,
            is_Enum_PythonToCpp_QNetworkRequest_RedirectPolicy_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QNetworkRequest::RedirectPolicy");
        Shiboken::Conversions::registerConverterAlias(converter, "RedirectPolicy");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'RedirectPolicy' enum.

    // Initialization of enum 'TransferTimeoutConstant'.
    const char *TransferTimeoutConstant_Initializer[] = {
        "DefaultTransferTimeoutConstant",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t TransferTimeoutConstant_InitializerValues[] = {
        uint16_t(QNetworkRequest::TransferTimeoutConstant::DefaultTransferTimeoutConstant) //  0x7530  30000
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QNetworkRequest_TypeF(),
        "2:PySide6.QtNetwork.QNetworkRequest.TransferTimeoutConstant",
        TransferTimeoutConstant_Initializer, TransferTimeoutConstant_InitializerValues);
    SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_TransferTimeoutConstant_IDX].type = EType;
    // Register converter for enum 'QNetworkRequest::TransferTimeoutConstant'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QNetworkRequest_TransferTimeoutConstant_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QNetworkRequest_TransferTimeoutConstant,
            is_Enum_PythonToCpp_QNetworkRequest_TransferTimeoutConstant_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QNetworkRequest::TransferTimeoutConstant");
        Shiboken::Conversions::registerConverterAlias(converter, "TransferTimeoutConstant");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'TransferTimeoutConstant' enum.

    qRegisterMetaType< ::QNetworkRequest >("QNetworkRequest");
    qRegisterMetaType< ::QNetworkRequest::KnownHeaders >("QNetworkRequest::KnownHeaders");
    qRegisterMetaType< ::QNetworkRequest::Attribute >("QNetworkRequest::Attribute");
    qRegisterMetaType< ::QNetworkRequest::CacheLoadControl >("QNetworkRequest::CacheLoadControl");
    qRegisterMetaType< ::QNetworkRequest::LoadControl >("QNetworkRequest::LoadControl");
    qRegisterMetaType< ::QNetworkRequest::Priority >("QNetworkRequest::Priority");
    qRegisterMetaType< ::QNetworkRequest::RedirectPolicy >("QNetworkRequest::RedirectPolicy");
    qRegisterMetaType< ::QNetworkRequest::TransferTimeoutConstant >("QNetworkRequest::TransferTimeoutConstant");

    return pyType;
}
