// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnetwork_python.h"

// main header
#include "qpassworddigestor_wrapper.h"

// Extra includes
#include <qpassworddigestor.h>

// Argument includes
#include <qbytearray.h>
#include <qcryptographichash.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QPasswordDigestorFunc_deriveKeyPbkdf1(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "deriveKeyPbkdf1", 5, 5, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QPasswordDigestor::deriveKeyPbkdf1(QCryptographicHash::Algorithm,QByteArray,QByteArray,int,quint64)->QByteArray
    if (numArgs == 5
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCryptographicHash_Algorithm_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyArgs[4])))) {
        overloadId = 0; // deriveKeyPbkdf1(QCryptographicHash::Algorithm,QByteArray,QByteArray,int,quint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "deriveKeyPbkdf1", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QtNetworkQPasswordDigestor_IDX]);

    // Call function/method
    {
        ::QCryptographicHash::Algorithm cppArg0{QCryptographicHash::Md4};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QByteArray cppArg1_local;
        ::QByteArray *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QByteArray cppArg2_local;
        ::QByteArray *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2].isValue())
            pythonToCpp[2](pyArgs[2], &cppArg2_local);
        else
            pythonToCpp[2](pyArgs[2], &cppArg2);

        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        quint64 cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);

        if (Shiboken::Errors::occurred() == nullptr) {
            // deriveKeyPbkdf1(QCryptographicHash::Algorithm,QByteArray,QByteArray,int,quint64)
            QByteArray cppResult = ::QPasswordDigestor::deriveKeyPbkdf1(cppArg0, *cppArg1, *cppArg2, cppArg3, cppArg4);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPasswordDigestorFunc_deriveKeyPbkdf2(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "deriveKeyPbkdf2", 5, 5, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QPasswordDigestor::deriveKeyPbkdf2(QCryptographicHash::Algorithm,QByteArray,QByteArray,int,quint64)->QByteArray
    if (numArgs == 5
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCryptographicHash_Algorithm_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyArgs[4])))) {
        overloadId = 0; // deriveKeyPbkdf2(QCryptographicHash::Algorithm,QByteArray,QByteArray,int,quint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "deriveKeyPbkdf2", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QtNetworkQPasswordDigestor_IDX]);

    // Call function/method
    {
        ::QCryptographicHash::Algorithm cppArg0{QCryptographicHash::Md4};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QByteArray cppArg1_local;
        ::QByteArray *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QByteArray cppArg2_local;
        ::QByteArray *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2].isValue())
            pythonToCpp[2](pyArgs[2], &cppArg2_local);
        else
            pythonToCpp[2](pyArgs[2], &cppArg2);

        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        quint64 cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);

        if (Shiboken::Errors::occurred() == nullptr) {
            // deriveKeyPbkdf2(QCryptographicHash::Algorithm,QByteArray,QByteArray,int,quint64)
            QByteArray cppResult = ::QPasswordDigestor::deriveKeyPbkdf2(cppArg0, *cppArg1, *cppArg2, cppArg3, cppArg4);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QPasswordDigestor_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QPasswordDigestor_methods[] = {
    {"deriveKeyPbkdf1", reinterpret_cast<PyCFunction>(Sbk_QPasswordDigestorFunc_deriveKeyPbkdf1), METH_VARARGS|METH_STATIC, nullptr},
    {"deriveKeyPbkdf2", reinterpret_cast<PyCFunction>(Sbk_QPasswordDigestorFunc_deriveKeyPbkdf2), METH_VARARGS|METH_STATIC, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QPasswordDigestor_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QPasswordDigestor_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QPasswordDigestor_Type = nullptr;
static PyTypeObject *Sbk_QPasswordDigestor_TypeF(void)
{
    return _Sbk_QPasswordDigestor_Type;
}

static PyType_Slot Sbk_QPasswordDigestor_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(Sbk_object_dealloc /* PYSIDE-832: Prevent replacement of "0" with subtype_dealloc. */)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QPasswordDigestor_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QPasswordDigestor_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QPasswordDigestor_methods)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QPasswordDigestor_spec = {
    "2:PySide6.QtNetwork.QPasswordDigestor",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QPasswordDigestor_slots
};

} //extern "C"

// Type conversion functions.

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QtNetworkQPasswordDigestor_SignatureStrings[] = {
    "PySide6.QtNetwork.QPasswordDigestor.deriveKeyPbkdf1(algorithm:PySide6.QtCore.QCryptographicHash.Algorithm,password:typing.Union[PySide6.QtCore.QByteArray, char*],salt:typing.Union[PySide6.QtCore.QByteArray, char*],iterations:int,dkLen:quint64)->PySide6.QtCore.QByteArray",
    "PySide6.QtNetwork.QPasswordDigestor.deriveKeyPbkdf2(algorithm:PySide6.QtCore.QCryptographicHash.Algorithm,password:typing.Union[PySide6.QtCore.QByteArray, char*],salt:typing.Union[PySide6.QtCore.QByteArray, char*],iterations:int,dkLen:quint64)->PySide6.QtCore.QByteArray",
    nullptr}; // Sentinel
#else
static constexpr size_t QtNetworkQPasswordDigestor_SignatureByteSize = 176;
static constexpr uint8_t QtNetworkQPasswordDigestor_SignatureBytes[176] = {
    0x78, 0xda, 0xdd, 0x90, 0xb1, 0x0a, 0xc2, 0x30, 0x14, 0x45, 0x77, 0xbf, 0xc2, 0x51, 0xa5, 0x06,
    0x14, 0xe9, 0xd0, 0x41, 0xa8, 0x75, 0x10, 0x14, 0x49, 0x11, 0x27, 0x71, 0x88, 0xcd, 0x33, 0x7d,
    0xb4, 0x26, 0xf5, 0xe5, 0xa9, 0xe4, 0xef, 0xed, 0xa0, 0x0e, 0x82, 0x43, 0x57, 0xb7, 0x3b, 0x9c,
    0x73, 0x86, 0x2b, 0xc3, 0x0e, 0x35, 0xc4, 0x22, 0xe7, 0x2d, 0xf0, 0xc3, 0x51, 0x25, 0x72, 0xa9,
    0xbc, 0x6f, 0x97, 0x5e, 0xa2, 0x01, 0xcf, 0x8e, 0x84, 0x06, 0xc2, 0x3b, 0xac, 0x21, 0xc8, 0x53,
    0xa5, 0xcf, 0x93, 0x81, 0xaa, 0x8d, 0x23, 0xe4, 0xf2, 0x92, 0xc8, 0x8f, 0x9d, 0x39, 0x02, 0x91,
    0x67, 0x14, 0x1a, 0x76, 0x86, 0x54, 0x53, 0x62, 0xb1, 0x52, 0xbe, 0x14, 0xe9, 0x9b, 0x8d, 0x9a,
    0x57, 0x36, 0xe1, 0xd0, 0xa0, 0x35, 0x62, 0x6f, 0xd1, 0xd9, 0xc3, 0x77, 0x61, 0x11, 0x18, 0x52,
    0x22, 0x15, 0xa2, 0x7e, 0x51, 0x2a, 0x1a, 0x1d, 0x23, 0xaf, 0x6a, 0xee, 0xea, 0x20, 0x03, 0x29,
    0x6e, 0x59, 0x9f, 0xa0, 0xe5, 0x48, 0x57, 0x1b, 0xb0, 0xc9, 0xf5, 0xd6, 0xee, 0x78, 0x36, 0x1c,
    0xcf, 0x7f, 0x06, 0x7a, 0xb2, 0xf3, 0x1d, 0xd3, 0x7f, 0xbe, 0xe3, 0x09, 0x32, 0xaf, 0xc7, 0x50
};
#endif

PyTypeObject *init_QtNetworkQPasswordDigestor(PyObject *module)
{
    if (SbkPySide6_QtNetworkTypeStructs[SBK_QtNetworkQPasswordDigestor_IDX].type != nullptr)
        return SbkPySide6_QtNetworkTypeStructs[SBK_QtNetworkQPasswordDigestor_IDX].type;

    Shiboken::AutoDecRef Sbk_QPasswordDigestor_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QPasswordDigestor_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QPasswordDigestor",
        "QPasswordDigestor",
        &Sbk_QPasswordDigestor_spec,
        nullptr,
        Sbk_QPasswordDigestor_Type_bases.object(),
        0);
    auto *pyType = Sbk_QPasswordDigestor_TypeF(); // references _Sbk_QPasswordDigestor_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QtNetworkQPasswordDigestor_SignatureStrings);
#else
    InitSignatureBytes(pyType, QtNetworkQPasswordDigestor_SignatureBytes, QtNetworkQPasswordDigestor_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QPasswordDigestor_PropertyStrings);
    SbkPySide6_QtNetworkTypeStructs[SBK_QtNetworkQPasswordDigestor_IDX].type = pyType;



    return pyType;
}
