// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnetwork_python.h"

// main header
#include "qrestaccessmanager_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QMap>
#include <QString>
#include <QtNetwork/qhttpmultipart.h>
#include <QtNetwork/qnetworkaccessmanager.h>
#include <QtNetwork/qnetworkreply.h>
#include <QtNetwork/qnetworkrequest.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qiodevice.h>
#include <qjsondocument.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Begin code injection
// ========================================================================
// START of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-functor)]
class QRestFunctor
{
public:
    explicit QRestFunctor(PyObject *callable) noexcept : m_callable(callable)
    {
        Py_INCREF(callable);
    }

    void operator()(QRestReply &restReply);

private:
    PyObject *m_callable;
};

void QRestFunctor::operator()(QRestReply &restReply)
{
    Q_ASSERT(m_callable);
    Shiboken::GilState state;
    Shiboken::AutoDecRef arglist(PyTuple_New(1));
    auto *restReplyPtr = &restReply;
    auto *pyRestReply = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QRestReply_IDX]), restReplyPtr);
    PyTuple_SetItem(arglist.object(), 0, pyRestReply);
    Shiboken::AutoDecRef ret(PyObject_CallObject(m_callable, arglist));
    Py_DECREF(m_callable);
    m_callable = nullptr;
}
// END of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-functor)]
// ========================================================================
// End of code injection


// Native ---------------------------------------------------------

void QRestAccessManagerWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QRestAccessManagerWrapper::QRestAccessManagerWrapper(::QNetworkAccessManager * manager, ::QObject * parent) : QRestAccessManager(manager, parent)
{
}

void QRestAccessManagerWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRestAccessManager", funcName);
        return;
    }
}

void QRestAccessManagerWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRestAccessManager", funcName);
        return;
    }
}

void QRestAccessManagerWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRestAccessManager", funcName);
        return;
    }
}

void QRestAccessManagerWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRestAccessManager", funcName);
        return;
    }
}

bool QRestAccessManagerWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRestAccessManager", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QRestAccessManager", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QRestAccessManagerWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRestAccessManager", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QRestAccessManager", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QRestAccessManagerWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRestAccessManager", funcName);
        return;
    }
}

const QMetaObject *QRestAccessManagerWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QRestAccessManager::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QRestAccessManagerWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QRestAccessManager::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QRestAccessManagerWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QRestAccessManagerWrapper *>(this));
    return QRestAccessManager::qt_metacast(_clname);
}

QRestAccessManagerWrapper::~QRestAccessManagerWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QRestAccessManager_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QRestAccessManager >()))
        return -1;

    QRestAccessManagerWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:QRestAccessManager", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QRestAccessManager::QRestAccessManager(QNetworkAccessManager*,QObject*=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAccessManager_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // QRestAccessManager(QNetworkAccessManager*,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 0; // QRestAccessManager(QNetworkAccessManager*,QObject*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QRestAccessManager_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtNetworkTypeStructs[SBK_QRestAccessManager_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QRestAccessManager_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QRestAccessManager_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                // fall through to handle extra keyword signals and properties
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QNetworkAccessManager *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return -1;
        ::QObject *cppArg1 = nullptr;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QRestAccessManager(QNetworkAccessManager*,QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QRestAccessManagerWrapper(cppArg0, cppArg1);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QRestAccessManagerWrapper(cppArg0, cppArg1);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[1], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QRestAccessManager >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QRestAccessManager_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QRestAccessManager_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QRestAccessManagerFunc_deleteResource(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRestAccessManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QRestAccessManager_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 2)
        return Shiboken::returnWrongArguments(args, "deleteResource", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QRestAccessManager_IDX]);

    if (PyArg_UnpackTuple(args, "deleteResource", 1, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRestAccessManager::deleteResource(QNetworkRequest,QObject*,PyCallable*)->QNetworkReply*
    // 1: QRestAccessManager::deleteResource(QNetworkRequest)->QNetworkReply*
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // deleteResource(QNetworkRequest)
        } else if (numArgs == 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))
            && PyCallable_Check(pyArgs[2])) {
            overloadId = 0; // deleteResource(QNetworkRequest,QObject*,PyCallable*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "deleteResource", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QRestAccessManager_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // deleteResource(QNetworkRequest request, QObject *context, PyCallable *slot)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QObject *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)

            if (Shiboken::Errors::occurred() == nullptr) {
                // deleteResource(QNetworkRequest,QObject*,PyCallable*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-callback)]
                auto *networkReply = cppSelf->deleteResource(cppArg0, cppArg1, QRestFunctor(pyArgs[3-1]));
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), networkReply);
                // END of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-callback)]
                // ========================================================================
                // End of code injection

                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 1: // deleteResource(const QNetworkRequest &request)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0_local;
            ::QNetworkRequest *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // deleteResource(QNetworkRequest)
                QNetworkReply * cppResult = cppSelf->deleteResource(*cppArg0);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), cppResult);
                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRestAccessManagerFunc_get(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRestAccessManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QRestAccessManager_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "get", 1, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRestAccessManager::get(QNetworkRequest,QByteArray,QObject*,PyCallable*)->QNetworkReply*
    // 1: QRestAccessManager::get(QNetworkRequest,QIODevice*,QObject*,PyCallable*)->QNetworkReply*
    // 2: QRestAccessManager::get(QNetworkRequest,QJsonDocument,QObject*,PyCallable*)->QNetworkReply*
    // 3: QRestAccessManager::get(QNetworkRequest,QObject*,PyCallable*)->QNetworkReply*
    // 4: QRestAccessManager::get(QNetworkRequest)->QNetworkReply*
    // 5: QRestAccessManager::get(QNetworkRequest,QIODevice*)->QNetworkReply*
    // 6: QRestAccessManager::get(QNetworkRequest,QByteArray)->QNetworkReply*
    // 7: QRestAccessManager::get(QNetworkRequest,QJsonDocument)->QNetworkReply*
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 4; // get(QNetworkRequest)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 7; // get(QNetworkRequest,QJsonDocument)
            } else if (numArgs == 4
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[2])))
                && PyCallable_Check(pyArgs[3])) {
                overloadId = 2; // get(QNetworkRequest,QJsonDocument,QObject*,PyCallable*)
            }
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 5; // get(QNetworkRequest,QIODevice*)
            } else if (numArgs == 4
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[2])))
                && PyCallable_Check(pyArgs[3])) {
                overloadId = 1; // get(QNetworkRequest,QIODevice*,QObject*,PyCallable*)
            }
        } else if (numArgs == 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))
            && PyCallable_Check(pyArgs[2])) {
            overloadId = 3; // get(QNetworkRequest,QObject*,PyCallable*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 6; // get(QNetworkRequest,QByteArray)
            } else if (numArgs == 4
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[2])))
                && PyCallable_Check(pyArgs[3])) {
                overloadId = 0; // get(QNetworkRequest,QByteArray,QObject*,PyCallable*)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "get", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QRestAccessManager_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // get(QNetworkRequest request, QByteArray data, QObject *context, PyCallable *slot)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QByteArray cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QObject *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            SBK_UNUSED(cppArg2)

            if (Shiboken::Errors::occurred() == nullptr) {
                // get(QNetworkRequest,QByteArray,QObject*,PyCallable*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-data-callback)]
                auto *networkReply = cppSelf->get(cppArg0, cppArg1, cppArg2, QRestFunctor(pyArgs[4-1]));
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), networkReply);
                // END of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-data-callback)]
                // ========================================================================
                // End of code injection

                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 1: // get(QNetworkRequest request, QIODevice *data, QObject *context, PyCallable *slot)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QIODevice *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QObject *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            SBK_UNUSED(cppArg2)

            if (Shiboken::Errors::occurred() == nullptr) {
                // get(QNetworkRequest,QIODevice*,QObject*,PyCallable*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-data-callback)]
                auto *networkReply = cppSelf->get(cppArg0, cppArg1, cppArg2, QRestFunctor(pyArgs[4-1]));
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), networkReply);
                // END of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-data-callback)]
                // ========================================================================
                // End of code injection

                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 2: // get(QNetworkRequest request, QJsonDocument data, QObject *context, PyCallable *slot)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QJsonDocument cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QObject *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            SBK_UNUSED(cppArg2)

            if (Shiboken::Errors::occurred() == nullptr) {
                // get(QNetworkRequest,QJsonDocument,QObject*,PyCallable*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-data-callback)]
                auto *networkReply = cppSelf->get(cppArg0, cppArg1, cppArg2, QRestFunctor(pyArgs[4-1]));
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), networkReply);
                // END of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-data-callback)]
                // ========================================================================
                // End of code injection

                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 3: // get(QNetworkRequest request, QObject *context, PyCallable *slot)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QObject *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)

            if (Shiboken::Errors::occurred() == nullptr) {
                // get(QNetworkRequest,QObject*,PyCallable*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-callback)]
                auto *networkReply = cppSelf->get(cppArg0, cppArg1, QRestFunctor(pyArgs[3-1]));
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), networkReply);
                // END of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-callback)]
                // ========================================================================
                // End of code injection

                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 4: // get(const QNetworkRequest &request)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0_local;
            ::QNetworkRequest *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // get(QNetworkRequest)
                QNetworkReply * cppResult = cppSelf->get(*cppArg0);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), cppResult);
                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 5: // get(const QNetworkRequest &request, QIODevice *data)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0_local;
            ::QNetworkRequest *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QIODevice *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // get(QNetworkRequest,QIODevice*)
                QNetworkReply * cppResult = cppSelf->get(*cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), cppResult);
                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 6: // get(const QNetworkRequest &request, const QByteArray &data)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0_local;
            ::QNetworkRequest *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QByteArray cppArg1_local;
            ::QByteArray *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // get(QNetworkRequest,QByteArray)
                QNetworkReply * cppResult = cppSelf->get(*cppArg0, *cppArg1);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), cppResult);
                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 7: // get(const QNetworkRequest &request, const QJsonDocument &data)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0_local;
            ::QNetworkRequest *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QJsonDocument cppArg1_local;
            ::QJsonDocument *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // get(QNetworkRequest,QJsonDocument)
                QNetworkReply * cppResult = cppSelf->get(*cppArg0, *cppArg1);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), cppResult);
                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRestAccessManagerFunc_head(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRestAccessManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QRestAccessManager_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 2)
        return Shiboken::returnWrongArguments(args, "head", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QRestAccessManager_IDX]);

    if (PyArg_UnpackTuple(args, "head", 1, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRestAccessManager::head(QNetworkRequest,QObject*,PyCallable*)->QNetworkReply*
    // 1: QRestAccessManager::head(QNetworkRequest)->QNetworkReply*
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // head(QNetworkRequest)
        } else if (numArgs == 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))
            && PyCallable_Check(pyArgs[2])) {
            overloadId = 0; // head(QNetworkRequest,QObject*,PyCallable*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "head", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QRestAccessManager_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // head(QNetworkRequest request, QObject *context, PyCallable *slot)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QObject *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)

            if (Shiboken::Errors::occurred() == nullptr) {
                // head(QNetworkRequest,QObject*,PyCallable*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-callback)]
                auto *networkReply = cppSelf->head(cppArg0, cppArg1, QRestFunctor(pyArgs[3-1]));
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), networkReply);
                // END of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-callback)]
                // ========================================================================
                // End of code injection

                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 1: // head(const QNetworkRequest &request)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0_local;
            ::QNetworkRequest *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // head(QNetworkRequest)
                QNetworkReply * cppResult = cppSelf->head(*cppArg0);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), cppResult);
                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRestAccessManagerFunc_networkAccessManager(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRestAccessManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QRestAccessManager_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // networkAccessManager()const
        QNetworkAccessManager * cppResult = const_cast<const ::QRestAccessManager *>(cppSelf)->networkAccessManager();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAccessManager_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRestAccessManagerFunc_patch(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRestAccessManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QRestAccessManager_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 3)
        return Shiboken::returnWrongArguments(args, "patch", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QRestAccessManager_IDX]);

    if (PyArg_UnpackTuple(args, "patch", 2, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRestAccessManager::patch(QNetworkRequest,QByteArray,QObject*,PyCallable*)->QNetworkReply*
    // 1: QRestAccessManager::patch(QNetworkRequest,QIODevice*,QObject*,PyCallable*)->QNetworkReply*
    // 2: QRestAccessManager::patch(QNetworkRequest,QJsonDocument,QObject*,PyCallable*)->QNetworkReply*
    // 3: QRestAccessManager::patch(QNetworkRequest,QMap<QString,QVariant>,QObject*,PyCallable*)->QNetworkReply*
    // 4: QRestAccessManager::patch(QNetworkRequest,QIODevice*)->QNetworkReply*
    // 5: QRestAccessManager::patch(QNetworkRequest,QByteArray)->QNetworkReply*
    // 6: QRestAccessManager::patch(QNetworkRequest,QJsonDocument)->QNetworkReply*
    // 7: QRestAccessManager::patch(QNetworkRequest,QMap<QString,QVariant>)->QNetworkReply*
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), (pyArgs[0])))) {
        if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QMap_QString_QVariant_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 7; // patch(QNetworkRequest,QMap<QString,QVariant>)
            } else if (numArgs == 4
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[2])))
                && PyCallable_Check(pyArgs[3])) {
                overloadId = 3; // patch(QNetworkRequest,QMap<QString,QVariant>,QObject*,PyCallable*)
            }
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 6; // patch(QNetworkRequest,QJsonDocument)
            } else if (numArgs == 4
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[2])))
                && PyCallable_Check(pyArgs[3])) {
                overloadId = 2; // patch(QNetworkRequest,QJsonDocument,QObject*,PyCallable*)
            }
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 4; // patch(QNetworkRequest,QIODevice*)
            } else if (numArgs == 4
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[2])))
                && PyCallable_Check(pyArgs[3])) {
                overloadId = 1; // patch(QNetworkRequest,QIODevice*,QObject*,PyCallable*)
            }
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 5; // patch(QNetworkRequest,QByteArray)
            } else if (numArgs == 4
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[2])))
                && PyCallable_Check(pyArgs[3])) {
                overloadId = 0; // patch(QNetworkRequest,QByteArray,QObject*,PyCallable*)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "patch", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QRestAccessManager_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // patch(QNetworkRequest request, QByteArray data, QObject *context, PyCallable *slot)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QByteArray cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QObject *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            SBK_UNUSED(cppArg2)

            if (Shiboken::Errors::occurred() == nullptr) {
                // patch(QNetworkRequest,QByteArray,QObject*,PyCallable*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-data-callback)]
                auto *networkReply = cppSelf->patch(cppArg0, cppArg1, cppArg2, QRestFunctor(pyArgs[4-1]));
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), networkReply);
                // END of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-data-callback)]
                // ========================================================================
                // End of code injection

                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 1: // patch(QNetworkRequest request, QIODevice *data, QObject *context, PyCallable *slot)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QIODevice *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QObject *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            SBK_UNUSED(cppArg2)

            if (Shiboken::Errors::occurred() == nullptr) {
                // patch(QNetworkRequest,QIODevice*,QObject*,PyCallable*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-data-callback)]
                auto *networkReply = cppSelf->patch(cppArg0, cppArg1, cppArg2, QRestFunctor(pyArgs[4-1]));
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), networkReply);
                // END of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-data-callback)]
                // ========================================================================
                // End of code injection

                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 2: // patch(QNetworkRequest request, QJsonDocument data, QObject *context, PyCallable *slot)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QJsonDocument cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QObject *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            SBK_UNUSED(cppArg2)

            if (Shiboken::Errors::occurred() == nullptr) {
                // patch(QNetworkRequest,QJsonDocument,QObject*,PyCallable*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-data-callback)]
                auto *networkReply = cppSelf->patch(cppArg0, cppArg1, cppArg2, QRestFunctor(pyArgs[4-1]));
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), networkReply);
                // END of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-data-callback)]
                // ========================================================================
                // End of code injection

                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 3: // patch(QNetworkRequest request, QMap<QString,QVariant> data, QObject *context, PyCallable *slot)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)
            ::QMap<QString,QVariant> cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QObject *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            SBK_UNUSED(cppArg2)

            if (Shiboken::Errors::occurred() == nullptr) {
                // patch(QNetworkRequest,QMap<QString,QVariant>,QObject*,PyCallable*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-data-callback)]
                auto *networkReply = cppSelf->patch(cppArg0, cppArg1, cppArg2, QRestFunctor(pyArgs[4-1]));
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), networkReply);
                // END of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-data-callback)]
                // ========================================================================
                // End of code injection

                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 4: // patch(const QNetworkRequest &request, QIODevice *data)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0_local;
            ::QNetworkRequest *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QIODevice *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // patch(QNetworkRequest,QIODevice*)
                QNetworkReply * cppResult = cppSelf->patch(*cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), cppResult);
                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 5: // patch(const QNetworkRequest &request, const QByteArray &data)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0_local;
            ::QNetworkRequest *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QByteArray cppArg1_local;
            ::QByteArray *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // patch(QNetworkRequest,QByteArray)
                QNetworkReply * cppResult = cppSelf->patch(*cppArg0, *cppArg1);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), cppResult);
                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 6: // patch(const QNetworkRequest &request, const QJsonDocument &data)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0_local;
            ::QNetworkRequest *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QJsonDocument cppArg1_local;
            ::QJsonDocument *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // patch(QNetworkRequest,QJsonDocument)
                QNetworkReply * cppResult = cppSelf->patch(*cppArg0, *cppArg1);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), cppResult);
                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 7: // patch(const QNetworkRequest &request, const QMap<QString,QVariant> &data)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0_local;
            ::QNetworkRequest *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QMap<QString,QVariant> cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // patch(QNetworkRequest,QMap<QString,QVariant>)
                QNetworkReply * cppResult = cppSelf->patch(*cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), cppResult);
                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRestAccessManagerFunc_post(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRestAccessManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QRestAccessManager_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 3)
        return Shiboken::returnWrongArguments(args, "post", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QRestAccessManager_IDX]);

    if (PyArg_UnpackTuple(args, "post", 2, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRestAccessManager::post(QNetworkRequest,QByteArray,QObject*,PyCallable*)->QNetworkReply*
    // 1: QRestAccessManager::post(QNetworkRequest,QHttpMultiPart*,QObject*,PyCallable*)->QNetworkReply*
    // 2: QRestAccessManager::post(QNetworkRequest,QIODevice*,QObject*,PyCallable*)->QNetworkReply*
    // 3: QRestAccessManager::post(QNetworkRequest,QJsonDocument,QObject*,PyCallable*)->QNetworkReply*
    // 4: QRestAccessManager::post(QNetworkRequest,QMap<QString,QVariant>,QObject*,PyCallable*)->QNetworkReply*
    // 5: QRestAccessManager::post(QNetworkRequest,QHttpMultiPart*)->QNetworkReply*
    // 6: QRestAccessManager::post(QNetworkRequest,QIODevice*)->QNetworkReply*
    // 7: QRestAccessManager::post(QNetworkRequest,QByteArray)->QNetworkReply*
    // 8: QRestAccessManager::post(QNetworkRequest,QJsonDocument)->QNetworkReply*
    // 9: QRestAccessManager::post(QNetworkRequest,QMap<QString,QVariant>)->QNetworkReply*
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), (pyArgs[0])))) {
        if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QMap_QString_QVariant_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 9; // post(QNetworkRequest,QMap<QString,QVariant>)
            } else if (numArgs == 4
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[2])))
                && PyCallable_Check(pyArgs[3])) {
                overloadId = 4; // post(QNetworkRequest,QMap<QString,QVariant>,QObject*,PyCallable*)
            }
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 8; // post(QNetworkRequest,QJsonDocument)
            } else if (numArgs == 4
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[2])))
                && PyCallable_Check(pyArgs[3])) {
                overloadId = 3; // post(QNetworkRequest,QJsonDocument,QObject*,PyCallable*)
            }
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 6; // post(QNetworkRequest,QIODevice*)
            } else if (numArgs == 4
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[2])))
                && PyCallable_Check(pyArgs[3])) {
                overloadId = 2; // post(QNetworkRequest,QIODevice*,QObject*,PyCallable*)
            }
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpMultiPart_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 5; // post(QNetworkRequest,QHttpMultiPart*)
            } else if (numArgs == 4
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[2])))
                && PyCallable_Check(pyArgs[3])) {
                overloadId = 1; // post(QNetworkRequest,QHttpMultiPart*,QObject*,PyCallable*)
            }
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 7; // post(QNetworkRequest,QByteArray)
            } else if (numArgs == 4
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[2])))
                && PyCallable_Check(pyArgs[3])) {
                overloadId = 0; // post(QNetworkRequest,QByteArray,QObject*,PyCallable*)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "post", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QRestAccessManager_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // post(QNetworkRequest request, QByteArray data, QObject *context, PyCallable *slot)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QByteArray cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QObject *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            SBK_UNUSED(cppArg2)

            if (Shiboken::Errors::occurred() == nullptr) {
                // post(QNetworkRequest,QByteArray,QObject*,PyCallable*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-data-callback)]
                auto *networkReply = cppSelf->post(cppArg0, cppArg1, cppArg2, QRestFunctor(pyArgs[4-1]));
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), networkReply);
                // END of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-data-callback)]
                // ========================================================================
                // End of code injection

                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 1: // post(QNetworkRequest request, QHttpMultiPart *data, QObject *context, PyCallable *slot)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QHttpMultiPart *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QObject *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            SBK_UNUSED(cppArg2)

            if (Shiboken::Errors::occurred() == nullptr) {
                // post(QNetworkRequest,QHttpMultiPart*,QObject*,PyCallable*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-data-callback)]
                auto *networkReply = cppSelf->post(cppArg0, cppArg1, cppArg2, QRestFunctor(pyArgs[4-1]));
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), networkReply);
                // END of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-data-callback)]
                // ========================================================================
                // End of code injection

                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 2: // post(QNetworkRequest request, QIODevice *data, QObject *context, PyCallable *slot)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QIODevice *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QObject *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            SBK_UNUSED(cppArg2)

            if (Shiboken::Errors::occurred() == nullptr) {
                // post(QNetworkRequest,QIODevice*,QObject*,PyCallable*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-data-callback)]
                auto *networkReply = cppSelf->post(cppArg0, cppArg1, cppArg2, QRestFunctor(pyArgs[4-1]));
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), networkReply);
                // END of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-data-callback)]
                // ========================================================================
                // End of code injection

                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 3: // post(QNetworkRequest request, QJsonDocument data, QObject *context, PyCallable *slot)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QJsonDocument cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QObject *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            SBK_UNUSED(cppArg2)

            if (Shiboken::Errors::occurred() == nullptr) {
                // post(QNetworkRequest,QJsonDocument,QObject*,PyCallable*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-data-callback)]
                auto *networkReply = cppSelf->post(cppArg0, cppArg1, cppArg2, QRestFunctor(pyArgs[4-1]));
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), networkReply);
                // END of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-data-callback)]
                // ========================================================================
                // End of code injection

                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 4: // post(QNetworkRequest request, QMap<QString,QVariant> data, QObject *context, PyCallable *slot)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)
            ::QMap<QString,QVariant> cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QObject *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            SBK_UNUSED(cppArg2)

            if (Shiboken::Errors::occurred() == nullptr) {
                // post(QNetworkRequest,QMap<QString,QVariant>,QObject*,PyCallable*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-data-callback)]
                auto *networkReply = cppSelf->post(cppArg0, cppArg1, cppArg2, QRestFunctor(pyArgs[4-1]));
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), networkReply);
                // END of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-data-callback)]
                // ========================================================================
                // End of code injection

                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 5: // post(const QNetworkRequest &request, QHttpMultiPart *data)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0_local;
            ::QNetworkRequest *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QHttpMultiPart *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // post(QNetworkRequest,QHttpMultiPart*)
                QNetworkReply * cppResult = cppSelf->post(*cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), cppResult);
                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 6: // post(const QNetworkRequest &request, QIODevice *data)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0_local;
            ::QNetworkRequest *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QIODevice *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // post(QNetworkRequest,QIODevice*)
                QNetworkReply * cppResult = cppSelf->post(*cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), cppResult);
                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 7: // post(const QNetworkRequest &request, const QByteArray &data)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0_local;
            ::QNetworkRequest *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QByteArray cppArg1_local;
            ::QByteArray *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // post(QNetworkRequest,QByteArray)
                QNetworkReply * cppResult = cppSelf->post(*cppArg0, *cppArg1);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), cppResult);
                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 8: // post(const QNetworkRequest &request, const QJsonDocument &data)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0_local;
            ::QNetworkRequest *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QJsonDocument cppArg1_local;
            ::QJsonDocument *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // post(QNetworkRequest,QJsonDocument)
                QNetworkReply * cppResult = cppSelf->post(*cppArg0, *cppArg1);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), cppResult);
                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 9: // post(const QNetworkRequest &request, const QMap<QString,QVariant> &data)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0_local;
            ::QNetworkRequest *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QMap<QString,QVariant> cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // post(QNetworkRequest,QMap<QString,QVariant>)
                QNetworkReply * cppResult = cppSelf->post(*cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), cppResult);
                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRestAccessManagerFunc_put(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRestAccessManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QRestAccessManager_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 3)
        return Shiboken::returnWrongArguments(args, "put", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QRestAccessManager_IDX]);

    if (PyArg_UnpackTuple(args, "put", 2, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRestAccessManager::put(QNetworkRequest,QByteArray,QObject*,PyCallable*)->QNetworkReply*
    // 1: QRestAccessManager::put(QNetworkRequest,QHttpMultiPart*,QObject*,PyCallable*)->QNetworkReply*
    // 2: QRestAccessManager::put(QNetworkRequest,QIODevice*,QObject*,PyCallable*)->QNetworkReply*
    // 3: QRestAccessManager::put(QNetworkRequest,QJsonDocument,QObject*,PyCallable*)->QNetworkReply*
    // 4: QRestAccessManager::put(QNetworkRequest,QMap<QString,QVariant>,QObject*,PyCallable*)->QNetworkReply*
    // 5: QRestAccessManager::put(QNetworkRequest,QHttpMultiPart*)->QNetworkReply*
    // 6: QRestAccessManager::put(QNetworkRequest,QIODevice*)->QNetworkReply*
    // 7: QRestAccessManager::put(QNetworkRequest,QByteArray)->QNetworkReply*
    // 8: QRestAccessManager::put(QNetworkRequest,QJsonDocument)->QNetworkReply*
    // 9: QRestAccessManager::put(QNetworkRequest,QMap<QString,QVariant>)->QNetworkReply*
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), (pyArgs[0])))) {
        if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QMap_QString_QVariant_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 9; // put(QNetworkRequest,QMap<QString,QVariant>)
            } else if (numArgs == 4
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[2])))
                && PyCallable_Check(pyArgs[3])) {
                overloadId = 4; // put(QNetworkRequest,QMap<QString,QVariant>,QObject*,PyCallable*)
            }
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 8; // put(QNetworkRequest,QJsonDocument)
            } else if (numArgs == 4
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[2])))
                && PyCallable_Check(pyArgs[3])) {
                overloadId = 3; // put(QNetworkRequest,QJsonDocument,QObject*,PyCallable*)
            }
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 6; // put(QNetworkRequest,QIODevice*)
            } else if (numArgs == 4
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[2])))
                && PyCallable_Check(pyArgs[3])) {
                overloadId = 2; // put(QNetworkRequest,QIODevice*,QObject*,PyCallable*)
            }
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpMultiPart_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 5; // put(QNetworkRequest,QHttpMultiPart*)
            } else if (numArgs == 4
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[2])))
                && PyCallable_Check(pyArgs[3])) {
                overloadId = 1; // put(QNetworkRequest,QHttpMultiPart*,QObject*,PyCallable*)
            }
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 7; // put(QNetworkRequest,QByteArray)
            } else if (numArgs == 4
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[2])))
                && PyCallable_Check(pyArgs[3])) {
                overloadId = 0; // put(QNetworkRequest,QByteArray,QObject*,PyCallable*)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "put", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QRestAccessManager_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // put(QNetworkRequest request, QByteArray data, QObject *context, PyCallable *slot)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QByteArray cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QObject *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            SBK_UNUSED(cppArg2)

            if (Shiboken::Errors::occurred() == nullptr) {
                // put(QNetworkRequest,QByteArray,QObject*,PyCallable*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-data-callback)]
                auto *networkReply = cppSelf->put(cppArg0, cppArg1, cppArg2, QRestFunctor(pyArgs[4-1]));
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), networkReply);
                // END of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-data-callback)]
                // ========================================================================
                // End of code injection

                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 1: // put(QNetworkRequest request, QHttpMultiPart *data, QObject *context, PyCallable *slot)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QHttpMultiPart *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QObject *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            SBK_UNUSED(cppArg2)

            if (Shiboken::Errors::occurred() == nullptr) {
                // put(QNetworkRequest,QHttpMultiPart*,QObject*,PyCallable*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-data-callback)]
                auto *networkReply = cppSelf->put(cppArg0, cppArg1, cppArg2, QRestFunctor(pyArgs[4-1]));
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), networkReply);
                // END of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-data-callback)]
                // ========================================================================
                // End of code injection

                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 2: // put(QNetworkRequest request, QIODevice *data, QObject *context, PyCallable *slot)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QIODevice *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QObject *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            SBK_UNUSED(cppArg2)

            if (Shiboken::Errors::occurred() == nullptr) {
                // put(QNetworkRequest,QIODevice*,QObject*,PyCallable*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-data-callback)]
                auto *networkReply = cppSelf->put(cppArg0, cppArg1, cppArg2, QRestFunctor(pyArgs[4-1]));
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), networkReply);
                // END of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-data-callback)]
                // ========================================================================
                // End of code injection

                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 3: // put(QNetworkRequest request, QJsonDocument data, QObject *context, PyCallable *slot)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QJsonDocument cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QObject *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            SBK_UNUSED(cppArg2)

            if (Shiboken::Errors::occurred() == nullptr) {
                // put(QNetworkRequest,QJsonDocument,QObject*,PyCallable*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-data-callback)]
                auto *networkReply = cppSelf->put(cppArg0, cppArg1, cppArg2, QRestFunctor(pyArgs[4-1]));
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), networkReply);
                // END of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-data-callback)]
                // ========================================================================
                // End of code injection

                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 4: // put(QNetworkRequest request, QMap<QString,QVariant> data, QObject *context, PyCallable *slot)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)
            ::QMap<QString,QVariant> cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QObject *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            SBK_UNUSED(cppArg2)

            if (Shiboken::Errors::occurred() == nullptr) {
                // put(QNetworkRequest,QMap<QString,QVariant>,QObject*,PyCallable*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-data-callback)]
                auto *networkReply = cppSelf->put(cppArg0, cppArg1, cppArg2, QRestFunctor(pyArgs[4-1]));
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), networkReply);
                // END of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-data-callback)]
                // ========================================================================
                // End of code injection

                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 5: // put(const QNetworkRequest &request, QHttpMultiPart *data)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0_local;
            ::QNetworkRequest *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QHttpMultiPart *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // put(QNetworkRequest,QHttpMultiPart*)
                QNetworkReply * cppResult = cppSelf->put(*cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), cppResult);
                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 6: // put(const QNetworkRequest &request, QIODevice *data)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0_local;
            ::QNetworkRequest *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QIODevice *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // put(QNetworkRequest,QIODevice*)
                QNetworkReply * cppResult = cppSelf->put(*cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), cppResult);
                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 7: // put(const QNetworkRequest &request, const QByteArray &data)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0_local;
            ::QNetworkRequest *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QByteArray cppArg1_local;
            ::QByteArray *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // put(QNetworkRequest,QByteArray)
                QNetworkReply * cppResult = cppSelf->put(*cppArg0, *cppArg1);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), cppResult);
                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 8: // put(const QNetworkRequest &request, const QJsonDocument &data)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0_local;
            ::QNetworkRequest *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QJsonDocument cppArg1_local;
            ::QJsonDocument *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // put(QNetworkRequest,QJsonDocument)
                QNetworkReply * cppResult = cppSelf->put(*cppArg0, *cppArg1);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), cppResult);
                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 9: // put(const QNetworkRequest &request, const QMap<QString,QVariant> &data)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0_local;
            ::QNetworkRequest *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QMap<QString,QVariant> cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // put(QNetworkRequest,QMap<QString,QVariant>)
                QNetworkReply * cppResult = cppSelf->put(*cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), cppResult);
                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRestAccessManagerFunc_sendCustomRequest(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRestAccessManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QRestAccessManager_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 4)
        return Shiboken::returnWrongArguments(args, "sendCustomRequest", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QRestAccessManager_IDX]);

    if (PyArg_UnpackTuple(args, "sendCustomRequest", 3, 5, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRestAccessManager::sendCustomRequest(QNetworkRequest,QByteArray,QByteArray,QObject*,PyCallable*)->QNetworkReply*
    // 1: QRestAccessManager::sendCustomRequest(QNetworkRequest,QByteArray,QHttpMultiPart*,QObject*,PyCallable*)->QNetworkReply*
    // 2: QRestAccessManager::sendCustomRequest(QNetworkRequest,QByteArray,QIODevice*,QObject*,PyCallable*)->QNetworkReply*
    // 3: QRestAccessManager::sendCustomRequest(QNetworkRequest,QByteArray,QHttpMultiPart*)->QNetworkReply*
    // 4: QRestAccessManager::sendCustomRequest(QNetworkRequest,QByteArray,QIODevice*)->QNetworkReply*
    // 5: QRestAccessManager::sendCustomRequest(QNetworkRequest,QByteArray,QByteArray)->QNetworkReply*
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
        if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 4; // sendCustomRequest(QNetworkRequest,QByteArray,QIODevice*)
            } else if (numArgs == 5
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[3])))
                && PyCallable_Check(pyArgs[4])) {
                overloadId = 2; // sendCustomRequest(QNetworkRequest,QByteArray,QIODevice*,QObject*,PyCallable*)
            }
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpMultiPart_IDX]), (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 3; // sendCustomRequest(QNetworkRequest,QByteArray,QHttpMultiPart*)
            } else if (numArgs == 5
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[3])))
                && PyCallable_Check(pyArgs[4])) {
                overloadId = 1; // sendCustomRequest(QNetworkRequest,QByteArray,QHttpMultiPart*,QObject*,PyCallable*)
            }
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 5; // sendCustomRequest(QNetworkRequest,QByteArray,QByteArray)
            } else if (numArgs == 5
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[3])))
                && PyCallable_Check(pyArgs[4])) {
                overloadId = 0; // sendCustomRequest(QNetworkRequest,QByteArray,QByteArray,QObject*,PyCallable*)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "sendCustomRequest", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QRestAccessManager_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // sendCustomRequest(QNetworkRequest request, QByteArray method, QByteArray data, QObject *context, PyCallable *slot)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QByteArray cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QByteArray cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            SBK_UNUSED(cppArg2)
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QObject *cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            SBK_UNUSED(cppArg3)

            if (Shiboken::Errors::occurred() == nullptr) {
                // sendCustomRequest(QNetworkRequest,QByteArray,QByteArray,QObject*,PyCallable*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-method-data-callback)]
                auto *networkReply = cppSelf->sendCustomRequest(cppArg0, cppArg1, cppArg2, cppArg3, QRestFunctor(pyArgs[5-1]));
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), networkReply);
                // END of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-method-data-callback)]
                // ========================================================================
                // End of code injection

                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 1: // sendCustomRequest(QNetworkRequest request, QByteArray method, QHttpMultiPart *data, QObject *context, PyCallable *slot)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QByteArray cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QHttpMultiPart *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            SBK_UNUSED(cppArg2)
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QObject *cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            SBK_UNUSED(cppArg3)

            if (Shiboken::Errors::occurred() == nullptr) {
                // sendCustomRequest(QNetworkRequest,QByteArray,QHttpMultiPart*,QObject*,PyCallable*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-method-data-callback)]
                auto *networkReply = cppSelf->sendCustomRequest(cppArg0, cppArg1, cppArg2, cppArg3, QRestFunctor(pyArgs[5-1]));
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), networkReply);
                // END of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-method-data-callback)]
                // ========================================================================
                // End of code injection

                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 2: // sendCustomRequest(QNetworkRequest request, QByteArray method, QIODevice *data, QObject *context, PyCallable *slot)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QByteArray cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QIODevice *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            SBK_UNUSED(cppArg2)
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QObject *cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            SBK_UNUSED(cppArg3)

            if (Shiboken::Errors::occurred() == nullptr) {
                // sendCustomRequest(QNetworkRequest,QByteArray,QIODevice*,QObject*,PyCallable*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-method-data-callback)]
                auto *networkReply = cppSelf->sendCustomRequest(cppArg0, cppArg1, cppArg2, cppArg3, QRestFunctor(pyArgs[5-1]));
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), networkReply);
                // END of custom code block [file: ../glue/qtnetwork.cpp (qrestaccessmanager-method-data-callback)]
                // ========================================================================
                // End of code injection

                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 3: // sendCustomRequest(const QNetworkRequest &request, const QByteArray &method, QHttpMultiPart *data)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0_local;
            ::QNetworkRequest *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QByteArray cppArg1_local;
            ::QByteArray *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QHttpMultiPart *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // sendCustomRequest(QNetworkRequest,QByteArray,QHttpMultiPart*)
                QNetworkReply * cppResult = cppSelf->sendCustomRequest(*cppArg0, *cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), cppResult);
                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 4: // sendCustomRequest(const QNetworkRequest &request, const QByteArray &method, QIODevice *data)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0_local;
            ::QNetworkRequest *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QByteArray cppArg1_local;
            ::QByteArray *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QIODevice *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // sendCustomRequest(QNetworkRequest,QByteArray,QIODevice*)
                QNetworkReply * cppResult = cppSelf->sendCustomRequest(*cppArg0, *cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), cppResult);
                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 5: // sendCustomRequest(const QNetworkRequest &request, const QByteArray &method, const QByteArray &data)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0_local;
            ::QNetworkRequest *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QByteArray cppArg1_local;
            ::QByteArray *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QByteArray cppArg2_local;
            ::QByteArray *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);


            if (Shiboken::Errors::occurred() == nullptr) {
                // sendCustomRequest(QNetworkRequest,QByteArray,QByteArray)
                QNetworkReply * cppResult = cppSelf->sendCustomRequest(*cppArg0, *cppArg1, *cppArg2);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), cppResult);
                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QRestAccessManager_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QRestAccessManager_methods[] = {
    {"deleteResource", reinterpret_cast<PyCFunction>(Sbk_QRestAccessManagerFunc_deleteResource), METH_VARARGS, nullptr},
    {"get", reinterpret_cast<PyCFunction>(Sbk_QRestAccessManagerFunc_get), METH_VARARGS, nullptr},
    {"head", reinterpret_cast<PyCFunction>(Sbk_QRestAccessManagerFunc_head), METH_VARARGS, nullptr},
    {"networkAccessManager", reinterpret_cast<PyCFunction>(Sbk_QRestAccessManagerFunc_networkAccessManager), METH_NOARGS, nullptr},
    {"patch", reinterpret_cast<PyCFunction>(Sbk_QRestAccessManagerFunc_patch), METH_VARARGS, nullptr},
    {"post", reinterpret_cast<PyCFunction>(Sbk_QRestAccessManagerFunc_post), METH_VARARGS, nullptr},
    {"put", reinterpret_cast<PyCFunction>(Sbk_QRestAccessManagerFunc_put), METH_VARARGS, nullptr},
    {"sendCustomRequest", reinterpret_cast<PyCFunction>(Sbk_QRestAccessManagerFunc_sendCustomRequest), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QRestAccessManager_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QRestAccessManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QRestAccessManager_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QRestAccessManagerWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QRestAccessManager_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QRestAccessManager_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QRestAccessManager_Type = nullptr;
static PyTypeObject *Sbk_QRestAccessManager_TypeF(void)
{
    return _Sbk_QRestAccessManager_Type;
}

static PyType_Slot Sbk_QRestAccessManager_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QRestAccessManager_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QRestAccessManager_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QRestAccessManager_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QRestAccessManager_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QRestAccessManager_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QRestAccessManager_spec = {
    "2:PySide6.QtNetwork.QRestAccessManager",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QRestAccessManager_slots
};

} //extern "C"

static void *Sbk_QRestAccessManager_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QRestAccessManager *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QRestAccessManager_PythonToCpp_QRestAccessManager_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QRestAccessManager_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QRestAccessManager_PythonToCpp_QRestAccessManager_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QRestAccessManager_TypeF()))
        return QRestAccessManager_PythonToCpp_QRestAccessManager_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QRestAccessManager_PTR_CppToPython_QRestAccessManager(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QRestAccessManager *>(const_cast<void *>(cppIn)), Sbk_QRestAccessManager_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QRestAccessManager_SignatureStrings[] = {
    "PySide6.QtNetwork.QRestAccessManager(self,manager:PySide6.QtNetwork.QNetworkAccessManager,parent:PySide6.QtCore.QObject=nullptr)",
    "1:PySide6.QtNetwork.QRestAccessManager.deleteResource(self,request:PySide6.QtNetwork.QNetworkRequest,context:PySide6.QtCore.QObject,slot:PyCallable)->PySide6.QtNetwork.QNetworkReply",
    "0:PySide6.QtNetwork.QRestAccessManager.deleteResource(self,request:PySide6.QtNetwork.QNetworkRequest)->PySide6.QtNetwork.QNetworkReply",
    "7:PySide6.QtNetwork.QRestAccessManager.get(self,request:PySide6.QtNetwork.QNetworkRequest,data:typing.Union[PySide6.QtCore.QByteArray, char*],context:PySide6.QtCore.QObject,slot:PyCallable)->PySide6.QtNetwork.QNetworkReply",
    "6:PySide6.QtNetwork.QRestAccessManager.get(self,request:PySide6.QtNetwork.QNetworkRequest,data:PySide6.QtCore.QIODevice,context:PySide6.QtCore.QObject,slot:PyCallable)->PySide6.QtNetwork.QNetworkReply",
    "5:PySide6.QtNetwork.QRestAccessManager.get(self,request:PySide6.QtNetwork.QNetworkRequest,data:PySide6.QtCore.QJsonDocument,context:PySide6.QtCore.QObject,slot:PyCallable)->PySide6.QtNetwork.QNetworkReply",
    "4:PySide6.QtNetwork.QRestAccessManager.get(self,request:PySide6.QtNetwork.QNetworkRequest,context:PySide6.QtCore.QObject,slot:PyCallable)->PySide6.QtNetwork.QNetworkReply",
    "3:PySide6.QtNetwork.QRestAccessManager.get(self,request:PySide6.QtNetwork.QNetworkRequest)->PySide6.QtNetwork.QNetworkReply",
    "2:PySide6.QtNetwork.QRestAccessManager.get(self,request:PySide6.QtNetwork.QNetworkRequest,data:PySide6.QtCore.QIODevice)->PySide6.QtNetwork.QNetworkReply",
    "1:PySide6.QtNetwork.QRestAccessManager.get(self,request:PySide6.QtNetwork.QNetworkRequest,data:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtNetwork.QNetworkReply",
    "0:PySide6.QtNetwork.QRestAccessManager.get(self,request:PySide6.QtNetwork.QNetworkRequest,data:PySide6.QtCore.QJsonDocument)->PySide6.QtNetwork.QNetworkReply",
    "1:PySide6.QtNetwork.QRestAccessManager.head(self,request:PySide6.QtNetwork.QNetworkRequest,context:PySide6.QtCore.QObject,slot:PyCallable)->PySide6.QtNetwork.QNetworkReply",
    "0:PySide6.QtNetwork.QRestAccessManager.head(self,request:PySide6.QtNetwork.QNetworkRequest)->PySide6.QtNetwork.QNetworkReply",
    "PySide6.QtNetwork.QRestAccessManager.networkAccessManager(self)->PySide6.QtNetwork.QNetworkAccessManager",
    "7:PySide6.QtNetwork.QRestAccessManager.patch(self,request:PySide6.QtNetwork.QNetworkRequest,data:typing.Union[PySide6.QtCore.QByteArray, char*],context:PySide6.QtCore.QObject,slot:PyCallable)->PySide6.QtNetwork.QNetworkReply",
    "6:PySide6.QtNetwork.QRestAccessManager.patch(self,request:PySide6.QtNetwork.QNetworkRequest,data:PySide6.QtCore.QIODevice,context:PySide6.QtCore.QObject,slot:PyCallable)->PySide6.QtNetwork.QNetworkReply",
    "5:PySide6.QtNetwork.QRestAccessManager.patch(self,request:PySide6.QtNetwork.QNetworkRequest,data:PySide6.QtCore.QJsonDocument,context:PySide6.QtCore.QObject,slot:PyCallable)->PySide6.QtNetwork.QNetworkReply",
    "4:PySide6.QtNetwork.QRestAccessManager.patch(self,request:PySide6.QtNetwork.QNetworkRequest,data:QMap[QString, QVariant],context:PySide6.QtCore.QObject,slot:PyCallable)->PySide6.QtNetwork.QNetworkReply",
    "3:PySide6.QtNetwork.QRestAccessManager.patch(self,request:PySide6.QtNetwork.QNetworkRequest,data:PySide6.QtCore.QIODevice)->PySide6.QtNetwork.QNetworkReply",
    "2:PySide6.QtNetwork.QRestAccessManager.patch(self,request:PySide6.QtNetwork.QNetworkRequest,data:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtNetwork.QNetworkReply",
    "1:PySide6.QtNetwork.QRestAccessManager.patch(self,request:PySide6.QtNetwork.QNetworkRequest,data:PySide6.QtCore.QJsonDocument)->PySide6.QtNetwork.QNetworkReply",
    "0:PySide6.QtNetwork.QRestAccessManager.patch(self,request:PySide6.QtNetwork.QNetworkRequest,data:QMap[QString, QVariant])->PySide6.QtNetwork.QNetworkReply",
    "9:PySide6.QtNetwork.QRestAccessManager.post(self,request:PySide6.QtNetwork.QNetworkRequest,data:typing.Union[PySide6.QtCore.QByteArray, char*],context:PySide6.QtCore.QObject,slot:PyCallable)->PySide6.QtNetwork.QNetworkReply",
    "8:PySide6.QtNetwork.QRestAccessManager.post(self,request:PySide6.QtNetwork.QNetworkRequest,data:PySide6.QtNetwork.QHttpMultiPart,context:PySide6.QtCore.QObject,slot:PyCallable)->PySide6.QtNetwork.QNetworkReply",
    "7:PySide6.QtNetwork.QRestAccessManager.post(self,request:PySide6.QtNetwork.QNetworkRequest,data:PySide6.QtCore.QIODevice,context:PySide6.QtCore.QObject,slot:PyCallable)->PySide6.QtNetwork.QNetworkReply",
    "6:PySide6.QtNetwork.QRestAccessManager.post(self,request:PySide6.QtNetwork.QNetworkRequest,data:PySide6.QtCore.QJsonDocument,context:PySide6.QtCore.QObject,slot:PyCallable)->PySide6.QtNetwork.QNetworkReply",
    "5:PySide6.QtNetwork.QRestAccessManager.post(self,request:PySide6.QtNetwork.QNetworkRequest,data:QMap[QString, QVariant],context:PySide6.QtCore.QObject,slot:PyCallable)->PySide6.QtNetwork.QNetworkReply",
    "4:PySide6.QtNetwork.QRestAccessManager.post(self,request:PySide6.QtNetwork.QNetworkRequest,data:PySide6.QtNetwork.QHttpMultiPart)->PySide6.QtNetwork.QNetworkReply",
    "3:PySide6.QtNetwork.QRestAccessManager.post(self,request:PySide6.QtNetwork.QNetworkRequest,data:PySide6.QtCore.QIODevice)->PySide6.QtNetwork.QNetworkReply",
    "2:PySide6.QtNetwork.QRestAccessManager.post(self,request:PySide6.QtNetwork.QNetworkRequest,data:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtNetwork.QNetworkReply",
    "1:PySide6.QtNetwork.QRestAccessManager.post(self,request:PySide6.QtNetwork.QNetworkRequest,data:PySide6.QtCore.QJsonDocument)->PySide6.QtNetwork.QNetworkReply",
    "0:PySide6.QtNetwork.QRestAccessManager.post(self,request:PySide6.QtNetwork.QNetworkRequest,data:QMap[QString, QVariant])->PySide6.QtNetwork.QNetworkReply",
    "9:PySide6.QtNetwork.QRestAccessManager.put(self,request:PySide6.QtNetwork.QNetworkRequest,data:typing.Union[PySide6.QtCore.QByteArray, char*],context:PySide6.QtCore.QObject,slot:PyCallable)->PySide6.QtNetwork.QNetworkReply",
    "8:PySide6.QtNetwork.QRestAccessManager.put(self,request:PySide6.QtNetwork.QNetworkRequest,data:PySide6.QtNetwork.QHttpMultiPart,context:PySide6.QtCore.QObject,slot:PyCallable)->PySide6.QtNetwork.QNetworkReply",
    "7:PySide6.QtNetwork.QRestAccessManager.put(self,request:PySide6.QtNetwork.QNetworkRequest,data:PySide6.QtCore.QIODevice,context:PySide6.QtCore.QObject,slot:PyCallable)->PySide6.QtNetwork.QNetworkReply",
    "6:PySide6.QtNetwork.QRestAccessManager.put(self,request:PySide6.QtNetwork.QNetworkRequest,data:PySide6.QtCore.QJsonDocument,context:PySide6.QtCore.QObject,slot:PyCallable)->PySide6.QtNetwork.QNetworkReply",
    "5:PySide6.QtNetwork.QRestAccessManager.put(self,request:PySide6.QtNetwork.QNetworkRequest,data:QMap[QString, QVariant],context:PySide6.QtCore.QObject,slot:PyCallable)->PySide6.QtNetwork.QNetworkReply",
    "4:PySide6.QtNetwork.QRestAccessManager.put(self,request:PySide6.QtNetwork.QNetworkRequest,data:PySide6.QtNetwork.QHttpMultiPart)->PySide6.QtNetwork.QNetworkReply",
    "3:PySide6.QtNetwork.QRestAccessManager.put(self,request:PySide6.QtNetwork.QNetworkRequest,data:PySide6.QtCore.QIODevice)->PySide6.QtNetwork.QNetworkReply",
    "2:PySide6.QtNetwork.QRestAccessManager.put(self,request:PySide6.QtNetwork.QNetworkRequest,data:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtNetwork.QNetworkReply",
    "1:PySide6.QtNetwork.QRestAccessManager.put(self,request:PySide6.QtNetwork.QNetworkRequest,data:PySide6.QtCore.QJsonDocument)->PySide6.QtNetwork.QNetworkReply",
    "0:PySide6.QtNetwork.QRestAccessManager.put(self,request:PySide6.QtNetwork.QNetworkRequest,data:QMap[QString, QVariant])->PySide6.QtNetwork.QNetworkReply",
    "5:PySide6.QtNetwork.QRestAccessManager.sendCustomRequest(self,request:PySide6.QtNetwork.QNetworkRequest,method:typing.Union[PySide6.QtCore.QByteArray, char*],data:typing.Union[PySide6.QtCore.QByteArray, char*],context:PySide6.QtCore.QObject,slot:PyCallable)->PySide6.QtNetwork.QNetworkReply",
    "4:PySide6.QtNetwork.QRestAccessManager.sendCustomRequest(self,request:PySide6.QtNetwork.QNetworkRequest,method:typing.Union[PySide6.QtCore.QByteArray, char*],data:PySide6.QtNetwork.QHttpMultiPart,context:PySide6.QtCore.QObject,slot:PyCallable)->PySide6.QtNetwork.QNetworkReply",
    "3:PySide6.QtNetwork.QRestAccessManager.sendCustomRequest(self,request:PySide6.QtNetwork.QNetworkRequest,method:typing.Union[PySide6.QtCore.QByteArray, char*],data:PySide6.QtCore.QIODevice,context:PySide6.QtCore.QObject,slot:PyCallable)->PySide6.QtNetwork.QNetworkReply",
    "2:PySide6.QtNetwork.QRestAccessManager.sendCustomRequest(self,request:PySide6.QtNetwork.QNetworkRequest,method:typing.Union[PySide6.QtCore.QByteArray, char*],data:PySide6.QtNetwork.QHttpMultiPart)->PySide6.QtNetwork.QNetworkReply",
    "1:PySide6.QtNetwork.QRestAccessManager.sendCustomRequest(self,request:PySide6.QtNetwork.QNetworkRequest,method:typing.Union[PySide6.QtCore.QByteArray, char*],data:PySide6.QtCore.QIODevice)->PySide6.QtNetwork.QNetworkReply",
    "0:PySide6.QtNetwork.QRestAccessManager.sendCustomRequest(self,request:PySide6.QtNetwork.QNetworkRequest,method:typing.Union[PySide6.QtCore.QByteArray, char*],data:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtNetwork.QNetworkReply",
    nullptr}; // Sentinel
#else
static constexpr size_t QRestAccessManager_SignatureByteSize = 522;
static constexpr uint8_t QRestAccessManager_SignatureBytes[522] = {
    0x78, 0xda, 0xdd, 0x97, 0xc1, 0x52, 0xdb, 0x30, 0x10, 0x86, 0xef, 0x3c, 0x05, 0x47, 0xc2, 0x18,
    0x4f, 0x81, 0x10, 0x4a, 0x66, 0xda, 0x19, 0x08, 0x87, 0xb6, 0x33, 0x81, 0x38, 0x0c, 0x5c, 0x98,
    0x1c, 0x84, 0xbc, 0x4d, 0xdc, 0x2a, 0x92, 0x2b, 0xad, 0x68, 0xfd, 0xf6, 0xa4, 0x4d, 0x0e, 0x85,
    0x84, 0x8c, 0x92, 0x59, 0x29, 0xb2, 0x6f, 0x8e, 0xb3, 0xf2, 0xfe, 0xff, 0x66, 0x77, 0x3f, 0x67,
    0x50, 0xdd, 0x15, 0x39, 0x74, 0xd2, 0x0c, 0x6f, 0x00, 0x7f, 0x2b, 0xfd, 0x33, 0xcd, 0x86, 0x60,
    0xf0, 0x92, 0x73, 0x30, 0xa6, 0xcf, 0x24, 0x1b, 0x83, 0x3e, 0x30, 0x20, 0xbe, 0x27, 0xd3, 0xf9,
    0x87, 0xee, 0x60, 0xf9, 0xc4, 0xe2, 0xe2, 0xd5, 0xa1, 0xa4, 0x64, 0x1a, 0x24, 0xfe, 0x17, 0xde,
    0x53, 0x1a, 0xd2, 0xec, 0xf6, 0xe9, 0x07, 0x70, 0xfc, 0x24, 0xad, 0x10, 0x25, 0xea, 0xd6, 0xde,
    0xf1, 0xaa, 0x07, 0x2e, 0x49, 0x48, 0x73, 0x10, 0x80, 0x30, 0xbb, 0xaf, 0xac, 0xe6, 0x30, 0x57,
    0xa4, 0xe1, 0x97, 0x9d, 0x05, 0xae, 0x51, 0x34, 0x9c, 0x47, 0x24, 0x5c, 0x49, 0x84, 0x3f, 0xef,
    0x89, 0x49, 0x8c, 0x50, 0x7f, 0xbf, 0xeb, 0x31, 0x21, 0xd8, 0x93, 0x80, 0xd6, 0xd1, 0xe7, 0x75,
    0x8f, 0x2c, 0x45, 0xb5, 0xf7, 0x21, 0x80, 0x6a, 0x07, 0x19, 0xe7, 0x6e, 0x32, 0xc6, 0x80, 0x9b,
    0x56, 0x2c, 0x67, 0xc8, 0xba, 0x58, 0x95, 0x85, 0x1c, 0xa7, 0xf7, 0xb2, 0x50, 0xf2, 0xf1, 0x6d,
    0xed, 0xae, 0x2a, 0x84, 0x4b, 0xad, 0x59, 0x95, 0xec, 0xf3, 0x09, 0xd3, 0x87, 0x23, 0xfa, 0x2a,
    0x77, 0xfc, 0xda, 0x7b, 0xab, 0xf3, 0xeb, 0xed, 0x35, 0x3c, 0x17, 0x1c, 0xe8, 0x8d, 0x9c, 0x85,
    0x35, 0xf2, 0xcd, 0x28, 0x79, 0xad, 0xb8, 0x9d, 0xce, 0x06, 0x90, 0xde, 0x4c, 0xdb, 0x9b, 0x19,
    0x72, 0xa9, 0xa7, 0xbe, 0xa4, 0x3a, 0xe4, 0x3e, 0xd9, 0x4d, 0xf3, 0x3a, 0x28, 0x3b, 0x8e, 0x69,
    0x6b, 0xd0, 0x2d, 0x5b, 0x1f, 0xd3, 0x43, 0x57, 0xcd, 0x09, 0xb0, 0xbc, 0x2e, 0xd8, 0xda, 0x42,
    0xab, 0x43, 0x72, 0xa7, 0xd4, 0x72, 0xc5, 0xab, 0xc4, 0x3f, 0x29, 0x6b, 0x13, 0xbc, 0x0a, 0x77,
    0xa5, 0x62, 0xc9, 0x90, 0x4f, 0x9a, 0xcc, 0xc5, 0xed, 0x0d, 0x46, 0x47, 0x46, 0x3a, 0x2b, 0x51,
    0xb0, 0x71, 0x7b, 0x3b, 0x59, 0x9f, 0x95, 0x8f, 0xd9, 0x1d, 0xea, 0x59, 0x03, 0x26, 0xfb, 0xd9,
    0x03, 0xd3, 0x05, 0x93, 0x38, 0xda, 0x19, 0x3a, 0xe9, 0x7b, 0x8c, 0x0e, 0xad, 0xa1, 0x06, 0x9c,
    0x0e, 0x12, 0x7e, 0xda, 0x9c, 0x0e, 0x0c, 0xe4, 0x7d, 0xeb, 0x20, 0xed, 0xc2, 0x51, 0x9a, 0x32,
    0xf5, 0xfc, 0x93, 0xf3, 0xd1, 0xb3, 0xbf, 0x15, 0x61, 0x5f, 0x10, 0xcb, 0xbe, 0x15, 0x58, 0x0c,
    0x98, 0xf6, 0xb0, 0x04, 0xcf, 0x83, 0x39, 0xf2, 0x4d, 0xa7, 0x4e, 0x60, 0x27, 0x7e, 0xe1, 0x74,
    0xe6, 0xd9, 0x4d, 0x30, 0x36, 0xb5, 0x77, 0x3c, 0x32, 0x84, 0xf8, 0xa4, 0x9e, 0x01, 0x42, 0x7a,
    0x86, 0x59, 0xa8, 0x84, 0xf0, 0xf4, 0x31, 0x85, 0x84, 0xec, 0x24, 0x1e, 0x2b, 0x42, 0x74, 0xda,
    0x66, 0x93, 0xd3, 0x36, 0x0d, 0x9c, 0xb6, 0x29, 0xdc, 0xb4, 0x4d, 0xc2, 0xa6, 0x6d, 0x08, 0x35,
    0x6d, 0xf4, 0xd0, 0xb4, 0xd1, 0x32, 0xd3, 0xd6, 0x0c, 0x99, 0x36, 0x6a, 0x62, 0xda, 0xd0, 0xc0,
    0x74, 0x1c, 0x75, 0x03, 0x32, 0xef, 0x59, 0x83, 0x6a, 0xba, 0xc8, 0xbb, 0xa9, 0xcc, 0x29, 0xe0,
    0x44, 0xe5, 0x9b, 0x02, 0x34, 0x0a, 0xe8, 0xb6, 0xe3, 0x2f, 0x51, 0x78, 0x70, 0x9f, 0xd6, 0xa9,
    0x28, 0xbe, 0xe1, 0x7f, 0x52, 0xff, 0x0e, 0xa1, 0xdb, 0xb0, 0x31, 0xfe, 0xe4, 0x74, 0x1b, 0xba,
    0x3e, 0x8b, 0xd0, 0xc1, 0xf3, 0x0b, 0x03, 0x91, 0xe6, 0xf9
};
#endif

PyTypeObject *init_QRestAccessManager(PyObject *module)
{
    if (SbkPySide6_QtNetworkTypeStructs[SBK_QRestAccessManager_IDX].type != nullptr)
        return SbkPySide6_QtNetworkTypeStructs[SBK_QRestAccessManager_IDX].type;

    Shiboken::AutoDecRef Sbk_QRestAccessManager_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QRestAccessManager_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QRestAccessManager",
        "QRestAccessManager*",
        &Sbk_QRestAccessManager_spec,
        &Shiboken::callCppDestructor< QRestAccessManager >,
        Sbk_QRestAccessManager_Type_bases.object(),
        0);
    auto *pyType = Sbk_QRestAccessManager_TypeF(); // references _Sbk_QRestAccessManager_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QRestAccessManager_SignatureStrings);
#else
    InitSignatureBytes(pyType, QRestAccessManager_SignatureBytes, QRestAccessManager_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QRestAccessManager_PropertyStrings);
    SbkPySide6_QtNetworkTypeStructs[SBK_QRestAccessManager_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QRestAccessManager_PythonToCpp_QRestAccessManager_PTR,
        is_QRestAccessManager_PythonToCpp_QRestAccessManager_PTR_Convertible,
        QRestAccessManager_PTR_CppToPython_QRestAccessManager);

    Shiboken::Conversions::registerConverterName(converter, "QRestAccessManager");
    Shiboken::Conversions::registerConverterName(converter, "QRestAccessManager*");
    Shiboken::Conversions::registerConverterName(converter, "QRestAccessManager&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QRestAccessManager).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QRestAccessManagerWrapper).name());


    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QRestAccessManager_TypeF(), &Sbk_QRestAccessManager_typeDiscovery);


    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QRestAccessManager::staticMetaObject, sizeof(QRestAccessManagerWrapper));

    return pyType;
}

