// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnetwork_python.h"

// main header
#include "qrestreply_wrapper.h"

// Argument includes
#include <QString>
#include <QtNetwork/qnetworkreply.h>
#include <QtNetwork/qrestreply.h>
#include <qbytearray.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QRestReply_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QRestReply >()))
        return -1;

    ::QRestReply *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QRestReply", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QRestReply::QRestReply(QNetworkReply*)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QRestReply(QNetworkReply*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QRestReply_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtNetworkTypeStructs[SBK_QRestReply_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QNetworkReply *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QRestReply(QNetworkReply*)
            cptr = new ::QRestReply(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QRestReply >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QRestReply_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QRestReplyFunc_error(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRestReply *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QRestReply_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // error()const
        QNetworkReply::NetworkError cppResult = const_cast<const ::QRestReply *>(cppSelf)->error();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_NetworkError_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRestReplyFunc_errorString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRestReply *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QRestReply_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // errorString()const
        QString cppResult = const_cast<const ::QRestReply *>(cppSelf)->errorString();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRestReplyFunc_hasError(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRestReply *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QRestReply_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hasError()const
        bool cppResult = const_cast<const ::QRestReply *>(cppSelf)->hasError();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRestReplyFunc_httpStatus(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRestReply *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QRestReply_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // httpStatus()const
        int cppResult = const_cast<const ::QRestReply *>(cppSelf)->httpStatus();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRestReplyFunc_isHttpStatusSuccess(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRestReply *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QRestReply_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isHttpStatusSuccess()const
        bool cppResult = const_cast<const ::QRestReply *>(cppSelf)->isHttpStatusSuccess();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRestReplyFunc_isSuccess(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRestReply *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QRestReply_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isSuccess()const
        bool cppResult = const_cast<const ::QRestReply *>(cppSelf)->isSuccess();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRestReplyFunc_networkReply(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRestReply *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QRestReply_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // networkReply()const
        QNetworkReply * cppResult = const_cast<const ::QRestReply *>(cppSelf)->networkReply();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRestReplyFunc_readBody(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRestReply *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QRestReply_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // readBody()
        QByteArray cppResult = cppSelf->readBody();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRestReplyFunc_readJson(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRestReply *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QRestReply_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // readJson()
        // Begin code injection
        // ========================================================================
        // START of custom code block [file: ../glue/qtnetwork.cpp (qrestreply-readjson)]
        QJsonParseError jsonParseError;
        std::optional<QJsonDocument> documentOptional = cppSelf->readJson(&jsonParseError);

        PyObject *pyDocument{};
        if (documentOptional.has_value()) {
            const auto &document = documentOptional.value();
            pyDocument = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]), &document);
        } else {
            pyDocument = Py_None;
            Py_INCREF(Py_None);
        }

        pyResult = PyTuple_New(2);
        PyTuple_SetItem(pyResult, 0, pyDocument);
        PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonParseError_IDX]), &jsonParseError));
        // END of custom code block [file: ../glue/qtnetwork.cpp (qrestreply-readjson)]
        // ========================================================================
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRestReplyFunc_readText(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRestReply *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QRestReply_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // readText()
        QString cppResult = cppSelf->readText();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRestReplyFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRestReply *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QRestReply_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRestReply::swap(QRestReply&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QRestReply_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QRestReply&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QRestReply_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRestReply *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QRestReply&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QRestReply_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QRestReply_methods[] = {
    {"error", reinterpret_cast<PyCFunction>(Sbk_QRestReplyFunc_error), METH_NOARGS, nullptr},
    {"errorString", reinterpret_cast<PyCFunction>(Sbk_QRestReplyFunc_errorString), METH_NOARGS, nullptr},
    {"hasError", reinterpret_cast<PyCFunction>(Sbk_QRestReplyFunc_hasError), METH_NOARGS, nullptr},
    {"httpStatus", reinterpret_cast<PyCFunction>(Sbk_QRestReplyFunc_httpStatus), METH_NOARGS, nullptr},
    {"isHttpStatusSuccess", reinterpret_cast<PyCFunction>(Sbk_QRestReplyFunc_isHttpStatusSuccess), METH_NOARGS, nullptr},
    {"isSuccess", reinterpret_cast<PyCFunction>(Sbk_QRestReplyFunc_isSuccess), METH_NOARGS, nullptr},
    {"networkReply", reinterpret_cast<PyCFunction>(Sbk_QRestReplyFunc_networkReply), METH_NOARGS, nullptr},
    {"readBody", reinterpret_cast<PyCFunction>(Sbk_QRestReplyFunc_readBody), METH_NOARGS, nullptr},
    {"readJson", reinterpret_cast<PyCFunction>(Sbk_QRestReplyFunc_readJson), METH_NOARGS, nullptr},
    {"readText", reinterpret_cast<PyCFunction>(Sbk_QRestReplyFunc_readText), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QRestReplyFunc_swap), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QRestReply_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QRestReply_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QRestReply_Type = nullptr;
static PyTypeObject *Sbk_QRestReply_TypeF(void)
{
    return _Sbk_QRestReply_Type;
}

static PyType_Slot Sbk_QRestReply_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QRestReply_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QRestReply_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QRestReply_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QRestReply_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QRestReply_spec = {
    "2:PySide6.QtNetwork.QRestReply",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QRestReply_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QRestReply_PythonToCpp_QRestReply_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QRestReply_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QRestReply_PythonToCpp_QRestReply_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QRestReply_TypeF()))
        return QRestReply_PythonToCpp_QRestReply_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QRestReply_PTR_CppToPython_QRestReply(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QRestReply_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QRestReply_SignatureStrings[] = {
    "PySide6.QtNetwork.QRestReply(self,reply:PySide6.QtNetwork.QNetworkReply)",
    "PySide6.QtNetwork.QRestReply.error(self)->PySide6.QtNetwork.QNetworkReply.NetworkError",
    "PySide6.QtNetwork.QRestReply.errorString(self)->QString",
    "PySide6.QtNetwork.QRestReply.hasError(self)->bool",
    "PySide6.QtNetwork.QRestReply.httpStatus(self)->int",
    "PySide6.QtNetwork.QRestReply.isHttpStatusSuccess(self)->bool",
    "PySide6.QtNetwork.QRestReply.isSuccess(self)->bool",
    "PySide6.QtNetwork.QRestReply.networkReply(self)->PySide6.QtNetwork.QNetworkReply",
    "PySide6.QtNetwork.QRestReply.readBody(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtNetwork.QRestReply.readJson(self)->Tuple[Optional[PySide6.QtCore.QJsonDocument],PySide6.QtCore.QJsonParseError]",
    "PySide6.QtNetwork.QRestReply.readText(self)->QString",
    "PySide6.QtNetwork.QRestReply.swap(self,other:PySide6.QtNetwork.QRestReply)",
    nullptr}; // Sentinel
#else
static constexpr size_t QRestReply_SignatureByteSize = 229;
static constexpr uint8_t QRestReply_SignatureBytes[229] = {
    0x78, 0xda, 0x95, 0x92, 0xc1, 0x6e, 0xc2, 0x30, 0x0c, 0x86, 0xef, 0x3c, 0xc9, 0x2a, 0xb1, 0x1c,
    0x39, 0x70, 0x40, 0x1a, 0x0c, 0x09, 0x71, 0x18, 0x2d, 0xe5, 0x86, 0x38, 0x84, 0xd6, 0xd0, 0x88,
    0x2c, 0x8e, 0x6c, 0x57, 0xac, 0x6f, 0x8f, 0x5a, 0x28, 0x42, 0x03, 0xa5, 0xe5, 0x16, 0x2b, 0xff,
    0xf7, 0x39, 0x72, 0x1c, 0x57, 0xa9, 0xc9, 0x61, 0xa4, 0x12, 0xf9, 0x01, 0x39, 0x23, 0x9d, 0x54,
    0xb2, 0x06, 0x96, 0x35, 0x78, 0x5b, 0x7d, 0x30, 0xd8, 0xc3, 0x90, 0xea, 0xe3, 0x38, 0x7e, 0xce,
    0xdd, 0x0e, 0x4d, 0x34, 0x1a, 0xc4, 0x01, 0x91, 0x02, 0x22, 0xa4, 0x46, 0x17, 0x7d, 0x4e, 0x3a,
    0x54, 0xea, 0x56, 0xcc, 0x6b, 0xa6, 0x87, 0x36, 0x15, 0x32, 0xee, 0xd8, 0xca, 0x93, 0x6b, 0x19,
    0xe6, 0x0a, 0xcd, 0xf3, 0xc7, 0x17, 0xed, 0x11, 0x6d, 0x07, 0x21, 0xe2, 0x53, 0xd1, 0x52, 0x72,
    0xcb, 0x18, 0x27, 0x61, 0xc4, 0xf0, 0xe2, 0x0e, 0xa5, 0x65, 0x96, 0x01, 0x73, 0xff, 0x7e, 0xe6,
    0x7d, 0xc4, 0x3d, 0xcc, 0xb0, 0xe7, 0xa8, 0xc3, 0x42, 0x02, 0x9d, 0x4f, 0x31, 0x7f, 0x21, 0x9b,
    0x21, 0x81, 0x4a, 0xa6, 0x95, 0xc0, 0x17, 0x91, 0xee, 0xa1, 0x59, 0x32, 0xba, 0x56, 0xb3, 0x29,
    0xbd, 0x85, 0xed, 0xca, 0x8b, 0x41, 0xa7, 0xed, 0xf6, 0xbf, 0xb5, 0x8e, 0x7e, 0x63, 0x56, 0xfe,
    0x82, 0x93, 0xdd, 0xf0, 0xd5, 0x6d, 0xac, 0x89, 0xa1, 0xf9, 0xbf, 0x5d, 0x77, 0xe7, 0x0d, 0xfc,
    0xc9, 0x5b, 0xbb, 0xc1, 0x67, 0xed, 0xaf, 0x8b, 0x8f, 0x52, 0x00, 0x8d, 0x43, 0xe1, 0x68, 0x70,
    0x01, 0xe8, 0x4a, 0x30, 0xdc
};
#endif

PyTypeObject *init_QRestReply(PyObject *module)
{
    if (SbkPySide6_QtNetworkTypeStructs[SBK_QRestReply_IDX].type != nullptr)
        return SbkPySide6_QtNetworkTypeStructs[SBK_QRestReply_IDX].type;

    Shiboken::AutoDecRef Sbk_QRestReply_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QRestReply_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QRestReply",
        "QRestReply*",
        &Sbk_QRestReply_spec,
        &Shiboken::callCppDestructor< ::QRestReply >,
        Sbk_QRestReply_Type_bases.object(),
        0);
    auto *pyType = Sbk_QRestReply_TypeF(); // references _Sbk_QRestReply_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QRestReply_SignatureStrings);
#else
    InitSignatureBytes(pyType, QRestReply_SignatureBytes, QRestReply_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QRestReply_PropertyStrings);
    SbkPySide6_QtNetworkTypeStructs[SBK_QRestReply_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QRestReply_PythonToCpp_QRestReply_PTR,
        is_QRestReply_PythonToCpp_QRestReply_PTR_Convertible,
        QRestReply_PTR_CppToPython_QRestReply);

    Shiboken::Conversions::registerConverterName(converter, "QRestReply");
    Shiboken::Conversions::registerConverterName(converter, "QRestReply*");
    Shiboken::Conversions::registerConverterName(converter, "QRestReply&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QRestReply).name());

    qRegisterMetaType< ::QRestReply *>();

    return pyType;
}
