// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnetwork_python.h"

// main header
#include "qssldiffiehellmanparameters_wrapper.h"

// Argument includes
#include <QString>
#include <QtNetwork/qssl.h>
#include <QtNetwork/qssldiffiehellmanparameters.h>
#include <qbytearray.h>
#include <qiodevice.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSslDiffieHellmanParameters_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSslDiffieHellmanParameters >()))
        return -1;

    ::QSslDiffieHellmanParameters *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QSslDiffieHellmanParameters", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QSslDiffieHellmanParameters::QSslDiffieHellmanParameters()
    // 1: QSslDiffieHellmanParameters::QSslDiffieHellmanParameters(QSslDiffieHellmanParameters)
    if (numArgs == 0) {
        overloadId = 0; // QSslDiffieHellmanParameters()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslDiffieHellmanParameters_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QSslDiffieHellmanParameters(QSslDiffieHellmanParameters)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QSslDiffieHellmanParameters_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtNetworkTypeStructs[SBK_QSslDiffieHellmanParameters_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QSslDiffieHellmanParameters()
        {

            // QSslDiffieHellmanParameters()
            cptr = new ::QSslDiffieHellmanParameters();
            break;
        }
        case 1: // QSslDiffieHellmanParameters(const QSslDiffieHellmanParameters &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QSslDiffieHellmanParameters cppArg0_local;
            ::QSslDiffieHellmanParameters *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QSslDiffieHellmanParameters(QSslDiffieHellmanParameters)
                cptr = new ::QSslDiffieHellmanParameters(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QSslDiffieHellmanParameters >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QSslDiffieHellmanParameters_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSslDiffieHellmanParametersFunc_defaultParameters(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // defaultParameters()
        QSslDiffieHellmanParameters cppResult = ::QSslDiffieHellmanParameters::defaultParameters();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslDiffieHellmanParameters_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSslDiffieHellmanParametersFunc_error(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSslDiffieHellmanParameters *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslDiffieHellmanParameters_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // error()const
        QSslDiffieHellmanParameters::Error cppResult = const_cast<const ::QSslDiffieHellmanParameters *>(cppSelf)->error();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslDiffieHellmanParameters_Error_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSslDiffieHellmanParametersFunc_errorString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSslDiffieHellmanParameters *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslDiffieHellmanParameters_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // errorString()const
        QString cppResult = const_cast<const ::QSslDiffieHellmanParameters *>(cppSelf)->errorString();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSslDiffieHellmanParametersFunc_fromEncoded(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "fromEncoded", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QSslDiffieHellmanParameters_IDX]);

    if (PyArg_ParseTuple(args, "|OO:fromEncoded", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QSslDiffieHellmanParameters::fromEncoded(QIODevice*,QSsl::EncodingFormat=)->QSslDiffieHellmanParameters
    // 1: static QSslDiffieHellmanParameters::fromEncoded(QByteArray,QSsl::EncodingFormat=)->QSslDiffieHellmanParameters
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // fromEncoded(QByteArray,QSsl::EncodingFormat)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSsl_EncodingFormat_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 1; // fromEncoded(QByteArray,QSsl::EncodingFormat)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // fromEncoded(QIODevice*,QSsl::EncodingFormat)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSsl_EncodingFormat_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // fromEncoded(QIODevice*,QSsl::EncodingFormat)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fromEncoded", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QSslDiffieHellmanParameters_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // fromEncoded(QIODevice *device, QSsl::EncodingFormat format)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_format = Shiboken::String::createStaticString("format");
                if (PyDict_Contains(kwds, key_format) != 0) {
                    value = PyDict_GetItem(kwds, key_format);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_format);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "fromEncoded", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QSslDiffieHellmanParameters_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSsl_EncodingFormat_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "fromEncoded", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QSslDiffieHellmanParameters_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_format);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "fromEncoded", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QSslDiffieHellmanParameters_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QIODevice *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QSsl::EncodingFormat cppArg1(QSsl::Pem);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fromEncoded(QIODevice*,QSsl::EncodingFormat)
                QSslDiffieHellmanParameters cppResult = ::QSslDiffieHellmanParameters::fromEncoded(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslDiffieHellmanParameters_IDX]), &cppResult);
            }
            break;
        }
        case 1: // fromEncoded(const QByteArray &encoded, QSsl::EncodingFormat format)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_format = Shiboken::String::createStaticString("format");
                if (PyDict_Contains(kwds, key_format) != 0) {
                    value = PyDict_GetItem(kwds, key_format);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_format);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "fromEncoded", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QSslDiffieHellmanParameters_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSsl_EncodingFormat_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "fromEncoded", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QSslDiffieHellmanParameters_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_format);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "fromEncoded", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QSslDiffieHellmanParameters_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QSsl::EncodingFormat cppArg1(QSsl::Pem);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fromEncoded(QByteArray,QSsl::EncodingFormat)
                QSslDiffieHellmanParameters cppResult = ::QSslDiffieHellmanParameters::fromEncoded(*cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslDiffieHellmanParameters_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSslDiffieHellmanParametersFunc_isEmpty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSslDiffieHellmanParameters *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslDiffieHellmanParameters_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isEmpty()const
        bool cppResult = const_cast<const ::QSslDiffieHellmanParameters *>(cppSelf)->isEmpty();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSslDiffieHellmanParametersFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSslDiffieHellmanParameters *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslDiffieHellmanParameters_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QSslDiffieHellmanParameters *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSslDiffieHellmanParametersFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSslDiffieHellmanParameters *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslDiffieHellmanParameters_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSslDiffieHellmanParameters::swap(QSslDiffieHellmanParameters&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslDiffieHellmanParameters_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QSslDiffieHellmanParameters&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QSslDiffieHellmanParameters_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSslDiffieHellmanParameters cppArg0_local;
        ::QSslDiffieHellmanParameters *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QSslDiffieHellmanParameters&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSslDiffieHellmanParameters__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QSslDiffieHellmanParameters *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslDiffieHellmanParameters_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslDiffieHellmanParameters_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QSslDiffieHellmanParameters_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QSslDiffieHellmanParameters_EnumFlagInfo[] = {
    "Error:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSslDiffieHellmanParameters_methods[] = {
    {"defaultParameters", reinterpret_cast<PyCFunction>(Sbk_QSslDiffieHellmanParametersFunc_defaultParameters), METH_NOARGS|METH_STATIC, nullptr},
    {"error", reinterpret_cast<PyCFunction>(Sbk_QSslDiffieHellmanParametersFunc_error), METH_NOARGS, nullptr},
    {"errorString", reinterpret_cast<PyCFunction>(Sbk_QSslDiffieHellmanParametersFunc_errorString), METH_NOARGS, nullptr},
    {"fromEncoded", reinterpret_cast<PyCFunction>(Sbk_QSslDiffieHellmanParametersFunc_fromEncoded), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"isEmpty", reinterpret_cast<PyCFunction>(Sbk_QSslDiffieHellmanParametersFunc_isEmpty), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QSslDiffieHellmanParametersFunc_isValid), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QSslDiffieHellmanParametersFunc_swap), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QSslDiffieHellmanParameters__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QSslDiffieHellmanParameters_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QSslDiffieHellmanParameters *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslDiffieHellmanParameters_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslDiffieHellmanParameters_IDX]), (pyArg)))) {
                // operator!=(const QSslDiffieHellmanParameters &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QSslDiffieHellmanParameters cppArg0_local;
                ::QSslDiffieHellmanParameters *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslDiffieHellmanParameters_IDX]), (pyArg)))) {
                // operator==(const QSslDiffieHellmanParameters &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QSslDiffieHellmanParameters cppArg0_local;
                ::QSslDiffieHellmanParameters *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static Py_hash_t Sbk_QSslDiffieHellmanParameters_HashFunc(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSslDiffieHellmanParameters *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslDiffieHellmanParameters_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return Py_hash_t(qHash(*cppSelf));
}

static int Sbk_QSslDiffieHellmanParameters_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSslDiffieHellmanParameters_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QSslDiffieHellmanParameters__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSslDiffieHellmanParameters *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslDiffieHellmanParameters_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSslDiffieHellmanParameters_Type = nullptr;
static PyTypeObject *Sbk_QSslDiffieHellmanParameters_TypeF(void)
{
    return _Sbk_QSslDiffieHellmanParameters_Type;
}

static PyType_Slot Sbk_QSslDiffieHellmanParameters_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QSslDiffieHellmanParameters__repr__)},
    {Py_tp_hash,        reinterpret_cast<void *>(&Sbk_QSslDiffieHellmanParameters_HashFunc)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSslDiffieHellmanParameters_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSslDiffieHellmanParameters_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QSslDiffieHellmanParameters_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSslDiffieHellmanParameters_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSslDiffieHellmanParameters_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSslDiffieHellmanParameters_spec = {
    "2:PySide6.QtNetwork.QSslDiffieHellmanParameters",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSslDiffieHellmanParameters_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QSslDiffieHellmanParameters_Error(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSslDiffieHellmanParameters::Error>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSslDiffieHellmanParameters::Error *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QSslDiffieHellmanParameters_Error_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslDiffieHellmanParameters_Error_IDX])))
        return Enum_PythonToCpp_QSslDiffieHellmanParameters_Error;
    return {};
}

static PyObject *QSslDiffieHellmanParameters_Error_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QSslDiffieHellmanParameters::Error>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QSslDiffieHellmanParameters::Error *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslDiffieHellmanParameters_Error_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSslDiffieHellmanParameters_PythonToCpp_QSslDiffieHellmanParameters_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSslDiffieHellmanParameters_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSslDiffieHellmanParameters_PythonToCpp_QSslDiffieHellmanParameters_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSslDiffieHellmanParameters_TypeF()))
        return QSslDiffieHellmanParameters_PythonToCpp_QSslDiffieHellmanParameters_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSslDiffieHellmanParameters_PTR_CppToPython_QSslDiffieHellmanParameters(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QSslDiffieHellmanParameters_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QSslDiffieHellmanParameters_COPY_CppToPython_QSslDiffieHellmanParameters(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QSslDiffieHellmanParameters *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QSslDiffieHellmanParameters_TypeF(), new ::QSslDiffieHellmanParameters(*source), true, true);
}

// Python to C++ copy conversion.
static void QSslDiffieHellmanParameters_PythonToCpp_QSslDiffieHellmanParameters_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QSslDiffieHellmanParameters *>(cppOut) = *reinterpret_cast< ::QSslDiffieHellmanParameters *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslDiffieHellmanParameters_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QSslDiffieHellmanParameters_PythonToCpp_QSslDiffieHellmanParameters_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QSslDiffieHellmanParameters_TypeF()))
        return QSslDiffieHellmanParameters_PythonToCpp_QSslDiffieHellmanParameters_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSslDiffieHellmanParameters_SignatureStrings[] = {
    "1:PySide6.QtNetwork.QSslDiffieHellmanParameters(self)",
    "0:PySide6.QtNetwork.QSslDiffieHellmanParameters(self,other:PySide6.QtNetwork.QSslDiffieHellmanParameters)",
    "PySide6.QtNetwork.QSslDiffieHellmanParameters.defaultParameters()->PySide6.QtNetwork.QSslDiffieHellmanParameters",
    "PySide6.QtNetwork.QSslDiffieHellmanParameters.error(self)->PySide6.QtNetwork.QSslDiffieHellmanParameters.Error",
    "PySide6.QtNetwork.QSslDiffieHellmanParameters.errorString(self)->QString",
    "1:PySide6.QtNetwork.QSslDiffieHellmanParameters.fromEncoded(device:PySide6.QtCore.QIODevice,format:PySide6.QtNetwork.QSsl.EncodingFormat=QSsl.Pem)->PySide6.QtNetwork.QSslDiffieHellmanParameters",
    "0:PySide6.QtNetwork.QSslDiffieHellmanParameters.fromEncoded(encoded:typing.Union[PySide6.QtCore.QByteArray, char*],format:PySide6.QtNetwork.QSsl.EncodingFormat=QSsl.Pem)->PySide6.QtNetwork.QSslDiffieHellmanParameters",
    "PySide6.QtNetwork.QSslDiffieHellmanParameters.isEmpty(self)->bool",
    "PySide6.QtNetwork.QSslDiffieHellmanParameters.isValid(self)->bool",
    "PySide6.QtNetwork.QSslDiffieHellmanParameters.swap(self,other:PySide6.QtNetwork.QSslDiffieHellmanParameters)",
    "PySide6.QtNetwork.QSslDiffieHellmanParameters.__copy__(self)->typing.Self",
    "PySide6.QtNetwork.QSslDiffieHellmanParameters.__ne__(self,rhs:PySide6.QtNetwork.QSslDiffieHellmanParameters)->bool",
    "PySide6.QtNetwork.QSslDiffieHellmanParameters.__eq__(self,rhs:PySide6.QtNetwork.QSslDiffieHellmanParameters)->bool",
    "PySide6.QtNetwork.QSslDiffieHellmanParameters.__hash__(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t QSslDiffieHellmanParameters_SignatureByteSize = 283;
static constexpr uint8_t QSslDiffieHellmanParameters_SignatureBytes[283] = {
    0x78, 0xda, 0xbd, 0x53, 0x4b, 0x4b, 0xc4, 0x30, 0x10, 0xbe, 0xf7, 0x57, 0x78, 0xdc, 0x4a, 0x0d,
    0xbb, 0x17, 0x0f, 0x0b, 0x0a, 0xea, 0x56, 0xf4, 0xa2, 0x2d, 0x45, 0x2f, 0x22, 0x21, 0x36, 0x13,
    0x1b, 0xcc, 0xa3, 0x4e, 0xa2, 0x4b, 0xfe, 0xbd, 0xb5, 0xdd, 0xe2, 0xb2, 0xe0, 0x21, 0x5d, 0xe8,
    0x29, 0x4c, 0x32, 0xf3, 0xbd, 0x86, 0xac, 0xd6, 0x45, 0xa8, 0x24, 0x87, 0x73, 0x52, 0xfa, 0x07,
    0xf0, 0x5b, 0x8b, 0x1f, 0xa4, 0xac, 0x9c, 0xda, 0x48, 0x21, 0x24, 0xdc, 0x81, 0x52, 0x9a, 0x99,
    0x82, 0x21, 0xd3, 0xe0, 0x01, 0xdd, 0xc2, 0x81, 0x12, 0x69, 0xb2, 0x9c, 0x30, 0x95, 0x59, 0xdf,
    0x00, 0xc6, 0x0d, 0xa6, 0x49, 0x54, 0x3b, 0xe1, 0x20, 0xd8, 0x97, 0xf2, 0x7b, 0xcc, 0xe9, 0xd9,
    0x65, 0x14, 0x44, 0x24, 0x21, 0x20, 0x5a, 0x1c, 0x42, 0x89, 0x24, 0x22, 0xf9, 0xef, 0xe8, 0x14,
    0xba, 0xca, 0xa3, 0x34, 0xef, 0x23, 0x69, 0x39, 0x94, 0xc9, 0x2a, 0x2e, 0x59, 0x22, 0xd0, 0xea,
    0xdc, 0xd4, 0x96, 0x03, 0x5f, 0x70, 0xf8, 0x96, 0x35, 0xec, 0x01, 0xdc, 0x58, 0x04, 0x52, 0xde,
    0x3f, 0x6e, 0xfa, 0x87, 0x4c, 0x58, 0xd4, 0xcc, 0xff, 0x43, 0x40, 0x7a, 0x94, 0x4e, 0xc2, 0x6d,
    0xdf, 0x75, 0xd1, 0xdf, 0x15, 0xa0, 0xa3, 0x93, 0x5f, 0x1e, 0xe1, 0x00, 0x86, 0x73, 0xed, 0x43,
    0xdb, 0x29, 0x21, 0x4f, 0x46, 0x5a, 0xf3, 0x72, 0xe8, 0xe7, 0x3a, 0x78, 0xb8, 0x42, 0x64, 0x21,
    0x3b, 0xa9, 0x1b, 0x86, 0xa7, 0xaf, 0x33, 0x19, 0x8b, 0xb3, 0x25, 0x5d, 0xae, 0x5b, 0x1f, 0xc6,
    0xfd, 0xbe, 0x59, 0xab, 0xa2, 0x11, 0x9e, 0x99, 0x92, 0xfc, 0x08, 0x04, 0xb7, 0x65, 0xed, 0x6c,
    0x9f, 0x96, 0xd2, 0xda, 0xb6, 0x81, 0xd2, 0x51, 0xef, 0x6e, 0x87, 0x55, 0x57, 0x45, 0x23, 0x19,
    0xd8, 0xe1, 0x64, 0xd8, 0xb8, 0x48, 0xd9, 0x93, 0x92, 0xa2, 0x14, 0x3e, 0x67, 0xa7, 0x6c, 0x98,
    0x6b, 0xfe, 0xf2, 0x92, 0xc6, 0x27, 0x3f, 0x74, 0x45, 0x22, 0xef
};
#endif

PyTypeObject *init_QSslDiffieHellmanParameters(PyObject *module)
{
    if (SbkPySide6_QtNetworkTypeStructs[SBK_QSslDiffieHellmanParameters_IDX].type != nullptr)
        return SbkPySide6_QtNetworkTypeStructs[SBK_QSslDiffieHellmanParameters_IDX].type;

    Shiboken::AutoDecRef Sbk_QSslDiffieHellmanParameters_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QSslDiffieHellmanParameters_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSslDiffieHellmanParameters",
        "QSslDiffieHellmanParameters",
        &Sbk_QSslDiffieHellmanParameters_spec,
        &Shiboken::callCppDestructor< ::QSslDiffieHellmanParameters >,
        Sbk_QSslDiffieHellmanParameters_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QSslDiffieHellmanParameters_TypeF(); // references _Sbk_QSslDiffieHellmanParameters_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSslDiffieHellmanParameters_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSslDiffieHellmanParameters_SignatureBytes, QSslDiffieHellmanParameters_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSslDiffieHellmanParameters_PropertyStrings);
    SbkPySide6_QtNetworkTypeStructs[SBK_QSslDiffieHellmanParameters_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSslDiffieHellmanParameters_PythonToCpp_QSslDiffieHellmanParameters_PTR,
        is_QSslDiffieHellmanParameters_PythonToCpp_QSslDiffieHellmanParameters_PTR_Convertible,
        QSslDiffieHellmanParameters_PTR_CppToPython_QSslDiffieHellmanParameters,
        QSslDiffieHellmanParameters_COPY_CppToPython_QSslDiffieHellmanParameters);

    Shiboken::Conversions::registerConverterName(converter, "QSslDiffieHellmanParameters");
    Shiboken::Conversions::registerConverterName(converter, "QSslDiffieHellmanParameters*");
    Shiboken::Conversions::registerConverterName(converter, "QSslDiffieHellmanParameters&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSslDiffieHellmanParameters).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QSslDiffieHellmanParameters_PythonToCpp_QSslDiffieHellmanParameters_COPY,
        is_QSslDiffieHellmanParameters_PythonToCpp_QSslDiffieHellmanParameters_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QSslDiffieHellmanParameters_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Error'.
    const char *Error_Initializer[] = {
        "NoError",
        "InvalidInputDataError",
        "UnsafeParametersError",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Error_InitializerValues[] = {
        uint8_t(QSslDiffieHellmanParameters::Error::NoError),               //  0x00  0
        uint8_t(QSslDiffieHellmanParameters::Error::InvalidInputDataError), //  0x01  1
        uint8_t(QSslDiffieHellmanParameters::Error::UnsafeParametersError)  //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSslDiffieHellmanParameters_TypeF(),
        "2:PySide6.QtNetwork.QSslDiffieHellmanParameters.Error",
        Error_Initializer, Error_InitializerValues);
    SbkPySide6_QtNetworkTypeStructs[SBK_QSslDiffieHellmanParameters_Error_IDX].type = EType;
    // Register converter for enum 'QSslDiffieHellmanParameters::Error'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSslDiffieHellmanParameters_Error_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QSslDiffieHellmanParameters_Error,
            is_Enum_PythonToCpp_QSslDiffieHellmanParameters_Error_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QSslDiffieHellmanParameters::Error");
        Shiboken::Conversions::registerConverterAlias(converter, "Error");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Error' enum.

    qRegisterMetaType< ::QSslDiffieHellmanParameters >("QSslDiffieHellmanParameters");
    qRegisterMetaType< ::QSslDiffieHellmanParameters::Error >("QSslDiffieHellmanParameters::Error");

    return pyType;
}
