// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnetwork_python.h"

// main header
#include "qsslerror_wrapper.h"

// Argument includes
#include <QString>
#include <QtNetwork/qsslcertificate.h>
#include <QtNetwork/qsslerror.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSslError_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSslError >()))
        return -1;

    ::QSslError *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QSslError", 0, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QSslError::QSslError()
    // 1: QSslError::QSslError(QSslError::SslError)
    // 2: QSslError::QSslError(QSslError::SslError,QSslCertificate)
    // 3: QSslError::QSslError(QSslError)
    if (numArgs == 0) {
        overloadId = 0; // QSslError()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslError_IDX]), (pyArgs[0])))) {
        overloadId = 3; // QSslError(QSslError)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslError_SslError_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QSslError(QSslError::SslError)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslCertificate_IDX]), (pyArgs[1])))) {
            overloadId = 2; // QSslError(QSslError::SslError,QSslCertificate)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QSslError_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtNetworkTypeStructs[SBK_QSslError_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QSslError()
        {

            // QSslError()
            cptr = new ::QSslError();
            break;
        }
        case 1: // QSslError(QSslError::SslError error)
        {
            ::QSslError::SslError cppArg0{QSslError::NoError};
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QSslError(QSslError::SslError)
                cptr = new ::QSslError(cppArg0);
            }
            break;
        }
        case 2: // QSslError(QSslError::SslError error, const QSslCertificate &certificate)
        {
            ::QSslError::SslError cppArg0{QSslError::NoError};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QSslCertificate cppArg1_local;
            ::QSslCertificate *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QSslError(QSslError::SslError,QSslCertificate)
                cptr = new ::QSslError(cppArg0, *cppArg1);
            }
            break;
        }
        case 3: // QSslError(const QSslError &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QSslError cppArg0_local;
            ::QSslError *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QSslError(QSslError)
                cptr = new ::QSslError(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QSslError >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QSslError_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSslErrorFunc_certificate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSslError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // certificate()const
        QSslCertificate cppResult = const_cast<const ::QSslError *>(cppSelf)->certificate();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslCertificate_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSslErrorFunc_error(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSslError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // error()const
        QSslError::SslError cppResult = const_cast<const ::QSslError *>(cppSelf)->error();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslError_SslError_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSslErrorFunc_errorString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSslError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // errorString()const
        QString cppResult = const_cast<const ::QSslError *>(cppSelf)->errorString();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSslErrorFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSslError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSslError::swap(QSslError&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslError_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QSslError&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QSslError_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSslError cppArg0_local;
        ::QSslError *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QSslError&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSslError__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QSslError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslError_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslError_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QSslError_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QSslError_EnumFlagInfo[] = {
    "SslError:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSslError_methods[] = {
    {"certificate", reinterpret_cast<PyCFunction>(Sbk_QSslErrorFunc_certificate), METH_NOARGS, nullptr},
    {"error", reinterpret_cast<PyCFunction>(Sbk_QSslErrorFunc_error), METH_NOARGS, nullptr},
    {"errorString", reinterpret_cast<PyCFunction>(Sbk_QSslErrorFunc_errorString), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QSslErrorFunc_swap), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QSslError__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QSslError_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QSslError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslError_IDX]), (pyArg)))) {
                // operator!=(const QSslError &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QSslError cppArg0_local;
                ::QSslError *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslError_IDX]), (pyArg)))) {
                // operator==(const QSslError &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QSslError cppArg0_local;
                ::QSslError *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static Py_hash_t Sbk_QSslError_HashFunc(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSslError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return Py_hash_t(qHash(*cppSelf));
}

static int Sbk_QSslError_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSslError_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QSslError__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSslError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSslError_Type = nullptr;
static PyTypeObject *Sbk_QSslError_TypeF(void)
{
    return _Sbk_QSslError_Type;
}

static PyType_Slot Sbk_QSslError_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QSslError__repr__)},
    {Py_tp_hash,        reinterpret_cast<void *>(&Sbk_QSslError_HashFunc)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSslError_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSslError_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QSslError_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSslError_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSslError_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSslError_spec = {
    "2:PySide6.QtNetwork.QSslError",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSslError_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QSslError_SslError(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSslError::SslError>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSslError::SslError *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QSslError_SslError_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslError_SslError_IDX])))
        return Enum_PythonToCpp_QSslError_SslError;
    return {};
}

static PyObject *QSslError_SslError_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QSslError::SslError>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QSslError::SslError *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslError_SslError_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSslError_PythonToCpp_QSslError_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSslError_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSslError_PythonToCpp_QSslError_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSslError_TypeF()))
        return QSslError_PythonToCpp_QSslError_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSslError_PTR_CppToPython_QSslError(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QSslError_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QSslError_COPY_CppToPython_QSslError(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QSslError *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QSslError_TypeF(), new ::QSslError(*source), true, true);
}

// Python to C++ copy conversion.
static void QSslError_PythonToCpp_QSslError_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QSslError *>(cppOut) = *reinterpret_cast< ::QSslError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslError_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QSslError_PythonToCpp_QSslError_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QSslError_TypeF()))
        return QSslError_PythonToCpp_QSslError_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSslError_SignatureStrings[] = {
    "3:PySide6.QtNetwork.QSslError(self)",
    "2:PySide6.QtNetwork.QSslError(self,error:PySide6.QtNetwork.QSslError.SslError)",
    "1:PySide6.QtNetwork.QSslError(self,error:PySide6.QtNetwork.QSslError.SslError,certificate:typing.Union[PySide6.QtNetwork.QSslCertificate, PySide6.QtCore.QIODevice])",
    "0:PySide6.QtNetwork.QSslError(self,other:PySide6.QtNetwork.QSslError)",
    "PySide6.QtNetwork.QSslError.certificate(self)->PySide6.QtNetwork.QSslCertificate",
    "PySide6.QtNetwork.QSslError.error(self)->PySide6.QtNetwork.QSslError.SslError",
    "PySide6.QtNetwork.QSslError.errorString(self)->QString",
    "PySide6.QtNetwork.QSslError.swap(self,other:PySide6.QtNetwork.QSslError)",
    "PySide6.QtNetwork.QSslError.__copy__(self)->typing.Self",
    "PySide6.QtNetwork.QSslError.__ne__(self,other:PySide6.QtNetwork.QSslError)->bool",
    "PySide6.QtNetwork.QSslError.__eq__(self,other:PySide6.QtNetwork.QSslError)->bool",
    "PySide6.QtNetwork.QSslError.__hash__(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t QSslError_SignatureByteSize = 213;
static constexpr uint8_t QSslError_SignatureBytes[213] = {
    0x78, 0xda, 0xad, 0x91, 0x3f, 0x0f, 0x82, 0x30, 0x10, 0xc5, 0xf7, 0x7e, 0x0a, 0x47, 0x9b, 0x40,
    0xe3, 0x9f, 0xc4, 0x81, 0x81, 0x45, 0x1d, 0x5c, 0x54, 0xd2, 0x38, 0x19, 0x43, 0x10, 0x0f, 0x69,
    0x24, 0x3d, 0x2c, 0x8d, 0x84, 0x6f, 0x2f, 0x06, 0x08, 0x9a, 0x68, 0xeb, 0xc0, 0xd6, 0x4b, 0xde,
    0xfb, 0xf5, 0xdd, 0xbb, 0xb9, 0xb7, 0xaf, 0xb8, 0xb8, 0xc0, 0x82, 0x05, 0x7a, 0x0b, 0xba, 0x44,
    0x75, 0x63, 0x01, 0x2f, 0xb2, 0xb5, 0x52, 0xa8, 0xc6, 0x05, 0x64, 0x09, 0x25, 0x33, 0xab, 0xc6,
    0x81, 0xd7, 0xd3, 0x24, 0x63, 0xdd, 0x83, 0x92, 0xe9, 0x90, 0x38, 0x27, 0x06, 0xa5, 0x45, 0x22,
    0xe2, 0x48, 0x83, 0xa7, 0xab, 0x5c, 0xc8, 0x2b, 0x3b, 0x48, 0x81, 0xf2, 0xf8, 0xdd, 0xbd, 0xec,
    0xe5, 0xce, 0xa8, 0x97, 0x2c, 0x51, 0x01, 0x0b, 0x36, 0xbb, 0x15, 0x3c, 0x44, 0x0c, 0x27, 0x4a,
    0x26, 0xf6, 0x90, 0xa8, 0x53, 0x30, 0x86, 0xa4, 0xc4, 0xb4, 0xc1, 0x5b, 0xf0, 0xa6, 0x67, 0xd7,
    0xb7, 0x46, 0x36, 0x02, 0xa1, 0x3f, 0xd9, 0x2f, 0xd4, 0x67, 0x77, 0x76, 0x1a, 0xd7, 0xaa, 0x2e,
    0xb4, 0x63, 0x06, 0xcd, 0x68, 0xb4, 0x15, 0x65, 0x94, 0x0f, 0x52, 0x4f, 0x18, 0xc6, 0x98, 0x57,
    0x61, 0xd8, 0x7d, 0xde, 0xde, 0x96, 0xd7, 0x93, 0xc5, 0x27, 0xa1, 0x75, 0xfd, 0x11, 0xc1, 0xf5,
    0xcf, 0x88, 0x99, 0x05, 0x08, 0xf7, 0x81, 0x81, 0x69, 0x54, 0xa4, 0xfd, 0x66, 0x42, 0x6a, 0xf2,
    0x04, 0xfa, 0x87, 0x47, 0xb8
};
#endif

PyTypeObject *init_QSslError(PyObject *module)
{
    if (SbkPySide6_QtNetworkTypeStructs[SBK_QSslError_IDX].type != nullptr)
        return SbkPySide6_QtNetworkTypeStructs[SBK_QSslError_IDX].type;

    Shiboken::AutoDecRef Sbk_QSslError_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QSslError_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSslError",
        "QSslError",
        &Sbk_QSslError_spec,
        &Shiboken::callCppDestructor< ::QSslError >,
        Sbk_QSslError_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QSslError_TypeF(); // references _Sbk_QSslError_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSslError_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSslError_SignatureBytes, QSslError_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSslError_PropertyStrings);
    SbkPySide6_QtNetworkTypeStructs[SBK_QSslError_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSslError_PythonToCpp_QSslError_PTR,
        is_QSslError_PythonToCpp_QSslError_PTR_Convertible,
        QSslError_PTR_CppToPython_QSslError,
        QSslError_COPY_CppToPython_QSslError);

    Shiboken::Conversions::registerConverterName(converter, "QSslError");
    Shiboken::Conversions::registerConverterName(converter, "QSslError*");
    Shiboken::Conversions::registerConverterName(converter, "QSslError&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSslError).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QSslError_PythonToCpp_QSslError_COPY,
        is_QSslError_PythonToCpp_QSslError_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QSslError_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'SslError'.
    const char *SslError_Initializer[] = {
        "NoError",
        "UnableToGetIssuerCertificate",
        "UnableToDecryptCertificateSignature",
        "UnableToDecodeIssuerPublicKey",
        "CertificateSignatureFailed",
        "CertificateNotYetValid",
        "CertificateExpired",
        "InvalidNotBeforeField",
        "InvalidNotAfterField",
        "SelfSignedCertificate",
        "SelfSignedCertificateInChain",
        "UnableToGetLocalIssuerCertificate",
        "UnableToVerifyFirstCertificate",
        "CertificateRevoked",
        "InvalidCaCertificate",
        "PathLengthExceeded",
        "InvalidPurpose",
        "CertificateUntrusted",
        "CertificateRejected",
        "SubjectIssuerMismatch",
        "AuthorityIssuerSerialNumberMismatch",
        "NoPeerCertificate",
        "HostNameMismatch",
        "NoSslSupport",
        "CertificateBlacklisted",
        "CertificateStatusUnknown",
        "OcspNoResponseFound",
        "OcspMalformedRequest",
        "OcspMalformedResponse",
        "OcspInternalError",
        "OcspTryLater",
        "OcspSigRequred",
        "OcspUnauthorized",
        "OcspResponseCannotBeTrusted",
        "OcspResponseCertIdUnknown",
        "OcspResponseExpired",
        "OcspStatusUnknown",
        "UnspecifiedError",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t SslError_InitializerValues[] = {
        int8_t(QSslError::SslError::NoError),                             //  0x00  0
        int8_t(QSslError::SslError::UnableToGetIssuerCertificate),        //  0x01  1
        int8_t(QSslError::SslError::UnableToDecryptCertificateSignature), //  0x02  2
        int8_t(QSslError::SslError::UnableToDecodeIssuerPublicKey),       //  0x03  3
        int8_t(QSslError::SslError::CertificateSignatureFailed),          //  0x04  4
        int8_t(QSslError::SslError::CertificateNotYetValid),              //  0x05  5
        int8_t(QSslError::SslError::CertificateExpired),                  //  0x06  6
        int8_t(QSslError::SslError::InvalidNotBeforeField),               //  0x07  7
        int8_t(QSslError::SslError::InvalidNotAfterField),                //  0x08  8
        int8_t(QSslError::SslError::SelfSignedCertificate),               //  0x09  9
        int8_t(QSslError::SslError::SelfSignedCertificateInChain),        //  0x0a  10
        int8_t(QSslError::SslError::UnableToGetLocalIssuerCertificate),   //  0x0b  11
        int8_t(QSslError::SslError::UnableToVerifyFirstCertificate),      //  0x0c  12
        int8_t(QSslError::SslError::CertificateRevoked),                  //  0x0d  13
        int8_t(QSslError::SslError::InvalidCaCertificate),                //  0x0e  14
        int8_t(QSslError::SslError::PathLengthExceeded),                  //  0x0f  15
        int8_t(QSslError::SslError::InvalidPurpose),                      //  0x10  16
        int8_t(QSslError::SslError::CertificateUntrusted),                //  0x11  17
        int8_t(QSslError::SslError::CertificateRejected),                 //  0x12  18
        int8_t(QSslError::SslError::SubjectIssuerMismatch),               //  0x13  19
        int8_t(QSslError::SslError::AuthorityIssuerSerialNumberMismatch), //  0x14  20
        int8_t(QSslError::SslError::NoPeerCertificate),                   //  0x15  21
        int8_t(QSslError::SslError::HostNameMismatch),                    //  0x16  22
        int8_t(QSslError::SslError::NoSslSupport),                        //  0x17  23
        int8_t(QSslError::SslError::CertificateBlacklisted),              //  0x18  24
        int8_t(QSslError::SslError::CertificateStatusUnknown),            //  0x19  25
        int8_t(QSslError::SslError::OcspNoResponseFound),                 //  0x1a  26
        int8_t(QSslError::SslError::OcspMalformedRequest),                //  0x1b  27
        int8_t(QSslError::SslError::OcspMalformedResponse),               //  0x1c  28
        int8_t(QSslError::SslError::OcspInternalError),                   //  0x1d  29
        int8_t(QSslError::SslError::OcspTryLater),                        //  0x1e  30
        int8_t(QSslError::SslError::OcspSigRequred),                      //  0x1f  31
        int8_t(QSslError::SslError::OcspUnauthorized),                    //  0x20  32
        int8_t(QSslError::SslError::OcspResponseCannotBeTrusted),         //  0x21  33
        int8_t(QSslError::SslError::OcspResponseCertIdUnknown),           //  0x22  34
        int8_t(QSslError::SslError::OcspResponseExpired),                 //  0x23  35
        int8_t(QSslError::SslError::OcspStatusUnknown),                   //  0x24  36
        int8_t(QSslError::SslError::UnspecifiedError)                     // -0x01 -1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSslError_TypeF(),
        "2:PySide6.QtNetwork.QSslError.SslError",
        SslError_Initializer, SslError_InitializerValues);
    SbkPySide6_QtNetworkTypeStructs[SBK_QSslError_SslError_IDX].type = EType;
    // Register converter for enum 'QSslError::SslError'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSslError_SslError_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QSslError_SslError,
            is_Enum_PythonToCpp_QSslError_SslError_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QSslError::SslError");
        Shiboken::Conversions::registerConverterAlias(converter, "SslError");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'SslError' enum.

    qRegisterMetaType< ::QSslError >("QSslError");
    qRegisterMetaType< ::QSslError::SslError >("QSslError::SslError");

    return pyType;
}
