// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnetwork_python.h"

// main header
#include "qsslpresharedkeyauthenticator_wrapper.h"

// Argument includes
#include <QtNetwork/qsslpresharedkeyauthenticator.h>
#include <qbytearray.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSslPreSharedKeyAuthenticator_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSslPreSharedKeyAuthenticator >()))
        return -1;

    ::QSslPreSharedKeyAuthenticator *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QSslPreSharedKeyAuthenticator", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QSslPreSharedKeyAuthenticator::QSslPreSharedKeyAuthenticator()
    // 1: QSslPreSharedKeyAuthenticator::QSslPreSharedKeyAuthenticator(QSslPreSharedKeyAuthenticator)
    if (numArgs == 0) {
        overloadId = 0; // QSslPreSharedKeyAuthenticator()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslPreSharedKeyAuthenticator_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QSslPreSharedKeyAuthenticator(QSslPreSharedKeyAuthenticator)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QSslPreSharedKeyAuthenticator_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtNetworkTypeStructs[SBK_QSslPreSharedKeyAuthenticator_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QSslPreSharedKeyAuthenticator()
        {

            // QSslPreSharedKeyAuthenticator()
            cptr = new ::QSslPreSharedKeyAuthenticator();
            break;
        }
        case 1: // QSslPreSharedKeyAuthenticator(const QSslPreSharedKeyAuthenticator &authenticator)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QSslPreSharedKeyAuthenticator cppArg0_local;
            ::QSslPreSharedKeyAuthenticator *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QSslPreSharedKeyAuthenticator(QSslPreSharedKeyAuthenticator)
                cptr = new ::QSslPreSharedKeyAuthenticator(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QSslPreSharedKeyAuthenticator >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QSslPreSharedKeyAuthenticator_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSslPreSharedKeyAuthenticatorFunc_identity(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSslPreSharedKeyAuthenticator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslPreSharedKeyAuthenticator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // identity()const
        QByteArray cppResult = const_cast<const ::QSslPreSharedKeyAuthenticator *>(cppSelf)->identity();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSslPreSharedKeyAuthenticatorFunc_identityHint(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSslPreSharedKeyAuthenticator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslPreSharedKeyAuthenticator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // identityHint()const
        QByteArray cppResult = const_cast<const ::QSslPreSharedKeyAuthenticator *>(cppSelf)->identityHint();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSslPreSharedKeyAuthenticatorFunc_maximumIdentityLength(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSslPreSharedKeyAuthenticator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslPreSharedKeyAuthenticator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maximumIdentityLength()const
        int cppResult = const_cast<const ::QSslPreSharedKeyAuthenticator *>(cppSelf)->maximumIdentityLength();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSslPreSharedKeyAuthenticatorFunc_maximumPreSharedKeyLength(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSslPreSharedKeyAuthenticator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslPreSharedKeyAuthenticator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maximumPreSharedKeyLength()const
        int cppResult = const_cast<const ::QSslPreSharedKeyAuthenticator *>(cppSelf)->maximumPreSharedKeyLength();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSslPreSharedKeyAuthenticatorFunc_preSharedKey(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSslPreSharedKeyAuthenticator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslPreSharedKeyAuthenticator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // preSharedKey()const
        QByteArray cppResult = const_cast<const ::QSslPreSharedKeyAuthenticator *>(cppSelf)->preSharedKey();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSslPreSharedKeyAuthenticatorFunc_setIdentity(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSslPreSharedKeyAuthenticator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslPreSharedKeyAuthenticator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSslPreSharedKeyAuthenticator::setIdentity(QByteArray)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // setIdentity(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setIdentity", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QSslPreSharedKeyAuthenticator_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setIdentity(QByteArray)
            cppSelf->setIdentity(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSslPreSharedKeyAuthenticatorFunc_setPreSharedKey(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSslPreSharedKeyAuthenticator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslPreSharedKeyAuthenticator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSslPreSharedKeyAuthenticator::setPreSharedKey(QByteArray)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // setPreSharedKey(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPreSharedKey", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QSslPreSharedKeyAuthenticator_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setPreSharedKey(QByteArray)
            cppSelf->setPreSharedKey(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSslPreSharedKeyAuthenticatorFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSslPreSharedKeyAuthenticator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslPreSharedKeyAuthenticator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSslPreSharedKeyAuthenticator::swap(QSslPreSharedKeyAuthenticator&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslPreSharedKeyAuthenticator_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QSslPreSharedKeyAuthenticator&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QSslPreSharedKeyAuthenticator_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSslPreSharedKeyAuthenticator cppArg0_local;
        ::QSslPreSharedKeyAuthenticator *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QSslPreSharedKeyAuthenticator&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSslPreSharedKeyAuthenticator__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QSslPreSharedKeyAuthenticator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslPreSharedKeyAuthenticator_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslPreSharedKeyAuthenticator_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QSslPreSharedKeyAuthenticator_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSslPreSharedKeyAuthenticator_methods[] = {
    {"identity", reinterpret_cast<PyCFunction>(Sbk_QSslPreSharedKeyAuthenticatorFunc_identity), METH_NOARGS, nullptr},
    {"identityHint", reinterpret_cast<PyCFunction>(Sbk_QSslPreSharedKeyAuthenticatorFunc_identityHint), METH_NOARGS, nullptr},
    {"maximumIdentityLength", reinterpret_cast<PyCFunction>(Sbk_QSslPreSharedKeyAuthenticatorFunc_maximumIdentityLength), METH_NOARGS, nullptr},
    {"maximumPreSharedKeyLength", reinterpret_cast<PyCFunction>(Sbk_QSslPreSharedKeyAuthenticatorFunc_maximumPreSharedKeyLength), METH_NOARGS, nullptr},
    {"preSharedKey", reinterpret_cast<PyCFunction>(Sbk_QSslPreSharedKeyAuthenticatorFunc_preSharedKey), METH_NOARGS, nullptr},
    {"setIdentity", reinterpret_cast<PyCFunction>(Sbk_QSslPreSharedKeyAuthenticatorFunc_setIdentity), METH_O, nullptr},
    {"setPreSharedKey", reinterpret_cast<PyCFunction>(Sbk_QSslPreSharedKeyAuthenticatorFunc_setPreSharedKey), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QSslPreSharedKeyAuthenticatorFunc_swap), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QSslPreSharedKeyAuthenticator__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QSslPreSharedKeyAuthenticator_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QSslPreSharedKeyAuthenticator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslPreSharedKeyAuthenticator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslPreSharedKeyAuthenticator_IDX]), (pyArg)))) {
                // operator!=(const QSslPreSharedKeyAuthenticator &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QSslPreSharedKeyAuthenticator cppArg0_local;
                ::QSslPreSharedKeyAuthenticator *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslPreSharedKeyAuthenticator_IDX]), (pyArg)))) {
                // operator==(const QSslPreSharedKeyAuthenticator &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QSslPreSharedKeyAuthenticator cppArg0_local;
                ::QSslPreSharedKeyAuthenticator *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QSslPreSharedKeyAuthenticator_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSslPreSharedKeyAuthenticator_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSslPreSharedKeyAuthenticator_Type = nullptr;
static PyTypeObject *Sbk_QSslPreSharedKeyAuthenticator_TypeF(void)
{
    return _Sbk_QSslPreSharedKeyAuthenticator_Type;
}

static PyType_Slot Sbk_QSslPreSharedKeyAuthenticator_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSslPreSharedKeyAuthenticator_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSslPreSharedKeyAuthenticator_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QSslPreSharedKeyAuthenticator_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSslPreSharedKeyAuthenticator_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSslPreSharedKeyAuthenticator_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSslPreSharedKeyAuthenticator_spec = {
    "2:PySide6.QtNetwork.QSslPreSharedKeyAuthenticator",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSslPreSharedKeyAuthenticator_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSslPreSharedKeyAuthenticator_PythonToCpp_QSslPreSharedKeyAuthenticator_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSslPreSharedKeyAuthenticator_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSslPreSharedKeyAuthenticator_PythonToCpp_QSslPreSharedKeyAuthenticator_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSslPreSharedKeyAuthenticator_TypeF()))
        return QSslPreSharedKeyAuthenticator_PythonToCpp_QSslPreSharedKeyAuthenticator_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSslPreSharedKeyAuthenticator_PTR_CppToPython_QSslPreSharedKeyAuthenticator(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QSslPreSharedKeyAuthenticator_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QSslPreSharedKeyAuthenticator_COPY_CppToPython_QSslPreSharedKeyAuthenticator(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QSslPreSharedKeyAuthenticator *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QSslPreSharedKeyAuthenticator_TypeF(), new ::QSslPreSharedKeyAuthenticator(*source), true, true);
}

// Python to C++ copy conversion.
static void QSslPreSharedKeyAuthenticator_PythonToCpp_QSslPreSharedKeyAuthenticator_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QSslPreSharedKeyAuthenticator *>(cppOut) = *reinterpret_cast< ::QSslPreSharedKeyAuthenticator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslPreSharedKeyAuthenticator_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QSslPreSharedKeyAuthenticator_PythonToCpp_QSslPreSharedKeyAuthenticator_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QSslPreSharedKeyAuthenticator_TypeF()))
        return QSslPreSharedKeyAuthenticator_PythonToCpp_QSslPreSharedKeyAuthenticator_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSslPreSharedKeyAuthenticator_SignatureStrings[] = {
    "1:PySide6.QtNetwork.QSslPreSharedKeyAuthenticator(self)",
    "0:PySide6.QtNetwork.QSslPreSharedKeyAuthenticator(self,authenticator:PySide6.QtNetwork.QSslPreSharedKeyAuthenticator)",
    "PySide6.QtNetwork.QSslPreSharedKeyAuthenticator.identity(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtNetwork.QSslPreSharedKeyAuthenticator.identityHint(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtNetwork.QSslPreSharedKeyAuthenticator.maximumIdentityLength(self)->int",
    "PySide6.QtNetwork.QSslPreSharedKeyAuthenticator.maximumPreSharedKeyLength(self)->int",
    "PySide6.QtNetwork.QSslPreSharedKeyAuthenticator.preSharedKey(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtNetwork.QSslPreSharedKeyAuthenticator.setIdentity(self,identity:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "PySide6.QtNetwork.QSslPreSharedKeyAuthenticator.setPreSharedKey(self,preSharedKey:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "PySide6.QtNetwork.QSslPreSharedKeyAuthenticator.swap(self,other:PySide6.QtNetwork.QSslPreSharedKeyAuthenticator)",
    "PySide6.QtNetwork.QSslPreSharedKeyAuthenticator.__copy__(self)->typing.Self",
    "PySide6.QtNetwork.QSslPreSharedKeyAuthenticator.__ne__(self,rhs:PySide6.QtNetwork.QSslPreSharedKeyAuthenticator)->bool",
    "PySide6.QtNetwork.QSslPreSharedKeyAuthenticator.__eq__(self,rhs:PySide6.QtNetwork.QSslPreSharedKeyAuthenticator)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QSslPreSharedKeyAuthenticator_SignatureByteSize = 237;
static constexpr uint8_t QSslPreSharedKeyAuthenticator_SignatureBytes[237] = {
    0x78, 0xda, 0xbd, 0x93, 0xb1, 0x0a, 0xc2, 0x30, 0x10, 0x40, 0x77, 0xbf, 0xc2, 0xd1, 0x4a, 0x0c,
    0xba, 0x38, 0x38, 0x08, 0xea, 0xa2, 0x28, 0xd2, 0x52, 0x9c, 0x44, 0x4a, 0xac, 0xa7, 0x0d, 0xb6,
    0x49, 0x4d, 0x4f, 0x34, 0x7f, 0x6f, 0xc0, 0x16, 0x83, 0xe0, 0xd0, 0x58, 0xdd, 0x92, 0x4b, 0xee,
    0xbd, 0xbb, 0x1c, 0x19, 0x8c, 0x7c, 0x1d, 0xf2, 0x03, 0x0c, 0x69, 0x80, 0x6b, 0xc0, 0x9b, 0x54,
    0x67, 0x1a, 0x84, 0x45, 0xea, 0x2b, 0x08, 0x13, 0xa6, 0xe0, 0xb0, 0x04, 0x3d, 0xb9, 0x62, 0x02,
    0x02, 0x79, 0xcc, 0x50, 0xaa, 0x4e, 0x01, 0xe9, 0xd1, 0x6b, 0xf5, 0x9d, 0xf2, 0x08, 0xb3, 0x43,
    0x75, 0x11, 0x5e, 0xab, 0x66, 0x02, 0x35, 0x97, 0xcd, 0x1a, 0xf5, 0xb3, 0xe8, 0xde, 0xf8, 0x95,
    0x3f, 0x93, 0x0a, 0x68, 0x30, 0xd5, 0x08, 0x13, 0xa5, 0x98, 0x76, 0x26, 0xcf, 0xb9, 0xc0, 0xe6,
    0xe9, 0x19, 0xbb, 0xf3, 0xec, 0x9a, 0x2d, 0x4a, 0xc9, 0x0a, 0xc4, 0x09, 0x93, 0x4a, 0x63, 0x8c,
    0xae, 0x40, 0xfb, 0xc2, 0xf7, 0xd0, 0xdc, 0x3a, 0x69, 0xfe, 0x0d, 0x0a, 0xc0, 0x85, 0x3d, 0x3e,
    0x52, 0x3d, 0xf9, 0x08, 0x75, 0xce, 0xc5, 0x89, 0x6e, 0x04, 0x97, 0x62, 0xfb, 0x51, 0x48, 0xda,
    0xb1, 0x01, 0x77, 0x77, 0x9e, 0x8b, 0xd9, 0x7f, 0x6f, 0x8d, 0xd8, 0xcd, 0xfe, 0xbe, 0x82, 0x1b,
    0xcb, 0x9f, 0x5a, 0x69, 0xc2, 0x7f, 0xf8, 0x28, 0x51, 0x14, 0xcb, 0x5c, 0x47, 0x51, 0x35, 0xc6,
    0xb2, 0xc1, 0xd0, 0xec, 0x1c, 0x58, 0x02, 0x4a, 0x12, 0x51, 0x49, 0x51, 0xbb, 0xf8, 0xde, 0x78,
    0x2f, 0x65, 0xea, 0xa0, 0x85, 0x4b, 0x03, 0xda, 0x07, 0xc7, 0xe1, 0xe3, 0x6a
};
#endif

PyTypeObject *init_QSslPreSharedKeyAuthenticator(PyObject *module)
{
    if (SbkPySide6_QtNetworkTypeStructs[SBK_QSslPreSharedKeyAuthenticator_IDX].type != nullptr)
        return SbkPySide6_QtNetworkTypeStructs[SBK_QSslPreSharedKeyAuthenticator_IDX].type;

    Shiboken::AutoDecRef Sbk_QSslPreSharedKeyAuthenticator_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QSslPreSharedKeyAuthenticator_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSslPreSharedKeyAuthenticator",
        "QSslPreSharedKeyAuthenticator",
        &Sbk_QSslPreSharedKeyAuthenticator_spec,
        &Shiboken::callCppDestructor< ::QSslPreSharedKeyAuthenticator >,
        Sbk_QSslPreSharedKeyAuthenticator_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QSslPreSharedKeyAuthenticator_TypeF(); // references _Sbk_QSslPreSharedKeyAuthenticator_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSslPreSharedKeyAuthenticator_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSslPreSharedKeyAuthenticator_SignatureBytes, QSslPreSharedKeyAuthenticator_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSslPreSharedKeyAuthenticator_PropertyStrings);
    SbkPySide6_QtNetworkTypeStructs[SBK_QSslPreSharedKeyAuthenticator_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSslPreSharedKeyAuthenticator_PythonToCpp_QSslPreSharedKeyAuthenticator_PTR,
        is_QSslPreSharedKeyAuthenticator_PythonToCpp_QSslPreSharedKeyAuthenticator_PTR_Convertible,
        QSslPreSharedKeyAuthenticator_PTR_CppToPython_QSslPreSharedKeyAuthenticator,
        QSslPreSharedKeyAuthenticator_COPY_CppToPython_QSslPreSharedKeyAuthenticator);

    Shiboken::Conversions::registerConverterName(converter, "QSslPreSharedKeyAuthenticator");
    Shiboken::Conversions::registerConverterName(converter, "QSslPreSharedKeyAuthenticator*");
    Shiboken::Conversions::registerConverterName(converter, "QSslPreSharedKeyAuthenticator&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSslPreSharedKeyAuthenticator).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QSslPreSharedKeyAuthenticator_PythonToCpp_QSslPreSharedKeyAuthenticator_COPY,
        is_QSslPreSharedKeyAuthenticator_PythonToCpp_QSslPreSharedKeyAuthenticator_COPY_Convertible);

    qRegisterMetaType< ::QSslPreSharedKeyAuthenticator >("QSslPreSharedKeyAuthenticator");

    return pyType;
}
