// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QSslSocketWrapper_H
#define SBK_QSslSocketWrapper_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtNetwork/qsslsocket.h>

namespace PySide { class DynamicQMetaObject; }

class QSslSocketWrapper : public QSslSocket
{
public:
    QSslSocketWrapper(const QSslSocketWrapper &) = delete;
    QSslSocketWrapper& operator=(const QSslSocketWrapper &) = delete;
    QSslSocketWrapper(QSslSocketWrapper &&) = delete;
    QSslSocketWrapper& operator=(QSslSocketWrapper &&) = delete;

    QSslSocketWrapper(::QObject * parent = nullptr);
    bool atEnd() const override;
    qint64 bytesAvailable() const override;
    qint64 bytesToWrite() const override;
    bool canReadLine() const override;
    void childEvent(::QChildEvent * event) override;
    void close() override;
    void connectNotify(const ::QMetaMethod & signal) override;
    void connectToHost(const ::QString & hostName, quint16 port, ::QFlags<QIODeviceBase::OpenModeFlag> openMode = QIODeviceBase::OpenModeFlag::ReadWrite, ::QAbstractSocket::NetworkLayerProtocol protocol = QAbstractSocket::NetworkLayerProtocol::AnyIPProtocol) override;
    void customEvent(::QEvent * event) override;
    void disconnectFromHost() override;
    void disconnectNotify(const ::QMetaMethod & signal) override;
    bool event(::QEvent * event) override;
    bool eventFilter(::QObject * watched, ::QEvent * event) override;
    bool isSequential() const override;
    bool open(::QFlags<QIODeviceBase::OpenModeFlag> mode) override;
    qint64 pos() const override;
    qint64 readData(char * data, qint64 maxlen) override;
    qint64 readLineData(char * data, qint64 maxlen) override;
    bool reset() override;
    void resume() override;
    bool seek(qint64 pos) override;
    void setReadBufferSize(qint64 size) override;
    bool setSocketDescriptor(::qintptr socketDescriptor, ::QAbstractSocket::SocketState state = QAbstractSocket::SocketState::ConnectedState, ::QFlags<QIODeviceBase::OpenModeFlag> openMode = QIODeviceBase::OpenModeFlag::ReadWrite) override;
    void setSocketOption(::QAbstractSocket::SocketOption option, const ::QVariant & value) override;
    qint64 size() const override;
    qint64 skipData(qint64 maxSize) override;
    ::qintptr socketDescriptor() const override;
    ::QVariant socketOption(::QAbstractSocket::SocketOption option) override;
    void timerEvent(::QTimerEvent * event) override;
    bool waitForBytesWritten(int msecs = 30000) override;
    bool waitForConnected(int msecs = 30000) override;
    bool waitForDisconnected(int msecs = 30000) override;
    bool waitForReadyRead(int msecs = 30000) override;
    qint64 writeData(const char * data, qint64 len) override;
    ~QSslSocketWrapper() override;

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();
    void resetPyMethodCache();
private:
    mutable bool m_PyMethodCache[34] = {false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QSslSocketWrapper_H

