// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnetworkauth_python.h"

// main header
#include "qabstractoauth_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QMap>
#include <QMultiMap>
#include <QString>
#include <QtNetwork/qnetworkaccessmanager.h>
#include <QtNetwork/qnetworkreply.h>
#include <QtNetwork/qnetworkrequest.h>
#include <QtNetworkAuth/qabstractoauth.h>
#include <QtNetworkAuth/qabstractoauthreplyhandler.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qurl.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Begin code injection
// ========================================================================
// START of custom code block [file: ../glue/qtnetworkauth.cpp (qabstractoauth-lookuphost-functor)]
struct QAbstractOAuthModifyFunctor : public Shiboken::PyObjectHolder
{
public:
    using Shiboken::PyObjectHolder::PyObjectHolder;

    void operator()(QAbstractOAuth::Stage stage, QMultiMap<QString, QVariant>* dictPointer);
};

void QAbstractOAuthModifyFunctor::operator()(QAbstractOAuth::Stage stage,
                                             QMultiMap<QString, QVariant>* dictPointer)
{
    auto *callable = object();
    if (!PyCallable_Check(callable)) {
        qWarning("Argument 1 of setModifyParametersFunction() must be a callable.");
        return;
    }
    Shiboken::GilState state;
    QMultiMap<QString, QVariant> dict = *dictPointer;
    Shiboken::AutoDecRef arglist(PyTuple_New(2));
    PyTuple_SetItem(arglist, 0, Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_Stage_IDX])))->converter, &stage));
    PyTuple_SetItem(arglist, 1, Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMultiMap_QString_QVariant_IDX], &dict));
    Shiboken::AutoDecRef ret(PyObject_CallObject(callable, arglist));

    if (!ret.isNull() && PyDict_Check(ret.object()) != 0) {
        PyObject *key{};
        PyObject *value{};
        Py_ssize_t pos = 0;
        while (PyDict_Next(ret.object(), &pos, &key, &value)) {
            ::QString cppKey;
Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], key, &(cppKey));
            ::QVariant cppValue;
Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], value, &(cppValue));
            dictPointer->replace(cppKey, cppValue);
        }
    }
}
// END of custom code block [file: ../glue/qtnetworkauth.cpp (qabstractoauth-lookuphost-functor)]
// ========================================================================
// End of code injection


// Native ---------------------------------------------------------

void QAbstractOAuthWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

void QAbstractOAuthWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractOAuth", funcName);
        return;
    }
}

void QAbstractOAuthWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractOAuth", funcName);
        return;
    }
}

void QAbstractOAuthWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractOAuth", funcName);
        return;
    }
}

::QNetworkReply * QAbstractOAuthWrapper::deleteResource(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters)
{
    if (m_PyMethodCache[3]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QAbstractOAuth.deleteResource");
        return nullptr;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "deleteResource";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        Shiboken::Errors::setPureVirtualMethodError("QAbstractOAuth.deleteResource");
        return nullptr;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], &parameters)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], &parameters)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractOAuth", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstractOAuth", funcName, Shiboken::SbkType< QNetworkReply >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QNetworkReply *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QAbstractOAuthWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[4]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractOAuth", funcName);
        return;
    }
}

bool QAbstractOAuthWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractOAuth", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstractOAuth", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QAbstractOAuthWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[6])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractOAuth", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstractOAuth", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QNetworkReply * QAbstractOAuthWrapper::get(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters)
{
    if (m_PyMethodCache[7]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QAbstractOAuth.get");
        return nullptr;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "get";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[7] = true;
        Shiboken::Errors::setPureVirtualMethodError("QAbstractOAuth.get");
        return nullptr;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], &parameters)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], &parameters)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractOAuth", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstractOAuth", funcName, Shiboken::SbkType< QNetworkReply >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QNetworkReply *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QAbstractOAuthWrapper::grant()
{
    if (m_PyMethodCache[8]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QAbstractOAuth.grant");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "grant";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[8] = true;
        Shiboken::Errors::setPureVirtualMethodError("QAbstractOAuth.grant");
        return;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractOAuth", funcName);
        return;
    }
}

::QNetworkReply * QAbstractOAuthWrapper::head(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters)
{
    if (m_PyMethodCache[9]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QAbstractOAuth.head");
        return nullptr;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "head";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[9] = true;
        Shiboken::Errors::setPureVirtualMethodError("QAbstractOAuth.head");
        return nullptr;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], &parameters)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], &parameters)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractOAuth", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstractOAuth", funcName, Shiboken::SbkType< QNetworkReply >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QNetworkReply *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QNetworkReply * QAbstractOAuthWrapper::post(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters)
{
    if (m_PyMethodCache[10]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QAbstractOAuth.post");
        return nullptr;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "post";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[10] = true;
        Shiboken::Errors::setPureVirtualMethodError("QAbstractOAuth.post");
        return nullptr;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], &parameters)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], &parameters)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractOAuth", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstractOAuth", funcName, Shiboken::SbkType< QNetworkReply >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QNetworkReply *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QAbstractOAuthWrapper::prepareRequest(::QNetworkRequest * request, const ::QByteArray & verb, const ::QByteArray & body)
{
    if (m_PyMethodCache[11]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QAbstractOAuth.prepareRequest");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "prepareRequest";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[11] = true;
        Shiboken::Errors::setPureVirtualMethodError("QAbstractOAuth.prepareRequest");
        return;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[3] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), request),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &verb),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &body)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), request),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &verb),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &body)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 3, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractOAuth", funcName);
        return;
    }
}

::QNetworkReply * QAbstractOAuthWrapper::put(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters)
{
    if (m_PyMethodCache[12]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QAbstractOAuth.put");
        return nullptr;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "put";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[12] = true;
        Shiboken::Errors::setPureVirtualMethodError("QAbstractOAuth.put");
        return nullptr;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], &parameters)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], &parameters)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractOAuth", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstractOAuth", funcName, Shiboken::SbkType< QNetworkReply >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QNetworkReply *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QAbstractOAuthWrapper::resourceOwnerAuthorization(const ::QUrl & url, const ::QMultiMap<QString,QVariant> & parameters)
{
    if (m_PyMethodCache[13]) {
        return this->::QAbstractOAuth::resourceOwnerAuthorization(url, parameters);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "resourceOwnerAuthorization";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[13] = true;
        gil.release();
        return this->::QAbstractOAuth::resourceOwnerAuthorization(url, parameters);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMultiMap_QString_QVariant_IDX], &parameters)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMultiMap_QString_QVariant_IDX], &parameters)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractOAuth", funcName);
        return;
    }
}

void QAbstractOAuthWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[14]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[14] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractOAuth", funcName);
        return;
    }
}

const QMetaObject *QAbstractOAuthWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QAbstractOAuth::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QAbstractOAuthWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QAbstractOAuth::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QAbstractOAuthWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QAbstractOAuthWrapper *>(this));
    return QAbstractOAuth::qt_metacast(_clname);
}

QAbstractOAuthWrapper::~QAbstractOAuthWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QAbstractOAuthFunc_authorizationUrl(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // authorizationUrl()const
        QUrl cppResult = const_cast<const ::QAbstractOAuth *>(cppSelf)->authorizationUrl();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractOAuthFunc_callback(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // callback()const
        QString cppResult = const_cast<const ::QAbstractOAuth *>(cppSelf)->callback();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractOAuthFunc_clientIdentifier(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clientIdentifier()const
        QString cppResult = const_cast<const ::QAbstractOAuth *>(cppSelf)->clientIdentifier();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractOAuthFunc_contentType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // contentType()const
        QAbstractOAuth::ContentType cppResult = const_cast<const ::QAbstractOAuth *>(cppSelf)->contentType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_ContentType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractOAuthFunc_deleteResource(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "deleteResource", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]);

    if (PyArg_ParseTuple(args, "|OO:deleteResource", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractOAuth::deleteResource(QUrl,const QMap<QString,QVariant>&=)->QNetworkReply*
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // deleteResource(QUrl,QMap<QString,QVariant>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], (pyArgs[1])))) {
            overloadId = 0; // deleteResource(QUrl,QMap<QString,QVariant>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "deleteResource", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parameters = Shiboken::String::createStaticString("parameters");
            if (PyDict_Contains(kwds, key_parameters) != 0) {
                value = PyDict_GetItem(kwds, key_parameters);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_parameters);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "deleteResource", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "deleteResource", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parameters);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "deleteResource", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QMap<QString,QVariant> cppArg1 = QVariantMap();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // deleteResource(QUrl,QMap<QString,QVariant>)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QAbstractOAuth.deleteResource");
                return {};
            }
            QNetworkReply * cppResult = cppSelf->deleteResource(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractOAuthFunc_extraTokens(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // extraTokens()const
        QMap<QString,QVariant> cppResult = const_cast<const ::QAbstractOAuth *>(cppSelf)->extraTokens();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractOAuthFunc_generateRandomString(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QAbstractOAuth::generateRandomString(quint8)->QByteArray
    if (SbkChar_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint8>(), (pyArg)))) {
        overloadId = 0; // generateRandomString(quint8)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "generateRandomString", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]);

    // Call function/method
    {
        quint8 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // generateRandomString(quint8)
            QByteArray cppResult = ::QAbstractOAuth::generateRandomString(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractOAuthFunc_get(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "get", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]);

    if (PyArg_ParseTuple(args, "|OO:get", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractOAuth::get(QUrl,const QMap<QString,QVariant>&=)->QNetworkReply*
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // get(QUrl,QMap<QString,QVariant>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], (pyArgs[1])))) {
            overloadId = 0; // get(QUrl,QMap<QString,QVariant>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "get", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parameters = Shiboken::String::createStaticString("parameters");
            if (PyDict_Contains(kwds, key_parameters) != 0) {
                value = PyDict_GetItem(kwds, key_parameters);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_parameters);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "get", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "get", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parameters);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "get", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QMap<QString,QVariant> cppArg1 = QVariantMap();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // get(QUrl,QMap<QString,QVariant>)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QAbstractOAuth.get");
                return {};
            }
            QNetworkReply * cppResult = cppSelf->get(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractOAuthFunc_grant(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // grant()
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QAbstractOAuth.grant");
            return {};
        }
        cppSelf->grant();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstractOAuthFunc_head(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "head", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]);

    if (PyArg_ParseTuple(args, "|OO:head", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractOAuth::head(QUrl,const QMap<QString,QVariant>&=)->QNetworkReply*
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // head(QUrl,QMap<QString,QVariant>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], (pyArgs[1])))) {
            overloadId = 0; // head(QUrl,QMap<QString,QVariant>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "head", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parameters = Shiboken::String::createStaticString("parameters");
            if (PyDict_Contains(kwds, key_parameters) != 0) {
                value = PyDict_GetItem(kwds, key_parameters);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_parameters);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "head", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "head", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parameters);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "head", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QMap<QString,QVariant> cppArg1 = QVariantMap();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // head(QUrl,QMap<QString,QVariant>)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QAbstractOAuth.head");
                return {};
            }
            QNetworkReply * cppResult = cppSelf->head(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractOAuthFunc_networkAccessManager(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // networkAccessManager()const
        QNetworkAccessManager * cppResult = const_cast<const ::QAbstractOAuth *>(cppSelf)->networkAccessManager();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAccessManager_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractOAuthFunc_post(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "post", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]);

    if (PyArg_ParseTuple(args, "|OO:post", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractOAuth::post(QUrl,const QMap<QString,QVariant>&=)->QNetworkReply*
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // post(QUrl,QMap<QString,QVariant>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], (pyArgs[1])))) {
            overloadId = 0; // post(QUrl,QMap<QString,QVariant>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "post", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parameters = Shiboken::String::createStaticString("parameters");
            if (PyDict_Contains(kwds, key_parameters) != 0) {
                value = PyDict_GetItem(kwds, key_parameters);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_parameters);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "post", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "post", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parameters);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "post", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QMap<QString,QVariant> cppArg1 = QVariantMap();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // post(QUrl,QMap<QString,QVariant>)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QAbstractOAuth.post");
                return {};
            }
            QNetworkReply * cppResult = cppSelf->post(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractOAuthFunc_prepareRequest(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "prepareRequest", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:prepareRequest", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractOAuth::prepareRequest(QNetworkRequest*,QByteArray,const QByteArray&=)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // prepareRequest(QNetworkRequest*,QByteArray,QByteArray)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[2])))) {
            overloadId = 0; // prepareRequest(QNetworkRequest*,QByteArray,QByteArray)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "prepareRequest", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_body = Shiboken::String::createStaticString("body");
            if (PyDict_Contains(kwds, key_body) != 0) {
                value = PyDict_GetItem(kwds, key_body);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_body);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "prepareRequest", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "prepareRequest", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_body);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "prepareRequest", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QNetworkRequest *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QByteArray cppArg1_local;
        ::QByteArray *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QByteArray cppArg2_local = QByteArray();
        ::QByteArray *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2]) {
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // prepareRequest(QNetworkRequest*,QByteArray,QByteArray)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QAbstractOAuth.prepareRequest");
                return {};
            }
            cppSelf->prepareRequest(cppArg0, *cppArg1, *cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstractOAuthFunc_put(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "put", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]);

    if (PyArg_ParseTuple(args, "|OO:put", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractOAuth::put(QUrl,const QMap<QString,QVariant>&=)->QNetworkReply*
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // put(QUrl,QMap<QString,QVariant>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], (pyArgs[1])))) {
            overloadId = 0; // put(QUrl,QMap<QString,QVariant>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "put", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parameters = Shiboken::String::createStaticString("parameters");
            if (PyDict_Contains(kwds, key_parameters) != 0) {
                value = PyDict_GetItem(kwds, key_parameters);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_parameters);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "put", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "put", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parameters);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "put", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QMap<QString,QVariant> cppArg1 = QVariantMap();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // put(QUrl,QMap<QString,QVariant>)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QAbstractOAuth.put");
                return {};
            }
            QNetworkReply * cppResult = cppSelf->put(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractOAuthFunc_replyHandler(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // replyHandler()const
        QAbstractOAuthReplyHandler * cppResult = const_cast<const ::QAbstractOAuth *>(cppSelf)->replyHandler();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuthReplyHandler_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractOAuthFunc_resourceOwnerAuthorization(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "resourceOwnerAuthorization", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractOAuth::resourceOwnerAuthorization(QUrl,QMultiMap<QString,QVariant>)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMultiMap_QString_QVariant_IDX], (pyArgs[1])))) {
        overloadId = 0; // resourceOwnerAuthorization(QUrl,QMultiMap<QString,QVariant>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "resourceOwnerAuthorization", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QMultiMap<QString,QVariant> cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // resourceOwnerAuthorization(QUrl,QMultiMap<QString,QVariant>)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractOAuth::resourceOwnerAuthorization(*cppArg0, cppArg1)
                : cppSelf->resourceOwnerAuthorization(*cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstractOAuthFunc_setAuthorizationUrl(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractOAuth::setAuthorizationUrl(QUrl)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // setAuthorizationUrl(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAuthorizationUrl", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setAuthorizationUrl(QUrl)
            cppSelf->setAuthorizationUrl(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstractOAuthFunc_setClientIdentifier(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractOAuth::setClientIdentifier(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setClientIdentifier(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setClientIdentifier", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setClientIdentifier(QString)
            cppSelf->setClientIdentifier(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstractOAuthFunc_setContentType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractOAuth::setContentType(QAbstractOAuth::ContentType)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_ContentType_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setContentType(QAbstractOAuth::ContentType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setContentType", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]);

    // Call function/method
    {
        ::QAbstractOAuth::ContentType cppArg0{QAbstractOAuth::ContentType::WwwFormUrlEncoded};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setContentType(QAbstractOAuth::ContentType)
            cppSelf->setContentType(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstractOAuthFunc_setModifyParametersFunction(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractOAuth::setModifyParametersFunction(PyObject*)
    if (true) {
        overloadId = 0; // setModifyParametersFunction(PyObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setModifyParametersFunction", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]);

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // setModifyParametersFunction(PyObject*)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtnetworkauth.cpp (qabstractoauth-setmodifyparametersfunction)]
            cppSelf->setModifyParametersFunction(QAbstractOAuthModifyFunctor(pyArg));
            // END of custom code block [file: ../glue/qtnetworkauth.cpp (qabstractoauth-setmodifyparametersfunction)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstractOAuthFunc_setNetworkAccessManager(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractOAuth::setNetworkAccessManager(QNetworkAccessManager*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAccessManager_IDX]), (pyArg)))) {
        overloadId = 0; // setNetworkAccessManager(QNetworkAccessManager*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setNetworkAccessManager", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QNetworkAccessManager *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setNetworkAccessManager(QNetworkAccessManager*)
            cppSelf->setNetworkAccessManager(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstractOAuthFunc_setReplyHandler(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractOAuth::setReplyHandler(QAbstractOAuthReplyHandler*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuthReplyHandler_IDX]), (pyArg)))) {
        overloadId = 0; // setReplyHandler(QAbstractOAuthReplyHandler*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setReplyHandler", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAbstractOAuthReplyHandler *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setReplyHandler(QAbstractOAuthReplyHandler*)
            cppSelf->setReplyHandler(cppArg0);

            // Ownership transferences.
            Shiboken::Object::releaseOwnership(pyArg);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstractOAuthFunc_setStatus(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractOAuth::setStatus(QAbstractOAuth::Status)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_Status_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setStatus(QAbstractOAuth::Status)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStatus", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]);

    // Call function/method
    {
        ::QAbstractOAuth::Status cppArg0{QAbstractOAuth::Status::NotAuthenticated};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStatus(QAbstractOAuth::Status)
            cppSelf->setStatus(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstractOAuthFunc_setToken(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractOAuth::setToken(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setToken(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setToken", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setToken(QString)
            cppSelf->setToken(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstractOAuthFunc_status(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // status()const
        QAbstractOAuth::Status cppResult = const_cast<const ::QAbstractOAuth *>(cppSelf)->status();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_Status_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractOAuthFunc_token(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOAuth *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // token()const
        QString cppResult = const_cast<const ::QAbstractOAuth *>(cppSelf)->token();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QAbstractOAuth_PropertyStrings[] = {
    "authorizationUrl::",
    "clientIdentifier::",
    "contentType::",
    "extraTokens:",
    "status:",
    "token::",
    nullptr // Sentinel
};

static const char *Sbk_QAbstractOAuth_EnumFlagInfo[] = {
    "ContentType:Enum",
    "Error:Enum",
    "Stage:Enum",
    "Status:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QAbstractOAuth_methods[] = {
    {"authorizationUrl", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuthFunc_authorizationUrl), METH_NOARGS, nullptr},
    {"callback", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuthFunc_callback), METH_NOARGS, nullptr},
    {"clientIdentifier", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuthFunc_clientIdentifier), METH_NOARGS, nullptr},
    {"contentType", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuthFunc_contentType), METH_NOARGS, nullptr},
    {"deleteResource", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuthFunc_deleteResource), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"extraTokens", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuthFunc_extraTokens), METH_NOARGS, nullptr},
    {"generateRandomString", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuthFunc_generateRandomString), METH_O|METH_STATIC, nullptr},
    {"get", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuthFunc_get), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"grant", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuthFunc_grant), METH_NOARGS, nullptr},
    {"head", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuthFunc_head), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"networkAccessManager", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuthFunc_networkAccessManager), METH_NOARGS, nullptr},
    {"post", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuthFunc_post), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"prepareRequest", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuthFunc_prepareRequest), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"put", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuthFunc_put), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"replyHandler", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuthFunc_replyHandler), METH_NOARGS, nullptr},
    {"resourceOwnerAuthorization", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuthFunc_resourceOwnerAuthorization), METH_VARARGS, nullptr},
    {"setAuthorizationUrl", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuthFunc_setAuthorizationUrl), METH_O, nullptr},
    {"setClientIdentifier", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuthFunc_setClientIdentifier), METH_O, nullptr},
    {"setContentType", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuthFunc_setContentType), METH_O, nullptr},
    {"setModifyParametersFunction", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuthFunc_setModifyParametersFunction), METH_O, nullptr},
    {"setNetworkAccessManager", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuthFunc_setNetworkAccessManager), METH_O, nullptr},
    {"setReplyHandler", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuthFunc_setReplyHandler), METH_O, nullptr},
    {"setStatus", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuthFunc_setStatus), METH_O, nullptr},
    {"setToken", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuthFunc_setToken), METH_O, nullptr},
    {"status", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuthFunc_status), METH_NOARGS, nullptr},
    {"token", reinterpret_cast<PyCFunction>(Sbk_QAbstractOAuthFunc_token), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QAbstractOAuth_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QAbstractOAuth *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QAbstractOAuthWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QAbstractOAuth_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QAbstractOAuth_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QAbstractOAuth_Type = nullptr;
static PyTypeObject *Sbk_QAbstractOAuth_TypeF(void)
{
    return _Sbk_QAbstractOAuth_Type;
}

static PyType_Slot Sbk_QAbstractOAuth_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QAbstractOAuth_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QAbstractOAuth_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QAbstractOAuth_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QAbstractOAuth_methods)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QAbstractOAuth_spec = {
    "2:PySide6.QtNetworkAuth.QAbstractOAuth",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QAbstractOAuth_slots
};

} //extern "C"

static void *Sbk_QAbstractOAuth_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QAbstractOAuth *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QAbstractOAuth_Status(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAbstractOAuth::Status>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAbstractOAuth::Status *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAbstractOAuth_Status_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_Status_IDX])))
        return Enum_PythonToCpp_QAbstractOAuth_Status;
    return {};
}

static PyObject *QAbstractOAuth_Status_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAbstractOAuth::Status>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAbstractOAuth::Status *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_Status_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QAbstractOAuth_Stage(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAbstractOAuth::Stage>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAbstractOAuth::Stage *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAbstractOAuth_Stage_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_Stage_IDX])))
        return Enum_PythonToCpp_QAbstractOAuth_Stage;
    return {};
}

static PyObject *QAbstractOAuth_Stage_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAbstractOAuth::Stage>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAbstractOAuth::Stage *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_Stage_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QAbstractOAuth_Error(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAbstractOAuth::Error>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAbstractOAuth::Error *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAbstractOAuth_Error_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_Error_IDX])))
        return Enum_PythonToCpp_QAbstractOAuth_Error;
    return {};
}

static PyObject *QAbstractOAuth_Error_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAbstractOAuth::Error>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAbstractOAuth::Error *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_Error_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QAbstractOAuth_ContentType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAbstractOAuth::ContentType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAbstractOAuth::ContentType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAbstractOAuth_ContentType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_ContentType_IDX])))
        return Enum_PythonToCpp_QAbstractOAuth_ContentType;
    return {};
}

static PyObject *QAbstractOAuth_ContentType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAbstractOAuth::ContentType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAbstractOAuth::ContentType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_ContentType_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAbstractOAuth_PythonToCpp_QAbstractOAuth_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QAbstractOAuth_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAbstractOAuth_PythonToCpp_QAbstractOAuth_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QAbstractOAuth_TypeF()))
        return QAbstractOAuth_PythonToCpp_QAbstractOAuth_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAbstractOAuth_PTR_CppToPython_QAbstractOAuth(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QAbstractOAuth *>(const_cast<void *>(cppIn)), Sbk_QAbstractOAuth_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QAbstractOAuth_SignatureStrings[] = {
    "PySide6.QtNetworkAuth.QAbstractOAuth.authorizationUrl(self)->PySide6.QtCore.QUrl",
    "PySide6.QtNetworkAuth.QAbstractOAuth.callback(self)->QString",
    "PySide6.QtNetworkAuth.QAbstractOAuth.clientIdentifier(self)->QString",
    "PySide6.QtNetworkAuth.QAbstractOAuth.contentType(self)->PySide6.QtNetworkAuth.QAbstractOAuth.ContentType",
    "PySide6.QtNetworkAuth.QAbstractOAuth.deleteResource(self,url:typing.Union[PySide6.QtCore.QUrl, QString],parameters:QMap[QString, QVariant]=QVariantMap())->PySide6.QtNetwork.QNetworkReply",
    "PySide6.QtNetworkAuth.QAbstractOAuth.extraTokens(self)->QMap[QString, QVariant]",
    "PySide6.QtNetworkAuth.QAbstractOAuth.generateRandomString(length:quint8)->PySide6.QtCore.QByteArray",
    "PySide6.QtNetworkAuth.QAbstractOAuth.get(self,url:typing.Union[PySide6.QtCore.QUrl, QString],parameters:QMap[QString, QVariant]=QVariantMap())->PySide6.QtNetwork.QNetworkReply",
    "PySide6.QtNetworkAuth.QAbstractOAuth.grant(self)",
    "PySide6.QtNetworkAuth.QAbstractOAuth.head(self,url:typing.Union[PySide6.QtCore.QUrl, QString],parameters:QMap[QString, QVariant]=QVariantMap())->PySide6.QtNetwork.QNetworkReply",
    "PySide6.QtNetworkAuth.QAbstractOAuth.networkAccessManager(self)->PySide6.QtNetwork.QNetworkAccessManager",
    "PySide6.QtNetworkAuth.QAbstractOAuth.post(self,url:typing.Union[PySide6.QtCore.QUrl, QString],parameters:QMap[QString, QVariant]=QVariantMap())->PySide6.QtNetwork.QNetworkReply",
    "PySide6.QtNetworkAuth.QAbstractOAuth.prepareRequest(self,request:PySide6.QtNetwork.QNetworkRequest,verb:typing.Union[PySide6.QtCore.QByteArray, char*],body:typing.Union[PySide6.QtCore.QByteArray, char*]=QByteArray())",
    "PySide6.QtNetworkAuth.QAbstractOAuth.put(self,url:typing.Union[PySide6.QtCore.QUrl, QString],parameters:QMap[QString, QVariant]=QVariantMap())->PySide6.QtNetwork.QNetworkReply",
    "PySide6.QtNetworkAuth.QAbstractOAuth.replyHandler(self)->PySide6.QtNetworkAuth.QAbstractOAuthReplyHandler",
    "PySide6.QtNetworkAuth.QAbstractOAuth.resourceOwnerAuthorization(self,url:typing.Union[PySide6.QtCore.QUrl, QString],parameters:QMultiMap[QString, QVariant])",
    "PySide6.QtNetworkAuth.QAbstractOAuth.setAuthorizationUrl(self,url:typing.Union[PySide6.QtCore.QUrl, QString])",
    "PySide6.QtNetworkAuth.QAbstractOAuth.setClientIdentifier(self,clientIdentifier:QString)",
    "PySide6.QtNetworkAuth.QAbstractOAuth.setContentType(self,contentType:PySide6.QtNetworkAuth.QAbstractOAuth.ContentType)",
    "PySide6.QtNetworkAuth.QAbstractOAuth.setModifyParametersFunction(self,modifyParametersFunction:PyObject)",
    "PySide6.QtNetworkAuth.QAbstractOAuth.setNetworkAccessManager(self,networkAccessManager:PySide6.QtNetwork.QNetworkAccessManager)",
    "PySide6.QtNetworkAuth.QAbstractOAuth.setReplyHandler(self,handler:PySide6.QtNetworkAuth.QAbstractOAuthReplyHandler)",
    "PySide6.QtNetworkAuth.QAbstractOAuth.setStatus(self,status:PySide6.QtNetworkAuth.QAbstractOAuth.Status)",
    "PySide6.QtNetworkAuth.QAbstractOAuth.setToken(self,token:QString)",
    "PySide6.QtNetworkAuth.QAbstractOAuth.status(self)->PySide6.QtNetworkAuth.QAbstractOAuth.Status",
    "PySide6.QtNetworkAuth.QAbstractOAuth.token(self)->QString",
    nullptr}; // Sentinel
#else
static constexpr size_t QAbstractOAuth_SignatureByteSize = 512;
static constexpr uint8_t QAbstractOAuth_SignatureBytes[512] = {
    0x78, 0xda, 0xd5, 0x56, 0x4d, 0x6f, 0xdb, 0x30, 0x0c, 0xbd, 0xef, 0x57, 0xf4, 0x98, 0x0e, 0x9a,
    0x8f, 0xc3, 0x60, 0xa0, 0x03, 0xbc, 0x00, 0xc3, 0x76, 0x48, 0x13, 0x27, 0xed, 0x2e, 0x45, 0x0e,
    0xb2, 0xcd, 0xd8, 0x5a, 0x14, 0xc9, 0xa5, 0xe9, 0x75, 0xde, 0xaf, 0x9f, 0x1a, 0x39, 0x76, 0x96,
    0x39, 0x01, 0xbd, 0x9d, 0x72, 0x31, 0x24, 0x53, 0x7c, 0x8f, 0x1f, 0x12, 0xc9, 0x45, 0xb3, 0x52,
    0x19, 0xbc, 0x0f, 0x62, 0xba, 0x07, 0x7a, 0xb1, 0xb8, 0x8d, 0x6a, 0x2a, 0x82, 0x38, 0x4a, 0x2a,
    0x42, 0x99, 0xd2, 0x7c, 0xbf, 0x95, 0xee, 0x63, 0x51, 0xfd, 0x92, 0xa4, 0xac, 0x79, 0x44, 0x3d,
    0xa9, 0x40, 0x6f, 0x6e, 0xdf, 0x7d, 0x5c, 0x74, 0xca, 0x53, 0x8b, 0x10, 0xc4, 0x4e, 0xf4, 0x66,
    0xc1, 0x01, 0x4c, 0xa5, 0xd6, 0x89, 0x4c, 0xb7, 0x07, 0xa0, 0x78, 0x45, 0xa8, 0x4c, 0xce, 0x54,
    0xd6, 0x0a, 0x0c, 0x7d, 0xcd, 0xdc, 0x47, 0x6d, 0x14, 0xe0, 0xbf, 0x81, 0x58, 0x43, 0x0e, 0xe0,
    0xa1, 0x29, 0xe1, 0x6f, 0x6f, 0x2e, 0xe8, 0x4d, 0x7b, 0x3d, 0x1e, 0x51, 0x06, 0x1a, 0x08, 0x96,
    0x50, 0xd9, 0x1a, 0x53, 0xcf, 0x25, 0x6a, 0xd4, 0x21, 0x35, 0xa5, 0x33, 0x36, 0x78, 0x34, 0x2e,
    0xa4, 0x4f, 0x03, 0x81, 0x14, 0x37, 0xad, 0x3f, 0x6b, 0x51, 0x4a, 0x94, 0x3b, 0x07, 0x82, 0x55,
    0x18, 0xcf, 0x64, 0xf9, 0xd4, 0x0a, 0xdc, 0x89, 0x6f, 0x12, 0x95, 0x34, 0xb4, 0xbe, 0x3b, 0xac,
    0x9c, 0x78, 0x72, 0x3b, 0xe4, 0x4b, 0x10, 0xb7, 0x8b, 0x25, 0x94, 0xba, 0xe1, 0x99, 0x0e, 0x3f,
    0xdd, 0xe6, 0xc1, 0x6e, 0xc1, 0x54, 0x5d, 0x8c, 0x87, 0xf9, 0x79, 0x78, 0x39, 0x18, 0x40, 0xe9,
    0x82, 0x21, 0x4d, 0x66, 0x77, 0x1e, 0x64, 0xa2, 0xc1, 0xe4, 0x54, 0x84, 0xcf, 0xb5, 0x32, 0xf4,
    0x61, 0xe0, 0x4e, 0x7d, 0x6a, 0x08, 0x22, 0x44, 0xd9, 0x70, 0x39, 0xe8, 0xaa, 0x62, 0x9c, 0xa3,
    0x43, 0xf4, 0xd1, 0xe5, 0x29, 0x14, 0x20, 0xb3, 0xab, 0xf2, 0xd0, 0xb4, 0xa2, 0x34, 0x85, 0xaa,
    0x9a, 0x49, 0x23, 0xf3, 0xfe, 0xc9, 0x9e, 0x27, 0xf8, 0xe3, 0x38, 0x8f, 0xa8, 0xb4, 0xd5, 0x75,
    0xe5, 0xbe, 0x44, 0x70, 0xd4, 0xae, 0x36, 0x3c, 0xd7, 0x70, 0x30, 0x1d, 0xfd, 0x26, 0xbc, 0x44,
    0xb0, 0x3f, 0x21, 0x7e, 0x00, 0x26, 0x97, 0xbd, 0xec, 0x9e, 0x8e, 0xb8, 0x49, 0x0b, 0x89, 0x6f,
    0xd7, 0x22, 0xb1, 0x59, 0x33, 0x52, 0xe7, 0xae, 0xff, 0xe5, 0x3c, 0x67, 0x3a, 0x56, 0x5f, 0x57,
    0x22, 0xf0, 0xf5, 0xe8, 0x17, 0x57, 0x95, 0xf4, 0x85, 0xab, 0x39, 0xa0, 0xb8, 0x3c, 0xd2, 0xe3,
    0x32, 0xf9, 0x3e, 0x30, 0x7f, 0x71, 0xa5, 0x30, 0x3a, 0x6e, 0xab, 0xff, 0x1f, 0xb0, 0x5a, 0x93,
    0x1a, 0x8e, 0x1a, 0x33, 0x6d, 0x15, 0x50, 0x34, 0xd4, 0xe9, 0x47, 0x5a, 0xc5, 0x67, 0x9b, 0x0e,
    0x75, 0x72, 0x71, 0xda, 0xdf, 0xc3, 0x16, 0x78, 0x04, 0xee, 0x49, 0x73, 0x17, 0x47, 0xdd, 0x3e,
    0x1c, 0xdb, 0xe6, 0xf9, 0xb4, 0x33, 0x9b, 0xa9, 0x4d, 0xb3, 0xe8, 0x72, 0xf2, 0xb9, 0x36, 0x69,
    0x9f, 0xda, 0xdd, 0x19, 0xa9, 0x33, 0x68, 0x9e, 0x7c, 0x87, 0x94, 0xf8, 0x44, 0xf7, 0xe7, 0x4a,
    0xaa, 0x18, 0x2a, 0xb6, 0x21, 0xb3, 0xca, 0xf2, 0xf9, 0x97, 0xa7, 0xef, 0x45, 0x14, 0x7e, 0x13,
    0x8e, 0x7d, 0x35, 0x7c, 0xce, 0x15, 0x49, 0xaa, 0xfd, 0x1c, 0x22, 0xaa, 0xfd, 0x9a, 0x97, 0x49,
    0xaf, 0xc7, 0xe7, 0xd9, 0xcf, 0x3b, 0x9e, 0x86, 0x5e, 0x97, 0x63, 0x6f, 0x5f, 0x6f, 0x26, 0x77,
    0xa4, 0xf4, 0x16, 0xf2, 0xe0, 0xa9, 0xb3, 0xee, 0x68, 0xe0, 0xfd, 0x0d, 0x16, 0x20, 0x58, 0x4a
};
#endif

PyTypeObject *init_QAbstractOAuth(PyObject *module)
{
    if (SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX].type != nullptr)
        return SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX].type;

    Shiboken::AutoDecRef Sbk_QAbstractOAuth_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QAbstractOAuth_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QAbstractOAuth",
        "QAbstractOAuth*",
        &Sbk_QAbstractOAuth_spec,
        &Shiboken::callCppDestructor< QAbstractOAuth >,
        Sbk_QAbstractOAuth_Type_bases.object(),
        0);
    auto *pyType = Sbk_QAbstractOAuth_TypeF(); // references _Sbk_QAbstractOAuth_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QAbstractOAuth_SignatureStrings);
#else
    InitSignatureBytes(pyType, QAbstractOAuth_SignatureBytes, QAbstractOAuth_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QAbstractOAuth_PropertyStrings);
    SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAbstractOAuth_PythonToCpp_QAbstractOAuth_PTR,
        is_QAbstractOAuth_PythonToCpp_QAbstractOAuth_PTR_Convertible,
        QAbstractOAuth_PTR_CppToPython_QAbstractOAuth);

    Shiboken::Conversions::registerConverterName(converter, "QAbstractOAuth");
    Shiboken::Conversions::registerConverterName(converter, "QAbstractOAuth*");
    Shiboken::Conversions::registerConverterName(converter, "QAbstractOAuth&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QAbstractOAuth).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QAbstractOAuthWrapper).name());


    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QAbstractOAuth_TypeF(), &Sbk_QAbstractOAuth_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QAbstractOAuth_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Status'.
    const char *Status_Initializer[] = {
        "NotAuthenticated",
        "TemporaryCredentialsReceived",
        "Granted",
        "RefreshingToken",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t Status_InitializerValues[] = {
        int8_t(QAbstractOAuth::Status::NotAuthenticated),             //  0x00  0
        int8_t(QAbstractOAuth::Status::TemporaryCredentialsReceived), //  0x01  1
        int8_t(QAbstractOAuth::Status::Granted),                      //  0x02  2
        int8_t(QAbstractOAuth::Status::RefreshingToken)               //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAbstractOAuth_TypeF(),
        "2:PySide6.QtNetworkAuth.QAbstractOAuth.Status",
        Status_Initializer, Status_InitializerValues);
    SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_Status_IDX].type = EType;
    // Register converter for enum 'QAbstractOAuth::Status'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAbstractOAuth_Status_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAbstractOAuth_Status,
            is_Enum_PythonToCpp_QAbstractOAuth_Status_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAbstractOAuth::Status");
        Shiboken::Conversions::registerConverterAlias(converter, "Status");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Status' enum.

    // Initialization of enum 'Stage'.
    const char *Stage_Initializer[] = {
        "RequestingTemporaryCredentials",
        "RequestingAuthorization",
        "RequestingAccessToken",
        "RefreshingAccessToken",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t Stage_InitializerValues[] = {
        int8_t(QAbstractOAuth::Stage::RequestingTemporaryCredentials), //  0x00  0
        int8_t(QAbstractOAuth::Stage::RequestingAuthorization),        //  0x01  1
        int8_t(QAbstractOAuth::Stage::RequestingAccessToken),          //  0x02  2
        int8_t(QAbstractOAuth::Stage::RefreshingAccessToken)           //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAbstractOAuth_TypeF(),
        "2:PySide6.QtNetworkAuth.QAbstractOAuth.Stage",
        Stage_Initializer, Stage_InitializerValues);
    SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_Stage_IDX].type = EType;
    // Register converter for enum 'QAbstractOAuth::Stage'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAbstractOAuth_Stage_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAbstractOAuth_Stage,
            is_Enum_PythonToCpp_QAbstractOAuth_Stage_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAbstractOAuth::Stage");
        Shiboken::Conversions::registerConverterAlias(converter, "Stage");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Stage' enum.

    // Initialization of enum 'Error'.
    const char *Error_Initializer[] = {
        "NoError",
        "NetworkError",
        "ServerError",
        "OAuthTokenNotFoundError",
        "OAuthTokenSecretNotFoundError",
        "OAuthCallbackNotVerified",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t Error_InitializerValues[] = {
        int8_t(QAbstractOAuth::Error::NoError),                       //  0x00  0
        int8_t(QAbstractOAuth::Error::NetworkError),                  //  0x01  1
        int8_t(QAbstractOAuth::Error::ServerError),                   //  0x02  2
        int8_t(QAbstractOAuth::Error::OAuthTokenNotFoundError),       //  0x03  3
        int8_t(QAbstractOAuth::Error::OAuthTokenSecretNotFoundError), //  0x04  4
        int8_t(QAbstractOAuth::Error::OAuthCallbackNotVerified)       //  0x05  5
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAbstractOAuth_TypeF(),
        "2:PySide6.QtNetworkAuth.QAbstractOAuth.Error",
        Error_Initializer, Error_InitializerValues);
    SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_Error_IDX].type = EType;
    // Register converter for enum 'QAbstractOAuth::Error'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAbstractOAuth_Error_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAbstractOAuth_Error,
            is_Enum_PythonToCpp_QAbstractOAuth_Error_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAbstractOAuth::Error");
        Shiboken::Conversions::registerConverterAlias(converter, "Error");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Error' enum.

    // Initialization of enum 'ContentType'.
    const char *ContentType_Initializer[] = {
        "WwwFormUrlEncoded",
        "Json",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t ContentType_InitializerValues[] = {
        int8_t(QAbstractOAuth::ContentType::WwwFormUrlEncoded), //  0x00  0
        int8_t(QAbstractOAuth::ContentType::Json)               //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAbstractOAuth_TypeF(),
        "2:PySide6.QtNetworkAuth.QAbstractOAuth.ContentType",
        ContentType_Initializer, ContentType_InitializerValues);
    SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_ContentType_IDX].type = EType;
    // Register converter for enum 'QAbstractOAuth::ContentType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAbstractOAuth_ContentType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAbstractOAuth_ContentType,
            is_Enum_PythonToCpp_QAbstractOAuth_ContentType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAbstractOAuth::ContentType");
        Shiboken::Conversions::registerConverterAlias(converter, "ContentType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ContentType' enum.

    PySide::Signal::registerSignals(pyType, &::QAbstractOAuth::staticMetaObject);

    qRegisterMetaType< ::QAbstractOAuth::Status >("QAbstractOAuth::Status");
    qRegisterMetaType< ::QAbstractOAuth::Stage >("QAbstractOAuth::Stage");
    qRegisterMetaType< ::QAbstractOAuth::Error >("QAbstractOAuth::Error");
    qRegisterMetaType< ::QAbstractOAuth::ContentType >("QAbstractOAuth::ContentType");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QAbstractOAuth::staticMetaObject, sizeof(QAbstractOAuthWrapper));

    return pyType;
}

