// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnetworkauth_python.h"

// main header
#include "qoauth1_wrapper.h"

// Argument includes
#include <QMap>
#include <QMultiMap>
#include <QString>
#include <QtNetwork/qnetworkaccessmanager.h>
#include <QtNetwork/qnetworkreply.h>
#include <QtNetwork/qnetworkrequest.h>
#include <QtNetworkAuth/qabstractoauth.h>
#include <QtNetworkAuth/qabstractoauthreplyhandler.h>
#include <QtNetworkAuth/qoauth1.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qurl.h>
#include <qvariant.h>
#include <utility>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QOAuth1Wrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QOAuth1Wrapper::QOAuth1Wrapper(::QNetworkAccessManager * manager, ::QObject * parent) : QOAuth1(manager, parent)
{
}

QOAuth1Wrapper::QOAuth1Wrapper(::QObject * parent) : QOAuth1(parent)
{
}

QOAuth1Wrapper::QOAuth1Wrapper(const ::QString & clientIdentifier, const ::QString & clientSharedSecret, ::QNetworkAccessManager * manager, ::QObject * parent) : QOAuth1(clientIdentifier, clientSharedSecret, manager, parent)
{
}

void QOAuth1Wrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QOAuth1", funcName);
        return;
    }
}

void QOAuth1Wrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QOAuth1", funcName);
        return;
    }
}

void QOAuth1Wrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QOAuth1", funcName);
        return;
    }
}

::QNetworkReply * QOAuth1Wrapper::deleteResource(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters)
{
    if (m_PyMethodCache[3])
        return this->::QOAuth1::deleteResource(url, parameters);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "deleteResource";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QOAuth1::deleteResource(url, parameters);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], &parameters)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], &parameters)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QOAuth1", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QOAuth1", funcName, Shiboken::SbkType< QNetworkReply >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QNetworkReply *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QOAuth1Wrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[4]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QOAuth1", funcName);
        return;
    }
}

bool QOAuth1Wrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QOAuth1", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QOAuth1", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QOAuth1Wrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[6])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QOAuth1", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QOAuth1", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QNetworkReply * QOAuth1Wrapper::get(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters)
{
    if (m_PyMethodCache[7])
        return this->::QOAuth1::get(url, parameters);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "get";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[7] = true;
        gil.release();
        return this->::QOAuth1::get(url, parameters);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], &parameters)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], &parameters)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QOAuth1", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QOAuth1", funcName, Shiboken::SbkType< QNetworkReply >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QNetworkReply *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QOAuth1Wrapper::grant()
{
    if (m_PyMethodCache[8]) {
        return this->::QOAuth1::grant();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "grant";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[8] = true;
        gil.release();
        return this->::QOAuth1::grant();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QOAuth1", funcName);
        return;
    }
}

::QNetworkReply * QOAuth1Wrapper::head(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters)
{
    if (m_PyMethodCache[9])
        return this->::QOAuth1::head(url, parameters);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "head";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[9] = true;
        gil.release();
        return this->::QOAuth1::head(url, parameters);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], &parameters)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], &parameters)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QOAuth1", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QOAuth1", funcName, Shiboken::SbkType< QNetworkReply >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QNetworkReply *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QNetworkReply * QOAuth1Wrapper::post(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters)
{
    if (m_PyMethodCache[10])
        return this->::QOAuth1::post(url, parameters);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "post";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[10] = true;
        gil.release();
        return this->::QOAuth1::post(url, parameters);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], &parameters)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], &parameters)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QOAuth1", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QOAuth1", funcName, Shiboken::SbkType< QNetworkReply >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QNetworkReply *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QOAuth1Wrapper::prepareRequest(::QNetworkRequest * request, const ::QByteArray & verb, const ::QByteArray & body)
{
    if (m_PyMethodCache[11]) {
        return this->::QOAuth1::prepareRequest(request, verb, body);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "prepareRequest";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[11] = true;
        gil.release();
        return this->::QOAuth1::prepareRequest(request, verb, body);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[3] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), request),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &verb),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &body)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), request),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &verb),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &body)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 3, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QOAuth1", funcName);
        return;
    }
}

::QNetworkReply * QOAuth1Wrapper::put(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters)
{
    if (m_PyMethodCache[12])
        return this->::QOAuth1::put(url, parameters);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "put";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[12] = true;
        gil.release();
        return this->::QOAuth1::put(url, parameters);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], &parameters)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], &parameters)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QOAuth1", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QOAuth1", funcName, Shiboken::SbkType< QNetworkReply >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QNetworkReply *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QOAuth1Wrapper::resourceOwnerAuthorization(const ::QUrl & url, const ::QMultiMap<QString,QVariant> & parameters)
{
    if (m_PyMethodCache[13]) {
        return this->::QAbstractOAuth::resourceOwnerAuthorization(url, parameters);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "resourceOwnerAuthorization";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[13] = true;
        gil.release();
        return this->::QAbstractOAuth::resourceOwnerAuthorization(url, parameters);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMultiMap_QString_QVariant_IDX], &parameters)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMultiMap_QString_QVariant_IDX], &parameters)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QOAuth1", funcName);
        return;
    }
}

void QOAuth1Wrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[14]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[14] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QOAuth1", funcName);
        return;
    }
}

const QMetaObject *QOAuth1Wrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QOAuth1::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QOAuth1Wrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QOAuth1::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QOAuth1Wrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QOAuth1Wrapper *>(this));
    return QOAuth1::qt_metacast(_clname);
}

QOAuth1Wrapper::~QOAuth1Wrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QOAuth1_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QOAuth1 >()))
        return -1;

    QOAuth1Wrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OOOO:QOAuth1", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QOAuth1::QOAuth1(QNetworkAccessManager*,QObject*=)
    // 1: QOAuth1::QOAuth1(QObject*=)
    // 2: QOAuth1::QOAuth1(QString,QString,QNetworkAccessManager*,QObject*=)
    if (numArgs == 0) {
        overloadId = 1; // QOAuth1(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAccessManager_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // QOAuth1(QNetworkAccessManager*,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 0; // QOAuth1(QNetworkAccessManager*,QObject*)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QOAuth1(QObject*)
    } else if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAccessManager_IDX]), (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 2; // QOAuth1(QString,QString,QNetworkAccessManager*,QObject*)
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[3])))) {
            overloadId = 2; // QOAuth1(QString,QString,QNetworkAccessManager*,QObject*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QOAuth1(QNetworkAccessManager *manager, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QNetworkAccessManager *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QObject *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QOAuth1(QNetworkAccessManager*,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QOAuth1Wrapper(cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QOAuth1Wrapper(cppArg0, cppArg1);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
        case 1: // QOAuth1(QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0 = nullptr;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QOAuth1(QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QOAuth1Wrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QOAuth1Wrapper(cppArg0);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
        case 2: // QOAuth1(const QString &clientIdentifier, const QString &clientSharedSecret, QNetworkAccessManager *manager, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return -1;
            ::QNetworkAccessManager *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return -1;
            ::QObject *cppArg3 = nullptr;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QOAuth1(QString,QString,QNetworkAccessManager*,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QOAuth1Wrapper(cppArg0, cppArg1, cppArg2, cppArg3);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QOAuth1Wrapper(cppArg0, cppArg1, cppArg2, cppArg3);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[3], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QOAuth1 >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QOAuth1Func_clientCredentials(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth1 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clientCredentials()const
        std::pair<QString,QString> cppResult = const_cast<const ::QOAuth1 *>(cppSelf)->clientCredentials();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_std_pair_QString_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOAuth1Func_clientSharedSecret(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth1 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clientSharedSecret()const
        QString cppResult = const_cast<const ::QOAuth1 *>(cppSelf)->clientSharedSecret();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOAuth1Func_continueGrantWithVerifier(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth1 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOAuth1::continueGrantWithVerifier(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // continueGrantWithVerifier(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "continueGrantWithVerifier", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // continueGrantWithVerifier(QString)
            cppSelf->continueGrantWithVerifier(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOAuth1Func_deleteResource(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth1 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "deleteResource", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);

    if (PyArg_ParseTuple(args, "|OO:deleteResource", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractOAuth::deleteResource(QUrl,const QMap<QString,QVariant>&=)->QNetworkReply*
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // deleteResource(QUrl,QMap<QString,QVariant>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], (pyArgs[1])))) {
            overloadId = 0; // deleteResource(QUrl,QMap<QString,QVariant>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "deleteResource", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parameters = Shiboken::String::createStaticString("parameters");
            if (PyDict_Contains(kwds, key_parameters) != 0) {
                value = PyDict_GetItem(kwds, key_parameters);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_parameters);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "deleteResource", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "deleteResource", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parameters);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "deleteResource", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QMap<QString,QVariant> cppArg1 = QVariantMap();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // deleteResource(QUrl,QMap<QString,QVariant>)
            QNetworkReply * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QOAuth1::deleteResource(*cppArg0, cppArg1)
                : cppSelf->deleteResource(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), cppResult);

            // Ownership transferences.
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOAuth1Func_generateAuthorizationHeader(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QOAuth1::generateAuthorizationHeader(QMap<QString,QVariant>)->QByteArray
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // generateAuthorizationHeader(QMap<QString,QVariant>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "generateAuthorizationHeader", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);

    // Call function/method
    {
        ::QMap<QString,QVariant> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // generateAuthorizationHeader(QMap<QString,QVariant>)
            QByteArray cppResult = ::QOAuth1::generateAuthorizationHeader(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOAuth1Func_get(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth1 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "get", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);

    if (PyArg_ParseTuple(args, "|OO:get", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractOAuth::get(QUrl,const QMap<QString,QVariant>&=)->QNetworkReply*
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // get(QUrl,QMap<QString,QVariant>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], (pyArgs[1])))) {
            overloadId = 0; // get(QUrl,QMap<QString,QVariant>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "get", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parameters = Shiboken::String::createStaticString("parameters");
            if (PyDict_Contains(kwds, key_parameters) != 0) {
                value = PyDict_GetItem(kwds, key_parameters);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_parameters);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "get", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "get", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parameters);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "get", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QMap<QString,QVariant> cppArg1 = QVariantMap();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // get(QUrl,QMap<QString,QVariant>)
            QNetworkReply * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QOAuth1::get(*cppArg0, cppArg1)
                : cppSelf->get(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), cppResult);

            // Ownership transferences.
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOAuth1Func_grant(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth1 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // grant()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QOAuth1::grant()
            : cppSelf->grant();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOAuth1Func_head(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth1 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "head", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);

    if (PyArg_ParseTuple(args, "|OO:head", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractOAuth::head(QUrl,const QMap<QString,QVariant>&=)->QNetworkReply*
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // head(QUrl,QMap<QString,QVariant>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], (pyArgs[1])))) {
            overloadId = 0; // head(QUrl,QMap<QString,QVariant>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "head", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parameters = Shiboken::String::createStaticString("parameters");
            if (PyDict_Contains(kwds, key_parameters) != 0) {
                value = PyDict_GetItem(kwds, key_parameters);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_parameters);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "head", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "head", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parameters);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "head", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QMap<QString,QVariant> cppArg1 = QVariantMap();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // head(QUrl,QMap<QString,QVariant>)
            QNetworkReply * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QOAuth1::head(*cppArg0, cppArg1)
                : cppSelf->head(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), cppResult);

            // Ownership transferences.
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOAuth1Func_nonce(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // nonce()
        QByteArray cppResult = ::QOAuth1::nonce();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOAuth1Func_post(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth1 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "post", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);

    if (PyArg_ParseTuple(args, "|OO:post", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractOAuth::post(QUrl,const QMap<QString,QVariant>&=)->QNetworkReply*
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // post(QUrl,QMap<QString,QVariant>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], (pyArgs[1])))) {
            overloadId = 0; // post(QUrl,QMap<QString,QVariant>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "post", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parameters = Shiboken::String::createStaticString("parameters");
            if (PyDict_Contains(kwds, key_parameters) != 0) {
                value = PyDict_GetItem(kwds, key_parameters);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_parameters);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "post", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "post", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parameters);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "post", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QMap<QString,QVariant> cppArg1 = QVariantMap();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // post(QUrl,QMap<QString,QVariant>)
            QNetworkReply * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QOAuth1::post(*cppArg0, cppArg1)
                : cppSelf->post(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), cppResult);

            // Ownership transferences.
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOAuth1Func_prepareRequest(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth1 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "prepareRequest", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:prepareRequest", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractOAuth::prepareRequest(QNetworkRequest*,QByteArray,const QByteArray&=)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // prepareRequest(QNetworkRequest*,QByteArray,QByteArray)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[2])))) {
            overloadId = 0; // prepareRequest(QNetworkRequest*,QByteArray,QByteArray)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "prepareRequest", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_body = Shiboken::String::createStaticString("body");
            if (PyDict_Contains(kwds, key_body) != 0) {
                value = PyDict_GetItem(kwds, key_body);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_body);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "prepareRequest", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "prepareRequest", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_body);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "prepareRequest", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QNetworkRequest *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QByteArray cppArg1_local;
        ::QByteArray *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QByteArray cppArg2_local = QByteArray();
        ::QByteArray *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2]) {
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // prepareRequest(QNetworkRequest*,QByteArray,QByteArray)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QOAuth1::prepareRequest(cppArg0, *cppArg1, *cppArg2)
                : cppSelf->prepareRequest(cppArg0, *cppArg1, *cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOAuth1Func_put(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth1 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "put", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);

    if (PyArg_ParseTuple(args, "|OO:put", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractOAuth::put(QUrl,const QMap<QString,QVariant>&=)->QNetworkReply*
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // put(QUrl,QMap<QString,QVariant>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], (pyArgs[1])))) {
            overloadId = 0; // put(QUrl,QMap<QString,QVariant>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "put", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parameters = Shiboken::String::createStaticString("parameters");
            if (PyDict_Contains(kwds, key_parameters) != 0) {
                value = PyDict_GetItem(kwds, key_parameters);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_parameters);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "put", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "put", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parameters);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "put", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QMap<QString,QVariant> cppArg1 = QVariantMap();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // put(QUrl,QMap<QString,QVariant>)
            QNetworkReply * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QOAuth1::put(*cppArg0, cppArg1)
                : cppSelf->put(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), cppResult);

            // Ownership transferences.
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOAuth1Func_requestTemporaryCredentials(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth1 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "requestTemporaryCredentials", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:requestTemporaryCredentials", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOAuth1::requestTemporaryCredentials(QNetworkAccessManager::Operation,QUrl,const QMap<QString,QVariant>&=)->QNetworkReply*
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAccessManager_Operation_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // requestTemporaryCredentials(QNetworkAccessManager::Operation,QUrl,QMap<QString,QVariant>)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], (pyArgs[2])))) {
            overloadId = 0; // requestTemporaryCredentials(QNetworkAccessManager::Operation,QUrl,QMap<QString,QVariant>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "requestTemporaryCredentials", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parameters = Shiboken::String::createStaticString("parameters");
            if (PyDict_Contains(kwds, key_parameters) != 0) {
                value = PyDict_GetItem(kwds, key_parameters);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_parameters);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "requestTemporaryCredentials", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "requestTemporaryCredentials", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parameters);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "requestTemporaryCredentials", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);
            }
        }
        ::QNetworkAccessManager::Operation cppArg0{QNetworkAccessManager::UnknownOperation};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QUrl cppArg1_local;
        ::QUrl *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        ::QMap<QString,QVariant> cppArg2 = QVariantMap();
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // requestTemporaryCredentials(QNetworkAccessManager::Operation,QUrl,QMap<QString,QVariant>)
            QNetworkReply * cppResult = cppSelf->requestTemporaryCredentials(cppArg0, *cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOAuth1Func_requestTokenCredentials(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth1 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "requestTokenCredentials", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:requestTokenCredentials", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOAuth1::requestTokenCredentials(QNetworkAccessManager::Operation,QUrl,std::pair<QString,QString>,const QMap<QString,QVariant>&=)->QNetworkReply*
    if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAccessManager_Operation_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_std_pair_QString_QString_IDX], (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // requestTokenCredentials(QNetworkAccessManager::Operation,QUrl,std::pair<QString,QString>,QMap<QString,QVariant>)
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], (pyArgs[3])))) {
            overloadId = 0; // requestTokenCredentials(QNetworkAccessManager::Operation,QUrl,std::pair<QString,QString>,QMap<QString,QVariant>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "requestTokenCredentials", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parameters = Shiboken::String::createStaticString("parameters");
            if (PyDict_Contains(kwds, key_parameters) != 0) {
                value = PyDict_GetItem(kwds, key_parameters);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_parameters);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "requestTokenCredentials", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, "requestTokenCredentials", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parameters);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "requestTokenCredentials", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);
            }
        }
        ::QNetworkAccessManager::Operation cppArg0{QNetworkAccessManager::UnknownOperation};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QUrl cppArg1_local;
        ::QUrl *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        std::pair<QString,QString> cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        ::QMap<QString,QVariant> cppArg3 = QVariantMap();
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // requestTokenCredentials(QNetworkAccessManager::Operation,QUrl,std::pair<QString,QString>,QMap<QString,QVariant>)
            QNetworkReply * cppResult = cppSelf->requestTokenCredentials(cppArg0, *cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkReply_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOAuth1Func_setClientCredentials(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth1 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setClientCredentials", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOAuth1::setClientCredentials(QString,QString)
    // 1: QOAuth1::setClientCredentials(std::pair<QString,QString>)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // setClientCredentials(QString,QString)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_std_pair_QString_QString_IDX], (pyArgs[0])))) {
        overloadId = 1; // setClientCredentials(std::pair<QString,QString>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setClientCredentials", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setClientCredentials(const QString &clientIdentifier, const QString &clientSharedSecret)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setClientCredentials(QString,QString)
                cppSelf->setClientCredentials(cppArg0, cppArg1);
            }
            break;
        }
        case 1: // setClientCredentials(const std::pair<QString,QString> &clientCredentials)
        {
            std::pair<QString,QString> cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setClientCredentials(std::pair<QString,QString>)
                cppSelf->setClientCredentials(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOAuth1Func_setClientSharedSecret(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth1 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOAuth1::setClientSharedSecret(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setClientSharedSecret(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setClientSharedSecret", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setClientSharedSecret(QString)
            cppSelf->setClientSharedSecret(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOAuth1Func_setSignatureMethod(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth1 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOAuth1::setSignatureMethod(QOAuth1::SignatureMethod)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_SignatureMethod_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setSignatureMethod(QOAuth1::SignatureMethod)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSignatureMethod", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);

    // Call function/method
    {
        ::QOAuth1::SignatureMethod cppArg0{QOAuth1::SignatureMethod::Hmac_Sha1};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSignatureMethod(QOAuth1::SignatureMethod)
            cppSelf->setSignatureMethod(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOAuth1Func_setTemporaryCredentialsUrl(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth1 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOAuth1::setTemporaryCredentialsUrl(QUrl)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // setTemporaryCredentialsUrl(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTemporaryCredentialsUrl", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setTemporaryCredentialsUrl(QUrl)
            cppSelf->setTemporaryCredentialsUrl(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOAuth1Func_setTokenCredentials(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth1 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setTokenCredentials", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOAuth1::setTokenCredentials(QString,QString)
    // 1: QOAuth1::setTokenCredentials(std::pair<QString,QString>)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // setTokenCredentials(QString,QString)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_std_pair_QString_QString_IDX], (pyArgs[0])))) {
        overloadId = 1; // setTokenCredentials(std::pair<QString,QString>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setTokenCredentials", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setTokenCredentials(const QString &token, const QString &tokenSecret)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setTokenCredentials(QString,QString)
                cppSelf->setTokenCredentials(cppArg0, cppArg1);
            }
            break;
        }
        case 1: // setTokenCredentials(const std::pair<QString,QString> &tokenCredentials)
        {
            std::pair<QString,QString> cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setTokenCredentials(std::pair<QString,QString>)
                cppSelf->setTokenCredentials(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOAuth1Func_setTokenCredentialsUrl(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth1 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOAuth1::setTokenCredentialsUrl(QUrl)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // setTokenCredentialsUrl(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTokenCredentialsUrl", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setTokenCredentialsUrl(QUrl)
            cppSelf->setTokenCredentialsUrl(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOAuth1Func_setTokenSecret(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth1 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOAuth1::setTokenSecret(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setTokenSecret(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTokenSecret", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTokenSecret(QString)
            cppSelf->setTokenSecret(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOAuth1Func_setup(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth1 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setup", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOAuth1::setup(QNetworkRequest*,QMap<QString,QVariant>,QNetworkAccessManager::Operation)
    // 1: QOAuth1::setup(QNetworkRequest*,QMap<QString,QVariant>,QByteArray)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMap_QString_QVariant_IDX], (pyArgs[1])))) {
        if (numArgs == 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[2])))) {
            overloadId = 1; // setup(QNetworkRequest*,QMap<QString,QVariant>,QByteArray)
        } else if (numArgs == 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAccessManager_Operation_IDX])))->converter, (pyArgs[2])))) {
            overloadId = 0; // setup(QNetworkRequest*,QMap<QString,QVariant>,QNetworkAccessManager::Operation)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setup", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setup(QNetworkRequest *request, const QMap<QString,QVariant> &signingParameters, QNetworkAccessManager::Operation operation)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QMap<QString,QVariant> cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QNetworkAccessManager::Operation cppArg2{QNetworkAccessManager::UnknownOperation};
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setup(QNetworkRequest*,QMap<QString,QVariant>,QNetworkAccessManager::Operation)
                cppSelf->setup(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
        case 1: // setup(QNetworkRequest *request, const QMap<QString,QVariant> &signingParameters, const QByteArray &operationVerb)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QMap<QString,QVariant> cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QByteArray cppArg2_local;
            ::QByteArray *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setup(QNetworkRequest*,QMap<QString,QVariant>,QByteArray)
                cppSelf->setup(cppArg0, cppArg1, *cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOAuth1Func_signatureMethod(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth1 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // signatureMethod()const
        QOAuth1::SignatureMethod cppResult = const_cast<const ::QOAuth1 *>(cppSelf)->signatureMethod();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_SignatureMethod_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOAuth1Func_temporaryCredentialsUrl(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth1 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // temporaryCredentialsUrl()const
        QUrl cppResult = const_cast<const ::QOAuth1 *>(cppSelf)->temporaryCredentialsUrl();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOAuth1Func_tokenCredentials(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth1 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // tokenCredentials()const
        std::pair<QString,QString> cppResult = const_cast<const ::QOAuth1 *>(cppSelf)->tokenCredentials();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_std_pair_QString_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOAuth1Func_tokenCredentialsUrl(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth1 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // tokenCredentialsUrl()const
        QUrl cppResult = const_cast<const ::QOAuth1 *>(cppSelf)->tokenCredentialsUrl();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOAuth1Func_tokenSecret(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth1 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // tokenSecret()const
        QString cppResult = const_cast<const ::QOAuth1 *>(cppSelf)->tokenSecret();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QOAuth1_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QOAuth1_EnumFlagInfo[] = {
    "SignatureMethod:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QOAuth1_methods[] = {
    {"clientCredentials", reinterpret_cast<PyCFunction>(Sbk_QOAuth1Func_clientCredentials), METH_NOARGS, nullptr},
    {"clientSharedSecret", reinterpret_cast<PyCFunction>(Sbk_QOAuth1Func_clientSharedSecret), METH_NOARGS, nullptr},
    {"continueGrantWithVerifier", reinterpret_cast<PyCFunction>(Sbk_QOAuth1Func_continueGrantWithVerifier), METH_O, nullptr},
    {"deleteResource", reinterpret_cast<PyCFunction>(Sbk_QOAuth1Func_deleteResource), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"generateAuthorizationHeader", reinterpret_cast<PyCFunction>(Sbk_QOAuth1Func_generateAuthorizationHeader), METH_O|METH_STATIC, nullptr},
    {"get", reinterpret_cast<PyCFunction>(Sbk_QOAuth1Func_get), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"grant", reinterpret_cast<PyCFunction>(Sbk_QOAuth1Func_grant), METH_NOARGS, nullptr},
    {"head", reinterpret_cast<PyCFunction>(Sbk_QOAuth1Func_head), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"nonce", reinterpret_cast<PyCFunction>(Sbk_QOAuth1Func_nonce), METH_NOARGS|METH_STATIC, nullptr},
    {"post", reinterpret_cast<PyCFunction>(Sbk_QOAuth1Func_post), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"prepareRequest", reinterpret_cast<PyCFunction>(Sbk_QOAuth1Func_prepareRequest), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"put", reinterpret_cast<PyCFunction>(Sbk_QOAuth1Func_put), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"requestTemporaryCredentials", reinterpret_cast<PyCFunction>(Sbk_QOAuth1Func_requestTemporaryCredentials), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"requestTokenCredentials", reinterpret_cast<PyCFunction>(Sbk_QOAuth1Func_requestTokenCredentials), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setClientCredentials", reinterpret_cast<PyCFunction>(Sbk_QOAuth1Func_setClientCredentials), METH_VARARGS, nullptr},
    {"setClientSharedSecret", reinterpret_cast<PyCFunction>(Sbk_QOAuth1Func_setClientSharedSecret), METH_O, nullptr},
    {"setSignatureMethod", reinterpret_cast<PyCFunction>(Sbk_QOAuth1Func_setSignatureMethod), METH_O, nullptr},
    {"setTemporaryCredentialsUrl", reinterpret_cast<PyCFunction>(Sbk_QOAuth1Func_setTemporaryCredentialsUrl), METH_O, nullptr},
    {"setTokenCredentials", reinterpret_cast<PyCFunction>(Sbk_QOAuth1Func_setTokenCredentials), METH_VARARGS, nullptr},
    {"setTokenCredentialsUrl", reinterpret_cast<PyCFunction>(Sbk_QOAuth1Func_setTokenCredentialsUrl), METH_O, nullptr},
    {"setTokenSecret", reinterpret_cast<PyCFunction>(Sbk_QOAuth1Func_setTokenSecret), METH_O, nullptr},
    {"setup", reinterpret_cast<PyCFunction>(Sbk_QOAuth1Func_setup), METH_VARARGS, nullptr},
    {"signatureMethod", reinterpret_cast<PyCFunction>(Sbk_QOAuth1Func_signatureMethod), METH_NOARGS, nullptr},
    {"temporaryCredentialsUrl", reinterpret_cast<PyCFunction>(Sbk_QOAuth1Func_temporaryCredentialsUrl), METH_NOARGS, nullptr},
    {"tokenCredentials", reinterpret_cast<PyCFunction>(Sbk_QOAuth1Func_tokenCredentials), METH_NOARGS, nullptr},
    {"tokenCredentialsUrl", reinterpret_cast<PyCFunction>(Sbk_QOAuth1Func_tokenCredentialsUrl), METH_NOARGS, nullptr},
    {"tokenSecret", reinterpret_cast<PyCFunction>(Sbk_QOAuth1Func_tokenSecret), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QOAuth1_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QOAuth1 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QOAuth1Wrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QOAuth1_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QOAuth1_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QOAuth1_Type = nullptr;
static PyTypeObject *Sbk_QOAuth1_TypeF(void)
{
    return _Sbk_QOAuth1_Type;
}

static PyType_Slot Sbk_QOAuth1_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QOAuth1_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QOAuth1_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QOAuth1_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QOAuth1_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QOAuth1_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QOAuth1_spec = {
    "2:PySide6.QtNetworkAuth.QOAuth1",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QOAuth1_slots
};

} //extern "C"

static void *Sbk_QOAuth1_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QOAuth1 *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QOAuth1_SignatureMethod(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QOAuth1::SignatureMethod>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QOAuth1::SignatureMethod *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QOAuth1_SignatureMethod_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_SignatureMethod_IDX])))
        return Enum_PythonToCpp_QOAuth1_SignatureMethod;
    return {};
}

static PyObject *QOAuth1_SignatureMethod_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QOAuth1::SignatureMethod>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QOAuth1::SignatureMethod *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_SignatureMethod_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QOAuth1_PythonToCpp_QOAuth1_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QOAuth1_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QOAuth1_PythonToCpp_QOAuth1_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QOAuth1_TypeF()))
        return QOAuth1_PythonToCpp_QOAuth1_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QOAuth1_PTR_CppToPython_QOAuth1(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QOAuth1 *>(const_cast<void *>(cppIn)), Sbk_QOAuth1_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QOAuth1_SignatureStrings[] = {
    "2:PySide6.QtNetworkAuth.QOAuth1(self,manager:PySide6.QtNetwork.QNetworkAccessManager,parent:PySide6.QtCore.QObject=nullptr)",
    "1:PySide6.QtNetworkAuth.QOAuth1(self,parent:PySide6.QtCore.QObject=nullptr)",
    "0:PySide6.QtNetworkAuth.QOAuth1(self,clientIdentifier:QString,clientSharedSecret:QString,manager:PySide6.QtNetwork.QNetworkAccessManager,parent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtNetworkAuth.QOAuth1.clientCredentials(self)->std.pair[QString, QString]",
    "PySide6.QtNetworkAuth.QOAuth1.clientSharedSecret(self)->QString",
    "PySide6.QtNetworkAuth.QOAuth1.continueGrantWithVerifier(self,verifier:QString)",
    "PySide6.QtNetworkAuth.QOAuth1.deleteResource(self,url:typing.Union[PySide6.QtCore.QUrl, QString],parameters:QMap[QString, QVariant]=QVariantMap())->PySide6.QtNetwork.QNetworkReply",
    "PySide6.QtNetworkAuth.QOAuth1.generateAuthorizationHeader(oauthParams:QMap[QString, QVariant])->PySide6.QtCore.QByteArray",
    "PySide6.QtNetworkAuth.QOAuth1.get(self,url:typing.Union[PySide6.QtCore.QUrl, QString],parameters:QMap[QString, QVariant]=QVariantMap())->PySide6.QtNetwork.QNetworkReply",
    "PySide6.QtNetworkAuth.QOAuth1.grant(self)",
    "PySide6.QtNetworkAuth.QOAuth1.head(self,url:typing.Union[PySide6.QtCore.QUrl, QString],parameters:QMap[QString, QVariant]=QVariantMap())->PySide6.QtNetwork.QNetworkReply",
    "PySide6.QtNetworkAuth.QOAuth1.nonce()->PySide6.QtCore.QByteArray",
    "PySide6.QtNetworkAuth.QOAuth1.post(self,url:typing.Union[PySide6.QtCore.QUrl, QString],parameters:QMap[QString, QVariant]=QVariantMap())->PySide6.QtNetwork.QNetworkReply",
    "PySide6.QtNetworkAuth.QOAuth1.prepareRequest(self,request:PySide6.QtNetwork.QNetworkRequest,verb:typing.Union[PySide6.QtCore.QByteArray, char*],body:typing.Union[PySide6.QtCore.QByteArray, char*]=QByteArray())",
    "PySide6.QtNetworkAuth.QOAuth1.put(self,url:typing.Union[PySide6.QtCore.QUrl, QString],parameters:QMap[QString, QVariant]=QVariantMap())->PySide6.QtNetwork.QNetworkReply",
    "PySide6.QtNetworkAuth.QOAuth1.requestTemporaryCredentials(self,operation:PySide6.QtNetwork.QNetworkAccessManager.Operation,url:typing.Union[PySide6.QtCore.QUrl, QString],parameters:QMap[QString, QVariant]=QVariantMap())->PySide6.QtNetwork.QNetworkReply",
    "PySide6.QtNetworkAuth.QOAuth1.requestTokenCredentials(self,operation:PySide6.QtNetwork.QNetworkAccessManager.Operation,url:typing.Union[PySide6.QtCore.QUrl, QString],temporaryToken:std.pair[QString, QString],parameters:QMap[QString, QVariant]=QVariantMap())->PySide6.QtNetwork.QNetworkReply",
    "1:PySide6.QtNetworkAuth.QOAuth1.setClientCredentials(self,clientIdentifier:QString,clientSharedSecret:QString)",
    "0:PySide6.QtNetworkAuth.QOAuth1.setClientCredentials(self,clientCredentials:std.pair[QString, QString])",
    "PySide6.QtNetworkAuth.QOAuth1.setClientSharedSecret(self,clientSharedSecret:QString)",
    "PySide6.QtNetworkAuth.QOAuth1.setSignatureMethod(self,value:PySide6.QtNetworkAuth.QOAuth1.SignatureMethod)",
    "PySide6.QtNetworkAuth.QOAuth1.setTemporaryCredentialsUrl(self,url:typing.Union[PySide6.QtCore.QUrl, QString])",
    "1:PySide6.QtNetworkAuth.QOAuth1.setTokenCredentials(self,token:QString,tokenSecret:QString)",
    "0:PySide6.QtNetworkAuth.QOAuth1.setTokenCredentials(self,tokenCredentials:std.pair[QString, QString])",
    "PySide6.QtNetworkAuth.QOAuth1.setTokenCredentialsUrl(self,url:typing.Union[PySide6.QtCore.QUrl, QString])",
    "PySide6.QtNetworkAuth.QOAuth1.setTokenSecret(self,tokenSecret:QString)",
    "1:PySide6.QtNetworkAuth.QOAuth1.setup(self,request:PySide6.QtNetwork.QNetworkRequest,signingParameters:QMap[QString, QVariant],operation:PySide6.QtNetwork.QNetworkAccessManager.Operation)",
    "0:PySide6.QtNetworkAuth.QOAuth1.setup(self,request:PySide6.QtNetwork.QNetworkRequest,signingParameters:QMap[QString, QVariant],operationVerb:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "PySide6.QtNetworkAuth.QOAuth1.signatureMethod(self)->PySide6.QtNetworkAuth.QOAuth1.SignatureMethod",
    "PySide6.QtNetworkAuth.QOAuth1.temporaryCredentialsUrl(self)->PySide6.QtCore.QUrl",
    "PySide6.QtNetworkAuth.QOAuth1.tokenCredentials(self)->std.pair[QString, QString]",
    "PySide6.QtNetworkAuth.QOAuth1.tokenCredentialsUrl(self)->PySide6.QtCore.QUrl",
    "PySide6.QtNetworkAuth.QOAuth1.tokenSecret(self)->QString",
    nullptr}; // Sentinel
#else
static constexpr size_t QOAuth1_SignatureByteSize = 601;
static constexpr uint8_t QOAuth1_SignatureBytes[601] = {
    0x78, 0xda, 0xd5, 0x57, 0x4d, 0x73, 0xd3, 0x30, 0x10, 0xbd, 0xf3, 0x2b, 0x7a, 0x6c, 0x18, 0xe3,
    0xa1, 0x1c, 0x38, 0x64, 0x26, 0xcc, 0x40, 0x0e, 0xc0, 0x21, 0x34, 0x8e, 0x69, 0x38, 0x74, 0x72,
    0x50, 0xec, 0x6d, 0x22, 0xea, 0x48, 0x62, 0xbd, 0x2e, 0x63, 0x7e, 0x3d, 0xeb, 0xaf, 0xd4, 0xa4,
    0x8e, 0xe5, 0x38, 0x14, 0xc6, 0x97, 0xc4, 0xb2, 0xa4, 0xb7, 0x6f, 0xdf, 0x7e, 0x48, 0x7e, 0x33,
    0x9e, 0xa7, 0xbe, 0x0c, 0xe1, 0xad, 0xeb, 0xd1, 0x17, 0xa0, 0x9f, 0x1a, 0xef, 0xdf, 0x27, 0xb4,
    0x75, 0xbd, 0xeb, 0xec, 0xef, 0xea, 0x32, 0x86, 0xe8, 0xce, 0xd9, 0x09, 0x25, 0x36, 0x80, 0x4f,
    0x97, 0xba, 0x5e, 0xb5, 0x27, 0x08, 0x20, 0x8e, 0x67, 0xc5, 0x3a, 0xc7, 0x08, 0x04, 0x45, 0xb5,
    0xe5, 0x53, 0x8d, 0xc0, 0x90, 0xeb, 0xef, 0x10, 0xd0, 0x44, 0x25, 0x51, 0x64, 0x08, 0x47, 0x2f,
    0xae, 0xba, 0xd8, 0xee, 0x88, 0xf5, 0xba, 0x0b, 0x56, 0x10, 0x49, 0xc6, 0xfa, 0x1c, 0xf2, 0x8f,
    0xbc, 0x93, 0xec, 0x90, 0xe7, 0x13, 0x4a, 0xb5, 0x29, 0x27, 0xfc, 0x2d, 0xdb, 0x0a, 0x7d, 0x08,
    0x10, 0x68, 0x3f, 0xf5, 0x4c, 0xbe, 0xb7, 0xb2, 0x75, 0x0b, 0x3e, 0x53, 0x66, 0x93, 0x51, 0x15,
    0x51, 0x9c, 0xf3, 0x1f, 0xbd, 0x7a, 0x17, 0x53, 0xe8, 0x1a, 0x21, 0xf1, 0xb6, 0xa2, 0x77, 0x51,
    0x3e, 0xac, 0x3a, 0x21, 0xd6, 0x3d, 0xac, 0x20, 0x4b, 0x00, 0xdb, 0x7e, 0xcd, 0x44, 0x54, 0x02,
    0x1f, 0x51, 0x28, 0xfa, 0x26, 0x69, 0xbb, 0x04, 0xcc, 0x35, 0x2c, 0x94, 0x7d, 0x28, 0x47, 0x95,
    0x6c, 0x36, 0x07, 0x43, 0x88, 0x80, 0x60, 0x01, 0xb1, 0x4e, 0x30, 0x80, 0x02, 0x23, 0xc1, 0x68,
    0x4c, 0xa9, 0xe1, 0xdd, 0xee, 0x8d, 0x92, 0x5a, 0xdd, 0x1e, 0x6a, 0x78, 0x83, 0xd1, 0xa3, 0xbf,
    0x99, 0xd0, 0x62, 0xc7, 0x20, 0x18, 0x8f, 0xbd, 0x99, 0x30, 0x35, 0x45, 0x96, 0x02, 0x25, 0xb3,
    0x5c, 0x4d, 0xaa, 0x27, 0x9e, 0xbe, 0x1c, 0xb1, 0xab, 0xc7, 0x63, 0xb8, 0x00, 0x13, 0xa5, 0x16,
    0xce, 0x1b, 0x50, 0x80, 0x82, 0x20, 0x1b, 0x69, 0x94, 0xbf, 0x04, 0x31, 0xc9, 0x4f, 0x20, 0x42,
    0x16, 0x41, 0x0b, 0x7e, 0x39, 0xcf, 0x18, 0x1d, 0x65, 0xf3, 0x87, 0xfd, 0xc2, 0xa1, 0x0f, 0x29,
    0xa3, 0x21, 0x0a, 0xbb, 0x65, 0x1a, 0x88, 0x44, 0x59, 0x76, 0x14, 0x89, 0x65, 0x59, 0xb9, 0x65,
    0xdd, 0x86, 0xe1, 0x93, 0xd2, 0x8a, 0x33, 0xf4, 0x8c, 0xe8, 0x19, 0x1d, 0x0f, 0x24, 0x7c, 0x06,
    0x21, 0x6b, 0x5f, 0x0b, 0xf8, 0x91, 0x40, 0xc5, 0x19, 0x8b, 0xc1, 0xb8, 0x0d, 0x39, 0x5f, 0x91,
    0xf5, 0x80, 0x75, 0xbb, 0x7b, 0x7b, 0xc5, 0x9c, 0x8b, 0x80, 0x3b, 0xd1, 0xcb, 0x95, 0xb3, 0xd6,
    0x61, 0x7a, 0xe2, 0x9e, 0xc9, 0xe3, 0x2b, 0x76, 0xd9, 0xe6, 0x51, 0x32, 0x10, 0xe9, 0x4b, 0x99,
    0xbf, 0xc2, 0xce, 0x68, 0x14, 0x98, 0x1e, 0xf6, 0x7e, 0x47, 0x9b, 0xac, 0xf9, 0x30, 0xf3, 0xae,
    0x27, 0x91, 0x7b, 0x5d, 0xed, 0x18, 0x8c, 0xf3, 0xfa, 0x1e, 0xd4, 0xff, 0x74, 0x9c, 0x2a, 0xf5,
    0x73, 0x26, 0xe3, 0xe3, 0x87, 0xed, 0x73, 0x48, 0x64, 0xb9, 0x0d, 0xb9, 0x31, 0xd0, 0xb4, 0xf1,
    0x5a, 0xd0, 0xe7, 0x5a, 0x63, 0xbd, 0x30, 0x59, 0xcd, 0xd5, 0x5e, 0xb7, 0x08, 0x65, 0xab, 0xcf,
    0xbd, 0x95, 0x27, 0x37, 0x93, 0x56, 0xf2, 0x56, 0x50, 0x5f, 0x6e, 0x94, 0xa0, 0x04, 0x61, 0x06,
    0x7c, 0x58, 0x97, 0x27, 0xcd, 0x83, 0x88, 0x12, 0xb0, 0xb8, 0x7d, 0xb0, 0xb1, 0x83, 0xa9, 0xa6,
    0x92, 0xe5, 0xb4, 0xea, 0xd3, 0x76, 0x46, 0x5d, 0x92, 0xa0, 0xb9, 0x4a, 0x28, 0xcf, 0xd8, 0x4a,
    0xff, 0x7c, 0xd4, 0x23, 0xe2, 0x2d, 0xd8, 0x7f, 0x2d, 0xde, 0x87, 0x36, 0x7a, 0x6b, 0xd5, 0xcd,
    0x52, 0x3d, 0xa5, 0x1a, 0x65, 0xe9, 0x20, 0x79, 0x62, 0x4e, 0x3d, 0x0b, 0x63, 0x4e, 0x23, 0x46,
    0x9f, 0x5b, 0xdb, 0xc4, 0x39, 0xed, 0xad, 0x53, 0x48, 0xff, 0x09, 0xf7, 0xe5, 0xe9, 0x47, 0xbf,
    0x35, 0x7e, 0x0d, 0x15, 0xdc, 0xd4, 0x45, 0xdb, 0xaa, 0xd7, 0x62, 0x82, 0x5a, 0x2a, 0xb7, 0xe1,
    0xbe, 0xc7, 0x53, 0x36, 0xc0, 0xa6, 0xf2, 0x39, 0xe7, 0xab, 0x8d, 0x8e, 0xd4, 0x4a, 0x7f, 0x76,
    0xcd, 0xdf, 0x7e, 0xbf, 0x01, 0xa5, 0x64, 0xdd, 0xab
};
#endif

PyTypeObject *init_QOAuth1(PyObject *module)
{
    if (SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX].type != nullptr)
        return SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX].type;

    Shiboken::AutoDecRef Sbk_QOAuth1_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QAbstractOAuth_IDX]))));

    _Sbk_QOAuth1_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QOAuth1",
        "QOAuth1*",
        &Sbk_QOAuth1_spec,
        &Shiboken::callCppDestructor< QOAuth1 >,
        Sbk_QOAuth1_Type_bases.object(),
        0);
    auto *pyType = Sbk_QOAuth1_TypeF(); // references _Sbk_QOAuth1_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QOAuth1_SignatureStrings);
#else
    InitSignatureBytes(pyType, QOAuth1_SignatureBytes, QOAuth1_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QOAuth1_PropertyStrings);
    SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QOAuth1_PythonToCpp_QOAuth1_PTR,
        is_QOAuth1_PythonToCpp_QOAuth1_PTR_Convertible,
        QOAuth1_PTR_CppToPython_QOAuth1);

    Shiboken::Conversions::registerConverterName(converter, "QOAuth1");
    Shiboken::Conversions::registerConverterName(converter, "QOAuth1*");
    Shiboken::Conversions::registerConverterName(converter, "QOAuth1&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QOAuth1).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QOAuth1Wrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QOAuth1_TypeF(), &Sbk_QOAuth1_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QOAuth1_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'SignatureMethod'.
    const char *SignatureMethod_Initializer[] = {
        "Hmac_Sha1",
        "Rsa_Sha1",
        "PlainText",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t SignatureMethod_InitializerValues[] = {
        int8_t(QOAuth1::SignatureMethod::Hmac_Sha1), //  0x00  0
        int8_t(QOAuth1::SignatureMethod::Rsa_Sha1),  //  0x01  1
        int8_t(QOAuth1::SignatureMethod::PlainText)  //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QOAuth1_TypeF(),
        "2:PySide6.QtNetworkAuth.QOAuth1.SignatureMethod",
        SignatureMethod_Initializer, SignatureMethod_InitializerValues);
    SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1_SignatureMethod_IDX].type = EType;
    // Register converter for enum 'QOAuth1::SignatureMethod'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QOAuth1_SignatureMethod_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QOAuth1_SignatureMethod,
            is_Enum_PythonToCpp_QOAuth1_SignatureMethod_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QOAuth1::SignatureMethod");
        Shiboken::Conversions::registerConverterAlias(converter, "SignatureMethod");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'SignatureMethod' enum.

    PySide::Signal::registerSignals(pyType, &::QOAuth1::staticMetaObject);
    qRegisterMetaType< ::QOAuth1::SignatureMethod >("QOAuth1::SignatureMethod");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QOAuth1::staticMetaObject, sizeof(QOAuth1Wrapper));

    return pyType;
}
