// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnfc_python.h"

// main header
#include "qndeffilter_wrapper.h"

// inner classes
#include "qndeffilter_record_wrapper.h"

// Argument includes
#include <QtNfc/qndeffilter.h>
#include <QtNfc/qndefmessage.h>
#include <QtNfc/qndefrecord.h>
#include <qbytearray.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QNdefFilter_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QNdefFilter >()))
        return -1;

    ::QNdefFilter *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QNdefFilter", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QNdefFilter::QNdefFilter()
    // 1: QNdefFilter::QNdefFilter(QNdefFilter)
    if (numArgs == 0) {
        overloadId = 0; // QNdefFilter()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefFilter_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QNdefFilter(QNdefFilter)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNfcTypeStructs[SBK_QNdefFilter_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtNfcTypeStructs[SBK_QNdefFilter_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QNdefFilter()
        {

            // QNdefFilter()
            cptr = new ::QNdefFilter();
            break;
        }
        case 1: // QNdefFilter(const QNdefFilter &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QNdefFilter cppArg0_local;
            ::QNdefFilter *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QNdefFilter(QNdefFilter)
                cptr = new ::QNdefFilter(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QNdefFilter >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNfcTypeStructs[SBK_QNdefFilter_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QNdefFilterFunc_appendRecord(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefFilter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefFilter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "appendRecord", errInfo, SbkPySide6_QtNfcTypeStructs[SBK_QNdefFilter_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:appendRecord", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QNdefFilter::appendRecord(QNdefRecord::TypeNameFormat,QByteArray,uint=,uint=)->bool
    // 1: QNdefFilter::appendRecord(QNdefFilter::Record)->bool
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefFilter_Record_IDX]), (pyArgs[0])))) {
        overloadId = 1; // appendRecord(QNdefFilter::Record)
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_TypeNameFormat_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // appendRecord(QNdefRecord::TypeNameFormat,QByteArray,uint,uint)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 0; // appendRecord(QNdefRecord::TypeNameFormat,QByteArray,uint,uint)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[3])))) {
                overloadId = 0; // appendRecord(QNdefRecord::TypeNameFormat,QByteArray,uint,uint)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "appendRecord", errInfo, SbkPySide6_QtNfcTypeStructs[SBK_QNdefFilter_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // appendRecord(QNdefRecord::TypeNameFormat typeNameFormat, const QByteArray &type, unsigned int min, unsigned int max)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_min = Shiboken::String::createStaticString("min");
                if (PyDict_Contains(kwds, key_min) != 0) {
                    value = PyDict_GetItem(kwds, key_min);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_min);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "appendRecord", errInfo, SbkPySide6_QtNfcTypeStructs[SBK_QNdefFilter_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "appendRecord", errInfo, SbkPySide6_QtNfcTypeStructs[SBK_QNdefFilter_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_min);
                }
                static PyObject *const key_max = Shiboken::String::createStaticString("max");
                if (PyDict_Contains(kwds, key_max) != 0) {
                    value = PyDict_GetItem(kwds, key_max);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_max);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "appendRecord", errInfo, SbkPySide6_QtNfcTypeStructs[SBK_QNdefFilter_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "appendRecord", errInfo, SbkPySide6_QtNfcTypeStructs[SBK_QNdefFilter_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_max);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "appendRecord", errInfo, SbkPySide6_QtNfcTypeStructs[SBK_QNdefFilter_IDX]);
                }
            }
            ::QNdefRecord::TypeNameFormat cppArg0{QNdefRecord::Empty};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QByteArray cppArg1_local;
            ::QByteArray *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            unsigned int cppArg2 = 1;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            unsigned int cppArg3 = 1;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // appendRecord(QNdefRecord::TypeNameFormat,QByteArray,uint,uint)
                bool cppResult = cppSelf->appendRecord(cppArg0, *cppArg1, cppArg2, cppArg3);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // appendRecord(const QNdefFilter::Record &record)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "appendRecord", errInfo, SbkPySide6_QtNfcTypeStructs[SBK_QNdefFilter_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNdefFilter::Record cppArg0_local;
            ::QNdefFilter::Record *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // appendRecord(QNdefFilter::Record)
                bool cppResult = cppSelf->appendRecord(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNdefFilterFunc_clear(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefFilter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefFilter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clear()
        cppSelf->clear();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNdefFilterFunc_match(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefFilter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefFilter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNdefFilter::match(QNdefMessage)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), (pyArg)))) {
        overloadId = 0; // match(QNdefMessage)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "match", errInfo, SbkPySide6_QtNfcTypeStructs[SBK_QNdefFilter_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QNdefMessage cppArg0_local;
        ::QNdefMessage *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // match(QNdefMessage)const
            bool cppResult = const_cast<const ::QNdefFilter *>(cppSelf)->match(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNdefFilterFunc_orderMatch(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefFilter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefFilter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // orderMatch()const
        bool cppResult = const_cast<const ::QNdefFilter *>(cppSelf)->orderMatch();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNdefFilterFunc_recordAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefFilter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefFilter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNdefFilter::recordAt(qsizetype)const->QNdefFilter::Record
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // recordAt(qsizetype)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "recordAt", errInfo, SbkPySide6_QtNfcTypeStructs[SBK_QNdefFilter_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // recordAt(qsizetype)const
            QNdefFilter::Record cppResult = const_cast<const ::QNdefFilter *>(cppSelf)->recordAt(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefFilter_Record_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNdefFilterFunc_recordCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefFilter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefFilter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // recordCount()const
        qsizetype cppResult = const_cast<const ::QNdefFilter *>(cppSelf)->recordCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNdefFilterFunc_setOrderMatch(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefFilter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefFilter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNdefFilter::setOrderMatch(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setOrderMatch(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOrderMatch", errInfo, SbkPySide6_QtNfcTypeStructs[SBK_QNdefFilter_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOrderMatch(bool)
            cppSelf->setOrderMatch(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNdefFilter__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QNdefFilter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefFilter_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefFilter_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QNdefFilter_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QNdefFilter_methods[] = {
    {"appendRecord", reinterpret_cast<PyCFunction>(Sbk_QNdefFilterFunc_appendRecord), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"clear", reinterpret_cast<PyCFunction>(Sbk_QNdefFilterFunc_clear), METH_NOARGS, nullptr},
    {"match", reinterpret_cast<PyCFunction>(Sbk_QNdefFilterFunc_match), METH_O, nullptr},
    {"orderMatch", reinterpret_cast<PyCFunction>(Sbk_QNdefFilterFunc_orderMatch), METH_NOARGS, nullptr},
    {"recordAt", reinterpret_cast<PyCFunction>(Sbk_QNdefFilterFunc_recordAt), METH_O, nullptr},
    {"recordCount", reinterpret_cast<PyCFunction>(Sbk_QNdefFilterFunc_recordCount), METH_NOARGS, nullptr},
    {"setOrderMatch", reinterpret_cast<PyCFunction>(Sbk_QNdefFilterFunc_setOrderMatch), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QNdefFilter__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QNdefFilter_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QNdefFilter_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QNdefFilter_Type = nullptr;
static PyTypeObject *Sbk_QNdefFilter_TypeF(void)
{
    return _Sbk_QNdefFilter_Type;
}

static PyType_Slot Sbk_QNdefFilter_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QNdefFilter_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QNdefFilter_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QNdefFilter_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QNdefFilter_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QNdefFilter_spec = {
    "2:PySide6.QtNfc.QNdefFilter",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QNdefFilter_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QNdefFilter_PythonToCpp_QNdefFilter_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QNdefFilter_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QNdefFilter_PythonToCpp_QNdefFilter_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QNdefFilter_TypeF()))
        return QNdefFilter_PythonToCpp_QNdefFilter_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QNdefFilter_PTR_CppToPython_QNdefFilter(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QNdefFilter_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QNdefFilter_COPY_CppToPython_QNdefFilter(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QNdefFilter *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QNdefFilter_TypeF(), new ::QNdefFilter(*source), true, true);
}

// Python to C++ copy conversion.
static void QNdefFilter_PythonToCpp_QNdefFilter_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QNdefFilter *>(cppOut) = *reinterpret_cast< ::QNdefFilter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefFilter_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QNdefFilter_PythonToCpp_QNdefFilter_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QNdefFilter_TypeF()))
        return QNdefFilter_PythonToCpp_QNdefFilter_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QNdefFilter_SignatureStrings[] = {
    "1:PySide6.QtNfc.QNdefFilter(self)",
    "0:PySide6.QtNfc.QNdefFilter(self,other:PySide6.QtNfc.QNdefFilter)",
    "1:PySide6.QtNfc.QNdefFilter.appendRecord(self,typeNameFormat:PySide6.QtNfc.QNdefRecord.TypeNameFormat,type:typing.Union[PySide6.QtCore.QByteArray, char*],min:unsigned int=1,max:unsigned int=1)->bool",
    "0:PySide6.QtNfc.QNdefFilter.appendRecord(self,record:PySide6.QtNfc.QNdefFilter.Record)->bool",
    "PySide6.QtNfc.QNdefFilter.clear(self)",
    "PySide6.QtNfc.QNdefFilter.match(self,message:typing.Union[PySide6.QtNfc.QNdefMessage, QList[PySide6.QtNfc.QNdefRecord]])->bool",
    "PySide6.QtNfc.QNdefFilter.orderMatch(self)->bool",
    "PySide6.QtNfc.QNdefFilter.recordAt(self,i:qsizetype)->PySide6.QtNfc.QNdefFilter.Record",
    "PySide6.QtNfc.QNdefFilter.recordCount(self)->qsizetype",
    "PySide6.QtNfc.QNdefFilter.setOrderMatch(self,on:bool)",
    "PySide6.QtNfc.QNdefFilter.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QNdefFilter_SignatureByteSize = 281;
static constexpr uint8_t QNdefFilter_SignatureBytes[281] = {
    0x78, 0xda, 0x85, 0x91, 0x4f, 0x4f, 0x84, 0x30, 0x10, 0xc5, 0xef, 0x7c, 0x0a, 0x8e, 0x62, 0x6a,
    0x23, 0x17, 0x0f, 0x24, 0x9a, 0xac, 0x9b, 0xec, 0xc9, 0x45, 0x71, 0xf5, 0xb4, 0x21, 0xa4, 0x96,
    0x01, 0x9a, 0x40, 0x8b, 0xed, 0x6c, 0x22, 0x7e, 0x7a, 0xd9, 0xad, 0x60, 0xd6, 0x6c, 0xe9, 0xa5,
    0xe9, 0x9f, 0xdf, 0x7b, 0x33, 0xf3, 0x1a, 0x27, 0x2f, 0xc3, 0x4e, 0x94, 0x70, 0x47, 0x33, 0x4c,
    0x2b, 0x4e, 0xb3, 0xb4, 0x84, 0x6a, 0x23, 0x5a, 0x04, 0x7d, 0x65, 0xa0, 0xad, 0xa2, 0xe0, 0xd6,
    0x43, 0x10, 0x85, 0x0d, 0x68, 0x37, 0x14, 0x05, 0xb1, 0xfb, 0x91, 0xb2, 0xbe, 0x07, 0x59, 0xbe,
    0x02, 0x57, 0xba, 0xb4, 0x76, 0x38, 0xf4, 0x90, 0xb2, 0x0e, 0x36, 0x4a, 0x77, 0x0c, 0x2f, 0x49,
    0x2d, 0x4d, 0xdf, 0xce, 0xc0, 0x93, 0x2e, 0x19, 0x17, 0x21, 0x6b, 0xfa, 0x2e, 0x85, 0x92, 0xfb,
    0x3f, 0xe9, 0x5a, 0x69, 0xa0, 0xd9, 0xe3, 0x80, 0xb0, 0xd2, 0x9a, 0x0d, 0x24, 0xe4, 0x0d, 0xd3,
    0xd7, 0x39, 0xe9, 0x84, 0x4c, 0x0e, 0xd2, 0x88, 0x5a, 0x42, 0x19, 0x0a, 0x89, 0xf7, 0x31, 0xe9,
    0xd8, 0xd7, 0xbf, 0xab, 0xe8, 0xe6, 0xe1, 0x43, 0xa9, 0x76, 0x29, 0x88, 0x0b, 0x63, 0xe8, 0xd3,
    0x7e, 0x41, 0x62, 0xe1, 0xc9, 0xdc, 0xcd, 0xf1, 0x16, 0xd8, 0xf4, 0x17, 0x6e, 0x6a, 0x4c, 0x80,
    0x37, 0xb6, 0x72, 0x07, 0xc6, 0xb0, 0xda, 0x99, 0xc5, 0xac, 0xdc, 0x5a, 0x8e, 0x84, 0xd9, 0x93,
    0x30, 0xb8, 0x77, 0x06, 0x9d, 0xe7, 0xfe, 0x26, 0x47, 0x0c, 0xf4, 0x76, 0xee, 0xc1, 0x2f, 0xb0,
    0xf1, 0xac, 0xd0, 0xb6, 0x2c, 0x92, 0x4f, 0x23, 0xbe, 0xe1, 0xf8, 0x85, 0xa3, 0xd4, 0x97, 0x99,
    0xd7, 0x76, 0xad, 0x0e, 0x12, 0xa7, 0x46, 0x66, 0xe7, 0x05, 0x99, 0x01, 0x7c, 0x3e, 0x9f, 0x80,
    0x28, 0x99, 0x1c, 0x47, 0x58, 0xca, 0xbc, 0x28, 0xb8, 0xea, 0x87, 0xa2, 0x98, 0x2a, 0xfd, 0x06,
    0xbe, 0x1b, 0x4f, 0xc1, 0x0f, 0xaf, 0x04, 0x30, 0x00
};
#endif

PyTypeObject *init_QNdefFilter(PyObject *module)
{
    if (SbkPySide6_QtNfcTypeStructs[SBK_QNdefFilter_IDX].type != nullptr)
        return SbkPySide6_QtNfcTypeStructs[SBK_QNdefFilter_IDX].type;

    Shiboken::AutoDecRef Sbk_QNdefFilter_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QNdefFilter_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QNdefFilter",
        "QNdefFilter",
        &Sbk_QNdefFilter_spec,
        &Shiboken::callCppDestructor< ::QNdefFilter >,
        Sbk_QNdefFilter_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QNdefFilter_TypeF(); // references _Sbk_QNdefFilter_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QNdefFilter_SignatureStrings);
#else
    InitSignatureBytes(pyType, QNdefFilter_SignatureBytes, QNdefFilter_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QNdefFilter_PropertyStrings);
    SbkPySide6_QtNfcTypeStructs[SBK_QNdefFilter_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QNdefFilter_PythonToCpp_QNdefFilter_PTR,
        is_QNdefFilter_PythonToCpp_QNdefFilter_PTR_Convertible,
        QNdefFilter_PTR_CppToPython_QNdefFilter,
        QNdefFilter_COPY_CppToPython_QNdefFilter);

    Shiboken::Conversions::registerConverterName(converter, "QNdefFilter");
    Shiboken::Conversions::registerConverterName(converter, "QNdefFilter*");
    Shiboken::Conversions::registerConverterName(converter, "QNdefFilter&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QNdefFilter).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QNdefFilter_PythonToCpp_QNdefFilter_COPY,
        is_QNdefFilter_PythonToCpp_QNdefFilter_COPY_Convertible);

    qRegisterMetaType< ::QNdefFilter >("QNdefFilter");

    return pyType;
}
