// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnfc_python.h"

// main header
#include "qndefnfctextrecord_wrapper.h"

// Argument includes
#include <QString>
#include <QtNfc/qndefnfctextrecord.h>
#include <QtNfc/qndefrecord.h>
#include <qbytearray.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QNdefNfcTextRecord_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QNdefNfcTextRecord >()))
        return -1;

    ::QNdefNfcTextRecord *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QNdefNfcTextRecord", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QNdefNfcTextRecord::QNdefNfcTextRecord()
    // 1: QNdefNfcTextRecord::QNdefNfcTextRecord(QNdefNfcTextRecord)
    // 2: QNdefNfcTextRecord::QNdefNfcTextRecord(QNdefRecord)
    if (numArgs == 0) {
        overloadId = 0; // QNdefNfcTextRecord()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefNfcTextRecord_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QNdefNfcTextRecord(QNdefNfcTextRecord)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QNdefNfcTextRecord(QNdefRecord)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNfcTypeStructs[SBK_QNdefNfcTextRecord_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtNfcTypeStructs[SBK_QNdefNfcTextRecord_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QNdefNfcTextRecord()
        {

            // QNdefNfcTextRecord()
            cptr = new ::QNdefNfcTextRecord();
            break;
        }
        case 1: // QNdefNfcTextRecord(const QNdefNfcTextRecord &QNdefNfcTextRecord)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QNdefNfcTextRecord cppArg0_local;
            ::QNdefNfcTextRecord *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QNdefNfcTextRecord(QNdefNfcTextRecord)
                cptr = new ::QNdefNfcTextRecord(*cppArg0);
            }
            break;
        }
        case 2: // QNdefNfcTextRecord(const QNdefRecord &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QNdefRecord cppArg0_local;
            ::QNdefRecord *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QNdefNfcTextRecord(QNdefRecord)
                cptr = new ::QNdefNfcTextRecord(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QNdefNfcTextRecord >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNfcTypeStructs[SBK_QNdefNfcTextRecord_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QNdefNfcTextRecordFunc_encoding(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefNfcTextRecord *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefNfcTextRecord_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // encoding()const
        QNdefNfcTextRecord::Encoding cppResult = const_cast<const ::QNdefNfcTextRecord *>(cppSelf)->encoding();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefNfcTextRecord_Encoding_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNdefNfcTextRecordFunc_locale(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefNfcTextRecord *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefNfcTextRecord_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // locale()const
        QString cppResult = const_cast<const ::QNdefNfcTextRecord *>(cppSelf)->locale();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNdefNfcTextRecordFunc_setEncoding(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefNfcTextRecord *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefNfcTextRecord_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNdefNfcTextRecord::setEncoding(QNdefNfcTextRecord::Encoding)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefNfcTextRecord_Encoding_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setEncoding(QNdefNfcTextRecord::Encoding)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setEncoding", errInfo, SbkPySide6_QtNfcTypeStructs[SBK_QNdefNfcTextRecord_IDX]);

    // Call function/method
    {
        ::QNdefNfcTextRecord::Encoding cppArg0{QNdefNfcTextRecord::Utf8};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setEncoding(QNdefNfcTextRecord::Encoding)
            cppSelf->setEncoding(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNdefNfcTextRecordFunc_setLocale(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefNfcTextRecord *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefNfcTextRecord_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNdefNfcTextRecord::setLocale(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setLocale(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLocale", errInfo, SbkPySide6_QtNfcTypeStructs[SBK_QNdefNfcTextRecord_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLocale(QString)
            cppSelf->setLocale(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNdefNfcTextRecordFunc_setText(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefNfcTextRecord *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefNfcTextRecord_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNdefNfcTextRecord::setText(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setText(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setText", errInfo, SbkPySide6_QtNfcTypeStructs[SBK_QNdefNfcTextRecord_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setText(QString)
            cppSelf->setText(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNdefNfcTextRecordFunc_text(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefNfcTextRecord *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefNfcTextRecord_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // text()const
        QString cppResult = const_cast<const ::QNdefNfcTextRecord *>(cppSelf)->text();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNdefNfcTextRecord__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QNdefNfcTextRecord *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefNfcTextRecord_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefNfcTextRecord_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QNdefNfcTextRecord_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QNdefNfcTextRecord_EnumFlagInfo[] = {
    "Encoding:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QNdefNfcTextRecord_methods[] = {
    {"encoding", reinterpret_cast<PyCFunction>(Sbk_QNdefNfcTextRecordFunc_encoding), METH_NOARGS, nullptr},
    {"locale", reinterpret_cast<PyCFunction>(Sbk_QNdefNfcTextRecordFunc_locale), METH_NOARGS, nullptr},
    {"setEncoding", reinterpret_cast<PyCFunction>(Sbk_QNdefNfcTextRecordFunc_setEncoding), METH_O, nullptr},
    {"setLocale", reinterpret_cast<PyCFunction>(Sbk_QNdefNfcTextRecordFunc_setLocale), METH_O, nullptr},
    {"setText", reinterpret_cast<PyCFunction>(Sbk_QNdefNfcTextRecordFunc_setText), METH_O, nullptr},
    {"text", reinterpret_cast<PyCFunction>(Sbk_QNdefNfcTextRecordFunc_text), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QNdefNfcTextRecord__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QNdefNfcTextRecord_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QNdefNfcTextRecord_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QNdefNfcTextRecord_Type = nullptr;
static PyTypeObject *Sbk_QNdefNfcTextRecord_TypeF(void)
{
    return _Sbk_QNdefNfcTextRecord_Type;
}

static PyType_Slot Sbk_QNdefNfcTextRecord_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QNdefNfcTextRecord_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QNdefNfcTextRecord_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QNdefNfcTextRecord_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QNdefNfcTextRecord_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QNdefNfcTextRecord_spec = {
    "2:PySide6.QtNfc.QNdefNfcTextRecord",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QNdefNfcTextRecord_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QNdefNfcTextRecord_Encoding(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QNdefNfcTextRecord::Encoding>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QNdefNfcTextRecord::Encoding *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QNdefNfcTextRecord_Encoding_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefNfcTextRecord_Encoding_IDX])))
        return Enum_PythonToCpp_QNdefNfcTextRecord_Encoding;
    return {};
}

static PyObject *QNdefNfcTextRecord_Encoding_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QNdefNfcTextRecord::Encoding>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QNdefNfcTextRecord::Encoding *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefNfcTextRecord_Encoding_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QNdefNfcTextRecord_PythonToCpp_QNdefNfcTextRecord_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QNdefNfcTextRecord_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QNdefNfcTextRecord_PythonToCpp_QNdefNfcTextRecord_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QNdefNfcTextRecord_TypeF()))
        return QNdefNfcTextRecord_PythonToCpp_QNdefNfcTextRecord_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QNdefNfcTextRecord_PTR_CppToPython_QNdefNfcTextRecord(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QNdefNfcTextRecord_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QNdefNfcTextRecord_COPY_CppToPython_QNdefNfcTextRecord(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QNdefNfcTextRecord *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QNdefNfcTextRecord_TypeF(), new ::QNdefNfcTextRecord(*source), true, true);
}

// Python to C++ copy conversion.
static void QNdefNfcTextRecord_PythonToCpp_QNdefNfcTextRecord_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QNdefNfcTextRecord *>(cppOut) = *reinterpret_cast< ::QNdefNfcTextRecord *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefNfcTextRecord_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QNdefNfcTextRecord_PythonToCpp_QNdefNfcTextRecord_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QNdefNfcTextRecord_TypeF()))
        return QNdefNfcTextRecord_PythonToCpp_QNdefNfcTextRecord_COPY;
    return {};
}

// Implicit conversions.
static void constQNdefRecordREF_PythonToCpp_QNdefNfcTextRecord(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QNdefNfcTextRecord *>(cppOut) = ::QNdefNfcTextRecord( *reinterpret_cast< ::QNdefRecord *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]), reinterpret_cast<SbkObject *>(pyIn))));
}
static PythonToCppFunc is_constQNdefRecordREF_PythonToCpp_QNdefNfcTextRecord_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]), pyIn))
        return constQNdefRecordREF_PythonToCpp_QNdefNfcTextRecord;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QNdefNfcTextRecord_SignatureStrings[] = {
    "2:PySide6.QtNfc.QNdefNfcTextRecord(self)",
    "1:PySide6.QtNfc.QNdefNfcTextRecord(self,QNdefNfcTextRecord:PySide6.QtNfc.QNdefNfcTextRecord)",
    "0:PySide6.QtNfc.QNdefNfcTextRecord(self,other:PySide6.QtNfc.QNdefRecord)",
    "PySide6.QtNfc.QNdefNfcTextRecord.encoding(self)->PySide6.QtNfc.QNdefNfcTextRecord.Encoding",
    "PySide6.QtNfc.QNdefNfcTextRecord.locale(self)->QString",
    "PySide6.QtNfc.QNdefNfcTextRecord.setEncoding(self,encoding:PySide6.QtNfc.QNdefNfcTextRecord.Encoding)",
    "PySide6.QtNfc.QNdefNfcTextRecord.setLocale(self,locale:QString)",
    "PySide6.QtNfc.QNdefNfcTextRecord.setText(self,text:QString)",
    "PySide6.QtNfc.QNdefNfcTextRecord.text(self)->QString",
    "PySide6.QtNfc.QNdefNfcTextRecord.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QNdefNfcTextRecord_SignatureByteSize = 170;
static constexpr uint8_t QNdefNfcTextRecord_SignatureBytes[170] = {
    0x78, 0xda, 0x95, 0x90, 0xb1, 0x0a, 0xc2, 0x30, 0x10, 0x86, 0xf7, 0x3c, 0x89, 0x81, 0x1a, 0xd4,
    0xc1, 0xa1, 0x83, 0x5b, 0x37, 0x29, 0x8d, 0x71, 0x0f, 0x92, 0x5c, 0xb4, 0x50, 0x9a, 0xd2, 0xde,
    0x60, 0xde, 0xde, 0x48, 0x1b, 0x14, 0x14, 0x72, 0xdd, 0xee, 0x8e, 0xfb, 0xfe, 0xfb, 0x92, 0x43,
    0xd9, 0x04, 0xd5, 0x5a, 0x38, 0x0a, 0x89, 0xb5, 0x33, 0x42, 0xd6, 0x16, 0x5c, 0x2c, 0xae, 0xf0,
    0xc4, 0x0b, 0x18, 0x3f, 0xda, 0xcd, 0x04, 0x9d, 0xe3, 0x6c, 0x4f, 0x5b, 0x2c, 0x7e, 0xe7, 0x59,
    0x90, 0xb3, 0x1d, 0x31, 0xdc, 0xe3, 0x03, 0xc6, 0x7f, 0xbb, 0x29, 0x28, 0x17, 0x23, 0xa0, 0x37,
    0xde, 0xb6, 0xfd, 0x7d, 0x7e, 0xd5, 0xf6, 0x94, 0x05, 0xaa, 0x05, 0xc8, 0x47, 0x77, 0xde, 0xdc,
    0x3a, 0x48, 0xc1, 0x52, 0xe1, 0x48, 0xc2, 0x26, 0xc0, 0xea, 0x5b, 0xaa, 0x48, 0x8a, 0x25, 0xd9,
    0x8d, 0x93, 0xae, 0x9c, 0x3f, 0x7e, 0xc5, 0xec, 0x5a, 0x2e, 0x92, 0x34, 0xfe, 0xdd, 0xcd, 0x34,
    0xc6, 0x6a, 0x05, 0x8b, 0x09, 0x5c, 0xf3, 0x2d, 0x5a, 0x1b, 0x3f, 0x04, 0xad, 0x13, 0x88, 0x61,
    0x88, 0x9c, 0x50, 0xb1, 0x63, 0x2f, 0x49, 0x9a, 0xf7, 0x01
};
#endif

PyTypeObject *init_QNdefNfcTextRecord(PyObject *module)
{
    if (SbkPySide6_QtNfcTypeStructs[SBK_QNdefNfcTextRecord_IDX].type != nullptr)
        return SbkPySide6_QtNfcTypeStructs[SBK_QNdefNfcTextRecord_IDX].type;

    Shiboken::AutoDecRef Sbk_QNdefNfcTextRecord_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]))));

    _Sbk_QNdefNfcTextRecord_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QNdefNfcTextRecord",
        "QNdefNfcTextRecord",
        &Sbk_QNdefNfcTextRecord_spec,
        &Shiboken::callCppDestructor< ::QNdefNfcTextRecord >,
        Sbk_QNdefNfcTextRecord_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QNdefNfcTextRecord_TypeF(); // references _Sbk_QNdefNfcTextRecord_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QNdefNfcTextRecord_SignatureStrings);
#else
    InitSignatureBytes(pyType, QNdefNfcTextRecord_SignatureBytes, QNdefNfcTextRecord_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QNdefNfcTextRecord_PropertyStrings);
    SbkPySide6_QtNfcTypeStructs[SBK_QNdefNfcTextRecord_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QNdefNfcTextRecord_PythonToCpp_QNdefNfcTextRecord_PTR,
        is_QNdefNfcTextRecord_PythonToCpp_QNdefNfcTextRecord_PTR_Convertible,
        QNdefNfcTextRecord_PTR_CppToPython_QNdefNfcTextRecord,
        QNdefNfcTextRecord_COPY_CppToPython_QNdefNfcTextRecord);

    Shiboken::Conversions::registerConverterName(converter, "QNdefNfcTextRecord");
    Shiboken::Conversions::registerConverterName(converter, "QNdefNfcTextRecord*");
    Shiboken::Conversions::registerConverterName(converter, "QNdefNfcTextRecord&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QNdefNfcTextRecord).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QNdefNfcTextRecord_PythonToCpp_QNdefNfcTextRecord_COPY,
        is_QNdefNfcTextRecord_PythonToCpp_QNdefNfcTextRecord_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        constQNdefRecordREF_PythonToCpp_QNdefNfcTextRecord,
        is_constQNdefRecordREF_PythonToCpp_QNdefNfcTextRecord_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QNdefNfcTextRecord_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Encoding'.
    const char *Encoding_Initializer[] = {
        "Utf8",
        "Utf16",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Encoding_InitializerValues[] = {
        uint8_t(QNdefNfcTextRecord::Encoding::Utf8), //  0x00  0
        uint8_t(QNdefNfcTextRecord::Encoding::Utf16) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QNdefNfcTextRecord_TypeF(),
        "2:PySide6.QtNfc.QNdefNfcTextRecord.Encoding",
        Encoding_Initializer, Encoding_InitializerValues);
    SbkPySide6_QtNfcTypeStructs[SBK_QNdefNfcTextRecord_Encoding_IDX].type = EType;
    // Register converter for enum 'QNdefNfcTextRecord::Encoding'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QNdefNfcTextRecord_Encoding_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QNdefNfcTextRecord_Encoding,
            is_Enum_PythonToCpp_QNdefNfcTextRecord_Encoding_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QNdefNfcTextRecord::Encoding");
        Shiboken::Conversions::registerConverterAlias(converter, "Encoding");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Encoding' enum.

    qRegisterMetaType< ::QNdefNfcTextRecord >("QNdefNfcTextRecord");
    qRegisterMetaType< ::QNdefNfcTextRecord::Encoding >("QNdefNfcTextRecord::Encoding");

    return pyType;
}
