// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnfc_python.h"

// main header
#include "qndefrecord_wrapper.h"

// Argument includes
#include <QtNfc/qndefrecord.h>
#include <qbytearray.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QNdefRecord_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QNdefRecord >()))
        return -1;

    ::QNdefRecord *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QNdefRecord", 0, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QNdefRecord::QNdefRecord()
    // 1: QNdefRecord::QNdefRecord(QNdefRecord::TypeNameFormat,QByteArray)
    // 2: QNdefRecord::QNdefRecord(QNdefRecord)
    // 3: QNdefRecord::QNdefRecord(QNdefRecord,QNdefRecord::TypeNameFormat)
    // 4: QNdefRecord::QNdefRecord(QNdefRecord,QNdefRecord::TypeNameFormat,QByteArray)
    if (numArgs == 0) {
        overloadId = 0; // QNdefRecord()
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 2; // QNdefRecord(QNdefRecord)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_TypeNameFormat_IDX])))->converter, (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 3; // QNdefRecord(QNdefRecord,QNdefRecord::TypeNameFormat)
            } else if (numArgs == 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[2])))) {
                overloadId = 4; // QNdefRecord(QNdefRecord,QNdefRecord::TypeNameFormat,QByteArray)
            }
        }
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_TypeNameFormat_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
        overloadId = 1; // QNdefRecord(QNdefRecord::TypeNameFormat,QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QNdefRecord()
        {

            // QNdefRecord()
            cptr = new ::QNdefRecord();
            break;
        }
        case 1: // QNdefRecord(QNdefRecord::TypeNameFormat typeNameFormat, const QByteArray &type)
        {
            ::QNdefRecord::TypeNameFormat cppArg0{QNdefRecord::Empty};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QByteArray cppArg1_local;
            ::QByteArray *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QNdefRecord(QNdefRecord::TypeNameFormat,QByteArray)
                cptr = new ::QNdefRecord(cppArg0, *cppArg1);
            }
            break;
        }
        case 2: // QNdefRecord(const QNdefRecord &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QNdefRecord cppArg0_local;
            ::QNdefRecord *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QNdefRecord(QNdefRecord)
                cptr = new ::QNdefRecord(*cppArg0);
            }
            break;
        }
        case 3: // QNdefRecord(const QNdefRecord &other, QNdefRecord::TypeNameFormat typeNameFormat)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QNdefRecord cppArg0_local;
            ::QNdefRecord *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QNdefRecord::TypeNameFormat cppArg1{QNdefRecord::Empty};
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QNdefRecord(QNdefRecord,QNdefRecord::TypeNameFormat)
                cptr = new ::QNdefRecord(*cppArg0, cppArg1);
            }
            break;
        }
        case 4: // QNdefRecord(const QNdefRecord &other, QNdefRecord::TypeNameFormat typeNameFormat, const QByteArray &type)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QNdefRecord cppArg0_local;
            ::QNdefRecord *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QNdefRecord::TypeNameFormat cppArg1{QNdefRecord::Empty};
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return -1;
            ::QByteArray cppArg2_local;
            ::QByteArray *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QNdefRecord(QNdefRecord,QNdefRecord::TypeNameFormat,QByteArray)
                cptr = new ::QNdefRecord(*cppArg0, cppArg1, *cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QNdefRecord >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QNdefRecordFunc_clear(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefRecord *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clear()
        cppSelf->clear();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNdefRecordFunc_id(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefRecord *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // id()const
        QByteArray cppResult = const_cast<const ::QNdefRecord *>(cppSelf)->id();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNdefRecordFunc_isEmpty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefRecord *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isEmpty()const
        bool cppResult = const_cast<const ::QNdefRecord *>(cppSelf)->isEmpty();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNdefRecordFunc_payload(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefRecord *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // payload()const
        QByteArray cppResult = const_cast<const ::QNdefRecord *>(cppSelf)->payload();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNdefRecordFunc_setId(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefRecord *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNdefRecord::setId(QByteArray)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // setId(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setId", errInfo, SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setId(QByteArray)
            cppSelf->setId(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNdefRecordFunc_setPayload(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefRecord *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNdefRecord::setPayload(QByteArray)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // setPayload(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPayload", errInfo, SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setPayload(QByteArray)
            cppSelf->setPayload(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNdefRecordFunc_setType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefRecord *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNdefRecord::setType(QByteArray)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // setType(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setType", errInfo, SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setType(QByteArray)
            cppSelf->setType(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNdefRecordFunc_setTypeNameFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefRecord *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNdefRecord::setTypeNameFormat(QNdefRecord::TypeNameFormat)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_TypeNameFormat_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setTypeNameFormat(QNdefRecord::TypeNameFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTypeNameFormat", errInfo, SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]);

    // Call function/method
    {
        ::QNdefRecord::TypeNameFormat cppArg0{QNdefRecord::Empty};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTypeNameFormat(QNdefRecord::TypeNameFormat)
            cppSelf->setTypeNameFormat(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNdefRecordFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefRecord *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        QByteArray cppResult = const_cast<const ::QNdefRecord *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNdefRecordFunc_typeNameFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefRecord *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // typeNameFormat()const
        QNdefRecord::TypeNameFormat cppResult = const_cast<const ::QNdefRecord *>(cppSelf)->typeNameFormat();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_TypeNameFormat_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNdefRecord__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QNdefRecord *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QNdefRecord_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QNdefRecord_EnumFlagInfo[] = {
    "TypeNameFormat:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QNdefRecord_methods[] = {
    {"clear", reinterpret_cast<PyCFunction>(Sbk_QNdefRecordFunc_clear), METH_NOARGS, nullptr},
    {"id", reinterpret_cast<PyCFunction>(Sbk_QNdefRecordFunc_id), METH_NOARGS, nullptr},
    {"isEmpty", reinterpret_cast<PyCFunction>(Sbk_QNdefRecordFunc_isEmpty), METH_NOARGS, nullptr},
    {"payload", reinterpret_cast<PyCFunction>(Sbk_QNdefRecordFunc_payload), METH_NOARGS, nullptr},
    {"setId", reinterpret_cast<PyCFunction>(Sbk_QNdefRecordFunc_setId), METH_O, nullptr},
    {"setPayload", reinterpret_cast<PyCFunction>(Sbk_QNdefRecordFunc_setPayload), METH_O, nullptr},
    {"setType", reinterpret_cast<PyCFunction>(Sbk_QNdefRecordFunc_setType), METH_O, nullptr},
    {"setTypeNameFormat", reinterpret_cast<PyCFunction>(Sbk_QNdefRecordFunc_setTypeNameFormat), METH_O, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QNdefRecordFunc_type), METH_NOARGS, nullptr},
    {"typeNameFormat", reinterpret_cast<PyCFunction>(Sbk_QNdefRecordFunc_typeNameFormat), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QNdefRecord__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QNdefRecord_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QNdefRecord *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]), (pyArg)))) {
                // operator!=(const QNdefRecord &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QNdefRecord cppArg0_local;
                ::QNdefRecord *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]), (pyArg)))) {
                // operator==(const QNdefRecord &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QNdefRecord cppArg0_local;
                ::QNdefRecord *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static Py_hash_t Sbk_QNdefRecord_HashFunc(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefRecord *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return Py_hash_t(qHash(*cppSelf));
}

static int Sbk_QNdefRecord_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QNdefRecord_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QNdefRecord_Type = nullptr;
static PyTypeObject *Sbk_QNdefRecord_TypeF(void)
{
    return _Sbk_QNdefRecord_Type;
}

static PyType_Slot Sbk_QNdefRecord_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_hash,        reinterpret_cast<void *>(&Sbk_QNdefRecord_HashFunc)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QNdefRecord_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QNdefRecord_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QNdefRecord_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QNdefRecord_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QNdefRecord_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QNdefRecord_spec = {
    "2:PySide6.QtNfc.QNdefRecord",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QNdefRecord_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QNdefRecord_TypeNameFormat(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QNdefRecord::TypeNameFormat>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QNdefRecord::TypeNameFormat *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QNdefRecord_TypeNameFormat_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_TypeNameFormat_IDX])))
        return Enum_PythonToCpp_QNdefRecord_TypeNameFormat;
    return {};
}

static PyObject *QNdefRecord_TypeNameFormat_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QNdefRecord::TypeNameFormat>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QNdefRecord::TypeNameFormat *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_TypeNameFormat_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QNdefRecord_PythonToCpp_QNdefRecord_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QNdefRecord_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QNdefRecord_PythonToCpp_QNdefRecord_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QNdefRecord_TypeF()))
        return QNdefRecord_PythonToCpp_QNdefRecord_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QNdefRecord_PTR_CppToPython_QNdefRecord(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QNdefRecord_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QNdefRecord_COPY_CppToPython_QNdefRecord(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QNdefRecord *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QNdefRecord_TypeF(), new ::QNdefRecord(*source), true, true);
}

// Python to C++ copy conversion.
static void QNdefRecord_PythonToCpp_QNdefRecord_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QNdefRecord *>(cppOut) = *reinterpret_cast< ::QNdefRecord *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QNdefRecord_PythonToCpp_QNdefRecord_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QNdefRecord_TypeF()))
        return QNdefRecord_PythonToCpp_QNdefRecord_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QNdefRecord_SignatureStrings[] = {
    "4:PySide6.QtNfc.QNdefRecord(self)",
    "3:PySide6.QtNfc.QNdefRecord(self,typeNameFormat:PySide6.QtNfc.QNdefRecord.TypeNameFormat,type:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "2:PySide6.QtNfc.QNdefRecord(self,other:PySide6.QtNfc.QNdefRecord)",
    "1:PySide6.QtNfc.QNdefRecord(self,other:PySide6.QtNfc.QNdefRecord,typeNameFormat:PySide6.QtNfc.QNdefRecord.TypeNameFormat)",
    "0:PySide6.QtNfc.QNdefRecord(self,other:PySide6.QtNfc.QNdefRecord,typeNameFormat:PySide6.QtNfc.QNdefRecord.TypeNameFormat,type:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "PySide6.QtNfc.QNdefRecord.clear(self)",
    "PySide6.QtNfc.QNdefRecord.id(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtNfc.QNdefRecord.isEmpty(self)->bool",
    "PySide6.QtNfc.QNdefRecord.payload(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtNfc.QNdefRecord.setId(self,id:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "PySide6.QtNfc.QNdefRecord.setPayload(self,payload:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "PySide6.QtNfc.QNdefRecord.setType(self,type:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "PySide6.QtNfc.QNdefRecord.setTypeNameFormat(self,typeNameFormat:PySide6.QtNfc.QNdefRecord.TypeNameFormat)",
    "PySide6.QtNfc.QNdefRecord.type(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtNfc.QNdefRecord.typeNameFormat(self)->PySide6.QtNfc.QNdefRecord.TypeNameFormat",
    "PySide6.QtNfc.QNdefRecord.__copy__(self)->typing.Self",
    "PySide6.QtNfc.QNdefRecord.__ne__(self,other:PySide6.QtNfc.QNdefRecord)->bool",
    "PySide6.QtNfc.QNdefRecord.__eq__(self,other:PySide6.QtNfc.QNdefRecord)->bool",
    "PySide6.QtNfc.QNdefRecord.__hash__(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t QNdefRecord_SignatureByteSize = 267;
static constexpr uint8_t QNdefRecord_SignatureBytes[267] = {
    0x78, 0xda, 0xc5, 0x54, 0x4b, 0x4b, 0xc4, 0x30, 0x10, 0xbe, 0xe7, 0x57, 0x78, 0xb4, 0x52, 0x83,
    0x2f, 0x3c, 0xec, 0x61, 0x41, 0x45, 0xc1, 0x4b, 0xd9, 0xba, 0x7a, 0x12, 0x09, 0x31, 0x9d, 0xda,
    0x40, 0x9b, 0xa9, 0xe9, 0x5c, 0xf2, 0xef, 0xad, 0x92, 0x52, 0x17, 0x49, 0x0a, 0x6d, 0xc1, 0x4b,
    0x20, 0xf0, 0xbd, 0xe6, 0x91, 0x5c, 0x6d, 0x76, 0x6e, 0xaf, 0x0b, 0xb8, 0xe6, 0x39, 0x65, 0xa5,
    0xe2, 0x79, 0x56, 0x40, 0xf9, 0x04, 0x0a, 0x6d, 0x71, 0xdc, 0x41, 0x5d, 0x26, 0xec, 0x72, 0x02,
    0x91, 0x92, 0x6b, 0x21, 0x93, 0x0d, 0x3c, 0xa0, 0x6d, 0x24, 0x85, 0xd1, 0xfc, 0xf9, 0x00, 0xf8,
    0xc3, 0xdb, 0xf4, 0x87, 0x36, 0x1f, 0xfc, 0xc5, 0x68, 0x34, 0xaf, 0x23, 0xf5, 0x0e, 0x2d, 0xf0,
    0xfc, 0xd6, 0x11, 0xdc, 0x58, 0x2b, 0x5d, 0x7a, 0xa4, 0x2a, 0x69, 0x4f, 0xde, 0x12, 0x76, 0x31,
    0x95, 0x06, 0xa9, 0x02, 0x1b, 0x06, 0x25, 0xec, 0x7c, 0xa1, 0xc2, 0xdc, 0x7a, 0x13, 0x76, 0xf6,
    0x4f, 0xce, 0xf3, 0x3a, 0x1d, 0x56, 0x57, 0x35, 0x48, 0xeb, 0xb7, 0x23, 0x8c, 0xd2, 0x7e, 0x81,
    0x4e, 0xb7, 0x41, 0xb3, 0x18, 0xbb, 0xbb, 0x6f, 0x5a, 0x72, 0x83, 0xc4, 0x3b, 0x62, 0x1d, 0x41,
    0xb7, 0xd2, 0xd5, 0x28, 0x17, 0x19, 0x76, 0x40, 0x8f, 0x7e, 0x0c, 0xba, 0x58, 0xb1, 0x59, 0xbd,
    0xee, 0xee, 0x57, 0xba, 0xd4, 0x47, 0x5d, 0xd7, 0xe1, 0x7b, 0xde, 0xe3, 0x63, 0x5c, 0x5f, 0x7b,
    0xdc, 0xa5, 0x45, 0x4f, 0x3e, 0xe6, 0x44, 0x43, 0x09, 0x33, 0xe7, 0x47, 0x7f, 0x63, 0x1e, 0x28,
    0xc5, 0x93, 0x45, 0x84, 0x85, 0x50, 0xd8, 0x3a, 0x21, 0x06, 0x49, 0xdf, 0xdc, 0x7d, 0x7f, 0x8b,
    0xb2, 0x0c, 0x78, 0xce, 0xe4, 0x97, 0x34, 0xb9, 0xde, 0x42, 0xc0, 0xe7, 0x8a, 0x62, 0x95, 0xec,
    0xaa, 0xb1, 0x1e, 0x6d, 0x88, 0x7d, 0x01, 0xd9, 0x2f, 0x21, 0xff
};
#endif

PyTypeObject *init_QNdefRecord(PyObject *module)
{
    if (SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX].type != nullptr)
        return SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX].type;

    Shiboken::AutoDecRef Sbk_QNdefRecord_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QNdefRecord_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QNdefRecord",
        "QNdefRecord",
        &Sbk_QNdefRecord_spec,
        &Shiboken::callCppDestructor< ::QNdefRecord >,
        Sbk_QNdefRecord_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QNdefRecord_TypeF(); // references _Sbk_QNdefRecord_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QNdefRecord_SignatureStrings);
#else
    InitSignatureBytes(pyType, QNdefRecord_SignatureBytes, QNdefRecord_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QNdefRecord_PropertyStrings);
    SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QNdefRecord_PythonToCpp_QNdefRecord_PTR,
        is_QNdefRecord_PythonToCpp_QNdefRecord_PTR_Convertible,
        QNdefRecord_PTR_CppToPython_QNdefRecord,
        QNdefRecord_COPY_CppToPython_QNdefRecord);

    Shiboken::Conversions::registerConverterName(converter, "QNdefRecord");
    Shiboken::Conversions::registerConverterName(converter, "QNdefRecord*");
    Shiboken::Conversions::registerConverterName(converter, "QNdefRecord&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QNdefRecord).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QNdefRecord_PythonToCpp_QNdefRecord_COPY,
        is_QNdefRecord_PythonToCpp_QNdefRecord_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QNdefRecord_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'TypeNameFormat'.
    const char *TypeNameFormat_Initializer[] = {
        "Empty",
        "NfcRtd",
        "Mime",
        "Uri",
        "ExternalRtd",
        "Unknown",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t TypeNameFormat_InitializerValues[] = {
        uint8_t(QNdefRecord::TypeNameFormat::Empty),       //  0x00  0
        uint8_t(QNdefRecord::TypeNameFormat::NfcRtd),      //  0x01  1
        uint8_t(QNdefRecord::TypeNameFormat::Mime),        //  0x02  2
        uint8_t(QNdefRecord::TypeNameFormat::Uri),         //  0x03  3
        uint8_t(QNdefRecord::TypeNameFormat::ExternalRtd), //  0x04  4
        uint8_t(QNdefRecord::TypeNameFormat::Unknown)      //  0x05  5
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QNdefRecord_TypeF(),
        "2:PySide6.QtNfc.QNdefRecord.TypeNameFormat",
        TypeNameFormat_Initializer, TypeNameFormat_InitializerValues);
    SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_TypeNameFormat_IDX].type = EType;
    // Register converter for enum 'QNdefRecord::TypeNameFormat'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QNdefRecord_TypeNameFormat_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QNdefRecord_TypeNameFormat,
            is_Enum_PythonToCpp_QNdefRecord_TypeNameFormat_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QNdefRecord::TypeNameFormat");
        Shiboken::Conversions::registerConverterAlias(converter, "TypeNameFormat");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'TypeNameFormat' enum.

    qRegisterMetaType< ::QNdefRecord >("QNdefRecord");
    qRegisterMetaType< ::QNdefRecord::TypeNameFormat >("QNdefRecord::TypeNameFormat");

    return pyType;
}
