// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnfc_python.h"

// main header
#include "qnearfieldmanager_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QtNfc/qnearfieldmanager.h>
#include <QtNfc/qnearfieldtarget.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QNearFieldManagerWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QNearFieldManagerWrapper::QNearFieldManagerWrapper(::QObject * parent) : QNearFieldManager(parent)
{
}

void QNearFieldManagerWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QNearFieldManager", funcName);
        return;
    }
}

void QNearFieldManagerWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QNearFieldManager", funcName);
        return;
    }
}

void QNearFieldManagerWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QNearFieldManager", funcName);
        return;
    }
}

void QNearFieldManagerWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QNearFieldManager", funcName);
        return;
    }
}

bool QNearFieldManagerWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QNearFieldManager", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QNearFieldManager", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QNearFieldManagerWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QNearFieldManager", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QNearFieldManager", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QNearFieldManagerWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QNearFieldManager", funcName);
        return;
    }
}

const QMetaObject *QNearFieldManagerWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QNearFieldManager::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QNearFieldManagerWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QNearFieldManager::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QNearFieldManagerWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QNearFieldManagerWrapper *>(this));
    return QNearFieldManager::qt_metacast(_clname);
}

QNearFieldManagerWrapper::~QNearFieldManagerWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QNearFieldManager_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QNearFieldManager >()))
        return -1;

    QNearFieldManagerWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QNearFieldManager", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QNearFieldManager::QNearFieldManager(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QNearFieldManager(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QNearFieldManager(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldManager_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldManager_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldManager_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldManager_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                // fall through to handle extra keyword signals and properties
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QNearFieldManager(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QNearFieldManagerWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QNearFieldManagerWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QNearFieldManager >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldManager_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldManager_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QNearFieldManagerFunc_isEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNearFieldManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldManager_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isEnabled()const
        bool cppResult = const_cast<const ::QNearFieldManager *>(cppSelf)->isEnabled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNearFieldManagerFunc_isSupported(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNearFieldManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldManager_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "isSupported", errInfo, SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldManager_IDX]);

    if (PyArg_ParseTuple(args, "|O:isSupported", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QNearFieldManager::isSupported(QNearFieldTarget::AccessMethod=)const->bool
    if (numArgs == 0) {
        overloadId = 0; // isSupported(QNearFieldTarget::AccessMethod)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldTarget_AccessMethod_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // isSupported(QNearFieldTarget::AccessMethod)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "isSupported", errInfo, SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldManager_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_accessMethod = Shiboken::String::createStaticString("accessMethod");
            if (PyDict_Contains(kwds, key_accessMethod) != 0) {
                value = PyDict_GetItem(kwds, key_accessMethod);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_accessMethod);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "isSupported", errInfo, SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldManager_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldTarget_AccessMethod_IDX])))->converter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "isSupported", errInfo, SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldManager_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_accessMethod);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "isSupported", errInfo, SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldManager_IDX]);
            }
        }
        ::QNearFieldTarget::AccessMethod cppArg0(QNearFieldTarget::AnyAccess);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isSupported(QNearFieldTarget::AccessMethod)const
            bool cppResult = const_cast<const ::QNearFieldManager *>(cppSelf)->isSupported(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNearFieldManagerFunc_setUserInformation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNearFieldManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldManager_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNearFieldManager::setUserInformation(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setUserInformation(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUserInformation", errInfo, SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldManager_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setUserInformation(QString)
            cppSelf->setUserInformation(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNearFieldManagerFunc_startTargetDetection(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNearFieldManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldManager_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNearFieldManager::startTargetDetection(QNearFieldTarget::AccessMethod)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldTarget_AccessMethod_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // startTargetDetection(QNearFieldTarget::AccessMethod)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "startTargetDetection", errInfo, SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldManager_IDX]);

    // Call function/method
    {
        ::QNearFieldTarget::AccessMethod cppArg0{QNearFieldTarget::UnknownAccess};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // startTargetDetection(QNearFieldTarget::AccessMethod)
            bool cppResult = cppSelf->startTargetDetection(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNearFieldManagerFunc_stopTargetDetection(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNearFieldManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldManager_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "stopTargetDetection", errInfo, SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldManager_IDX]);

    if (PyArg_ParseTuple(args, "|O:stopTargetDetection", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QNearFieldManager::stopTargetDetection(const QString&=)
    if (numArgs == 0) {
        overloadId = 0; // stopTargetDetection(QString)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 0; // stopTargetDetection(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "stopTargetDetection", errInfo, SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldManager_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_errorMessage = Shiboken::String::createStaticString("errorMessage");
            if (PyDict_Contains(kwds, key_errorMessage) != 0) {
                value = PyDict_GetItem(kwds, key_errorMessage);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_errorMessage);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "stopTargetDetection", errInfo, SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldManager_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "stopTargetDetection", errInfo, SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldManager_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_errorMessage);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "stopTargetDetection", errInfo, SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldManager_IDX]);
            }
        }
        ::QString cppArg0 = QString();
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // stopTargetDetection(QString)
            cppSelf->stopTargetDetection(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QNearFieldManager_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QNearFieldManager_EnumFlagInfo[] = {
    "AdapterState:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QNearFieldManager_methods[] = {
    {"isEnabled", reinterpret_cast<PyCFunction>(Sbk_QNearFieldManagerFunc_isEnabled), METH_NOARGS, nullptr},
    {"isSupported", reinterpret_cast<PyCFunction>(Sbk_QNearFieldManagerFunc_isSupported), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setUserInformation", reinterpret_cast<PyCFunction>(Sbk_QNearFieldManagerFunc_setUserInformation), METH_O, nullptr},
    {"startTargetDetection", reinterpret_cast<PyCFunction>(Sbk_QNearFieldManagerFunc_startTargetDetection), METH_O, nullptr},
    {"stopTargetDetection", reinterpret_cast<PyCFunction>(Sbk_QNearFieldManagerFunc_stopTargetDetection), METH_VARARGS|METH_KEYWORDS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QNearFieldManager_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QNearFieldManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldManager_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QNearFieldManagerWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QNearFieldManager_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QNearFieldManager_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QNearFieldManager_Type = nullptr;
static PyTypeObject *Sbk_QNearFieldManager_TypeF(void)
{
    return _Sbk_QNearFieldManager_Type;
}

static PyType_Slot Sbk_QNearFieldManager_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QNearFieldManager_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QNearFieldManager_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QNearFieldManager_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QNearFieldManager_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QNearFieldManager_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QNearFieldManager_spec = {
    "2:PySide6.QtNfc.QNearFieldManager",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QNearFieldManager_slots
};

} //extern "C"

static void *Sbk_QNearFieldManager_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QNearFieldManager *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QNearFieldManager_AdapterState(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QNearFieldManager::AdapterState>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QNearFieldManager::AdapterState *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QNearFieldManager_AdapterState_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldManager_AdapterState_IDX])))
        return Enum_PythonToCpp_QNearFieldManager_AdapterState;
    return {};
}

static PyObject *QNearFieldManager_AdapterState_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QNearFieldManager::AdapterState>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QNearFieldManager::AdapterState *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldManager_AdapterState_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QNearFieldManager_PythonToCpp_QNearFieldManager_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QNearFieldManager_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QNearFieldManager_PythonToCpp_QNearFieldManager_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QNearFieldManager_TypeF()))
        return QNearFieldManager_PythonToCpp_QNearFieldManager_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QNearFieldManager_PTR_CppToPython_QNearFieldManager(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QNearFieldManager *>(const_cast<void *>(cppIn)), Sbk_QNearFieldManager_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QNearFieldManager_SignatureStrings[] = {
    "PySide6.QtNfc.QNearFieldManager(self,parent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtNfc.QNearFieldManager.isEnabled(self)->bool",
    "PySide6.QtNfc.QNearFieldManager.isSupported(self,accessMethod:PySide6.QtNfc.QNearFieldTarget.AccessMethod=QNearFieldTarget.AnyAccess)->bool",
    "PySide6.QtNfc.QNearFieldManager.setUserInformation(self,message:QString)",
    "PySide6.QtNfc.QNearFieldManager.startTargetDetection(self,accessMethod:PySide6.QtNfc.QNearFieldTarget.AccessMethod)->bool",
    "PySide6.QtNfc.QNearFieldManager.stopTargetDetection(self,errorMessage:QString=QString())",
    nullptr}; // Sentinel
#else
static constexpr size_t QNearFieldManager_SignatureByteSize = 204;
static constexpr uint8_t QNearFieldManager_SignatureBytes[204] = {
    0x78, 0xda, 0x9d, 0x90, 0xcd, 0x0a, 0xc2, 0x40, 0x0c, 0x84, 0xef, 0x3e, 0x89, 0x05, 0xdd, 0xa3,
    0x87, 0x42, 0x05, 0xf1, 0x07, 0x3c, 0x54, 0x5b, 0xaa, 0x0f, 0x90, 0xb6, 0x69, 0x5d, 0xd9, 0x6e,
    0x96, 0x6c, 0x3c, 0xf8, 0xf6, 0x16, 0x2b, 0xa2, 0xf8, 0x57, 0x3c, 0xe5, 0x90, 0x99, 0x2f, 0x33,
    0x49, 0xce, 0x99, 0x2e, 0x71, 0xa2, 0x52, 0xd9, 0x54, 0x85, 0x4a, 0x37, 0x08, 0xbc, 0xd2, 0x68,
    0xca, 0x18, 0x2c, 0xd4, 0xc8, 0x43, 0x8f, 0xa6, 0x1a, 0x39, 0x60, 0xb4, 0x12, 0x26, 0x77, 0xed,
    0x9c, 0x18, 0x55, 0xba, 0xcd, 0x8f, 0x58, 0x48, 0x64, 0x4f, 0xc6, 0x38, 0xe1, 0x60, 0x90, 0x7c,
    0x67, 0x29, 0xed, 0x97, 0x16, 0x72, 0x83, 0xe5, 0x95, 0x1a, 0x8c, 0xa7, 0x39, 0x91, 0xe9, 0xe1,
    0xca, 0x4e, 0xce, 0x11, 0xcb, 0xcd, 0x37, 0x82, 0xa2, 0x40, 0xef, 0x63, 0x94, 0x03, 0x95, 0xe1,
    0x27, 0xf7, 0x0e, 0xb8, 0x46, 0x51, 0xb3, 0x07, 0x6d, 0xf4, 0xba, 0xb5, 0xe7, 0x4e, 0xd0, 0x37,
    0x8b, 0x47, 0xd9, 0x7b, 0xe4, 0xb5, 0xad, 0x88, 0x1b, 0x10, 0x4d, 0xb6, 0x8b, 0xd4, 0xb4, 0x8c,
    0x56, 0x10, 0xa6, 0x99, 0xb0, 0xb6, 0xf5, 0xef, 0x57, 0x78, 0x01, 0x96, 0x2e, 0xc5, 0x02, 0xa5,
    0xfd, 0xe2, 0x1d, 0xf5, 0x6f, 0xbb, 0xde, 0x15, 0x84, 0xdc, 0xdb, 0xc3, 0xc8, 0x4c, 0x1c, 0x3f,
    0x17, 0x89, 0x6e, 0x73, 0x18, 0x04, 0x83, 0x0b, 0xba, 0xd2, 0xc9, 0xa1
};
#endif

PyTypeObject *init_QNearFieldManager(PyObject *module)
{
    if (SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldManager_IDX].type != nullptr)
        return SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldManager_IDX].type;

    Shiboken::AutoDecRef Sbk_QNearFieldManager_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QNearFieldManager_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QNearFieldManager",
        "QNearFieldManager*",
        &Sbk_QNearFieldManager_spec,
        &Shiboken::callCppDestructor< QNearFieldManager >,
        Sbk_QNearFieldManager_Type_bases.object(),
        0);
    auto *pyType = Sbk_QNearFieldManager_TypeF(); // references _Sbk_QNearFieldManager_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QNearFieldManager_SignatureStrings);
#else
    InitSignatureBytes(pyType, QNearFieldManager_SignatureBytes, QNearFieldManager_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QNearFieldManager_PropertyStrings);
    SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldManager_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QNearFieldManager_PythonToCpp_QNearFieldManager_PTR,
        is_QNearFieldManager_PythonToCpp_QNearFieldManager_PTR_Convertible,
        QNearFieldManager_PTR_CppToPython_QNearFieldManager);

    Shiboken::Conversions::registerConverterName(converter, "QNearFieldManager");
    Shiboken::Conversions::registerConverterName(converter, "QNearFieldManager*");
    Shiboken::Conversions::registerConverterName(converter, "QNearFieldManager&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QNearFieldManager).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QNearFieldManagerWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QNearFieldManager_TypeF(), &Sbk_QNearFieldManager_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QNearFieldManager_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'AdapterState'.
    const char *AdapterState_Initializer[] = {
        "Offline",
        "TurningOn",
        "Online",
        "TurningOff",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t AdapterState_InitializerValues[] = {
        int8_t(QNearFieldManager::AdapterState::Offline),   //  0x01  1
        int8_t(QNearFieldManager::AdapterState::TurningOn), //  0x02  2
        int8_t(QNearFieldManager::AdapterState::Online),    //  0x03  3
        int8_t(QNearFieldManager::AdapterState::TurningOff) //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QNearFieldManager_TypeF(),
        "2:PySide6.QtNfc.QNearFieldManager.AdapterState",
        AdapterState_Initializer, AdapterState_InitializerValues);
    SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldManager_AdapterState_IDX].type = EType;
    // Register converter for enum 'QNearFieldManager::AdapterState'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QNearFieldManager_AdapterState_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QNearFieldManager_AdapterState,
            is_Enum_PythonToCpp_QNearFieldManager_AdapterState_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QNearFieldManager::AdapterState");
        Shiboken::Conversions::registerConverterAlias(converter, "AdapterState");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'AdapterState' enum.

    PySide::Signal::registerSignals(pyType, &::QNearFieldManager::staticMetaObject);
    qRegisterMetaType< ::QNearFieldManager::AdapterState >("QNearFieldManager::AdapterState");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QNearFieldManager::staticMetaObject, sizeof(QNearFieldManagerWrapper));

    return pyType;
}
