// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtopengl_python.h"

// main header
#include "qabstractopenglfunctions_wrapper.h"

// Argument includes
#include <QtGui/qopenglcontext.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QAbstractOpenGLFunctionsWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QAbstractOpenGLFunctionsWrapper::QAbstractOpenGLFunctionsWrapper()
{
}

bool QAbstractOpenGLFunctionsWrapper::initializeOpenGLFunctions()
{
    if (m_PyMethodCache[0])
        return this->::QAbstractOpenGLFunctions::initializeOpenGLFunctions();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "initializeOpenGLFunctions";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QAbstractOpenGLFunctions::initializeOpenGLFunctions();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractOpenGLFunctions", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstractOpenGLFunctions", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QAbstractOpenGLFunctionsWrapper::~QAbstractOpenGLFunctionsWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QAbstractOpenGLFunctions_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QAbstractOpenGLFunctions >()))
        return -1;

    QAbstractOpenGLFunctionsWrapper *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtOpenGLTypeStructs[SBK_QAbstractOpenGLFunctions_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QAbstractOpenGLFunctions()
        cptr = new QAbstractOpenGLFunctionsWrapper();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QAbstractOpenGLFunctions >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QAbstractOpenGLFunctionsFunc_initializeOpenGLFunctions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOpenGLFunctions *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QAbstractOpenGLFunctions_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // initializeOpenGLFunctions()
        bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QAbstractOpenGLFunctions::initializeOpenGLFunctions()
            : cppSelf->initializeOpenGLFunctions();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractOpenGLFunctionsFunc_isInitialized(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOpenGLFunctions *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QAbstractOpenGLFunctions_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isInitialized()const
        bool cppResult = const_cast<const ::QAbstractOpenGLFunctions *>(cppSelf)->isInitialized();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractOpenGLFunctionsFunc_owningContext(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOpenGLFunctions *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QAbstractOpenGLFunctions_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // owningContext()const
        QOpenGLContext * cppResult = const_cast<const ::QAbstractOpenGLFunctions *>(cppSelf)->owningContext();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QOpenGLContext_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractOpenGLFunctionsFunc_setOwningContext(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOpenGLFunctions *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QAbstractOpenGLFunctions_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractOpenGLFunctions::setOwningContext(const QOpenGLContext*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QOpenGLContext_IDX]), (pyArg)))) {
        overloadId = 0; // setOwningContext(const QOpenGLContext*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOwningContext", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QAbstractOpenGLFunctions_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QOpenGLContext *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOwningContext(const QOpenGLContext*)
            cppSelf->setOwningContext(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QAbstractOpenGLFunctions_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QAbstractOpenGLFunctions_methods[] = {
    {"initializeOpenGLFunctions", reinterpret_cast<PyCFunction>(Sbk_QAbstractOpenGLFunctionsFunc_initializeOpenGLFunctions), METH_NOARGS, nullptr},
    {"isInitialized", reinterpret_cast<PyCFunction>(Sbk_QAbstractOpenGLFunctionsFunc_isInitialized), METH_NOARGS, nullptr},
    {"owningContext", reinterpret_cast<PyCFunction>(Sbk_QAbstractOpenGLFunctionsFunc_owningContext), METH_NOARGS, nullptr},
    {"setOwningContext", reinterpret_cast<PyCFunction>(Sbk_QAbstractOpenGLFunctionsFunc_setOwningContext), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QAbstractOpenGLFunctions_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QAbstractOpenGLFunctions *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QAbstractOpenGLFunctions_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QAbstractOpenGLFunctionsWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QAbstractOpenGLFunctions_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QAbstractOpenGLFunctions_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QAbstractOpenGLFunctions_Type = nullptr;
static PyTypeObject *Sbk_QAbstractOpenGLFunctions_TypeF(void)
{
    return _Sbk_QAbstractOpenGLFunctions_Type;
}

static PyType_Slot Sbk_QAbstractOpenGLFunctions_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QAbstractOpenGLFunctions_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QAbstractOpenGLFunctions_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QAbstractOpenGLFunctions_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QAbstractOpenGLFunctions_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QAbstractOpenGLFunctions_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QAbstractOpenGLFunctions_spec = {
    "2:PySide6.QtOpenGL.QAbstractOpenGLFunctions",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QAbstractOpenGLFunctions_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAbstractOpenGLFunctions_PythonToCpp_QAbstractOpenGLFunctions_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QAbstractOpenGLFunctions_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAbstractOpenGLFunctions_PythonToCpp_QAbstractOpenGLFunctions_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QAbstractOpenGLFunctions_TypeF()))
        return QAbstractOpenGLFunctions_PythonToCpp_QAbstractOpenGLFunctions_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAbstractOpenGLFunctions_PTR_CppToPython_QAbstractOpenGLFunctions(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QAbstractOpenGLFunctions *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QAbstractOpenGLFunctions_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QAbstractOpenGLFunctions_SignatureStrings[] = {
    "PySide6.QtOpenGL.QAbstractOpenGLFunctions(self)",
    "PySide6.QtOpenGL.QAbstractOpenGLFunctions.initializeOpenGLFunctions(self)->bool",
    "PySide6.QtOpenGL.QAbstractOpenGLFunctions.isInitialized(self)->bool",
    "PySide6.QtOpenGL.QAbstractOpenGLFunctions.owningContext(self)->PySide6.QtGui.QOpenGLContext",
    "PySide6.QtOpenGL.QAbstractOpenGLFunctions.setOwningContext(self,context:PySide6.QtGui.QOpenGLContext)",
    nullptr}; // Sentinel
#else
static constexpr size_t QAbstractOpenGLFunctions_SignatureByteSize = 127;
static constexpr uint8_t QAbstractOpenGLFunctions_SignatureBytes[127] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0xf1, 0x2f, 0x48, 0xcd,
    0x73, 0xf7, 0xd1, 0x0b, 0x74, 0x4c, 0x2a, 0x2e, 0x29, 0x4a, 0x4c, 0x86, 0xf2, 0xdd, 0x4a, 0xf3,
    0x92, 0x4b, 0x32, 0xf3, 0xf3, 0x8a, 0x35, 0x8a, 0x53, 0x73, 0xd2, 0x34, 0xb9, 0x02, 0x88, 0x55,
    0xaf, 0x97, 0x99, 0x97, 0x59, 0x92, 0x99, 0x98, 0x93, 0x59, 0x95, 0x8a, 0xd5, 0x24, 0x5d, 0xbb,
    0xa4, 0xfc, 0xfc, 0x1c, 0x52, 0xcc, 0x2b, 0xf6, 0x84, 0x9b, 0x98, 0x42, 0xa6, 0x19, 0xf9, 0xe5,
    0x79, 0x99, 0x79, 0xe9, 0xce, 0xf9, 0x79, 0x25, 0xa9, 0x15, 0x25, 0x30, 0x33, 0x10, 0xda, 0xdd,
    0x4b, 0x33, 0xf5, 0x02, 0x21, 0x7a, 0xa0, 0x6a, 0x48, 0x30, 0xbb, 0x38, 0xb5, 0xc4, 0x1f, 0xc3,
    0x78, 0x9d, 0x64, 0x08, 0xc7, 0x0a, 0x9f, 0x25, 0x9a, 0x5c, 0x00, 0xb7, 0xf2, 0x8e, 0x7d
};
#endif

PyTypeObject *init_QAbstractOpenGLFunctions(PyObject *module)
{
    if (SbkPySide6_QtOpenGLTypeStructs[SBK_QAbstractOpenGLFunctions_IDX].type != nullptr)
        return SbkPySide6_QtOpenGLTypeStructs[SBK_QAbstractOpenGLFunctions_IDX].type;

    Shiboken::AutoDecRef Sbk_QAbstractOpenGLFunctions_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QAbstractOpenGLFunctions_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QAbstractOpenGLFunctions",
        "QAbstractOpenGLFunctions*",
        &Sbk_QAbstractOpenGLFunctions_spec,
        &Shiboken::callCppDestructor< QAbstractOpenGLFunctions >,
        Sbk_QAbstractOpenGLFunctions_Type_bases.object(),
        0);
    auto *pyType = Sbk_QAbstractOpenGLFunctions_TypeF(); // references _Sbk_QAbstractOpenGLFunctions_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QAbstractOpenGLFunctions_SignatureStrings);
#else
    InitSignatureBytes(pyType, QAbstractOpenGLFunctions_SignatureBytes, QAbstractOpenGLFunctions_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QAbstractOpenGLFunctions_PropertyStrings);
    SbkPySide6_QtOpenGLTypeStructs[SBK_QAbstractOpenGLFunctions_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAbstractOpenGLFunctions_PythonToCpp_QAbstractOpenGLFunctions_PTR,
        is_QAbstractOpenGLFunctions_PythonToCpp_QAbstractOpenGLFunctions_PTR_Convertible,
        QAbstractOpenGLFunctions_PTR_CppToPython_QAbstractOpenGLFunctions);

    Shiboken::Conversions::registerConverterName(converter, "QAbstractOpenGLFunctions");
    Shiboken::Conversions::registerConverterName(converter, "QAbstractOpenGLFunctions*");
    Shiboken::Conversions::registerConverterName(converter, "QAbstractOpenGLFunctions&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QAbstractOpenGLFunctions).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QAbstractOpenGLFunctionsWrapper).name());

    qRegisterMetaType< ::QAbstractOpenGLFunctions *>();

    return pyType;
}
