// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtopengl_python.h"

// main header
#include "qopenglbuffer_wrapper.h"

// Argument includes
#include <QtOpenGL/qopenglbuffer.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QOpenGLBuffer_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QOpenGLBuffer >()))
        return -1;

    ::QOpenGLBuffer *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QOpenGLBuffer", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QOpenGLBuffer::QOpenGLBuffer()
    // 1: QOpenGLBuffer::QOpenGLBuffer(QOpenGLBuffer::Type)
    // 2: QOpenGLBuffer::QOpenGLBuffer(QOpenGLBuffer)
    if (numArgs == 0) {
        overloadId = 0; // QOpenGLBuffer()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QOpenGLBuffer(QOpenGLBuffer)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_Type_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 1; // QOpenGLBuffer(QOpenGLBuffer::Type)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QOpenGLBuffer()
        {

            // QOpenGLBuffer()
            cptr = new ::QOpenGLBuffer();
            break;
        }
        case 1: // QOpenGLBuffer(QOpenGLBuffer::Type type)
        {
            ::QOpenGLBuffer::Type cppArg0 = static_cast< ::QOpenGLBuffer::Type>(0);
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QOpenGLBuffer(QOpenGLBuffer::Type)
                cptr = new ::QOpenGLBuffer(cppArg0);
            }
            break;
        }
        case 2: // QOpenGLBuffer(const QOpenGLBuffer &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QOpenGLBuffer *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QOpenGLBuffer(QOpenGLBuffer)
                cptr = new ::QOpenGLBuffer(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QOpenGLBuffer >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QOpenGLBufferFunc_allocate(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "allocate", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLBuffer::allocate(const void*,int)
    // 1: QOpenGLBuffer::allocate(int)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 1; // allocate(int)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // allocate(const void*,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "allocate", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // allocate(const void *data, int count)
        {
            void* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // allocate(const void*,int)
                cppSelf->allocate(cppArg0, cppArg1);
            }
            break;
        }
        case 1: // allocate(int count)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // allocate(int)
                cppSelf->allocate(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLBufferFunc_bind(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // bind()
        bool cppResult = cppSelf->bind();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLBufferFunc_bufferId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // bufferId()const
        unsigned int cppResult = const_cast<const ::QOpenGLBuffer *>(cppSelf)->bufferId();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLBufferFunc_create(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // create()
        bool cppResult = cppSelf->create();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLBufferFunc_destroy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // destroy()
        cppSelf->destroy();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLBufferFunc_isCreated(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isCreated()const
        bool cppResult = const_cast<const ::QOpenGLBuffer *>(cppSelf)->isCreated();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLBufferFunc_map(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLBuffer::map(QOpenGLBuffer::Access)->void*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_Access_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // map(QOpenGLBuffer::Access)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "map", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_IDX]);

    // Call function/method
    {
        ::QOpenGLBuffer::Access cppArg0 = static_cast< ::QOpenGLBuffer::Access>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // map(QOpenGLBuffer::Access)
            void * cppResult = cppSelf->map(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLBufferFunc_mapRange(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "mapRange", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLBuffer::mapRange(int,int,QFlags<QOpenGLBuffer::RangeAccessFlag>)->void*
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QFlags_QOpenGLBuffer_RangeAccessFlag_IDX])))->flagsConverter, (pyArgs[2])))) {
        overloadId = 0; // mapRange(int,int,QFlags<QOpenGLBuffer::RangeAccessFlag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "mapRange", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QFlags<QOpenGLBuffer::RangeAccessFlag> cppArg2 = QFlags<QOpenGLBuffer::RangeAccessFlag>(0);
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mapRange(int,int,QFlags<QOpenGLBuffer::RangeAccessFlag>)
            void * cppResult = cppSelf->mapRange(cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLBufferFunc_read(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "read", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLBuffer::read(int,void*,int)->bool
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        overloadId = 0; // read(int,void*,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "read", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        void* cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // read(int,void*,int)
            bool cppResult = cppSelf->read(cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLBufferFunc_release(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    if (!Shiboken::Object::isValid(self))
        return {};
    ::QOpenGLBuffer *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (self)
        cppSelf = reinterpret_cast< ::QOpenGLBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "release", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLBuffer::release()
    // 1: static QOpenGLBuffer::release(QOpenGLBuffer::Type)
    if (numArgs == 0) {
        overloadId = 0; // release()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_Type_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 1; // release(QOpenGLBuffer::Type)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "release", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // release()
        {

            // release()
            cppSelf->release();
            break;
        }
        case 1: // release(QOpenGLBuffer::Type type)
        {
            ::QOpenGLBuffer::Type cppArg0 = static_cast< ::QOpenGLBuffer::Type>(0);
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // release(QOpenGLBuffer::Type)
                ::QOpenGLBuffer::release(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLBufferFunc_setUsagePattern(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLBuffer::setUsagePattern(QOpenGLBuffer::UsagePattern)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_UsagePattern_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setUsagePattern(QOpenGLBuffer::UsagePattern)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUsagePattern", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_IDX]);

    // Call function/method
    {
        ::QOpenGLBuffer::UsagePattern cppArg0 = static_cast< ::QOpenGLBuffer::UsagePattern>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setUsagePattern(QOpenGLBuffer::UsagePattern)
            cppSelf->setUsagePattern(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLBufferFunc_size(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // size()const
        int cppResult = const_cast<const ::QOpenGLBuffer *>(cppSelf)->size();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLBufferFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLBuffer::swap(QOpenGLBuffer&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QOpenGLBuffer&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QOpenGLBuffer *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QOpenGLBuffer&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLBufferFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        QOpenGLBuffer::Type cppResult = const_cast<const ::QOpenGLBuffer *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_Type_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLBufferFunc_unmap(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // unmap()
        bool cppResult = cppSelf->unmap();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLBufferFunc_usagePattern(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // usagePattern()const
        QOpenGLBuffer::UsagePattern cppResult = const_cast<const ::QOpenGLBuffer *>(cppSelf)->usagePattern();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_UsagePattern_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLBufferFunc_write(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "write", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLBuffer::write(int,const void*,int)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        overloadId = 0; // write(int,const void*,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "write", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        void* cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // write(int,const void*,int)
            cppSelf->write(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyMethodDef Sbk_QOpenGLBufferMethod_release = {"release", reinterpret_cast<PyCFunction>(Sbk_QOpenGLBufferFunc_release), METH_VARARGS|METH_STATIC, nullptr};


static const char *Sbk_QOpenGLBuffer_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QOpenGLBuffer_EnumFlagInfo[] = {
    "Access:Enum",
    "RangeAccessFlag:Flag:RangeAccessFlags",
    "Type:Enum",
    "UsagePattern:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QOpenGLBuffer_methods[] = {
    {"allocate", reinterpret_cast<PyCFunction>(Sbk_QOpenGLBufferFunc_allocate), METH_VARARGS, nullptr},
    {"bind", reinterpret_cast<PyCFunction>(Sbk_QOpenGLBufferFunc_bind), METH_NOARGS, nullptr},
    {"bufferId", reinterpret_cast<PyCFunction>(Sbk_QOpenGLBufferFunc_bufferId), METH_NOARGS, nullptr},
    {"create", reinterpret_cast<PyCFunction>(Sbk_QOpenGLBufferFunc_create), METH_NOARGS, nullptr},
    {"destroy", reinterpret_cast<PyCFunction>(Sbk_QOpenGLBufferFunc_destroy), METH_NOARGS, nullptr},
    {"isCreated", reinterpret_cast<PyCFunction>(Sbk_QOpenGLBufferFunc_isCreated), METH_NOARGS, nullptr},
    {"map", reinterpret_cast<PyCFunction>(Sbk_QOpenGLBufferFunc_map), METH_O, nullptr},
    {"mapRange", reinterpret_cast<PyCFunction>(Sbk_QOpenGLBufferFunc_mapRange), METH_VARARGS, nullptr},
    {"read", reinterpret_cast<PyCFunction>(Sbk_QOpenGLBufferFunc_read), METH_VARARGS, nullptr},
    {"release", reinterpret_cast<PyCFunction>(Sbk_QOpenGLBufferFunc_release), METH_VARARGS|METH_STATIC, nullptr},
    {"setUsagePattern", reinterpret_cast<PyCFunction>(Sbk_QOpenGLBufferFunc_setUsagePattern), METH_O, nullptr},
    {"size", reinterpret_cast<PyCFunction>(Sbk_QOpenGLBufferFunc_size), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QOpenGLBufferFunc_swap), METH_O, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QOpenGLBufferFunc_type), METH_NOARGS, nullptr},
    {"unmap", reinterpret_cast<PyCFunction>(Sbk_QOpenGLBufferFunc_unmap), METH_NOARGS, nullptr},
    {"usagePattern", reinterpret_cast<PyCFunction>(Sbk_QOpenGLBufferFunc_usagePattern), METH_NOARGS, nullptr},
    {"write", reinterpret_cast<PyCFunction>(Sbk_QOpenGLBufferFunc_write), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QOpenGLBuffer_getattro(PyObject *self, PyObject *name)
{
    PySide::Feature::Select(self);
    // Search the method in the instance dict
    auto *ob_dict = SbkObject_GetDict_NoRef(self);
    if (auto *meth = PyDict_GetItem(ob_dict, name)) {
        Py_INCREF(meth);
        return meth;
    }
    // Search the method in the type dict
    if (Shiboken::Object::isUserType(self)) {
        Shiboken::AutoDecRef tmp(_Pep_PrivateMangle(self, name));
        Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
        if (auto *meth = PyDict_GetItem(tpDict.object(), tmp)) {
            if (std::strcmp(Py_TYPE(meth)->tp_name, "compiled_function") == 0) {
                auto descrGetFunc = reinterpret_cast<descrgetfunc>(PepType_GetSlot(Py_TYPE(meth), Py_tp_descr_get));
                ;
                return descrGetFunc(meth, self, nullptr);
            }
            return PyFunction_Check(meth) ? PyMethod_New(meth, self)
                                          : PyObject_GenericGetAttr(self, name);
        }
    }
    static PyMethodDef non_static_Sbk_QOpenGLBufferMethod_release = {
        Sbk_QOpenGLBufferMethod_release.ml_name,
        Sbk_QOpenGLBufferMethod_release.ml_meth,
        Sbk_QOpenGLBufferMethod_release.ml_flags & (~METH_STATIC),
        Sbk_QOpenGLBufferMethod_release.ml_doc,
    };
    if (Shiboken::String::compare(name, "release") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_QOpenGLBufferMethod_release, self, 0);
    return PyObject_GenericGetAttr(self, name);
}

} // extern "C"

static int Sbk_QOpenGLBuffer_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QOpenGLBuffer_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QOpenGLBuffer_Type = nullptr;
static PyTypeObject *Sbk_QOpenGLBuffer_TypeF(void)
{
    return _Sbk_QOpenGLBuffer_Type;
}

static PyType_Slot Sbk_QOpenGLBuffer_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_getattro,    reinterpret_cast<void *>(Sbk_QOpenGLBuffer_getattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QOpenGLBuffer_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QOpenGLBuffer_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QOpenGLBuffer_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QOpenGLBuffer_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QOpenGLBuffer_spec = {
    "2:PySide6.QtOpenGL.QOpenGLBuffer",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QOpenGLBuffer_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QOpenGLBuffer_Type(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QOpenGLBuffer::Type>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QOpenGLBuffer::Type *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QOpenGLBuffer_Type_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_Type_IDX])))
        return Enum_PythonToCpp_QOpenGLBuffer_Type;
    return {};
}

static PyObject *QOpenGLBuffer_Type_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QOpenGLBuffer::Type>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QOpenGLBuffer::Type *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_Type_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QOpenGLBuffer_UsagePattern(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QOpenGLBuffer::UsagePattern>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QOpenGLBuffer::UsagePattern *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QOpenGLBuffer_UsagePattern_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_UsagePattern_IDX])))
        return Enum_PythonToCpp_QOpenGLBuffer_UsagePattern;
    return {};
}

static PyObject *QOpenGLBuffer_UsagePattern_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QOpenGLBuffer::UsagePattern>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QOpenGLBuffer::UsagePattern *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_UsagePattern_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QOpenGLBuffer_Access(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QOpenGLBuffer::Access>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QOpenGLBuffer::Access *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QOpenGLBuffer_Access_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_Access_IDX])))
        return Enum_PythonToCpp_QOpenGLBuffer_Access;
    return {};
}

static PyObject *QOpenGLBuffer_Access_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QOpenGLBuffer::Access>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QOpenGLBuffer::Access *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_Access_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QOpenGLBuffer_RangeAccessFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QOpenGLBuffer::RangeAccessFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QOpenGLBuffer::RangeAccessFlag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QOpenGLBuffer_RangeAccessFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_RangeAccessFlag_IDX])))
        return Enum_PythonToCpp_QOpenGLBuffer_RangeAccessFlag;
    return {};
}

static PyObject *QOpenGLBuffer_RangeAccessFlag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QOpenGLBuffer::RangeAccessFlag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QOpenGLBuffer::RangeAccessFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_RangeAccessFlag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QOpenGLBuffer_RangeAccessFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QOpenGLBuffer::RangeAccessFlag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QOpenGLBuffer::RangeAccessFlag> *>(cppOut) = value;

}

static PyObject *QOpenGLBuffer_RangeAccessFlag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QOpenGLBuffer::RangeAccessFlag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_RangeAccessFlag_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QOpenGLBuffer_PythonToCpp_QOpenGLBuffer_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QOpenGLBuffer_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QOpenGLBuffer_PythonToCpp_QOpenGLBuffer_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QOpenGLBuffer_TypeF()))
        return QOpenGLBuffer_PythonToCpp_QOpenGLBuffer_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QOpenGLBuffer_PTR_CppToPython_QOpenGLBuffer(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QOpenGLBuffer_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QOpenGLBuffer_SignatureStrings[] = {
    "2:PySide6.QtOpenGL.QOpenGLBuffer(self)",
    "1:PySide6.QtOpenGL.QOpenGLBuffer(self,type:PySide6.QtOpenGL.QOpenGLBuffer.Type)",
    "0:PySide6.QtOpenGL.QOpenGLBuffer(self,other:PySide6.QtOpenGL.QOpenGLBuffer)",
    "1:PySide6.QtOpenGL.QOpenGLBuffer.allocate(self,data:bytes,count:int)",
    "0:PySide6.QtOpenGL.QOpenGLBuffer.allocate(self,count:int)",
    "PySide6.QtOpenGL.QOpenGLBuffer.bind(self)->bool",
    "PySide6.QtOpenGL.QOpenGLBuffer.bufferId(self)->unsigned int",
    "PySide6.QtOpenGL.QOpenGLBuffer.create(self)->bool",
    "PySide6.QtOpenGL.QOpenGLBuffer.destroy(self)",
    "PySide6.QtOpenGL.QOpenGLBuffer.isCreated(self)->bool",
    "PySide6.QtOpenGL.QOpenGLBuffer.map(self,access:PySide6.QtOpenGL.QOpenGLBuffer.Access)->void",
    "PySide6.QtOpenGL.QOpenGLBuffer.mapRange(self,offset:int,count:int,access:PySide6.QtOpenGL.QOpenGLBuffer.RangeAccessFlag)->void",
    "PySide6.QtOpenGL.QOpenGLBuffer.read(self,offset:int,data:void,count:int)->bool",
    "1:PySide6.QtOpenGL.QOpenGLBuffer.release(self)",
    "0:PySide6.QtOpenGL.QOpenGLBuffer.release(type:PySide6.QtOpenGL.QOpenGLBuffer.Type)",
    "PySide6.QtOpenGL.QOpenGLBuffer.setUsagePattern(self,value:PySide6.QtOpenGL.QOpenGLBuffer.UsagePattern)",
    "PySide6.QtOpenGL.QOpenGLBuffer.size(self)->int",
    "PySide6.QtOpenGL.QOpenGLBuffer.swap(self,other:PySide6.QtOpenGL.QOpenGLBuffer)",
    "PySide6.QtOpenGL.QOpenGLBuffer.type(self)->PySide6.QtOpenGL.QOpenGLBuffer.Type",
    "PySide6.QtOpenGL.QOpenGLBuffer.unmap(self)->bool",
    "PySide6.QtOpenGL.QOpenGLBuffer.usagePattern(self)->PySide6.QtOpenGL.QOpenGLBuffer.UsagePattern",
    "PySide6.QtOpenGL.QOpenGLBuffer.write(self,offset:int,data:void,count:int)",
    nullptr}; // Sentinel
#else
static constexpr size_t QOpenGLBuffer_SignatureByteSize = 311;
static constexpr uint8_t QOpenGLBuffer_SignatureBytes[311] = {
    0x78, 0xda, 0x95, 0x54, 0xcb, 0x4e, 0xc3, 0x30, 0x10, 0xbc, 0xf7, 0x2b, 0x38, 0x52, 0xa9, 0x44,
    0xc0, 0x81, 0x43, 0x0e, 0x48, 0x80, 0x04, 0x42, 0x42, 0xa2, 0xe5, 0xf1, 0x01, 0x9b, 0x78, 0x13,
    0x2c, 0x19, 0x3b, 0xb2, 0xd7, 0xad, 0xc2, 0xd7, 0x93, 0xda, 0x49, 0x89, 0xca, 0x61, 0xb7, 0x27,
    0x5f, 0xe6, 0xb1, 0x9e, 0x1d, 0xfb, 0xba, 0x5c, 0xf7, 0xef, 0x5a, 0xe1, 0x4d, 0xb1, 0xa1, 0xd7,
    0x0e, 0xed, 0xd3, 0x4b, 0xb1, 0xc9, 0xe7, 0x7d, 0x6c, 0x1a, 0xf4, 0xe7, 0x01, 0x4d, 0xb3, 0x5c,
    0x5c, 0x49, 0x60, 0x2b, 0xea, 0x3b, 0x64, 0x80, 0xc5, 0xc7, 0x80, 0x59, 0x2e, 0x2e, 0x45, 0x7a,
    0x8e, 0xbe, 0xd0, 0x33, 0x48, 0x7e, 0xb6, 0x02, 0x8c, 0x71, 0x35, 0x10, 0x66, 0x51, 0x05, 0x04,
    0x65, 0xd5, 0x13, 0x86, 0x55, 0xed, 0xa2, 0xa5, 0x52, 0x5b, 0xe2, 0x07, 0x3a, 0x12, 0x99, 0x31,
    0x19, 0x5e, 0xa5, 0xad, 0xca, 0x21, 0x5e, 0xdc, 0x56, 0xce, 0x19, 0x16, 0x9f, 0x8e, 0xe7, 0x03,
    0x27, 0xda, 0xa0, 0x5b, 0x8b, 0xea, 0x6c, 0x30, 0xe3, 0xb8, 0xb5, 0xc7, 0x69, 0x42, 0xa1, 0x9b,
    0xc2, 0x40, 0xde, 0xf5, 0xe3, 0x96, 0x19, 0xb0, 0x0e, 0x0f, 0xc9, 0xe0, 0xa4, 0xfb, 0x7c, 0x43,
    0x97, 0x23, 0x83, 0xba, 0xc6, 0x10, 0xb8, 0x98, 0xef, 0x12, 0x6a, 0xd0, 0xde, 0x3a, 0xad, 0x04,
    0xda, 0x6f, 0x60, 0xdb, 0x71, 0x27, 0xae, 0x69, 0x02, 0xa6, 0xa5, 0xfc, 0xad, 0x47, 0xe8, 0x9a,
    0x54, 0xb2, 0xf5, 0xa3, 0x81, 0x56, 0x68, 0x3f, 0x84, 0xa1, 0xfe, 0x59, 0xa7, 0x7a, 0xed, 0xd9,
    0xb3, 0x8e, 0x8c, 0x49, 0xb1, 0x45, 0xf5, 0x68, 0x10, 0xc2, 0xb8, 0x40, 0xbe, 0x92, 0x13, 0x5c,
    0xfe, 0xec, 0x18, 0xd0, 0x70, 0x87, 0xcf, 0x00, 0x2d, 0xae, 0x81, 0x08, 0xbd, 0xcd, 0x77, 0xdb,
    0x82, 0x89, 0xac, 0xfc, 0x9c, 0xc6, 0xdb, 0xe8, 0x9f, 0x43, 0x49, 0x05, 0xad, 0x0e, 0xbb, 0xa9,
    0x42, 0xb2, 0xff, 0x80, 0x91, 0xdb, 0xa7, 0x35, 0xb9, 0x0b, 0x42, 0xe3, 0xe4, 0xa2, 0x9d, 0x1a,
    0x2e, 0x7c, 0x10, 0xf1, 0x38, 0x61, 0x7e, 0x8e, 0x79, 0xba, 0x9c, 0xfc, 0xce, 0x6b, 0x42, 0x51,
    0x2b, 0x17, 0xbf, 0x59, 0x49, 0x19, 0xbc
};
#endif

PyTypeObject *init_QOpenGLBuffer(PyObject *module)
{
    if (SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_IDX].type != nullptr)
        return SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_IDX].type;

    Shiboken::AutoDecRef Sbk_QOpenGLBuffer_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QOpenGLBuffer_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QOpenGLBuffer",
        "QOpenGLBuffer*",
        &Sbk_QOpenGLBuffer_spec,
        &Shiboken::callCppDestructor< ::QOpenGLBuffer >,
        Sbk_QOpenGLBuffer_Type_bases.object(),
        0);
    auto *pyType = Sbk_QOpenGLBuffer_TypeF(); // references _Sbk_QOpenGLBuffer_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QOpenGLBuffer_SignatureStrings);
#else
    InitSignatureBytes(pyType, QOpenGLBuffer_SignatureBytes, QOpenGLBuffer_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QOpenGLBuffer_PropertyStrings);
    SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QOpenGLBuffer_PythonToCpp_QOpenGLBuffer_PTR,
        is_QOpenGLBuffer_PythonToCpp_QOpenGLBuffer_PTR_Convertible,
        QOpenGLBuffer_PTR_CppToPython_QOpenGLBuffer);

    Shiboken::Conversions::registerConverterName(converter, "QOpenGLBuffer");
    Shiboken::Conversions::registerConverterName(converter, "QOpenGLBuffer*");
    Shiboken::Conversions::registerConverterName(converter, "QOpenGLBuffer&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QOpenGLBuffer).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QOpenGLBuffer_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Type'.
    const char *Type_Initializer[] = {
        "VertexBuffer",
        "IndexBuffer",
        "PixelPackBuffer",
        "PixelUnpackBuffer",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t Type_InitializerValues[] = {
        uint16_t(QOpenGLBuffer::Type::VertexBuffer),     //  0x8892  34962
        uint16_t(QOpenGLBuffer::Type::IndexBuffer),      //  0x8893  34963
        uint16_t(QOpenGLBuffer::Type::PixelPackBuffer),  //  0x88eb  35051
        uint16_t(QOpenGLBuffer::Type::PixelUnpackBuffer) //  0x88ec  35052
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QOpenGLBuffer_TypeF(),
        "2:PySide6.QtOpenGL.QOpenGLBuffer.Type",
        Type_Initializer, Type_InitializerValues);
    SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_Type_IDX].type = EType;
    // Register converter for enum 'QOpenGLBuffer::Type'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QOpenGLBuffer_Type_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QOpenGLBuffer_Type,
            is_Enum_PythonToCpp_QOpenGLBuffer_Type_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QOpenGLBuffer::Type");
        Shiboken::Conversions::registerConverterAlias(converter, "Type");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Type' enum.

    // Initialization of enum 'UsagePattern'.
    const char *UsagePattern_Initializer[] = {
        "StreamDraw",
        "StreamRead",
        "StreamCopy",
        "StaticDraw",
        "StaticRead",
        "StaticCopy",
        "DynamicDraw",
        "DynamicRead",
        "DynamicCopy",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t UsagePattern_InitializerValues[] = {
        uint16_t(QOpenGLBuffer::UsagePattern::StreamDraw),  //  0x88e0  35040
        uint16_t(QOpenGLBuffer::UsagePattern::StreamRead),  //  0x88e1  35041
        uint16_t(QOpenGLBuffer::UsagePattern::StreamCopy),  //  0x88e2  35042
        uint16_t(QOpenGLBuffer::UsagePattern::StaticDraw),  //  0x88e4  35044
        uint16_t(QOpenGLBuffer::UsagePattern::StaticRead),  //  0x88e5  35045
        uint16_t(QOpenGLBuffer::UsagePattern::StaticCopy),  //  0x88e6  35046
        uint16_t(QOpenGLBuffer::UsagePattern::DynamicDraw), //  0x88e8  35048
        uint16_t(QOpenGLBuffer::UsagePattern::DynamicRead), //  0x88e9  35049
        uint16_t(QOpenGLBuffer::UsagePattern::DynamicCopy)  //  0x88ea  35050
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QOpenGLBuffer_TypeF(),
        "2:PySide6.QtOpenGL.QOpenGLBuffer.UsagePattern",
        UsagePattern_Initializer, UsagePattern_InitializerValues);
    SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_UsagePattern_IDX].type = EType;
    // Register converter for enum 'QOpenGLBuffer::UsagePattern'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QOpenGLBuffer_UsagePattern_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QOpenGLBuffer_UsagePattern,
            is_Enum_PythonToCpp_QOpenGLBuffer_UsagePattern_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QOpenGLBuffer::UsagePattern");
        Shiboken::Conversions::registerConverterAlias(converter, "UsagePattern");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'UsagePattern' enum.

    // Initialization of enum 'Access'.
    const char *Access_Initializer[] = {
        "ReadOnly",
        "WriteOnly",
        "ReadWrite",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t Access_InitializerValues[] = {
        uint16_t(QOpenGLBuffer::Access::ReadOnly),  //  0x88b8  35000
        uint16_t(QOpenGLBuffer::Access::WriteOnly), //  0x88b9  35001
        uint16_t(QOpenGLBuffer::Access::ReadWrite)  //  0x88ba  35002
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QOpenGLBuffer_TypeF(),
        "2:PySide6.QtOpenGL.QOpenGLBuffer.Access",
        Access_Initializer, Access_InitializerValues);
    SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_Access_IDX].type = EType;
    // Register converter for enum 'QOpenGLBuffer::Access'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QOpenGLBuffer_Access_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QOpenGLBuffer_Access,
            is_Enum_PythonToCpp_QOpenGLBuffer_Access_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QOpenGLBuffer::Access");
        Shiboken::Conversions::registerConverterAlias(converter, "Access");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Access' enum.

    // Initialization of enum 'RangeAccessFlag'.
    const char *RangeAccessFlag_Initializer[] = {
        "RangeRead",
        "RangeWrite",
        "RangeInvalidate",
        "RangeInvalidateBuffer",
        "RangeFlushExplicit",
        "RangeUnsynchronized",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t RangeAccessFlag_InitializerValues[] = {
        uint8_t(QOpenGLBuffer::RangeAccessFlag::RangeRead),             //  0x01  1
        uint8_t(QOpenGLBuffer::RangeAccessFlag::RangeWrite),            //  0x02  2
        uint8_t(QOpenGLBuffer::RangeAccessFlag::RangeInvalidate),       //  0x04  4
        uint8_t(QOpenGLBuffer::RangeAccessFlag::RangeInvalidateBuffer), //  0x08  8
        uint8_t(QOpenGLBuffer::RangeAccessFlag::RangeFlushExplicit),    //  0x10  16
        uint8_t(QOpenGLBuffer::RangeAccessFlag::RangeUnsynchronized)    //  0x20  32
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QOpenGLBuffer_TypeF(),
        "2:PySide6.QtOpenGL.QOpenGLBuffer.RangeAccessFlag",
        RangeAccessFlag_Initializer, RangeAccessFlag_InitializerValues);
    SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLBuffer_RangeAccessFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtOpenGLTypeStructs[SBK_QFlags_QOpenGLBuffer_RangeAccessFlag_IDX].type =
        EType;
    // Register converter for enum 'QOpenGLBuffer::RangeAccessFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QOpenGLBuffer_RangeAccessFlag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QOpenGLBuffer_RangeAccessFlag,
            is_Enum_PythonToCpp_QOpenGLBuffer_RangeAccessFlag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QOpenGLBuffer::RangeAccessFlag");
        Shiboken::Conversions::registerConverterAlias(converter, "RangeAccessFlag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QOpenGLBuffer_RangeAccessFlag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QOpenGLBuffer_RangeAccessFlag,
            is_Enum_PythonToCpp_QOpenGLBuffer_RangeAccessFlag_Convertible);
        // Register converter for flag 'QFlags<QOpenGLBuffer::RangeAccessFlag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QOpenGLBuffer::RangeAccessFlag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QOpenGLBuffer::RangeAccessFlags");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'RangeAccessFlag' enum/flags.

    qRegisterMetaType< ::QOpenGLBuffer *>();
    qRegisterMetaType< ::QOpenGLBuffer::Type >("QOpenGLBuffer::Type");
    qRegisterMetaType< ::QOpenGLBuffer::UsagePattern >("QOpenGLBuffer::UsagePattern");
    qRegisterMetaType< ::QOpenGLBuffer::Access >("QOpenGLBuffer::Access");
    qRegisterMetaType< ::QOpenGLBuffer::RangeAccessFlag >("QOpenGLBuffer::RangeAccessFlag");

    return pyType;
}
