// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtopengl_python.h"

// main header
#include "qopengldebugmessage_wrapper.h"

// Argument includes
#include <QString>
#include <QtOpenGL/qopengldebug.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QOpenGLDebugMessage_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QOpenGLDebugMessage >()))
        return -1;

    ::QOpenGLDebugMessage *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QOpenGLDebugMessage", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QOpenGLDebugMessage::QOpenGLDebugMessage()
    // 1: QOpenGLDebugMessage::QOpenGLDebugMessage(QOpenGLDebugMessage)
    if (numArgs == 0) {
        overloadId = 0; // QOpenGLDebugMessage()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QOpenGLDebugMessage(QOpenGLDebugMessage)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QOpenGLDebugMessage()
        {

            // QOpenGLDebugMessage()
            cptr = new ::QOpenGLDebugMessage();
            break;
        }
        case 1: // QOpenGLDebugMessage(const QOpenGLDebugMessage &debugMessage)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QOpenGLDebugMessage cppArg0_local;
            ::QOpenGLDebugMessage *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QOpenGLDebugMessage(QOpenGLDebugMessage)
                cptr = new ::QOpenGLDebugMessage(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QOpenGLDebugMessage >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QOpenGLDebugMessageFunc_createApplicationMessage(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "createApplicationMessage", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:createApplicationMessage", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QOpenGLDebugMessage::createApplicationMessage(QString,uint=,QOpenGLDebugMessage::Severity=,QOpenGLDebugMessage::Type=)->QOpenGLDebugMessage
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // createApplicationMessage(QString,uint,QOpenGLDebugMessage::Severity,QOpenGLDebugMessage::Type)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // createApplicationMessage(QString,uint,QOpenGLDebugMessage::Severity,QOpenGLDebugMessage::Type)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_Severity_IDX])))->converter, (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // createApplicationMessage(QString,uint,QOpenGLDebugMessage::Severity,QOpenGLDebugMessage::Type)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_Type_IDX])))->converter, (pyArgs[3])))) {
                    overloadId = 0; // createApplicationMessage(QString,uint,QOpenGLDebugMessage::Severity,QOpenGLDebugMessage::Type)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "createApplicationMessage", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_id = Shiboken::String::createStaticString("id");
            if (PyDict_Contains(kwds, key_id) != 0) {
                value = PyDict_GetItem(kwds, key_id);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_id);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "createApplicationMessage", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "createApplicationMessage", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_id);
            }
            static PyObject *const key_severity = Shiboken::String::createStaticString("severity");
            if (PyDict_Contains(kwds, key_severity) != 0) {
                value = PyDict_GetItem(kwds, key_severity);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_severity);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "createApplicationMessage", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_Severity_IDX])))->converter, (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "createApplicationMessage", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_severity);
            }
            static PyObject *const key_type = Shiboken::String::createStaticString("type");
            if (PyDict_Contains(kwds, key_type) != 0) {
                value = PyDict_GetItem(kwds, key_type);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_type);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "createApplicationMessage", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_Type_IDX])))->converter, (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, "createApplicationMessage", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_type);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "createApplicationMessage", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1 = 0;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QOpenGLDebugMessage::Severity cppArg2(QOpenGLDebugMessage::Severity::NotificationSeverity);
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);
        ::QOpenGLDebugMessage::Type cppArg3(QOpenGLDebugMessage::Type::OtherType);
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createApplicationMessage(QString,uint,QOpenGLDebugMessage::Severity,QOpenGLDebugMessage::Type)
            QOpenGLDebugMessage cppResult = ::QOpenGLDebugMessage::createApplicationMessage(cppArg0, cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLDebugMessageFunc_createThirdPartyMessage(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "createThirdPartyMessage", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:createThirdPartyMessage", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QOpenGLDebugMessage::createThirdPartyMessage(QString,uint=,QOpenGLDebugMessage::Severity=,QOpenGLDebugMessage::Type=)->QOpenGLDebugMessage
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // createThirdPartyMessage(QString,uint,QOpenGLDebugMessage::Severity,QOpenGLDebugMessage::Type)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // createThirdPartyMessage(QString,uint,QOpenGLDebugMessage::Severity,QOpenGLDebugMessage::Type)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_Severity_IDX])))->converter, (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // createThirdPartyMessage(QString,uint,QOpenGLDebugMessage::Severity,QOpenGLDebugMessage::Type)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_Type_IDX])))->converter, (pyArgs[3])))) {
                    overloadId = 0; // createThirdPartyMessage(QString,uint,QOpenGLDebugMessage::Severity,QOpenGLDebugMessage::Type)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "createThirdPartyMessage", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_id = Shiboken::String::createStaticString("id");
            if (PyDict_Contains(kwds, key_id) != 0) {
                value = PyDict_GetItem(kwds, key_id);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_id);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "createThirdPartyMessage", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "createThirdPartyMessage", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_id);
            }
            static PyObject *const key_severity = Shiboken::String::createStaticString("severity");
            if (PyDict_Contains(kwds, key_severity) != 0) {
                value = PyDict_GetItem(kwds, key_severity);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_severity);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "createThirdPartyMessage", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_Severity_IDX])))->converter, (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "createThirdPartyMessage", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_severity);
            }
            static PyObject *const key_type = Shiboken::String::createStaticString("type");
            if (PyDict_Contains(kwds, key_type) != 0) {
                value = PyDict_GetItem(kwds, key_type);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_type);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "createThirdPartyMessage", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_Type_IDX])))->converter, (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, "createThirdPartyMessage", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_type);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "createThirdPartyMessage", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1 = 0;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QOpenGLDebugMessage::Severity cppArg2(QOpenGLDebugMessage::Severity::NotificationSeverity);
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);
        ::QOpenGLDebugMessage::Type cppArg3(QOpenGLDebugMessage::Type::OtherType);
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createThirdPartyMessage(QString,uint,QOpenGLDebugMessage::Severity,QOpenGLDebugMessage::Type)
            QOpenGLDebugMessage cppResult = ::QOpenGLDebugMessage::createThirdPartyMessage(cppArg0, cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLDebugMessageFunc_id(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLDebugMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // id()const
        unsigned int cppResult = const_cast<const ::QOpenGLDebugMessage *>(cppSelf)->id();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLDebugMessageFunc_message(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLDebugMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // message()const
        QString cppResult = const_cast<const ::QOpenGLDebugMessage *>(cppSelf)->message();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLDebugMessageFunc_severity(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLDebugMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // severity()const
        QOpenGLDebugMessage::Severity cppResult = const_cast<const ::QOpenGLDebugMessage *>(cppSelf)->severity();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_Severity_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLDebugMessageFunc_source(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLDebugMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // source()const
        QOpenGLDebugMessage::Source cppResult = const_cast<const ::QOpenGLDebugMessage *>(cppSelf)->source();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_Source_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLDebugMessageFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLDebugMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLDebugMessage::swap(QOpenGLDebugMessage&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QOpenGLDebugMessage&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QOpenGLDebugMessage cppArg0_local;
        ::QOpenGLDebugMessage *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QOpenGLDebugMessage&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLDebugMessageFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLDebugMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        QOpenGLDebugMessage::Type cppResult = const_cast<const ::QOpenGLDebugMessage *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_Type_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLDebugMessage__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QOpenGLDebugMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QOpenGLDebugMessage_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QOpenGLDebugMessage_EnumFlagInfo[] = {
    "Severity:Flag:Severities",
    "Source:Flag:Sources",
    "Type:Flag:Types",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QOpenGLDebugMessage_methods[] = {
    {"createApplicationMessage", reinterpret_cast<PyCFunction>(Sbk_QOpenGLDebugMessageFunc_createApplicationMessage), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"createThirdPartyMessage", reinterpret_cast<PyCFunction>(Sbk_QOpenGLDebugMessageFunc_createThirdPartyMessage), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"id", reinterpret_cast<PyCFunction>(Sbk_QOpenGLDebugMessageFunc_id), METH_NOARGS, nullptr},
    {"message", reinterpret_cast<PyCFunction>(Sbk_QOpenGLDebugMessageFunc_message), METH_NOARGS, nullptr},
    {"severity", reinterpret_cast<PyCFunction>(Sbk_QOpenGLDebugMessageFunc_severity), METH_NOARGS, nullptr},
    {"source", reinterpret_cast<PyCFunction>(Sbk_QOpenGLDebugMessageFunc_source), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QOpenGLDebugMessageFunc_swap), METH_O, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QOpenGLDebugMessageFunc_type), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QOpenGLDebugMessage__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QOpenGLDebugMessage_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QOpenGLDebugMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_IDX]), (pyArg)))) {
                // operator!=(const QOpenGLDebugMessage &debugMessage) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QOpenGLDebugMessage cppArg0_local;
                ::QOpenGLDebugMessage *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_IDX]), (pyArg)))) {
                // operator==(const QOpenGLDebugMessage &debugMessage) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QOpenGLDebugMessage cppArg0_local;
                ::QOpenGLDebugMessage *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QOpenGLDebugMessage_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QOpenGLDebugMessage_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QOpenGLDebugMessage__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLDebugMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QOpenGLDebugMessage_Type = nullptr;
static PyTypeObject *Sbk_QOpenGLDebugMessage_TypeF(void)
{
    return _Sbk_QOpenGLDebugMessage_Type;
}

static PyType_Slot Sbk_QOpenGLDebugMessage_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QOpenGLDebugMessage__repr__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QOpenGLDebugMessage_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QOpenGLDebugMessage_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QOpenGLDebugMessage_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QOpenGLDebugMessage_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QOpenGLDebugMessage_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QOpenGLDebugMessage_spec = {
    "2:PySide6.QtOpenGL.QOpenGLDebugMessage",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QOpenGLDebugMessage_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QOpenGLDebugMessage_Source(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QOpenGLDebugMessage::Source>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QOpenGLDebugMessage::Source *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QOpenGLDebugMessage_Source_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_Source_IDX])))
        return Enum_PythonToCpp_QOpenGLDebugMessage_Source;
    return {};
}

static PyObject *QOpenGLDebugMessage_Source_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QOpenGLDebugMessage::Source>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QOpenGLDebugMessage::Source *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_Source_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QOpenGLDebugMessage_Source(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QOpenGLDebugMessage::Source>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QOpenGLDebugMessage::Source> *>(cppOut) = value;

}

static PyObject *QOpenGLDebugMessage_Source_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QOpenGLDebugMessage::Source> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_Source_IDX]), flags.toInt());

}

static void Enum_PythonToCpp_QOpenGLDebugMessage_Type(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QOpenGLDebugMessage::Type>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QOpenGLDebugMessage::Type *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QOpenGLDebugMessage_Type_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_Type_IDX])))
        return Enum_PythonToCpp_QOpenGLDebugMessage_Type;
    return {};
}

static PyObject *QOpenGLDebugMessage_Type_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QOpenGLDebugMessage::Type>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QOpenGLDebugMessage::Type *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_Type_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QOpenGLDebugMessage_Type(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QOpenGLDebugMessage::Type>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QOpenGLDebugMessage::Type> *>(cppOut) = value;

}

static PyObject *QOpenGLDebugMessage_Type_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QOpenGLDebugMessage::Type> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_Type_IDX]), flags.toInt());

}

static void Enum_PythonToCpp_QOpenGLDebugMessage_Severity(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QOpenGLDebugMessage::Severity>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QOpenGLDebugMessage::Severity *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QOpenGLDebugMessage_Severity_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_Severity_IDX])))
        return Enum_PythonToCpp_QOpenGLDebugMessage_Severity;
    return {};
}

static PyObject *QOpenGLDebugMessage_Severity_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QOpenGLDebugMessage::Severity>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QOpenGLDebugMessage::Severity *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_Severity_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QOpenGLDebugMessage_Severity(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QOpenGLDebugMessage::Severity>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QOpenGLDebugMessage::Severity> *>(cppOut) = value;

}

static PyObject *QOpenGLDebugMessage_Severity_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QOpenGLDebugMessage::Severity> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_Severity_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QOpenGLDebugMessage_PythonToCpp_QOpenGLDebugMessage_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QOpenGLDebugMessage_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QOpenGLDebugMessage_PythonToCpp_QOpenGLDebugMessage_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QOpenGLDebugMessage_TypeF()))
        return QOpenGLDebugMessage_PythonToCpp_QOpenGLDebugMessage_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QOpenGLDebugMessage_PTR_CppToPython_QOpenGLDebugMessage(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QOpenGLDebugMessage_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QOpenGLDebugMessage_COPY_CppToPython_QOpenGLDebugMessage(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QOpenGLDebugMessage *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QOpenGLDebugMessage_TypeF(), new ::QOpenGLDebugMessage(*source), true, true);
}

// Python to C++ copy conversion.
static void QOpenGLDebugMessage_PythonToCpp_QOpenGLDebugMessage_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QOpenGLDebugMessage *>(cppOut) = *reinterpret_cast< ::QOpenGLDebugMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QOpenGLDebugMessage_PythonToCpp_QOpenGLDebugMessage_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QOpenGLDebugMessage_TypeF()))
        return QOpenGLDebugMessage_PythonToCpp_QOpenGLDebugMessage_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QOpenGLDebugMessage_SignatureStrings[] = {
    "1:PySide6.QtOpenGL.QOpenGLDebugMessage(self)",
    "0:PySide6.QtOpenGL.QOpenGLDebugMessage(self,debugMessage:PySide6.QtOpenGL.QOpenGLDebugMessage)",
    "PySide6.QtOpenGL.QOpenGLDebugMessage.createApplicationMessage(text:QString,id:unsigned int=0,severity:PySide6.QtOpenGL.QOpenGLDebugMessage.Severity=QOpenGLDebugMessage.Severity.NotificationSeverity,type:PySide6.QtOpenGL.QOpenGLDebugMessage.Type=QOpenGLDebugMessage.Type.OtherType)->PySide6.QtOpenGL.QOpenGLDebugMessage",
    "PySide6.QtOpenGL.QOpenGLDebugMessage.createThirdPartyMessage(text:QString,id:unsigned int=0,severity:PySide6.QtOpenGL.QOpenGLDebugMessage.Severity=QOpenGLDebugMessage.Severity.NotificationSeverity,type:PySide6.QtOpenGL.QOpenGLDebugMessage.Type=QOpenGLDebugMessage.Type.OtherType)->PySide6.QtOpenGL.QOpenGLDebugMessage",
    "PySide6.QtOpenGL.QOpenGLDebugMessage.id(self)->unsigned int",
    "PySide6.QtOpenGL.QOpenGLDebugMessage.message(self)->QString",
    "PySide6.QtOpenGL.QOpenGLDebugMessage.severity(self)->PySide6.QtOpenGL.QOpenGLDebugMessage.Severity",
    "PySide6.QtOpenGL.QOpenGLDebugMessage.source(self)->PySide6.QtOpenGL.QOpenGLDebugMessage.Source",
    "PySide6.QtOpenGL.QOpenGLDebugMessage.swap(self,other:PySide6.QtOpenGL.QOpenGLDebugMessage)",
    "PySide6.QtOpenGL.QOpenGLDebugMessage.type(self)->PySide6.QtOpenGL.QOpenGLDebugMessage.Type",
    "PySide6.QtOpenGL.QOpenGLDebugMessage.__copy__(self)->typing.Self",
    "PySide6.QtOpenGL.QOpenGLDebugMessage.__ne__(self,debugMessage:PySide6.QtOpenGL.QOpenGLDebugMessage)->bool",
    "PySide6.QtOpenGL.QOpenGLDebugMessage.__eq__(self,debugMessage:PySide6.QtOpenGL.QOpenGLDebugMessage)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QOpenGLDebugMessage_SignatureByteSize = 277;
static constexpr uint8_t QOpenGLDebugMessage_SignatureBytes[277] = {
    0x78, 0xda, 0xed, 0x54, 0xc1, 0x4e, 0x84, 0x30, 0x10, 0xbd, 0xef, 0x57, 0x78, 0x94, 0x04, 0x9a,
    0xdd, 0x8b, 0x07, 0x12, 0x48, 0x4c, 0x4c, 0xbc, 0xe8, 0xee, 0x12, 0xf6, 0x4e, 0xba, 0x74, 0x60,
    0x27, 0xc1, 0xb6, 0x96, 0x41, 0xed, 0xdf, 0x0b, 0x02, 0x09, 0x17, 0xcd, 0xa0, 0x1e, 0xf7, 0xd4,
    0xa6, 0x33, 0xef, 0xbd, 0xe9, 0x9b, 0x76, 0x76, 0xf1, 0xd1, 0xe7, 0xa8, 0xe0, 0x4e, 0x64, 0x74,
    0xb0, 0xa0, 0x1f, 0x9f, 0x44, 0x36, 0xae, 0x0f, 0x70, 0xee, 0xea, 0x67, 0x68, 0x5b, 0x59, 0xc3,
    0x6d, 0x0b, 0x4d, 0x15, 0x6c, 0xb6, 0xfc, 0xe4, 0x50, 0x2d, 0x4e, 0x58, 0xb0, 0x60, 0xc3, 0xc9,
    0x12, 0xa5, 0x03, 0x49, 0x70, 0x6f, 0x6d, 0x83, 0xa5, 0x24, 0x34, 0x7a, 0x56, 0x25, 0xf8, 0xa0,
    0x38, 0xcb, 0xc9, 0xa1, 0xae, 0x43, 0x54, 0x71, 0xa7, 0x5b, 0xac, 0x35, 0xa8, 0x1b, 0xd4, 0x94,
    0x6c, 0xc3, 0x16, 0xde, 0xc0, 0x21, 0x79, 0x56, 0x2d, 0x22, 0x9f, 0xb2, 0x93, 0x9f, 0x82, 0x62,
    0x6f, 0x08, 0xab, 0xa9, 0x8c, 0xf9, 0x30, 0x24, 0x6f, 0x79, 0x17, 0x16, 0xa7, 0x3e, 0x33, 0xf9,
    0x2e, 0x20, 0x0e, 0x74, 0x01, 0x37, 0xec, 0x82, 0x28, 0xe5, 0xd0, 0xad, 0xb1, 0xef, 0x74, 0x41,
    0xa7, 0x8e, 0xd2, 0x91, 0xbf, 0xba, 0xb7, 0xc6, 0x3d, 0x54, 0xe3, 0x4f, 0x88, 0xd2, 0xa5, 0x3f,
    0x3c, 0xec, 0xcb, 0xf2, 0x2b, 0x45, 0xe9, 0xe4, 0x35, 0x0f, 0x3b, 0xdb, 0x3f, 0x83, 0x57, 0x75,
    0x81, 0x29, 0x61, 0x3a, 0x57, 0xc2, 0x3a, 0x81, 0x2f, 0x08, 0x93, 0xfe, 0x5d, 0xda, 0x71, 0x30,
    0x98, 0xa1, 0x33, 0xff, 0x39, 0x11, 0x86, 0x27, 0xb3, 0xaa, 0xee, 0xe1, 0x59, 0xf0, 0xa8, 0x8b,
    0xa2, 0x34, 0xd6, 0x17, 0xc5, 0x4c, 0xdf, 0x4b, 0xf5, 0x3d, 0xeb, 0x9d, 0x6d, 0x2a, 0x2e, 0x81,
    0x86, 0x09, 0xfe, 0x8b, 0x89, 0x18, 0xa5, 0x67, 0x63, 0x1a, 0xae, 0x12, 0xbc, 0xfe, 0x59, 0xe9,
    0x13, 0xa6, 0x70, 0x2d, 0x2a
};
#endif

PyTypeObject *init_QOpenGLDebugMessage(PyObject *module)
{
    if (SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_IDX].type != nullptr)
        return SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_IDX].type;

    Shiboken::AutoDecRef Sbk_QOpenGLDebugMessage_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QOpenGLDebugMessage_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QOpenGLDebugMessage",
        "QOpenGLDebugMessage",
        &Sbk_QOpenGLDebugMessage_spec,
        &Shiboken::callCppDestructor< ::QOpenGLDebugMessage >,
        Sbk_QOpenGLDebugMessage_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QOpenGLDebugMessage_TypeF(); // references _Sbk_QOpenGLDebugMessage_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QOpenGLDebugMessage_SignatureStrings);
#else
    InitSignatureBytes(pyType, QOpenGLDebugMessage_SignatureBytes, QOpenGLDebugMessage_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QOpenGLDebugMessage_PropertyStrings);
    SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QOpenGLDebugMessage_PythonToCpp_QOpenGLDebugMessage_PTR,
        is_QOpenGLDebugMessage_PythonToCpp_QOpenGLDebugMessage_PTR_Convertible,
        QOpenGLDebugMessage_PTR_CppToPython_QOpenGLDebugMessage,
        QOpenGLDebugMessage_COPY_CppToPython_QOpenGLDebugMessage);

    Shiboken::Conversions::registerConverterName(converter, "QOpenGLDebugMessage");
    Shiboken::Conversions::registerConverterName(converter, "QOpenGLDebugMessage*");
    Shiboken::Conversions::registerConverterName(converter, "QOpenGLDebugMessage&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QOpenGLDebugMessage).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QOpenGLDebugMessage_PythonToCpp_QOpenGLDebugMessage_COPY,
        is_QOpenGLDebugMessage_PythonToCpp_QOpenGLDebugMessage_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QOpenGLDebugMessage_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Source'.
    const char *Source_Initializer[] = {
        "InvalidSource",
        "APISource",
        "WindowSystemSource",
        "ShaderCompilerSource",
        "ThirdPartySource",
        "ApplicationSource",
        "OtherSource",
        "LastSource",
        "AnySource",
        nullptr};
    // "uint32_t" used instead of "unsigned int"
    constexpr uint32_t Source_InitializerValues[] = {
        uint32_t(QOpenGLDebugMessage::Source::InvalidSource),        //  0x00000000  0
        uint32_t(QOpenGLDebugMessage::Source::APISource),            //  0x00000001  1
        uint32_t(QOpenGLDebugMessage::Source::WindowSystemSource),   //  0x00000002  2
        uint32_t(QOpenGLDebugMessage::Source::ShaderCompilerSource), //  0x00000004  4
        uint32_t(QOpenGLDebugMessage::Source::ThirdPartySource),     //  0x00000008  8
        uint32_t(QOpenGLDebugMessage::Source::ApplicationSource),    //  0x00000010  16
        uint32_t(QOpenGLDebugMessage::Source::OtherSource),          //  0x00000020  32
        uint32_t(QOpenGLDebugMessage::Source::LastSource),           //  0x00000020  32
        uint32_t(QOpenGLDebugMessage::Source::AnySource)             //  0xffffffff  4294967295
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QOpenGLDebugMessage_TypeF(),
        "2:PySide6.QtOpenGL.QOpenGLDebugMessage.Source",
        Source_Initializer, Source_InitializerValues);
    SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_Source_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtOpenGLTypeStructs[SBK_QFlags_QOpenGLDebugMessage_Source_IDX].type =
        EType;
    // Register converter for enum 'QOpenGLDebugMessage::Source'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QOpenGLDebugMessage_Source_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QOpenGLDebugMessage_Source,
            is_Enum_PythonToCpp_QOpenGLDebugMessage_Source_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QOpenGLDebugMessage::Source");
        Shiboken::Conversions::registerConverterAlias(converter, "Source");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QOpenGLDebugMessage_Source_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QOpenGLDebugMessage_Source,
            is_Enum_PythonToCpp_QOpenGLDebugMessage_Source_Convertible);
        // Register converter for flag 'QFlags<QOpenGLDebugMessage::Source>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QOpenGLDebugMessage::Source>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QOpenGLDebugMessage::Sources");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'Source' enum/flags.

    // Initialization of enum 'Type'.
    const char *Type_Initializer[] = {
        "InvalidType",
        "ErrorType",
        "DeprecatedBehaviorType",
        "UndefinedBehaviorType",
        "PortabilityType",
        "PerformanceType",
        "OtherType",
        "MarkerType",
        "GroupPushType",
        "GroupPopType",
        "LastType",
        "AnyType",
        nullptr};
    // "uint32_t" used instead of "unsigned int"
    constexpr uint32_t Type_InitializerValues[] = {
        uint32_t(QOpenGLDebugMessage::Type::InvalidType),            //  0x00000000  0
        uint32_t(QOpenGLDebugMessage::Type::ErrorType),              //  0x00000001  1
        uint32_t(QOpenGLDebugMessage::Type::DeprecatedBehaviorType), //  0x00000002  2
        uint32_t(QOpenGLDebugMessage::Type::UndefinedBehaviorType),  //  0x00000004  4
        uint32_t(QOpenGLDebugMessage::Type::PortabilityType),        //  0x00000008  8
        uint32_t(QOpenGLDebugMessage::Type::PerformanceType),        //  0x00000010  16
        uint32_t(QOpenGLDebugMessage::Type::OtherType),              //  0x00000020  32
        uint32_t(QOpenGLDebugMessage::Type::MarkerType),             //  0x00000040  64
        uint32_t(QOpenGLDebugMessage::Type::GroupPushType),          //  0x00000080  128
        uint32_t(QOpenGLDebugMessage::Type::GroupPopType),           //  0x00000100  256
        uint32_t(QOpenGLDebugMessage::Type::LastType),               //  0x00000100  256
        uint32_t(QOpenGLDebugMessage::Type::AnyType)                 //  0xffffffff  4294967295
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QOpenGLDebugMessage_TypeF(),
        "2:PySide6.QtOpenGL.QOpenGLDebugMessage.Type",
        Type_Initializer, Type_InitializerValues);
    SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_Type_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtOpenGLTypeStructs[SBK_QFlags_QOpenGLDebugMessage_Type_IDX].type =
        EType;
    // Register converter for enum 'QOpenGLDebugMessage::Type'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QOpenGLDebugMessage_Type_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QOpenGLDebugMessage_Type,
            is_Enum_PythonToCpp_QOpenGLDebugMessage_Type_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QOpenGLDebugMessage::Type");
        Shiboken::Conversions::registerConverterAlias(converter, "Type");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QOpenGLDebugMessage_Type_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QOpenGLDebugMessage_Type,
            is_Enum_PythonToCpp_QOpenGLDebugMessage_Type_Convertible);
        // Register converter for flag 'QFlags<QOpenGLDebugMessage::Type>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QOpenGLDebugMessage::Type>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QOpenGLDebugMessage::Types");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'Type' enum/flags.

    // Initialization of enum 'Severity'.
    const char *Severity_Initializer[] = {
        "InvalidSeverity",
        "HighSeverity",
        "MediumSeverity",
        "LowSeverity",
        "NotificationSeverity",
        "LastSeverity",
        "AnySeverity",
        nullptr};
    // "uint32_t" used instead of "unsigned int"
    constexpr uint32_t Severity_InitializerValues[] = {
        uint32_t(QOpenGLDebugMessage::Severity::InvalidSeverity),      //  0x00000000  0
        uint32_t(QOpenGLDebugMessage::Severity::HighSeverity),         //  0x00000001  1
        uint32_t(QOpenGLDebugMessage::Severity::MediumSeverity),       //  0x00000002  2
        uint32_t(QOpenGLDebugMessage::Severity::LowSeverity),          //  0x00000004  4
        uint32_t(QOpenGLDebugMessage::Severity::NotificationSeverity), //  0x00000008  8
        uint32_t(QOpenGLDebugMessage::Severity::LastSeverity),         //  0x00000008  8
        uint32_t(QOpenGLDebugMessage::Severity::AnySeverity)           //  0xffffffff  4294967295
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QOpenGLDebugMessage_TypeF(),
        "2:PySide6.QtOpenGL.QOpenGLDebugMessage.Severity",
        Severity_Initializer, Severity_InitializerValues);
    SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLDebugMessage_Severity_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtOpenGLTypeStructs[SBK_QFlags_QOpenGLDebugMessage_Severity_IDX].type =
        EType;
    // Register converter for enum 'QOpenGLDebugMessage::Severity'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QOpenGLDebugMessage_Severity_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QOpenGLDebugMessage_Severity,
            is_Enum_PythonToCpp_QOpenGLDebugMessage_Severity_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QOpenGLDebugMessage::Severity");
        Shiboken::Conversions::registerConverterAlias(converter, "Severity");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QOpenGLDebugMessage_Severity_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QOpenGLDebugMessage_Severity,
            is_Enum_PythonToCpp_QOpenGLDebugMessage_Severity_Convertible);
        // Register converter for flag 'QFlags<QOpenGLDebugMessage::Severity>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QOpenGLDebugMessage::Severity>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QOpenGLDebugMessage::Severities");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'Severity' enum/flags.

    qRegisterMetaType< ::QOpenGLDebugMessage >("QOpenGLDebugMessage");
    qRegisterMetaType< ::QOpenGLDebugMessage::Source >("QOpenGLDebugMessage::Source");
    qRegisterMetaType< ::QOpenGLDebugMessage::Type >("QOpenGLDebugMessage::Type");
    qRegisterMetaType< ::QOpenGLDebugMessage::Severity >("QOpenGLDebugMessage::Severity");

    return pyType;
}
