// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtopengl_python.h"

// main header
#include "qopenglframebufferobject_wrapper.h"

// Argument includes
#include <QList>
#include <QtGui/qimage.h>
#include <QtOpenGL/qopenglframebufferobject.h>
#include <qrect.h>
#include <qsize.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

QOpenGLFramebufferObjectWrapper::QOpenGLFramebufferObjectWrapper(const ::QSize & size, ::QOpenGLFramebufferObject::Attachment attachment, unsigned int target, unsigned int internalFormat) : QOpenGLFramebufferObject(size, attachment, target, internalFormat)
{
}

QOpenGLFramebufferObjectWrapper::QOpenGLFramebufferObjectWrapper(const ::QSize & size, const ::QOpenGLFramebufferObjectFormat & format) : QOpenGLFramebufferObject(size, format)
{
}

QOpenGLFramebufferObjectWrapper::QOpenGLFramebufferObjectWrapper(const ::QSize & size, unsigned int target) : QOpenGLFramebufferObject(size, target)
{
}

QOpenGLFramebufferObjectWrapper::QOpenGLFramebufferObjectWrapper(int width, int height, ::QOpenGLFramebufferObject::Attachment attachment, unsigned int target, unsigned int internalFormat) : QOpenGLFramebufferObject(width, height, attachment, target, internalFormat)
{
}

QOpenGLFramebufferObjectWrapper::QOpenGLFramebufferObjectWrapper(int width, int height, const ::QOpenGLFramebufferObjectFormat & format) : QOpenGLFramebufferObject(width, height, format)
{
}

QOpenGLFramebufferObjectWrapper::QOpenGLFramebufferObjectWrapper(int width, int height, unsigned int target) : QOpenGLFramebufferObject(width, height, target)
{
}

QOpenGLFramebufferObjectWrapper::~QOpenGLFramebufferObjectWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QOpenGLFramebufferObject_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QOpenGLFramebufferObject >()))
        return -1;

    QOpenGLFramebufferObjectWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOO:QOpenGLFramebufferObject", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QOpenGLFramebufferObject::QOpenGLFramebufferObject(QSize,QOpenGLFramebufferObject::Attachment,uint=,uint=)
    // 1: QOpenGLFramebufferObject::QOpenGLFramebufferObject(QSize,QOpenGLFramebufferObjectFormat)
    // 2: QOpenGLFramebufferObject::QOpenGLFramebufferObject(QSize,uint=)
    // 3: QOpenGLFramebufferObject::QOpenGLFramebufferObject(int,int,QOpenGLFramebufferObject::Attachment,uint=,uint=)
    // 4: QOpenGLFramebufferObject::QOpenGLFramebufferObject(int,int,QOpenGLFramebufferObjectFormat)
    // 5: QOpenGLFramebufferObject::QOpenGLFramebufferObject(int,int,uint=)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 5; // QOpenGLFramebufferObject(int,int,uint)
        } else if (numArgs == 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObjectFormat_IDX]), (pyArgs[2])))) {
            overloadId = 4; // QOpenGLFramebufferObject(int,int,QOpenGLFramebufferObjectFormat)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_Attachment_IDX])))->converter, (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 3; // QOpenGLFramebufferObject(int,int,QOpenGLFramebufferObject::Attachment,uint,uint)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[3])))) {
                if (numArgs == 4) {
                    overloadId = 3; // QOpenGLFramebufferObject(int,int,QOpenGLFramebufferObject::Attachment,uint,uint)
                } else if (numArgs >= 5
                    && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[4])))) {
                    overloadId = 3; // QOpenGLFramebufferObject(int,int,QOpenGLFramebufferObject::Attachment,uint,uint)
                }
            }
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[2])))) {
            overloadId = 5; // QOpenGLFramebufferObject(int,int,uint)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 2; // QOpenGLFramebufferObject(QSize,uint)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObjectFormat_IDX]), (pyArgs[1])))) {
            overloadId = 1; // QOpenGLFramebufferObject(QSize,QOpenGLFramebufferObjectFormat)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_Attachment_IDX])))->converter, (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // QOpenGLFramebufferObject(QSize,QOpenGLFramebufferObject::Attachment,uint,uint)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // QOpenGLFramebufferObject(QSize,QOpenGLFramebufferObject::Attachment,uint,uint)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[3])))) {
                    overloadId = 0; // QOpenGLFramebufferObject(QSize,QOpenGLFramebufferObject::Attachment,uint,uint)
                }
            }
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))) {
            overloadId = 2; // QOpenGLFramebufferObject(QSize,uint)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QOpenGLFramebufferObject(const QSize &size, QOpenGLFramebufferObject::Attachment attachment, unsigned int target, unsigned int internalFormat)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_target = Shiboken::String::createStaticString("target");
                if (PyDict_Contains(kwds, key_target) != 0) {
                    value = PyDict_GetItem(kwds, key_target);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_target);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_target);
                }
                static PyObject *const key_internalFormat = Shiboken::String::createStaticString("internalFormat");
                if (PyDict_Contains(kwds, key_internalFormat) != 0) {
                    value = PyDict_GetItem(kwds, key_internalFormat);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_internalFormat);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_internalFormat);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QSize cppArg0_local;
            ::QSize *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QOpenGLFramebufferObject::Attachment cppArg1{QOpenGLFramebufferObject::NoAttachment};
            pythonToCpp[1](pyArgs[1], &cppArg1);
            unsigned int cppArg2 = GL_TEXTURE_2D;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            unsigned int cppArg3 = 0;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QOpenGLFramebufferObject(QSize,QOpenGLFramebufferObject::Attachment,uint,uint)
                cptr = new QOpenGLFramebufferObjectWrapper(*cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
        case 1: // QOpenGLFramebufferObject(const QSize &size, const QOpenGLFramebufferObjectFormat &format)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QSize cppArg0_local;
            ::QSize *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QOpenGLFramebufferObjectFormat cppArg1_local;
            ::QOpenGLFramebufferObjectFormat *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QOpenGLFramebufferObject(QSize,QOpenGLFramebufferObjectFormat)
                cptr = new QOpenGLFramebufferObjectWrapper(*cppArg0, *cppArg1);
            }
            break;
        }
        case 2: // QOpenGLFramebufferObject(const QSize &size, unsigned int target)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_target = Shiboken::String::createStaticString("target");
                if (PyDict_Contains(kwds, key_target) != 0) {
                    value = PyDict_GetItem(kwds, key_target);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_target);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_target);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QSize cppArg0_local;
            ::QSize *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            unsigned int cppArg1 = GL_TEXTURE_2D;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QOpenGLFramebufferObject(QSize,uint)
                cptr = new QOpenGLFramebufferObjectWrapper(*cppArg0, cppArg1);
            }
            break;
        }
        case 3: // QOpenGLFramebufferObject(int width, int height, QOpenGLFramebufferObject::Attachment attachment, unsigned int target, unsigned int internalFormat)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_target = Shiboken::String::createStaticString("target");
                if (PyDict_Contains(kwds, key_target) != 0) {
                    value = PyDict_GetItem(kwds, key_target);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_target);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_target);
                }
                static PyObject *const key_internalFormat = Shiboken::String::createStaticString("internalFormat");
                if (PyDict_Contains(kwds, key_internalFormat) != 0) {
                    value = PyDict_GetItem(kwds, key_internalFormat);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_internalFormat);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_internalFormat);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);
                }
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QOpenGLFramebufferObject::Attachment cppArg2{QOpenGLFramebufferObject::NoAttachment};
            pythonToCpp[2](pyArgs[2], &cppArg2);
            unsigned int cppArg3 = GL_TEXTURE_2D;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            unsigned int cppArg4 = 0;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QOpenGLFramebufferObject(int,int,QOpenGLFramebufferObject::Attachment,uint,uint)
                cptr = new QOpenGLFramebufferObjectWrapper(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            }
            break;
        }
        case 4: // QOpenGLFramebufferObject(int width, int height, const QOpenGLFramebufferObjectFormat &format)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return -1;
            ::QOpenGLFramebufferObjectFormat cppArg2_local;
            ::QOpenGLFramebufferObjectFormat *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QOpenGLFramebufferObject(int,int,QOpenGLFramebufferObjectFormat)
                cptr = new QOpenGLFramebufferObjectWrapper(cppArg0, cppArg1, *cppArg2);
            }
            break;
        }
        case 5: // QOpenGLFramebufferObject(int width, int height, unsigned int target)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_target = Shiboken::String::createStaticString("target");
                if (PyDict_Contains(kwds, key_target) != 0) {
                    value = PyDict_GetItem(kwds, key_target);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_target);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_target);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);
                }
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            unsigned int cppArg2 = GL_TEXTURE_2D;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QOpenGLFramebufferObject(int,int,uint)
                cptr = new QOpenGLFramebufferObjectWrapper(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QOpenGLFramebufferObject >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QOpenGLFramebufferObjectFunc_addColorAttachment(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFramebufferObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "addColorAttachment", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:addColorAttachment", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFramebufferObject::addColorAttachment(QSize,uint=)
    // 1: QOpenGLFramebufferObject::addColorAttachment(int,int,uint=)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 1; // addColorAttachment(int,int,uint)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[2])))) {
            overloadId = 1; // addColorAttachment(int,int,uint)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // addColorAttachment(QSize,uint)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))) {
            overloadId = 0; // addColorAttachment(QSize,uint)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addColorAttachment", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // addColorAttachment(const QSize &size, unsigned int internalFormat)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_internalFormat = Shiboken::String::createStaticString("internalFormat");
                if (PyDict_Contains(kwds, key_internalFormat) != 0) {
                    value = PyDict_GetItem(kwds, key_internalFormat);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_internalFormat);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "addColorAttachment", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "addColorAttachment", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_internalFormat);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "addColorAttachment", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QSize cppArg0_local;
            ::QSize *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            unsigned int cppArg1 = 0;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // addColorAttachment(QSize,uint)
                cppSelf->addColorAttachment(*cppArg0, cppArg1);
            }
            break;
        }
        case 1: // addColorAttachment(int width, int height, unsigned int internalFormat)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_internalFormat = Shiboken::String::createStaticString("internalFormat");
                if (PyDict_Contains(kwds, key_internalFormat) != 0) {
                    value = PyDict_GetItem(kwds, key_internalFormat);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_internalFormat);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "addColorAttachment", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "addColorAttachment", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_internalFormat);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "addColorAttachment", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);
                }
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            unsigned int cppArg2 = 0;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // addColorAttachment(int,int,uint)
                cppSelf->addColorAttachment(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFramebufferObjectFunc_attachment(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFramebufferObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // attachment()const
        QOpenGLFramebufferObject::Attachment cppResult = const_cast<const ::QOpenGLFramebufferObject *>(cppSelf)->attachment();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_Attachment_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLFramebufferObjectFunc_bind(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFramebufferObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // bind()
        bool cppResult = cppSelf->bind();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLFramebufferObjectFunc_bindDefault(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // bindDefault()
        bool cppResult = ::QOpenGLFramebufferObject::bindDefault();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLFramebufferObjectFunc_blitFramebuffer(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[9];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 9));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "blitFramebuffer", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);
    if (numArgs == 7)
        return Shiboken::returnWrongArguments(args, "blitFramebuffer", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOOOOOO:blitFramebuffer", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7]), &(pyArgs[8])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QOpenGLFramebufferObject::blitFramebuffer(QOpenGLFramebufferObject*,QOpenGLFramebufferObject*,uint=,uint=)
    // 1: static QOpenGLFramebufferObject::blitFramebuffer(QOpenGLFramebufferObject*,QRect,QOpenGLFramebufferObject*,QRect,uint=,uint=)
    // 2: static QOpenGLFramebufferObject::blitFramebuffer(QOpenGLFramebufferObject*,QRect,QOpenGLFramebufferObject*,QRect,uint,uint,int,int)
    // 3: static QOpenGLFramebufferObject::blitFramebuffer(QOpenGLFramebufferObject*,QRect,QOpenGLFramebufferObject*,QRect,uint,uint,int,int,QOpenGLFramebufferObject::FramebufferRestorePolicy)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]), (pyArgs[0])))) {
        if (numArgs >= 4
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]), (pyArgs[2])))
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[3])))) {
            if (numArgs == 4) {
                overloadId = 1; // blitFramebuffer(QOpenGLFramebufferObject*,QRect,QOpenGLFramebufferObject*,QRect,uint,uint)
            } else if (numArgs >= 5
                && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[4])))) {
                if (numArgs == 5) {
                    overloadId = 1; // blitFramebuffer(QOpenGLFramebufferObject*,QRect,QOpenGLFramebufferObject*,QRect,uint,uint)
                } else if (numArgs >= 6
                    && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[5])))) {
                    if (numArgs == 6) {
                        overloadId = 1; // blitFramebuffer(QOpenGLFramebufferObject*,QRect,QOpenGLFramebufferObject*,QRect,uint,uint)
                    } else if (numArgs >= 8
                        && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[6])))
                        && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[7])))) {
                        if (numArgs == 8) {
                            overloadId = 2; // blitFramebuffer(QOpenGLFramebufferObject*,QRect,QOpenGLFramebufferObject*,QRect,uint,uint,int,int)
                        } else if (numArgs == 9
                            && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_FramebufferRestorePolicy_IDX])))->converter, (pyArgs[8])))) {
                            overloadId = 3; // blitFramebuffer(QOpenGLFramebufferObject*,QRect,QOpenGLFramebufferObject*,QRect,uint,uint,int,int,QOpenGLFramebufferObject::FramebufferRestorePolicy)
                        }
                    }
                }
            }
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // blitFramebuffer(QOpenGLFramebufferObject*,QOpenGLFramebufferObject*,uint,uint)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // blitFramebuffer(QOpenGLFramebufferObject*,QOpenGLFramebufferObject*,uint,uint)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[3])))) {
                    overloadId = 0; // blitFramebuffer(QOpenGLFramebufferObject*,QOpenGLFramebufferObject*,uint,uint)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "blitFramebuffer", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // blitFramebuffer(QOpenGLFramebufferObject *target, QOpenGLFramebufferObject *source, unsigned int buffers, unsigned int filter)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_buffers = Shiboken::String::createStaticString("buffers");
                if (PyDict_Contains(kwds, key_buffers) != 0) {
                    value = PyDict_GetItem(kwds, key_buffers);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_buffers);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "blitFramebuffer", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "blitFramebuffer", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_buffers);
                }
                static PyObject *const key_filter = Shiboken::String::createStaticString("filter");
                if (PyDict_Contains(kwds, key_filter) != 0) {
                    value = PyDict_GetItem(kwds, key_filter);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_filter);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "blitFramebuffer", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "blitFramebuffer", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_filter);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "blitFramebuffer", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QOpenGLFramebufferObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QOpenGLFramebufferObject *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            unsigned int cppArg2 = GL_COLOR_BUFFER_BIT;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            unsigned int cppArg3 = GL_NEAREST;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // blitFramebuffer(QOpenGLFramebufferObject*,QOpenGLFramebufferObject*,uint,uint)
                ::QOpenGLFramebufferObject::blitFramebuffer(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
        case 1: // blitFramebuffer(QOpenGLFramebufferObject *target, const QRect &targetRect, QOpenGLFramebufferObject *source, const QRect &sourceRect, unsigned int buffers, unsigned int filter)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_buffers = Shiboken::String::createStaticString("buffers");
                if (PyDict_Contains(kwds, key_buffers) != 0) {
                    value = PyDict_GetItem(kwds, key_buffers);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_buffers);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "blitFramebuffer", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, "blitFramebuffer", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_buffers);
                }
                static PyObject *const key_filter = Shiboken::String::createStaticString("filter");
                if (PyDict_Contains(kwds, key_filter) != 0) {
                    value = PyDict_GetItem(kwds, key_filter);
                    if (value != nullptr && pyArgs[5] != nullptr ) {
                        errInfo.reset(key_filter);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "blitFramebuffer", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[5] = value;
                        if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[5]))))
                            return Shiboken::returnWrongArguments(args, "blitFramebuffer", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_filter);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "blitFramebuffer", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QOpenGLFramebufferObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QRect cppArg1_local;
            ::QRect *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QOpenGLFramebufferObject *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QRect cppArg3_local;
            ::QRect *cppArg3 = &cppArg3_local;
            if (pythonToCpp[3].isValue())
                pythonToCpp[3](pyArgs[3], &cppArg3_local);
            else
                pythonToCpp[3](pyArgs[3], &cppArg3);

            unsigned int cppArg4 = GL_COLOR_BUFFER_BIT;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);
            unsigned int cppArg5 = GL_NEAREST;
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);

            if (Shiboken::Errors::occurred() == nullptr) {
                // blitFramebuffer(QOpenGLFramebufferObject*,QRect,QOpenGLFramebufferObject*,QRect,uint,uint)
                ::QOpenGLFramebufferObject::blitFramebuffer(cppArg0, *cppArg1, cppArg2, *cppArg3, cppArg4, cppArg5);
            }
            break;
        }
        case 2: // blitFramebuffer(QOpenGLFramebufferObject *target, const QRect &targetRect, QOpenGLFramebufferObject *source, const QRect &sourceRect, unsigned int buffers, unsigned int filter, int readColorAttachmentIndex, int drawColorAttachmentIndex)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "blitFramebuffer", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QOpenGLFramebufferObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QRect cppArg1_local;
            ::QRect *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QOpenGLFramebufferObject *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QRect cppArg3_local;
            ::QRect *cppArg3 = &cppArg3_local;
            if (pythonToCpp[3].isValue())
                pythonToCpp[3](pyArgs[3], &cppArg3_local);
            else
                pythonToCpp[3](pyArgs[3], &cppArg3);

            unsigned int cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            unsigned int cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);
            int cppArg6;
            pythonToCpp[6](pyArgs[6], &cppArg6);
            int cppArg7;
            pythonToCpp[7](pyArgs[7], &cppArg7);

            if (Shiboken::Errors::occurred() == nullptr) {
                // blitFramebuffer(QOpenGLFramebufferObject*,QRect,QOpenGLFramebufferObject*,QRect,uint,uint,int,int)
                ::QOpenGLFramebufferObject::blitFramebuffer(cppArg0, *cppArg1, cppArg2, *cppArg3, cppArg4, cppArg5, cppArg6, cppArg7);
            }
            break;
        }
        case 3: // blitFramebuffer(QOpenGLFramebufferObject *target, const QRect &targetRect, QOpenGLFramebufferObject *source, const QRect &sourceRect, unsigned int buffers, unsigned int filter, int readColorAttachmentIndex, int drawColorAttachmentIndex, QOpenGLFramebufferObject::FramebufferRestorePolicy restorePolicy)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "blitFramebuffer", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QOpenGLFramebufferObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QRect cppArg1_local;
            ::QRect *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QOpenGLFramebufferObject *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QRect cppArg3_local;
            ::QRect *cppArg3 = &cppArg3_local;
            if (pythonToCpp[3].isValue())
                pythonToCpp[3](pyArgs[3], &cppArg3_local);
            else
                pythonToCpp[3](pyArgs[3], &cppArg3);

            unsigned int cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            unsigned int cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);
            int cppArg6;
            pythonToCpp[6](pyArgs[6], &cppArg6);
            int cppArg7;
            pythonToCpp[7](pyArgs[7], &cppArg7);
            ::QOpenGLFramebufferObject::FramebufferRestorePolicy cppArg8{QOpenGLFramebufferObject::DontRestoreFramebufferBinding};
            pythonToCpp[8](pyArgs[8], &cppArg8);

            if (Shiboken::Errors::occurred() == nullptr) {
                // blitFramebuffer(QOpenGLFramebufferObject*,QRect,QOpenGLFramebufferObject*,QRect,uint,uint,int,int,QOpenGLFramebufferObject::FramebufferRestorePolicy)
                ::QOpenGLFramebufferObject::blitFramebuffer(cppArg0, *cppArg1, cppArg2, *cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFramebufferObjectFunc_format(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFramebufferObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // format()const
        QOpenGLFramebufferObjectFormat cppResult = const_cast<const ::QOpenGLFramebufferObject *>(cppSelf)->format();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObjectFormat_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLFramebufferObjectFunc_handle(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFramebufferObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // handle()const
        unsigned int cppResult = const_cast<const ::QOpenGLFramebufferObject *>(cppSelf)->handle();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLFramebufferObjectFunc_hasOpenGLFramebufferBlit(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hasOpenGLFramebufferBlit()
        bool cppResult = ::QOpenGLFramebufferObject::hasOpenGLFramebufferBlit();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLFramebufferObjectFunc_hasOpenGLFramebufferObjects(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hasOpenGLFramebufferObjects()
        bool cppResult = ::QOpenGLFramebufferObject::hasOpenGLFramebufferObjects();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLFramebufferObjectFunc_height(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFramebufferObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // height()const
        int cppResult = const_cast<const ::QOpenGLFramebufferObject *>(cppSelf)->height();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLFramebufferObjectFunc_isBound(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFramebufferObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isBound()const
        bool cppResult = const_cast<const ::QOpenGLFramebufferObject *>(cppSelf)->isBound();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLFramebufferObjectFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFramebufferObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QOpenGLFramebufferObject *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLFramebufferObjectFunc_release(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFramebufferObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // release()
        bool cppResult = cppSelf->release();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLFramebufferObjectFunc_setAttachment(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFramebufferObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFramebufferObject::setAttachment(QOpenGLFramebufferObject::Attachment)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_Attachment_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setAttachment(QOpenGLFramebufferObject::Attachment)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAttachment", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);

    // Call function/method
    {
        ::QOpenGLFramebufferObject::Attachment cppArg0{QOpenGLFramebufferObject::NoAttachment};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAttachment(QOpenGLFramebufferObject::Attachment)
            cppSelf->setAttachment(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFramebufferObjectFunc_size(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFramebufferObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // size()const
        QSize cppResult = const_cast<const ::QOpenGLFramebufferObject *>(cppSelf)->size();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLFramebufferObjectFunc_sizes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFramebufferObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sizes()const
        QList<QSize> cppResult = const_cast<const ::QOpenGLFramebufferObject *>(cppSelf)->sizes();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtOpenGLTypeConverters[SBK_QtOpenGL_QList_QSize_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLFramebufferObjectFunc_takeTexture(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFramebufferObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "takeTexture", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFramebufferObject::takeTexture()->unsigned int
    // 1: QOpenGLFramebufferObject::takeTexture(int)->unsigned int
    if (numArgs == 0) {
        overloadId = 0; // takeTexture()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 1; // takeTexture(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "takeTexture", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // takeTexture()
        {

            // takeTexture()
            unsigned int cppResult = cppSelf->takeTexture();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), &cppResult);
            break;
        }
        case 1: // takeTexture(int colorAttachmentIndex)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // takeTexture(int)
                unsigned int cppResult = cppSelf->takeTexture(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLFramebufferObjectFunc_texture(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFramebufferObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // texture()const
        unsigned int cppResult = const_cast<const ::QOpenGLFramebufferObject *>(cppSelf)->texture();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLFramebufferObjectFunc_textures(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFramebufferObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // textures()const
        QList<unsigned int> cppResult = const_cast<const ::QOpenGLFramebufferObject *>(cppSelf)->textures();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtOpenGLTypeConverters[SBK_QtOpenGL_QList_unsignedint_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLFramebufferObjectFunc_toImage(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFramebufferObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "toImage", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);

    if (PyArg_ParseTuple(args, "|OO:toImage", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFramebufferObject::toImage(bool=)const->QImage
    // 1: QOpenGLFramebufferObject::toImage(bool,int)const->QImage
    if (numArgs == 0) {
        overloadId = 0; // toImage(bool)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // toImage(bool)const
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 1; // toImage(bool,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "toImage", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // toImage(bool flipped) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_flipped = Shiboken::String::createStaticString("flipped");
                if (PyDict_Contains(kwds, key_flipped) != 0) {
                    value = PyDict_GetItem(kwds, key_flipped);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_flipped);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "toImage", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments(args, "toImage", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_flipped);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "toImage", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);
                }
            }
            bool cppArg0 = true;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // toImage(bool)const
                QImage cppResult = const_cast<const ::QOpenGLFramebufferObject *>(cppSelf)->toImage(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImage_IDX]), &cppResult);
            }
            break;
        }
        case 1: // toImage(bool flipped, int colorAttachmentIndex) const
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "toImage", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]);
            }
            bool cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // toImage(bool,int)const
                QImage cppResult = const_cast<const ::QOpenGLFramebufferObject *>(cppSelf)->toImage(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImage_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLFramebufferObjectFunc_width(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFramebufferObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // width()const
        int cppResult = const_cast<const ::QOpenGLFramebufferObject *>(cppSelf)->width();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QOpenGLFramebufferObject_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QOpenGLFramebufferObject_EnumFlagInfo[] = {
    "Attachment:Enum",
    "FramebufferRestorePolicy:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QOpenGLFramebufferObject_methods[] = {
    {"addColorAttachment", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFramebufferObjectFunc_addColorAttachment), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"attachment", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFramebufferObjectFunc_attachment), METH_NOARGS, nullptr},
    {"bind", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFramebufferObjectFunc_bind), METH_NOARGS, nullptr},
    {"bindDefault", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFramebufferObjectFunc_bindDefault), METH_NOARGS|METH_STATIC, nullptr},
    {"blitFramebuffer", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFramebufferObjectFunc_blitFramebuffer), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"format", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFramebufferObjectFunc_format), METH_NOARGS, nullptr},
    {"handle", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFramebufferObjectFunc_handle), METH_NOARGS, nullptr},
    {"hasOpenGLFramebufferBlit", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFramebufferObjectFunc_hasOpenGLFramebufferBlit), METH_NOARGS|METH_STATIC, nullptr},
    {"hasOpenGLFramebufferObjects", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFramebufferObjectFunc_hasOpenGLFramebufferObjects), METH_NOARGS|METH_STATIC, nullptr},
    {"height", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFramebufferObjectFunc_height), METH_NOARGS, nullptr},
    {"isBound", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFramebufferObjectFunc_isBound), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFramebufferObjectFunc_isValid), METH_NOARGS, nullptr},
    {"release", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFramebufferObjectFunc_release), METH_NOARGS, nullptr},
    {"setAttachment", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFramebufferObjectFunc_setAttachment), METH_O, nullptr},
    {"size", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFramebufferObjectFunc_size), METH_NOARGS, nullptr},
    {"sizes", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFramebufferObjectFunc_sizes), METH_NOARGS, nullptr},
    {"takeTexture", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFramebufferObjectFunc_takeTexture), METH_VARARGS, nullptr},
    {"texture", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFramebufferObjectFunc_texture), METH_NOARGS, nullptr},
    {"textures", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFramebufferObjectFunc_textures), METH_NOARGS, nullptr},
    {"toImage", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFramebufferObjectFunc_toImage), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"width", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFramebufferObjectFunc_width), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QOpenGLFramebufferObject_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QOpenGLFramebufferObject_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QOpenGLFramebufferObject_Type = nullptr;
static PyTypeObject *Sbk_QOpenGLFramebufferObject_TypeF(void)
{
    return _Sbk_QOpenGLFramebufferObject_Type;
}

static PyType_Slot Sbk_QOpenGLFramebufferObject_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QOpenGLFramebufferObject_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QOpenGLFramebufferObject_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QOpenGLFramebufferObject_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QOpenGLFramebufferObject_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QOpenGLFramebufferObject_spec = {
    "2:PySide6.QtOpenGL.QOpenGLFramebufferObject",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QOpenGLFramebufferObject_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QOpenGLFramebufferObject_Attachment(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QOpenGLFramebufferObject::Attachment>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QOpenGLFramebufferObject::Attachment *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QOpenGLFramebufferObject_Attachment_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_Attachment_IDX])))
        return Enum_PythonToCpp_QOpenGLFramebufferObject_Attachment;
    return {};
}

static PyObject *QOpenGLFramebufferObject_Attachment_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QOpenGLFramebufferObject::Attachment>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QOpenGLFramebufferObject::Attachment *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_Attachment_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QOpenGLFramebufferObject_FramebufferRestorePolicy(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QOpenGLFramebufferObject::FramebufferRestorePolicy>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QOpenGLFramebufferObject::FramebufferRestorePolicy *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QOpenGLFramebufferObject_FramebufferRestorePolicy_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_FramebufferRestorePolicy_IDX])))
        return Enum_PythonToCpp_QOpenGLFramebufferObject_FramebufferRestorePolicy;
    return {};
}

static PyObject *QOpenGLFramebufferObject_FramebufferRestorePolicy_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QOpenGLFramebufferObject::FramebufferRestorePolicy>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QOpenGLFramebufferObject::FramebufferRestorePolicy *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_FramebufferRestorePolicy_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QOpenGLFramebufferObject_PythonToCpp_QOpenGLFramebufferObject_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QOpenGLFramebufferObject_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QOpenGLFramebufferObject_PythonToCpp_QOpenGLFramebufferObject_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QOpenGLFramebufferObject_TypeF()))
        return QOpenGLFramebufferObject_PythonToCpp_QOpenGLFramebufferObject_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QOpenGLFramebufferObject_PTR_CppToPython_QOpenGLFramebufferObject(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QOpenGLFramebufferObject *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QOpenGLFramebufferObject_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QOpenGLFramebufferObject_SignatureStrings[] = {
    "5:PySide6.QtOpenGL.QOpenGLFramebufferObject(self,size:PySide6.QtCore.QSize,attachment:PySide6.QtOpenGL.QOpenGLFramebufferObject.Attachment,target:unsigned int=GL_TEXTURE_2D,internalFormat:unsigned int=0)",
    "4:PySide6.QtOpenGL.QOpenGLFramebufferObject(self,size:PySide6.QtCore.QSize,format:PySide6.QtOpenGL.QOpenGLFramebufferObjectFormat)",
    "3:PySide6.QtOpenGL.QOpenGLFramebufferObject(self,size:PySide6.QtCore.QSize,target:unsigned int=GL_TEXTURE_2D)",
    "2:PySide6.QtOpenGL.QOpenGLFramebufferObject(self,width:int,height:int,attachment:PySide6.QtOpenGL.QOpenGLFramebufferObject.Attachment,target:unsigned int=GL_TEXTURE_2D,internalFormat:unsigned int=0)",
    "1:PySide6.QtOpenGL.QOpenGLFramebufferObject(self,width:int,height:int,format:PySide6.QtOpenGL.QOpenGLFramebufferObjectFormat)",
    "0:PySide6.QtOpenGL.QOpenGLFramebufferObject(self,width:int,height:int,target:unsigned int=GL_TEXTURE_2D)",
    "1:PySide6.QtOpenGL.QOpenGLFramebufferObject.addColorAttachment(self,size:PySide6.QtCore.QSize,internalFormat:unsigned int=0)",
    "0:PySide6.QtOpenGL.QOpenGLFramebufferObject.addColorAttachment(self,width:int,height:int,internalFormat:unsigned int=0)",
    "PySide6.QtOpenGL.QOpenGLFramebufferObject.attachment(self)->PySide6.QtOpenGL.QOpenGLFramebufferObject.Attachment",
    "PySide6.QtOpenGL.QOpenGLFramebufferObject.bind(self)->bool",
    "PySide6.QtOpenGL.QOpenGLFramebufferObject.bindDefault()->bool",
    "3:PySide6.QtOpenGL.QOpenGLFramebufferObject.blitFramebuffer(target:PySide6.QtOpenGL.QOpenGLFramebufferObject,source:PySide6.QtOpenGL.QOpenGLFramebufferObject,buffers:unsigned int=GL_COLOR_BUFFER_BIT,filter:unsigned int=GL_NEAREST)",
    "2:PySide6.QtOpenGL.QOpenGLFramebufferObject.blitFramebuffer(target:PySide6.QtOpenGL.QOpenGLFramebufferObject,targetRect:PySide6.QtCore.QRect,source:PySide6.QtOpenGL.QOpenGLFramebufferObject,sourceRect:PySide6.QtCore.QRect,buffers:unsigned int=GL_COLOR_BUFFER_BIT,filter:unsigned int=GL_NEAREST)",
    "1:PySide6.QtOpenGL.QOpenGLFramebufferObject.blitFramebuffer(target:PySide6.QtOpenGL.QOpenGLFramebufferObject,targetRect:PySide6.QtCore.QRect,source:PySide6.QtOpenGL.QOpenGLFramebufferObject,sourceRect:PySide6.QtCore.QRect,buffers:unsigned int,filter:unsigned int,readColorAttachmentIndex:int,drawColorAttachmentIndex:int)",
    "0:PySide6.QtOpenGL.QOpenGLFramebufferObject.blitFramebuffer(target:PySide6.QtOpenGL.QOpenGLFramebufferObject,targetRect:PySide6.QtCore.QRect,source:PySide6.QtOpenGL.QOpenGLFramebufferObject,sourceRect:PySide6.QtCore.QRect,buffers:unsigned int,filter:unsigned int,readColorAttachmentIndex:int,drawColorAttachmentIndex:int,restorePolicy:PySide6.QtOpenGL.QOpenGLFramebufferObject.FramebufferRestorePolicy)",
    "PySide6.QtOpenGL.QOpenGLFramebufferObject.format(self)->PySide6.QtOpenGL.QOpenGLFramebufferObjectFormat",
    "PySide6.QtOpenGL.QOpenGLFramebufferObject.handle(self)->unsigned int",
    "PySide6.QtOpenGL.QOpenGLFramebufferObject.hasOpenGLFramebufferBlit()->bool",
    "PySide6.QtOpenGL.QOpenGLFramebufferObject.hasOpenGLFramebufferObjects()->bool",
    "PySide6.QtOpenGL.QOpenGLFramebufferObject.height(self)->int",
    "PySide6.QtOpenGL.QOpenGLFramebufferObject.isBound(self)->bool",
    "PySide6.QtOpenGL.QOpenGLFramebufferObject.isValid(self)->bool",
    "PySide6.QtOpenGL.QOpenGLFramebufferObject.release(self)->bool",
    "PySide6.QtOpenGL.QOpenGLFramebufferObject.setAttachment(self,attachment:PySide6.QtOpenGL.QOpenGLFramebufferObject.Attachment)",
    "PySide6.QtOpenGL.QOpenGLFramebufferObject.size(self)->PySide6.QtCore.QSize",
    "PySide6.QtOpenGL.QOpenGLFramebufferObject.sizes(self)->QList[PySide6.QtCore.QSize]",
    "1:PySide6.QtOpenGL.QOpenGLFramebufferObject.takeTexture(self)->unsigned int",
    "0:PySide6.QtOpenGL.QOpenGLFramebufferObject.takeTexture(self,colorAttachmentIndex:int)->unsigned int",
    "PySide6.QtOpenGL.QOpenGLFramebufferObject.texture(self)->unsigned int",
    "PySide6.QtOpenGL.QOpenGLFramebufferObject.textures(self)->QList[unsigned int]",
    "1:PySide6.QtOpenGL.QOpenGLFramebufferObject.toImage(self,flipped:bool=true)->PySide6.QtGui.QImage",
    "0:PySide6.QtOpenGL.QOpenGLFramebufferObject.toImage(self,flipped:bool,colorAttachmentIndex:int)->PySide6.QtGui.QImage",
    "PySide6.QtOpenGL.QOpenGLFramebufferObject.width(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t QOpenGLFramebufferObject_SignatureByteSize = 553;
static constexpr uint8_t QOpenGLFramebufferObject_SignatureBytes[553] = {
    0x78, 0xda, 0xed, 0x56, 0xdf, 0x6f, 0x9b, 0x30, 0x10, 0x7e, 0xcf, 0x5f, 0xb1, 0xc7, 0x44, 0x62,
    0x28, 0xed, 0x7e, 0x3c, 0x44, 0xea, 0xa4, 0x26, 0x25, 0x51, 0xa4, 0x68, 0x29, 0x84, 0x4e, 0x95,
    0xaa, 0x29, 0x32, 0xf8, 0x08, 0xde, 0x1c, 0x3b, 0xb2, 0x8d, 0xda, 0xee, 0xaf, 0x1f, 0x85, 0xb2,
    0xd2, 0x40, 0x1a, 0x8e, 0x20, 0xed, 0x61, 0x7b, 0x02, 0x6c, 0xdf, 0xf7, 0xf9, 0xbe, 0x3b, 0xee,
    0xee, 0xd3, 0xe8, 0xfa, 0x71, 0xc5, 0x28, 0x7c, 0xb6, 0x5d, 0xb3, 0xdc, 0x81, 0x98, 0x2d, 0x6c,
    0x37, 0x7f, 0x4e, 0x15, 0xd9, 0x42, 0x90, 0x44, 0x11, 0xa8, 0x65, 0xf0, 0x03, 0x42, 0xd3, 0xd7,
    0xc0, 0x23, 0x4b, 0xb3, 0x5f, 0x50, 0xb2, 0x99, 0x48, 0x05, 0xb6, 0xbb, 0x4a, 0x17, 0x2d, 0x62,
    0x0c, 0x09, 0xe3, 0x2d, 0x08, 0xd3, 0x1c, 0xd3, 0xbe, 0xfc, 0x63, 0x64, 0x19, 0xa2, 0x36, 0x60,
    0x46, 0x89, 0xd0, 0x6c, 0x23, 0x80, 0xbe, 0x63, 0xc2, 0x5c, 0xcc, 0x16, 0x6b, 0xdf, 0xb9, 0xf5,
    0x6f, 0x3c, 0x67, 0x7d, 0x7e, 0x65, 0xa5, 0x2b, 0xa0, 0x04, 0xe1, 0x53, 0xa9, 0xb6, 0x64, 0xef,
    0xe4, 0x70, 0xd0, 0xfb, 0xd8, 0x9d, 0x2f, 0x51, 0xce, 0xd0, 0x18, 0x2f, 0xbf, 0xd1, 0xa0, 0xf7,
    0xa1, 0xbb, 0x2b, 0x1c, 0x95, 0x63, 0xd0, 0x3b, 0xc7, 0xb2, 0xdd, 0x33, 0x6a, 0xe2, 0x51, 0x8a,
    0x64, 0xc5, 0xc0, 0x36, 0xb1, 0xc9, 0x5e, 0xff, 0x7a, 0xdc, 0xce, 0x3a, 0x71, 0xa3, 0x6d, 0xc8,
    0x86, 0x9d, 0xb0, 0x37, 0x88, 0x16, 0xc2, 0x4d, 0x9b, 0x50, 0x3a, 0x91, 0x5c, 0xaa, 0x17, 0x99,
    0x8f, 0xa5, 0xcb, 0x11, 0x8d, 0x87, 0x1d, 0x90, 0xd7, 0x3a, 0x7e, 0x84, 0x17, 0xc1, 0xfa, 0x9a,
    0x6d, 0xf0, 0xfe, 0x4b, 0x9b, 0x6c, 0x44, 0x10, 0x06, 0x4c, 0xd0, 0x82, 0x2a, 0x90, 0x92, 0x23,
    0x4d, 0xaf, 0x20, 0x22, 0x09, 0x37, 0xfd, 0xc2, 0x1a, 0xf1, 0xeb, 0xdb, 0x01, 0x67, 0xa6, 0xb4,
    0xda, 0x7f, 0xce, 0x9e, 0xc6, 0x00, 0x96, 0x96, 0x89, 0x0a, 0x01, 0x61, 0x90, 0x7f, 0xe8, 0x4a,
    0x82, 0x4e, 0x96, 0x8b, 0xa5, 0xb7, 0x1e, 0xdf, 0x4c, 0xa7, 0x4e, 0xfa, 0x98, 0xfb, 0x56, 0xc4,
    0x78, 0x1a, 0xd0, 0xca, 0xb9, 0xaf, 0xce, 0xa5, 0xe7, 0xac, 0x7c, 0x54, 0xcd, 0x39, 0xdd, 0xcd,
    0xdc, 0xc0, 0x4b, 0x5f, 0x2b, 0x49, 0xef, 0xb5, 0x92, 0x21, 0x37, 0x38, 0x0c, 0xd8, 0x99, 0x4c,
    0x67, 0xff, 0x9c, 0x4c, 0x75, 0x92, 0x58, 0x0a, 0xc8, 0x7e, 0x2d, 0x99, 0x0b, 0x0a, 0x0f, 0x59,
    0xe9, 0xa0, 0x8a, 0xdc, 0x1f, 0xda, 0xc4, 0x55, 0xac, 0xff, 0x0a, 0xd6, 0x6c, 0x2a, 0xd0, 0x26,
    0x25, 0xbc, 0x96, 0x9c, 0x85, 0x8f, 0x08, 0x31, 0x4b, 0x2b, 0x5e, 0x19, 0x02, 0x53, 0xcc, 0xf3,
    0x66, 0x8c, 0x2e, 0xe4, 0x79, 0x13, 0x41, 0xf0, 0xc4, 0x44, 0x50, 0x0e, 0x05, 0x4f, 0x59, 0x38,
    0x14, 0x88, 0xae, 0x6c, 0x8d, 0xd3, 0x8c, 0xea, 0xe3, 0x1b, 0x43, 0x1d, 0x54, 0xbe, 0xa5, 0xdb,
    0xa0, 0x65, 0x6d, 0xb6, 0xf0, 0x0e, 0xe7, 0x14, 0xd3, 0x63, 0x99, 0xb4, 0x6e, 0x70, 0x4c, 0x7f,
    0x23, 0x9c, 0xb5, 0xb5, 0x56, 0xc0, 0x81, 0x68, 0x68, 0x69, 0xad, 0xc1, 0xec, 0x4f, 0x1e, 0x27,
    0x8e, 0xa8, 0x98, 0xcc, 0x7d, 0x9a, 0xb0, 0xaa, 0x79, 0xfb, 0x32, 0x68, 0x21, 0xa1, 0x74, 0x81,
    0xe5, 0x2e, 0x98, 0x36, 0x77, 0x75, 0x88, 0xdf, 0x51, 0xcd, 0xc2, 0x90, 0x9f, 0xe0, 0xc3, 0x83,
    0x49, 0x54, 0x7d, 0xda, 0x0f, 0x4f, 0xc0, 0xb2, 0xc2, 0x43, 0xd5, 0xb8, 0xf5, 0xbf, 0x65, 0xde,
    0xb8, 0x2a, 0x1a, 0x65, 0x4f, 0xcc, 0x32, 0x18, 0x52, 0x44, 0x39, 0xdf, 0x92, 0xcd, 0xb3, 0xd3,
    0x11, 0x67, 0xbb, 0x1d, 0xd0, 0xd1, 0x53, 0x9a, 0x5e, 0x18, 0x95, 0xc0, 0xab, 0xc8, 0xcf, 0x12,
    0x66, 0xbb, 0xd9, 0x69, 0x9c, 0xb4, 0x87, 0x18, 0xde, 0xd2, 0xb8, 0x96, 0xb5, 0x39, 0x67, 0x36,
    0x9f, 0x97, 0xab, 0xc5, 0x6f, 0x5f, 0xde, 0xbe, 0xa6
};
#endif

PyTypeObject *init_QOpenGLFramebufferObject(PyObject *module)
{
    if (SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX].type != nullptr)
        return SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX].type;

    Shiboken::AutoDecRef Sbk_QOpenGLFramebufferObject_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QOpenGLFramebufferObject_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QOpenGLFramebufferObject",
        "QOpenGLFramebufferObject*",
        &Sbk_QOpenGLFramebufferObject_spec,
        &Shiboken::callCppDestructor< QOpenGLFramebufferObject >,
        Sbk_QOpenGLFramebufferObject_Type_bases.object(),
        0);
    auto *pyType = Sbk_QOpenGLFramebufferObject_TypeF(); // references _Sbk_QOpenGLFramebufferObject_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QOpenGLFramebufferObject_SignatureStrings);
#else
    InitSignatureBytes(pyType, QOpenGLFramebufferObject_SignatureBytes, QOpenGLFramebufferObject_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QOpenGLFramebufferObject_PropertyStrings);
    SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QOpenGLFramebufferObject_PythonToCpp_QOpenGLFramebufferObject_PTR,
        is_QOpenGLFramebufferObject_PythonToCpp_QOpenGLFramebufferObject_PTR_Convertible,
        QOpenGLFramebufferObject_PTR_CppToPython_QOpenGLFramebufferObject);

    Shiboken::Conversions::registerConverterName(converter, "QOpenGLFramebufferObject");
    Shiboken::Conversions::registerConverterName(converter, "QOpenGLFramebufferObject*");
    Shiboken::Conversions::registerConverterName(converter, "QOpenGLFramebufferObject&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QOpenGLFramebufferObject).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QOpenGLFramebufferObjectWrapper).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QOpenGLFramebufferObject_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Attachment'.
    const char *Attachment_Initializer[] = {
        "NoAttachment",
        "CombinedDepthStencil",
        "Depth",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Attachment_InitializerValues[] = {
        uint8_t(QOpenGLFramebufferObject::Attachment::NoAttachment),         //  0x00  0
        uint8_t(QOpenGLFramebufferObject::Attachment::CombinedDepthStencil), //  0x01  1
        uint8_t(QOpenGLFramebufferObject::Attachment::Depth)                 //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QOpenGLFramebufferObject_TypeF(),
        "2:PySide6.QtOpenGL.QOpenGLFramebufferObject.Attachment",
        Attachment_Initializer, Attachment_InitializerValues);
    SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_Attachment_IDX].type = EType;
    // Register converter for enum 'QOpenGLFramebufferObject::Attachment'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QOpenGLFramebufferObject_Attachment_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QOpenGLFramebufferObject_Attachment,
            is_Enum_PythonToCpp_QOpenGLFramebufferObject_Attachment_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QOpenGLFramebufferObject::Attachment");
        Shiboken::Conversions::registerConverterAlias(converter, "Attachment");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Attachment' enum.

    // Initialization of enum 'FramebufferRestorePolicy'.
    const char *FramebufferRestorePolicy_Initializer[] = {
        "DontRestoreFramebufferBinding",
        "RestoreFramebufferBindingToDefault",
        "RestoreFrameBufferBinding",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t FramebufferRestorePolicy_InitializerValues[] = {
        uint8_t(QOpenGLFramebufferObject::FramebufferRestorePolicy::DontRestoreFramebufferBinding),      //  0x00  0
        uint8_t(QOpenGLFramebufferObject::FramebufferRestorePolicy::RestoreFramebufferBindingToDefault), //  0x01  1
        uint8_t(QOpenGLFramebufferObject::FramebufferRestorePolicy::RestoreFrameBufferBinding)           //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QOpenGLFramebufferObject_TypeF(),
        "2:PySide6.QtOpenGL.QOpenGLFramebufferObject.FramebufferRestorePolicy",
        FramebufferRestorePolicy_Initializer, FramebufferRestorePolicy_InitializerValues);
    SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_FramebufferRestorePolicy_IDX].type = EType;
    // Register converter for enum 'QOpenGLFramebufferObject::FramebufferRestorePolicy'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QOpenGLFramebufferObject_FramebufferRestorePolicy_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QOpenGLFramebufferObject_FramebufferRestorePolicy,
            is_Enum_PythonToCpp_QOpenGLFramebufferObject_FramebufferRestorePolicy_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QOpenGLFramebufferObject::FramebufferRestorePolicy");
        Shiboken::Conversions::registerConverterAlias(converter, "FramebufferRestorePolicy");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'FramebufferRestorePolicy' enum.

    qRegisterMetaType< ::QOpenGLFramebufferObject *>();
    qRegisterMetaType< ::QOpenGLFramebufferObject::Attachment >("QOpenGLFramebufferObject::Attachment");
    qRegisterMetaType< ::QOpenGLFramebufferObject::FramebufferRestorePolicy >("QOpenGLFramebufferObject::FramebufferRestorePolicy");

    return pyType;
}
