// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtopengl_python.h"

// main header
#include "qopenglframebufferobjectformat_wrapper.h"

// Argument includes
#include <QtOpenGL/qopenglframebufferobject.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QOpenGLFramebufferObjectFormat_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QOpenGLFramebufferObjectFormat >()))
        return -1;

    ::QOpenGLFramebufferObjectFormat *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QOpenGLFramebufferObjectFormat", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QOpenGLFramebufferObjectFormat::QOpenGLFramebufferObjectFormat()
    // 1: QOpenGLFramebufferObjectFormat::QOpenGLFramebufferObjectFormat(QOpenGLFramebufferObjectFormat)
    if (numArgs == 0) {
        overloadId = 0; // QOpenGLFramebufferObjectFormat()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObjectFormat_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QOpenGLFramebufferObjectFormat(QOpenGLFramebufferObjectFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObjectFormat_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObjectFormat_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QOpenGLFramebufferObjectFormat()
        {

            // QOpenGLFramebufferObjectFormat()
            cptr = new ::QOpenGLFramebufferObjectFormat();
            break;
        }
        case 1: // QOpenGLFramebufferObjectFormat(const QOpenGLFramebufferObjectFormat &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QOpenGLFramebufferObjectFormat cppArg0_local;
            ::QOpenGLFramebufferObjectFormat *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QOpenGLFramebufferObjectFormat(QOpenGLFramebufferObjectFormat)
                cptr = new ::QOpenGLFramebufferObjectFormat(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QOpenGLFramebufferObjectFormat >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObjectFormat_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QOpenGLFramebufferObjectFormatFunc_attachment(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFramebufferObjectFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObjectFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // attachment()const
        QOpenGLFramebufferObject::Attachment cppResult = const_cast<const ::QOpenGLFramebufferObjectFormat *>(cppSelf)->attachment();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_Attachment_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLFramebufferObjectFormatFunc_internalTextureFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFramebufferObjectFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObjectFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // internalTextureFormat()const
        unsigned int cppResult = const_cast<const ::QOpenGLFramebufferObjectFormat *>(cppSelf)->internalTextureFormat();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLFramebufferObjectFormatFunc_mipmap(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFramebufferObjectFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObjectFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // mipmap()const
        bool cppResult = const_cast<const ::QOpenGLFramebufferObjectFormat *>(cppSelf)->mipmap();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLFramebufferObjectFormatFunc_samples(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFramebufferObjectFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObjectFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // samples()const
        int cppResult = const_cast<const ::QOpenGLFramebufferObjectFormat *>(cppSelf)->samples();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLFramebufferObjectFormatFunc_setAttachment(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFramebufferObjectFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObjectFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFramebufferObjectFormat::setAttachment(QOpenGLFramebufferObject::Attachment)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_Attachment_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setAttachment(QOpenGLFramebufferObject::Attachment)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAttachment", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObjectFormat_IDX]);

    // Call function/method
    {
        ::QOpenGLFramebufferObject::Attachment cppArg0{QOpenGLFramebufferObject::NoAttachment};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAttachment(QOpenGLFramebufferObject::Attachment)
            cppSelf->setAttachment(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFramebufferObjectFormatFunc_setInternalTextureFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFramebufferObjectFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObjectFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFramebufferObjectFormat::setInternalTextureFormat(uint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // setInternalTextureFormat(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setInternalTextureFormat", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObjectFormat_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setInternalTextureFormat(uint)
            cppSelf->setInternalTextureFormat(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFramebufferObjectFormatFunc_setMipmap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFramebufferObjectFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObjectFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFramebufferObjectFormat::setMipmap(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setMipmap(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMipmap", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObjectFormat_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMipmap(bool)
            cppSelf->setMipmap(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFramebufferObjectFormatFunc_setSamples(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFramebufferObjectFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObjectFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFramebufferObjectFormat::setSamples(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setSamples(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSamples", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObjectFormat_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSamples(int)
            cppSelf->setSamples(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFramebufferObjectFormatFunc_setTextureTarget(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFramebufferObjectFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObjectFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFramebufferObjectFormat::setTextureTarget(uint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // setTextureTarget(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTextureTarget", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObjectFormat_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTextureTarget(uint)
            cppSelf->setTextureTarget(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFramebufferObjectFormatFunc_textureTarget(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFramebufferObjectFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObjectFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // textureTarget()const
        unsigned int cppResult = const_cast<const ::QOpenGLFramebufferObjectFormat *>(cppSelf)->textureTarget();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLFramebufferObjectFormat__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QOpenGLFramebufferObjectFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObjectFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObjectFormat_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QOpenGLFramebufferObjectFormat_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QOpenGLFramebufferObjectFormat_methods[] = {
    {"attachment", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFramebufferObjectFormatFunc_attachment), METH_NOARGS, nullptr},
    {"internalTextureFormat", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFramebufferObjectFormatFunc_internalTextureFormat), METH_NOARGS, nullptr},
    {"mipmap", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFramebufferObjectFormatFunc_mipmap), METH_NOARGS, nullptr},
    {"samples", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFramebufferObjectFormatFunc_samples), METH_NOARGS, nullptr},
    {"setAttachment", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFramebufferObjectFormatFunc_setAttachment), METH_O, nullptr},
    {"setInternalTextureFormat", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFramebufferObjectFormatFunc_setInternalTextureFormat), METH_O, nullptr},
    {"setMipmap", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFramebufferObjectFormatFunc_setMipmap), METH_O, nullptr},
    {"setSamples", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFramebufferObjectFormatFunc_setSamples), METH_O, nullptr},
    {"setTextureTarget", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFramebufferObjectFormatFunc_setTextureTarget), METH_O, nullptr},
    {"textureTarget", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFramebufferObjectFormatFunc_textureTarget), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFramebufferObjectFormat__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QOpenGLFramebufferObjectFormat_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QOpenGLFramebufferObjectFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObjectFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObjectFormat_IDX]), (pyArg)))) {
                // operator!=(const QOpenGLFramebufferObjectFormat &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QOpenGLFramebufferObjectFormat cppArg0_local;
                ::QOpenGLFramebufferObjectFormat *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObjectFormat_IDX]), (pyArg)))) {
                // operator==(const QOpenGLFramebufferObjectFormat &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QOpenGLFramebufferObjectFormat cppArg0_local;
                ::QOpenGLFramebufferObjectFormat *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QOpenGLFramebufferObjectFormat_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QOpenGLFramebufferObjectFormat_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QOpenGLFramebufferObjectFormat_Type = nullptr;
static PyTypeObject *Sbk_QOpenGLFramebufferObjectFormat_TypeF(void)
{
    return _Sbk_QOpenGLFramebufferObjectFormat_Type;
}

static PyType_Slot Sbk_QOpenGLFramebufferObjectFormat_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QOpenGLFramebufferObjectFormat_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QOpenGLFramebufferObjectFormat_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QOpenGLFramebufferObjectFormat_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QOpenGLFramebufferObjectFormat_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QOpenGLFramebufferObjectFormat_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QOpenGLFramebufferObjectFormat_spec = {
    "2:PySide6.QtOpenGL.QOpenGLFramebufferObjectFormat",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QOpenGLFramebufferObjectFormat_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QOpenGLFramebufferObjectFormat_PythonToCpp_QOpenGLFramebufferObjectFormat_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QOpenGLFramebufferObjectFormat_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QOpenGLFramebufferObjectFormat_PythonToCpp_QOpenGLFramebufferObjectFormat_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QOpenGLFramebufferObjectFormat_TypeF()))
        return QOpenGLFramebufferObjectFormat_PythonToCpp_QOpenGLFramebufferObjectFormat_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QOpenGLFramebufferObjectFormat_PTR_CppToPython_QOpenGLFramebufferObjectFormat(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QOpenGLFramebufferObjectFormat_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QOpenGLFramebufferObjectFormat_COPY_CppToPython_QOpenGLFramebufferObjectFormat(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QOpenGLFramebufferObjectFormat *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QOpenGLFramebufferObjectFormat_TypeF(), new ::QOpenGLFramebufferObjectFormat(*source), true, true);
}

// Python to C++ copy conversion.
static void QOpenGLFramebufferObjectFormat_PythonToCpp_QOpenGLFramebufferObjectFormat_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QOpenGLFramebufferObjectFormat *>(cppOut) = *reinterpret_cast< ::QOpenGLFramebufferObjectFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObjectFormat_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QOpenGLFramebufferObjectFormat_PythonToCpp_QOpenGLFramebufferObjectFormat_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QOpenGLFramebufferObjectFormat_TypeF()))
        return QOpenGLFramebufferObjectFormat_PythonToCpp_QOpenGLFramebufferObjectFormat_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QOpenGLFramebufferObjectFormat_SignatureStrings[] = {
    "1:PySide6.QtOpenGL.QOpenGLFramebufferObjectFormat(self)",
    "0:PySide6.QtOpenGL.QOpenGLFramebufferObjectFormat(self,other:PySide6.QtOpenGL.QOpenGLFramebufferObjectFormat)",
    "PySide6.QtOpenGL.QOpenGLFramebufferObjectFormat.attachment(self)->PySide6.QtOpenGL.QOpenGLFramebufferObject.Attachment",
    "PySide6.QtOpenGL.QOpenGLFramebufferObjectFormat.internalTextureFormat(self)->unsigned int",
    "PySide6.QtOpenGL.QOpenGLFramebufferObjectFormat.mipmap(self)->bool",
    "PySide6.QtOpenGL.QOpenGLFramebufferObjectFormat.samples(self)->int",
    "PySide6.QtOpenGL.QOpenGLFramebufferObjectFormat.setAttachment(self,attachment:PySide6.QtOpenGL.QOpenGLFramebufferObject.Attachment)",
    "PySide6.QtOpenGL.QOpenGLFramebufferObjectFormat.setInternalTextureFormat(self,internalTextureFormat:unsigned int)",
    "PySide6.QtOpenGL.QOpenGLFramebufferObjectFormat.setMipmap(self,enabled:bool)",
    "PySide6.QtOpenGL.QOpenGLFramebufferObjectFormat.setSamples(self,samples:int)",
    "PySide6.QtOpenGL.QOpenGLFramebufferObjectFormat.setTextureTarget(self,target:unsigned int)",
    "PySide6.QtOpenGL.QOpenGLFramebufferObjectFormat.textureTarget(self)->unsigned int",
    "PySide6.QtOpenGL.QOpenGLFramebufferObjectFormat.__copy__(self)->typing.Self",
    "PySide6.QtOpenGL.QOpenGLFramebufferObjectFormat.__ne__(self,other:PySide6.QtOpenGL.QOpenGLFramebufferObjectFormat)->bool",
    "PySide6.QtOpenGL.QOpenGLFramebufferObjectFormat.__eq__(self,other:PySide6.QtOpenGL.QOpenGLFramebufferObjectFormat)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QOpenGLFramebufferObjectFormat_SignatureByteSize = 259;
static constexpr uint8_t QOpenGLFramebufferObjectFormat_SignatureBytes[259] = {
    0x78, 0xda, 0xad, 0x94, 0x3d, 0x4f, 0xc3, 0x30, 0x10, 0x86, 0xf7, 0xfe, 0x0a, 0x46, 0x22, 0xb9,
    0x16, 0x2c, 0x0c, 0x1e, 0x2a, 0x75, 0x29, 0x42, 0x02, 0x95, 0x2a, 0xdd, 0x2d, 0x27, 0xb9, 0xa4,
    0x46, 0xfe, 0xc2, 0xbe, 0x48, 0xe4, 0xdf, 0xf3, 0xe5, 0xd0, 0x20, 0x40, 0x22, 0xd7, 0x4e, 0xb6,
    0x87, 0xf7, 0xb9, 0xbb, 0xf7, 0xb5, 0x7d, 0x2d, 0x1e, 0x87, 0x52, 0x37, 0x70, 0xc3, 0x77, 0xb8,
    0x0d, 0xe0, 0x6e, 0xef, 0xf9, 0xee, 0x73, 0xdd, 0x44, 0x65, 0xa1, 0xea, 0xdb, 0x16, 0xe2, 0xb6,
    0x7a, 0x82, 0x1a, 0x37, 0x3e, 0x5a, 0x85, 0x97, 0x09, 0x4c, 0x5b, 0x2c, 0xae, 0x48, 0x3a, 0xe6,
    0xf1, 0x00, 0x71, 0xae, 0xb4, 0x58, 0xcc, 0x14, 0x70, 0x85, 0xa8, 0xea, 0x83, 0x05, 0x97, 0xdb,
    0x5d, 0xae, 0xfe, 0x4d, 0xe0, 0xeb, 0x2f, 0xed, 0xec, 0xb2, 0xda, 0x21, 0x44, 0xa7, 0xcc, 0x1e,
    0x5e, 0xb0, 0x8f, 0x30, 0x35, 0x6c, 0xb9, 0xea, 0x5d, 0xd2, 0x9d, 0x83, 0xe6, 0x42, 0x13, 0xc8,
    0x56, 0x07, 0xab, 0xc2, 0x88, 0xaa, 0xbc, 0x37, 0xb3, 0x11, 0x49, 0xd9, 0x60, 0x20, 0x8d, 0x0c,
    0x4a, 0x17, 0x09, 0x70, 0xfd, 0xdd, 0x59, 0x76, 0x74, 0x5a, 0x50, 0x2c, 0x2e, 0x28, 0x3d, 0xdc,
    0xfd, 0x69, 0x33, 0xfb, 0x35, 0x01, 0x31, 0xb5, 0x9e, 0x54, 0xf1, 0xe1, 0x68, 0x3f, 0x03, 0xa7,
    0x2a, 0x03, 0x8d, 0x78, 0x0f, 0x81, 0x04, 0x2b, 0x27, 0x41, 0xb0, 0x9c, 0x8a, 0xa0, 0x76, 0x96,
    0x07, 0xdd, 0xab, 0xd8, 0x41, 0xf6, 0x00, 0x3f, 0xf6, 0x27, 0x0e, 0x8d, 0x3f, 0xb8, 0xa7, 0x5e,
    0x61, 0x29, 0x6b, 0x1f, 0x06, 0x29, 0x47, 0x18, 0x0e, 0x41, 0xbb, 0x8e, 0x97, 0x6f, 0x27, 0x02,
    0xcb, 0x41, 0x26, 0x11, 0xbf, 0x14, 0xe2, 0x23, 0x92, 0x12, 0x9e, 0xcf, 0x52, 0xf8, 0x15, 0x45,
    0x0b, 0x01, 0x39
};
#endif

PyTypeObject *init_QOpenGLFramebufferObjectFormat(PyObject *module)
{
    if (SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObjectFormat_IDX].type != nullptr)
        return SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObjectFormat_IDX].type;

    Shiboken::AutoDecRef Sbk_QOpenGLFramebufferObjectFormat_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QOpenGLFramebufferObjectFormat_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QOpenGLFramebufferObjectFormat",
        "QOpenGLFramebufferObjectFormat",
        &Sbk_QOpenGLFramebufferObjectFormat_spec,
        &Shiboken::callCppDestructor< ::QOpenGLFramebufferObjectFormat >,
        Sbk_QOpenGLFramebufferObjectFormat_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QOpenGLFramebufferObjectFormat_TypeF(); // references _Sbk_QOpenGLFramebufferObjectFormat_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QOpenGLFramebufferObjectFormat_SignatureStrings);
#else
    InitSignatureBytes(pyType, QOpenGLFramebufferObjectFormat_SignatureBytes, QOpenGLFramebufferObjectFormat_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QOpenGLFramebufferObjectFormat_PropertyStrings);
    SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObjectFormat_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QOpenGLFramebufferObjectFormat_PythonToCpp_QOpenGLFramebufferObjectFormat_PTR,
        is_QOpenGLFramebufferObjectFormat_PythonToCpp_QOpenGLFramebufferObjectFormat_PTR_Convertible,
        QOpenGLFramebufferObjectFormat_PTR_CppToPython_QOpenGLFramebufferObjectFormat,
        QOpenGLFramebufferObjectFormat_COPY_CppToPython_QOpenGLFramebufferObjectFormat);

    Shiboken::Conversions::registerConverterName(converter, "QOpenGLFramebufferObjectFormat");
    Shiboken::Conversions::registerConverterName(converter, "QOpenGLFramebufferObjectFormat*");
    Shiboken::Conversions::registerConverterName(converter, "QOpenGLFramebufferObjectFormat&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QOpenGLFramebufferObjectFormat).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QOpenGLFramebufferObjectFormat_PythonToCpp_QOpenGLFramebufferObjectFormat_COPY,
        is_QOpenGLFramebufferObjectFormat_PythonToCpp_QOpenGLFramebufferObjectFormat_COPY_Convertible);

    qRegisterMetaType< ::QOpenGLFramebufferObjectFormat >("QOpenGLFramebufferObjectFormat");

    return pyType;
}
