// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtopengl_python.h"

// main header
#include "qopengltextureblitter_wrapper.h"

// Argument includes
#include <QtGui/qgenericmatrix.h>
#include <QtGui/qmatrix4x4.h>
#include <QtOpenGL/qopengltextureblitter.h>
#include <qrect.h>
#include <qsize.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QOpenGLTextureBlitter_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QOpenGLTextureBlitter >()))
        return -1;

    ::QOpenGLTextureBlitter *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QOpenGLTextureBlitter()
        cptr = new ::QOpenGLTextureBlitter();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QOpenGLTextureBlitter >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QOpenGLTextureBlitterFunc_bind(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTextureBlitter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "bind", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_IDX]);

    if (PyArg_ParseTuple(args, "|O:bind", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLTextureBlitter::bind(uint=)
    if (numArgs == 0) {
        overloadId = 0; // bind(uint)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))) {
        overloadId = 0; // bind(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "bind", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_target = Shiboken::String::createStaticString("target");
            if (PyDict_Contains(kwds, key_target) != 0) {
                value = PyDict_GetItem(kwds, key_target);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_target);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "bind", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "bind", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_target);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "bind", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_IDX]);
            }
        }
        unsigned int cppArg0 = GL_TEXTURE_2D;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // bind(uint)
            cppSelf->bind(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLTextureBlitterFunc_blit(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTextureBlitter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "blit", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLTextureBlitter::blit(uint,QMatrix4x4,QOpenGLTextureBlitter::Origin)
    // 1: QOpenGLTextureBlitter::blit(uint,QMatrix4x4,QMatrix3x3)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), (pyArgs[1])))) {
        if (numArgs == 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix3x3_IDX]), (pyArgs[2])))) {
            overloadId = 1; // blit(uint,QMatrix4x4,QMatrix3x3)
        } else if (numArgs == 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_Origin_IDX])))->converter, (pyArgs[2])))) {
            overloadId = 0; // blit(uint,QMatrix4x4,QOpenGLTextureBlitter::Origin)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "blit", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // blit(unsigned int texture, const QMatrix4x4 &targetTransform, QOpenGLTextureBlitter::Origin sourceOrigin)
        {
            unsigned int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QMatrix4x4 cppArg1_local;
            ::QMatrix4x4 *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            ::QOpenGLTextureBlitter::Origin cppArg2{QOpenGLTextureBlitter::OriginBottomLeft};
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // blit(uint,QMatrix4x4,QOpenGLTextureBlitter::Origin)
                cppSelf->blit(cppArg0, *cppArg1, cppArg2);
            }
            break;
        }
        case 1: // blit(unsigned int texture, const QMatrix4x4 &targetTransform, const QMatrix3x3 &sourceTransform)
        {
            unsigned int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QMatrix4x4 cppArg1_local;
            ::QMatrix4x4 *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QMatrix3x3 cppArg2_local;
            ::QMatrix3x3 *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);


            if (Shiboken::Errors::occurred() == nullptr) {
                // blit(uint,QMatrix4x4,QMatrix3x3)
                cppSelf->blit(cppArg0, *cppArg1, *cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLTextureBlitterFunc_create(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTextureBlitter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // create()
        bool cppResult = cppSelf->create();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureBlitterFunc_destroy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTextureBlitter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // destroy()
        cppSelf->destroy();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLTextureBlitterFunc_isCreated(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTextureBlitter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isCreated()const
        bool cppResult = const_cast<const ::QOpenGLTextureBlitter *>(cppSelf)->isCreated();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureBlitterFunc_release(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTextureBlitter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // release()
        cppSelf->release();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLTextureBlitterFunc_setOpacity(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTextureBlitter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLTextureBlitter::setOpacity(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setOpacity(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOpacity", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOpacity(float)
            cppSelf->setOpacity(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLTextureBlitterFunc_setRedBlueSwizzle(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTextureBlitter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLTextureBlitter::setRedBlueSwizzle(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setRedBlueSwizzle(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRedBlueSwizzle", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRedBlueSwizzle(bool)
            cppSelf->setRedBlueSwizzle(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLTextureBlitterFunc_sourceTransform(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "sourceTransform", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QOpenGLTextureBlitter::sourceTransform(QRectF,QSize,QOpenGLTextureBlitter::Origin)->QMatrix3x3
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_Origin_IDX])))->converter, (pyArgs[2])))) {
        overloadId = 0; // sourceTransform(QRectF,QSize,QOpenGLTextureBlitter::Origin)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "sourceTransform", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QRectF cppArg0_local;
        ::QRectF *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QSize cppArg1_local;
        ::QSize *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        ::QOpenGLTextureBlitter::Origin cppArg2{QOpenGLTextureBlitter::OriginBottomLeft};
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // sourceTransform(QRectF,QSize,QOpenGLTextureBlitter::Origin)
            QMatrix3x3 cppResult = ::QOpenGLTextureBlitter::sourceTransform(*cppArg0, *cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix3x3_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureBlitterFunc_supportsExternalOESTarget(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTextureBlitter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // supportsExternalOESTarget()const
        bool cppResult = const_cast<const ::QOpenGLTextureBlitter *>(cppSelf)->supportsExternalOESTarget();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureBlitterFunc_supportsRectangleTarget(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTextureBlitter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // supportsRectangleTarget()const
        bool cppResult = const_cast<const ::QOpenGLTextureBlitter *>(cppSelf)->supportsRectangleTarget();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureBlitterFunc_targetTransform(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "targetTransform", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QOpenGLTextureBlitter::targetTransform(QRectF,QRect)->QMatrix4x4
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[1])))) {
        overloadId = 0; // targetTransform(QRectF,QRect)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "targetTransform", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QRectF cppArg0_local;
        ::QRectF *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QRect cppArg1_local;
        ::QRect *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // targetTransform(QRectF,QRect)
            QMatrix4x4 cppResult = ::QOpenGLTextureBlitter::targetTransform(*cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QOpenGLTextureBlitter_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QOpenGLTextureBlitter_EnumFlagInfo[] = {
    "Origin:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QOpenGLTextureBlitter_methods[] = {
    {"bind", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureBlitterFunc_bind), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"blit", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureBlitterFunc_blit), METH_VARARGS, nullptr},
    {"create", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureBlitterFunc_create), METH_NOARGS, nullptr},
    {"destroy", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureBlitterFunc_destroy), METH_NOARGS, nullptr},
    {"isCreated", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureBlitterFunc_isCreated), METH_NOARGS, nullptr},
    {"release", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureBlitterFunc_release), METH_NOARGS, nullptr},
    {"setOpacity", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureBlitterFunc_setOpacity), METH_O, nullptr},
    {"setRedBlueSwizzle", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureBlitterFunc_setRedBlueSwizzle), METH_O, nullptr},
    {"sourceTransform", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureBlitterFunc_sourceTransform), METH_VARARGS|METH_STATIC, nullptr},
    {"supportsExternalOESTarget", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureBlitterFunc_supportsExternalOESTarget), METH_NOARGS, nullptr},
    {"supportsRectangleTarget", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureBlitterFunc_supportsRectangleTarget), METH_NOARGS, nullptr},
    {"targetTransform", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureBlitterFunc_targetTransform), METH_VARARGS|METH_STATIC, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QOpenGLTextureBlitter_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QOpenGLTextureBlitter_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QOpenGLTextureBlitter_Type = nullptr;
static PyTypeObject *Sbk_QOpenGLTextureBlitter_TypeF(void)
{
    return _Sbk_QOpenGLTextureBlitter_Type;
}

static PyType_Slot Sbk_QOpenGLTextureBlitter_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QOpenGLTextureBlitter_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QOpenGLTextureBlitter_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QOpenGLTextureBlitter_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QOpenGLTextureBlitter_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QOpenGLTextureBlitter_spec = {
    "2:PySide6.QtOpenGL.QOpenGLTextureBlitter",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QOpenGLTextureBlitter_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QOpenGLTextureBlitter_Origin(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QOpenGLTextureBlitter::Origin>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QOpenGLTextureBlitter::Origin *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QOpenGLTextureBlitter_Origin_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_Origin_IDX])))
        return Enum_PythonToCpp_QOpenGLTextureBlitter_Origin;
    return {};
}

static PyObject *QOpenGLTextureBlitter_Origin_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QOpenGLTextureBlitter::Origin>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QOpenGLTextureBlitter::Origin *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_Origin_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QOpenGLTextureBlitter_PythonToCpp_QOpenGLTextureBlitter_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QOpenGLTextureBlitter_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QOpenGLTextureBlitter_PythonToCpp_QOpenGLTextureBlitter_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QOpenGLTextureBlitter_TypeF()))
        return QOpenGLTextureBlitter_PythonToCpp_QOpenGLTextureBlitter_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QOpenGLTextureBlitter_PTR_CppToPython_QOpenGLTextureBlitter(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QOpenGLTextureBlitter_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QOpenGLTextureBlitter_SignatureStrings[] = {
    "PySide6.QtOpenGL.QOpenGLTextureBlitter(self)",
    "PySide6.QtOpenGL.QOpenGLTextureBlitter.bind(self,target:unsigned int=GL_TEXTURE_2D)",
    "1:PySide6.QtOpenGL.QOpenGLTextureBlitter.blit(self,texture:unsigned int,targetTransform:typing.Union[PySide6.QtGui.QMatrix4x4, PySide6.QtGui.QTransform],sourceOrigin:PySide6.QtOpenGL.QOpenGLTextureBlitter.Origin)",
    "0:PySide6.QtOpenGL.QOpenGLTextureBlitter.blit(self,texture:unsigned int,targetTransform:typing.Union[PySide6.QtGui.QMatrix4x4, PySide6.QtGui.QTransform],sourceTransform:PySide6.QtGui.QMatrix3x3)",
    "PySide6.QtOpenGL.QOpenGLTextureBlitter.create(self)->bool",
    "PySide6.QtOpenGL.QOpenGLTextureBlitter.destroy(self)",
    "PySide6.QtOpenGL.QOpenGLTextureBlitter.isCreated(self)->bool",
    "PySide6.QtOpenGL.QOpenGLTextureBlitter.release(self)",
    "PySide6.QtOpenGL.QOpenGLTextureBlitter.setOpacity(self,opacity:float)",
    "PySide6.QtOpenGL.QOpenGLTextureBlitter.setRedBlueSwizzle(self,swizzle:bool)",
    "PySide6.QtOpenGL.QOpenGLTextureBlitter.sourceTransform(subTexture:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect],textureSize:PySide6.QtCore.QSize,origin:PySide6.QtOpenGL.QOpenGLTextureBlitter.Origin)->PySide6.QtGui.QMatrix3x3",
    "PySide6.QtOpenGL.QOpenGLTextureBlitter.supportsExternalOESTarget(self)->bool",
    "PySide6.QtOpenGL.QOpenGLTextureBlitter.supportsRectangleTarget(self)->bool",
    "PySide6.QtOpenGL.QOpenGLTextureBlitter.targetTransform(target:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect],viewport:PySide6.QtCore.QRect)->PySide6.QtGui.QMatrix4x4",
    nullptr}; // Sentinel
#else
static constexpr size_t QOpenGLTextureBlitter_SignatureByteSize = 358;
static constexpr uint8_t QOpenGLTextureBlitter_SignatureBytes[358] = {
    0x78, 0xda, 0xcd, 0x54, 0xc1, 0x6e, 0xc2, 0x30, 0x0c, 0xbd, 0xf7, 0x2b, 0x38, 0x82, 0x54, 0xaa,
    0x6d, 0xa0, 0x1d, 0x2a, 0x8d, 0x03, 0xac, 0xe3, 0xc2, 0x04, 0xa5, 0x45, 0x9a, 0x34, 0x21, 0x14,
    0x5a, 0x53, 0x59, 0xca, 0x92, 0x2a, 0x71, 0x47, 0xe1, 0xeb, 0xd7, 0x92, 0x32, 0x06, 0x02, 0xa9,
    0xf4, 0xb4, 0x53, 0xe4, 0xd8, 0x7e, 0xcf, 0x8e, 0x9f, 0x33, 0xdb, 0x05, 0x18, 0xc3, 0xb3, 0xe3,
    0xd3, 0x34, 0x05, 0x31, 0x9e, 0x38, 0xbe, 0x39, 0x43, 0xc8, 0x29, 0x53, 0x30, 0xe4, 0x48, 0x04,
    0xaa, 0xad, 0x81, 0x6f, 0x3a, 0xd6, 0xac, 0x56, 0xb0, 0xb3, 0x46, 0x11, 0x1f, 0x32, 0x6c, 0x62,
    0x2a, 0x01, 0x72, 0x33, 0xa1, 0x31, 0x11, 0x10, 0xb7, 0x50, 0xd0, 0xcb, 0x78, 0xb2, 0x0a, 0xbd,
    0x8f, 0x70, 0x31, 0xf7, 0x56, 0x4f, 0xaf, 0x1d, 0xeb, 0xd1, 0xad, 0x8b, 0x5a, 0x9c, 0x15, 0xaa,
    0x71, 0x9c, 0xc1, 0x56, 0x54, 0xa1, 0x62, 0x42, 0x6f, 0xa4, 0xfa, 0x72, 0x69, 0x97, 0xa2, 0x48,
    0x9c, 0x85, 0x40, 0x29, 0x3e, 0x4f, 0x14, 0xe3, 0x0c, 0x1d, 0xff, 0x9d, 0x91, 0xc2, 0xbc, 0x9f,
    0xf7, 0xed, 0xd6, 0x85, 0xe7, 0x37, 0x7f, 0x69, 0x6b, 0x99, 0xa9, 0x08, 0xa6, 0x0a, 0x13, 0x14,
    0x75, 0x6b, 0x34, 0xd1, 0x1d, 0xeb, 0xe1, 0x7f, 0x37, 0x75, 0x02, 0xbc, 0x8a, 0xd1, 0xcb, 0x7b,
    0xb5, 0x67, 0x1d, 0x29, 0x60, 0x04, 0x46, 0x1f, 0xdd, 0xc1, 0x5a, 0x4a, 0x5e, 0x37, 0x33, 0x06,
    0x4d, 0x4a, 0xee, 0xee, 0x93, 0x16, 0xea, 0xd1, 0x81, 0x30, 0x6e, 0xc2, 0xa8, 0x80, 0x03, 0xd3,
    0x70, 0x1f, 0xa3, 0x86, 0xc2, 0xcf, 0x22, 0x24, 0x53, 0xa9, 0x2d, 0x8d, 0xe1, 0x6e, 0xb8, 0x64,
    0x74, 0x0f, 0xca, 0x1c, 0xe2, 0x21, 0xcf, 0x20, 0xd8, 0xe2, 0x7e, 0xcf, 0x4d, 0x11, 0xb6, 0x36,
    0x86, 0x5b, 0x76, 0x51, 0x1f, 0xeb, 0x7c, 0x86, 0x6d, 0x9d, 0xad, 0xab, 0x88, 0x5b, 0xfa, 0x18,
    0x49, 0x05, 0x8e, 0x3f, 0x87, 0x88, 0xde, 0xfe, 0x8a, 0xe3, 0x74, 0xbd, 0x3c, 0xca, 0x2f, 0xc0,
    0x3d, 0xb8, 0x97, 0x11, 0xe5, 0xa5, 0x2d, 0x9b, 0x2c, 0x42, 0x77, 0x70, 0x4b, 0x60, 0xb5, 0x9b,
    0xcd, 0xd2, 0x54, 0x2a, 0xd2, 0x5e, 0x5e, 0x58, 0x82, 0xf1, 0xa9, 0x17, 0x84, 0x87, 0xa5, 0x68,
    0x22, 0x80, 0x23, 0x58, 0xd9, 0x32, 0x13, 0x09, 0x87, 0xe6, 0x50, 0x17, 0x9b, 0xd9, 0xae, 0x7e,
    0xba, 0xe6, 0x03, 0xf8, 0x46, 0xd8, 0x96, 0xc5, 0xb9, 0xd7, 0xdc, 0xb7, 0x1e, 0xb2, 0xd8, 0x76,
    0xeb, 0x07, 0x04, 0xbf, 0x18, 0xd9
};
#endif

PyTypeObject *init_QOpenGLTextureBlitter(PyObject *module)
{
    if (SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_IDX].type != nullptr)
        return SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_IDX].type;

    Shiboken::AutoDecRef Sbk_QOpenGLTextureBlitter_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QOpenGLTextureBlitter_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QOpenGLTextureBlitter",
        "QOpenGLTextureBlitter*",
        &Sbk_QOpenGLTextureBlitter_spec,
        &Shiboken::callCppDestructor< ::QOpenGLTextureBlitter >,
        Sbk_QOpenGLTextureBlitter_Type_bases.object(),
        0);
    auto *pyType = Sbk_QOpenGLTextureBlitter_TypeF(); // references _Sbk_QOpenGLTextureBlitter_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QOpenGLTextureBlitter_SignatureStrings);
#else
    InitSignatureBytes(pyType, QOpenGLTextureBlitter_SignatureBytes, QOpenGLTextureBlitter_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QOpenGLTextureBlitter_PropertyStrings);
    SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QOpenGLTextureBlitter_PythonToCpp_QOpenGLTextureBlitter_PTR,
        is_QOpenGLTextureBlitter_PythonToCpp_QOpenGLTextureBlitter_PTR_Convertible,
        QOpenGLTextureBlitter_PTR_CppToPython_QOpenGLTextureBlitter);

    Shiboken::Conversions::registerConverterName(converter, "QOpenGLTextureBlitter");
    Shiboken::Conversions::registerConverterName(converter, "QOpenGLTextureBlitter*");
    Shiboken::Conversions::registerConverterName(converter, "QOpenGLTextureBlitter&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QOpenGLTextureBlitter).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QOpenGLTextureBlitter_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Origin'.
    const char *Origin_Initializer[] = {
        "OriginBottomLeft",
        "OriginTopLeft",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Origin_InitializerValues[] = {
        uint8_t(QOpenGLTextureBlitter::Origin::OriginBottomLeft), //  0x00  0
        uint8_t(QOpenGLTextureBlitter::Origin::OriginTopLeft)     //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QOpenGLTextureBlitter_TypeF(),
        "2:PySide6.QtOpenGL.QOpenGLTextureBlitter.Origin",
        Origin_Initializer, Origin_InitializerValues);
    SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_Origin_IDX].type = EType;
    // Register converter for enum 'QOpenGLTextureBlitter::Origin'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QOpenGLTextureBlitter_Origin_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QOpenGLTextureBlitter_Origin,
            is_Enum_PythonToCpp_QOpenGLTextureBlitter_Origin_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QOpenGLTextureBlitter::Origin");
        Shiboken::Conversions::registerConverterAlias(converter, "Origin");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Origin' enum.

    qRegisterMetaType< ::QOpenGLTextureBlitter *>();
    qRegisterMetaType< ::QOpenGLTextureBlitter::Origin >("QOpenGLTextureBlitter::Origin");

    return pyType;
}
