// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtopengl_python.h"

// main header
#include "qopenglversionprofile_wrapper.h"

// Argument includes
#include <QtGui/qsurfaceformat.h>
#include <QtOpenGL/qopenglversionprofile.h>
#include <utility>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QOpenGLVersionProfile_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QOpenGLVersionProfile >()))
        return -1;

    ::QOpenGLVersionProfile *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QOpenGLVersionProfile", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QOpenGLVersionProfile::QOpenGLVersionProfile()
    // 1: QOpenGLVersionProfile::QOpenGLVersionProfile(QOpenGLVersionProfile)
    // 2: QOpenGLVersionProfile::QOpenGLVersionProfile(QSurfaceFormat)
    if (numArgs == 0) {
        overloadId = 0; // QOpenGLVersionProfile()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QOpenGLVersionProfile(QSurfaceFormat)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLVersionProfile_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QOpenGLVersionProfile(QOpenGLVersionProfile)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLVersionProfile_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLVersionProfile_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QOpenGLVersionProfile()
        {

            // QOpenGLVersionProfile()
            cptr = new ::QOpenGLVersionProfile();
            break;
        }
        case 1: // QOpenGLVersionProfile(const QOpenGLVersionProfile &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QOpenGLVersionProfile cppArg0_local;
            ::QOpenGLVersionProfile *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QOpenGLVersionProfile(QOpenGLVersionProfile)
                cptr = new ::QOpenGLVersionProfile(*cppArg0);
            }
            break;
        }
        case 2: // QOpenGLVersionProfile(const QSurfaceFormat &format)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QSurfaceFormat cppArg0_local;
            ::QSurfaceFormat *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QOpenGLVersionProfile(QSurfaceFormat)
                cptr = new ::QOpenGLVersionProfile(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QOpenGLVersionProfile >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLVersionProfile_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QOpenGLVersionProfileFunc_hasProfiles(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLVersionProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLVersionProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hasProfiles()const
        bool cppResult = const_cast<const ::QOpenGLVersionProfile *>(cppSelf)->hasProfiles();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLVersionProfileFunc_isLegacyVersion(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLVersionProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLVersionProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isLegacyVersion()const
        bool cppResult = const_cast<const ::QOpenGLVersionProfile *>(cppSelf)->isLegacyVersion();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLVersionProfileFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLVersionProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLVersionProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QOpenGLVersionProfile *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLVersionProfileFunc_profile(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLVersionProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLVersionProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // profile()const
        QSurfaceFormat::OpenGLContextProfile cppResult = const_cast<const ::QOpenGLVersionProfile *>(cppSelf)->profile();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_OpenGLContextProfile_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLVersionProfileFunc_setProfile(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLVersionProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLVersionProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLVersionProfile::setProfile(QSurfaceFormat::OpenGLContextProfile)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_OpenGLContextProfile_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setProfile(QSurfaceFormat::OpenGLContextProfile)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setProfile", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLVersionProfile_IDX]);

    // Call function/method
    {
        ::QSurfaceFormat::OpenGLContextProfile cppArg0{QSurfaceFormat::NoProfile};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setProfile(QSurfaceFormat::OpenGLContextProfile)
            cppSelf->setProfile(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLVersionProfileFunc_setVersion(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLVersionProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLVersionProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setVersion", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLVersionProfile::setVersion(int,int)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // setVersion(int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setVersion", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLVersionProfile_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setVersion(int,int)
            cppSelf->setVersion(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLVersionProfileFunc_version(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLVersionProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLVersionProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // version()const
        std::pair<int,int> cppResult = const_cast<const ::QOpenGLVersionProfile *>(cppSelf)->version();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtOpenGLTypeConverters[SBK_QtOpenGL_std_pair_int_int_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLVersionProfile__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QOpenGLVersionProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLVersionProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLVersionProfile_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QOpenGLVersionProfile_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QOpenGLVersionProfile_methods[] = {
    {"hasProfiles", reinterpret_cast<PyCFunction>(Sbk_QOpenGLVersionProfileFunc_hasProfiles), METH_NOARGS, nullptr},
    {"isLegacyVersion", reinterpret_cast<PyCFunction>(Sbk_QOpenGLVersionProfileFunc_isLegacyVersion), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QOpenGLVersionProfileFunc_isValid), METH_NOARGS, nullptr},
    {"profile", reinterpret_cast<PyCFunction>(Sbk_QOpenGLVersionProfileFunc_profile), METH_NOARGS, nullptr},
    {"setProfile", reinterpret_cast<PyCFunction>(Sbk_QOpenGLVersionProfileFunc_setProfile), METH_O, nullptr},
    {"setVersion", reinterpret_cast<PyCFunction>(Sbk_QOpenGLVersionProfileFunc_setVersion), METH_VARARGS, nullptr},
    {"version", reinterpret_cast<PyCFunction>(Sbk_QOpenGLVersionProfileFunc_version), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QOpenGLVersionProfile__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QOpenGLVersionProfile_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QOpenGLVersionProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLVersionProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLVersionProfile_IDX]), (pyArg)))) {
                // operator!=(const QOpenGLVersionProfile &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QOpenGLVersionProfile cppArg0_local;
                ::QOpenGLVersionProfile *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLVersionProfile_IDX]), (pyArg)))) {
                // operator==(const QOpenGLVersionProfile &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QOpenGLVersionProfile cppArg0_local;
                ::QOpenGLVersionProfile *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static Py_hash_t Sbk_QOpenGLVersionProfile_HashFunc(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLVersionProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLVersionProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return Py_hash_t(qHash(*cppSelf));
}

static int Sbk_QOpenGLVersionProfile_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QOpenGLVersionProfile_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QOpenGLVersionProfile__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLVersionProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLVersionProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QOpenGLVersionProfile_Type = nullptr;
static PyTypeObject *Sbk_QOpenGLVersionProfile_TypeF(void)
{
    return _Sbk_QOpenGLVersionProfile_Type;
}

static PyType_Slot Sbk_QOpenGLVersionProfile_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QOpenGLVersionProfile__repr__)},
    {Py_tp_hash,        reinterpret_cast<void *>(&Sbk_QOpenGLVersionProfile_HashFunc)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QOpenGLVersionProfile_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QOpenGLVersionProfile_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QOpenGLVersionProfile_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QOpenGLVersionProfile_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QOpenGLVersionProfile_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QOpenGLVersionProfile_spec = {
    "2:PySide6.QtOpenGL.QOpenGLVersionProfile",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QOpenGLVersionProfile_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QOpenGLVersionProfile_PythonToCpp_QOpenGLVersionProfile_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QOpenGLVersionProfile_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QOpenGLVersionProfile_PythonToCpp_QOpenGLVersionProfile_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QOpenGLVersionProfile_TypeF()))
        return QOpenGLVersionProfile_PythonToCpp_QOpenGLVersionProfile_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QOpenGLVersionProfile_PTR_CppToPython_QOpenGLVersionProfile(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QOpenGLVersionProfile_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QOpenGLVersionProfile_COPY_CppToPython_QOpenGLVersionProfile(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QOpenGLVersionProfile *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QOpenGLVersionProfile_TypeF(), new ::QOpenGLVersionProfile(*source), true, true);
}

// Python to C++ copy conversion.
static void QOpenGLVersionProfile_PythonToCpp_QOpenGLVersionProfile_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QOpenGLVersionProfile *>(cppOut) = *reinterpret_cast< ::QOpenGLVersionProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLVersionProfile_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QOpenGLVersionProfile_PythonToCpp_QOpenGLVersionProfile_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QOpenGLVersionProfile_TypeF()))
        return QOpenGLVersionProfile_PythonToCpp_QOpenGLVersionProfile_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QOpenGLVersionProfile_SignatureStrings[] = {
    "2:PySide6.QtOpenGL.QOpenGLVersionProfile(self)",
    "1:PySide6.QtOpenGL.QOpenGLVersionProfile(self,other:PySide6.QtOpenGL.QOpenGLVersionProfile)",
    "0:PySide6.QtOpenGL.QOpenGLVersionProfile(self,format:typing.Union[PySide6.QtGui.QSurfaceFormat, PySide6.QtGui.QSurfaceFormat.FormatOption])",
    "PySide6.QtOpenGL.QOpenGLVersionProfile.hasProfiles(self)->bool",
    "PySide6.QtOpenGL.QOpenGLVersionProfile.isLegacyVersion(self)->bool",
    "PySide6.QtOpenGL.QOpenGLVersionProfile.isValid(self)->bool",
    "PySide6.QtOpenGL.QOpenGLVersionProfile.profile(self)->PySide6.QtGui.QSurfaceFormat.OpenGLContextProfile",
    "PySide6.QtOpenGL.QOpenGLVersionProfile.setProfile(self,profile:PySide6.QtGui.QSurfaceFormat.OpenGLContextProfile)",
    "PySide6.QtOpenGL.QOpenGLVersionProfile.setVersion(self,majorVersion:int,minorVersion:int)",
    "PySide6.QtOpenGL.QOpenGLVersionProfile.version(self)->std.pair[int, int]",
    "PySide6.QtOpenGL.QOpenGLVersionProfile.__copy__(self)->typing.Self",
    "PySide6.QtOpenGL.QOpenGLVersionProfile.__ne__(self,rhs:PySide6.QtOpenGL.QOpenGLVersionProfile)->bool",
    "PySide6.QtOpenGL.QOpenGLVersionProfile.__eq__(self,rhs:PySide6.QtOpenGL.QOpenGLVersionProfile)->bool",
    "PySide6.QtOpenGL.QOpenGLVersionProfile.__hash__(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t QOpenGLVersionProfile_SignatureByteSize = 272;
static constexpr uint8_t QOpenGLVersionProfile_SignatureBytes[272] = {
    0x78, 0xda, 0xbd, 0x93, 0xb1, 0x6e, 0xc3, 0x20, 0x10, 0x86, 0x77, 0x3f, 0x45, 0xc6, 0x5a, 0x22,
    0xa8, 0xcd, 0xd0, 0xc1, 0x43, 0x96, 0x4a, 0xcd, 0x12, 0x29, 0xb1, 0xac, 0x66, 0x89, 0x22, 0x44,
    0xed, 0x73, 0x7c, 0x95, 0x0d, 0x04, 0x2e, 0x55, 0xfd, 0xf6, 0xa5, 0x35, 0x55, 0xe2, 0x25, 0xc2,
    0x19, 0xba, 0x70, 0x70, 0x70, 0xdf, 0x8f, 0xfe, 0x83, 0x45, 0xb6, 0xed, 0x0b, 0xac, 0xe0, 0x99,
    0xe7, 0xb4, 0x31, 0xa0, 0x56, 0x6b, 0x9e, 0x0f, 0x71, 0x07, 0xd6, 0xa1, 0x56, 0x5b, 0xab, 0x6b,
    0x6c, 0xe1, 0xc1, 0x41, 0x5b, 0xa7, 0xc9, 0xd3, 0x94, 0xe3, 0x4c, 0x53, 0x03, 0x36, 0xb2, 0x22,
    0x4d, 0x1e, 0x27, 0xb1, 0x6b, 0x6d, 0x3b, 0x49, 0x19, 0xf5, 0x06, 0xd5, 0x91, 0xbf, 0x29, 0xbf,
    0xbf, 0xbf, 0xd4, 0xaf, 0xce, 0xc8, 0xf3, 0xe2, 0x6c, 0x6b, 0x59, 0xc2, 0xeb, 0xef, 0x49, 0x36,
    0xbb, 0xb5, 0xcb, 0x87, 0xb0, 0x31, 0xe4, 0x39, 0x87, 0x34, 0x89, 0xbb, 0x09, 0x6f, 0xa4, 0x0b,
    0x53, 0x37, 0x18, 0x34, 0x5f, 0xbe, 0x6b, 0xdd, 0xc6, 0x96, 0xa3, 0x5b, 0xc3, 0x51, 0x96, 0x7d,
    0x48, 0xdf, 0x87, 0xd8, 0xc9, 0x16, 0xab, 0x7b, 0x4a, 0xcd, 0x75, 0x67, 0xe7, 0xcb, 0x9b, 0xf6,
    0x0c, 0x80, 0x17, 0xad, 0x08, 0xbe, 0x28, 0x00, 0x62, 0x75, 0x1c, 0xd0, 0xa8, 0x73, 0x41, 0x37,
    0x9b, 0x2c, 0x98, 0x4e, 0x50, 0xbc, 0xb6, 0x94, 0x75, 0xf2, 0x43, 0xdb, 0x90, 0xc9, 0x50, 0x11,
    0xeb, 0x50, 0x8d, 0x12, 0xd1, 0xe4, 0xcf, 0x71, 0xa7, 0x1c, 0x55, 0xdc, 0x48, 0xb4, 0xfb, 0x1f,
    0xe8, 0xcc, 0x0f, 0x87, 0x58, 0x90, 0x10, 0xa5, 0x36, 0xbd, 0x10, 0x7f, 0xa4, 0xf0, 0x8e, 0x0b,
    0xbf, 0x8a, 0x47, 0x28, 0x08, 0x00, 0x66, 0x1b, 0x17, 0xfb, 0xcf, 0xa6, 0x3d, 0x12, 0x21, 0xe0,
    0xf4, 0x0f, 0x22, 0xfe, 0x23, 0x35, 0x17, 0x33, 0xbc, 0x91, 0xc9, 0x37, 0x36, 0x95, 0xa9, 0xe1
};
#endif

PyTypeObject *init_QOpenGLVersionProfile(PyObject *module)
{
    if (SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLVersionProfile_IDX].type != nullptr)
        return SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLVersionProfile_IDX].type;

    Shiboken::AutoDecRef Sbk_QOpenGLVersionProfile_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QOpenGLVersionProfile_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QOpenGLVersionProfile",
        "QOpenGLVersionProfile",
        &Sbk_QOpenGLVersionProfile_spec,
        &Shiboken::callCppDestructor< ::QOpenGLVersionProfile >,
        Sbk_QOpenGLVersionProfile_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QOpenGLVersionProfile_TypeF(); // references _Sbk_QOpenGLVersionProfile_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QOpenGLVersionProfile_SignatureStrings);
#else
    InitSignatureBytes(pyType, QOpenGLVersionProfile_SignatureBytes, QOpenGLVersionProfile_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QOpenGLVersionProfile_PropertyStrings);
    SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLVersionProfile_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QOpenGLVersionProfile_PythonToCpp_QOpenGLVersionProfile_PTR,
        is_QOpenGLVersionProfile_PythonToCpp_QOpenGLVersionProfile_PTR_Convertible,
        QOpenGLVersionProfile_PTR_CppToPython_QOpenGLVersionProfile,
        QOpenGLVersionProfile_COPY_CppToPython_QOpenGLVersionProfile);

    Shiboken::Conversions::registerConverterName(converter, "QOpenGLVersionProfile");
    Shiboken::Conversions::registerConverterName(converter, "QOpenGLVersionProfile*");
    Shiboken::Conversions::registerConverterName(converter, "QOpenGLVersionProfile&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QOpenGLVersionProfile).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QOpenGLVersionProfile_PythonToCpp_QOpenGLVersionProfile_COPY,
        is_QOpenGLVersionProfile_PythonToCpp_QOpenGLVersionProfile_COPY_Convertible);

    qRegisterMetaType< ::QOpenGLVersionProfile >("QOpenGLVersionProfile");

    return pyType;
}
