// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtopengl_python.h"

// main header
#include "qopenglvertexarrayobject_binder_wrapper.h"

// Argument includes
#include <QtOpenGL/qopenglvertexarrayobject.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QOpenGLVertexArrayObject_Binder_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QOpenGLVertexArrayObject::Binder >()))
        return -1;

    ::QOpenGLVertexArrayObject::Binder *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "Binder", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: Binder::Binder(QOpenGLVertexArrayObject*)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLVertexArrayObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // Binder(QOpenGLVertexArrayObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLVertexArrayObject_Binder_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLVertexArrayObject_Binder_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QOpenGLVertexArrayObject *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Binder(QOpenGLVertexArrayObject*)
            cptr = new ::QOpenGLVertexArrayObject::Binder(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QOpenGLVertexArrayObject::Binder >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLVertexArrayObject_Binder_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QOpenGLVertexArrayObject_BinderFunc___enter__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLVertexArrayObject::Binder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLVertexArrayObject_Binder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // __enter__()
        // Begin code injection
        // ========================================================================
        // START of custom code block [file: ../glue/qtopengl.cpp (vao-binder-enter)]
        Py_INCREF(self);
        pyResult = self;
        // END of custom code block [file: ../glue/qtopengl.cpp (vao-binder-enter)]
        // ========================================================================
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLVertexArrayObject_BinderFunc___exit__(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLVertexArrayObject::Binder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLVertexArrayObject_Binder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "__exit__", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Binder::__exit__(PyObject*,PyObject*,PyObject*)
    if (numArgs == 3
        && true
        && true
        && true) {
        overloadId = 0; // __exit__(PyObject*,PyObject*,PyObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "__exit__", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLVertexArrayObject_Binder_IDX]);

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // __exit__(PyObject*,PyObject*,PyObject*)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtopengl.cpp (vao-binder-exit)]
            cppSelf->release();
            // END of custom code block [file: ../glue/qtopengl.cpp (vao-binder-exit)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLVertexArrayObject_BinderFunc_rebind(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLVertexArrayObject::Binder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLVertexArrayObject_Binder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rebind()
        cppSelf->rebind();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLVertexArrayObject_BinderFunc_release(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLVertexArrayObject::Binder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLVertexArrayObject_Binder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // release()
        cppSelf->release();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QOpenGLVertexArrayObject_Binder_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QOpenGLVertexArrayObject_Binder_methods[] = {
    {"__enter__", reinterpret_cast<PyCFunction>(Sbk_QOpenGLVertexArrayObject_BinderFunc___enter__), METH_NOARGS, nullptr},
    {"__exit__", reinterpret_cast<PyCFunction>(Sbk_QOpenGLVertexArrayObject_BinderFunc___exit__), METH_VARARGS, nullptr},
    {"rebind", reinterpret_cast<PyCFunction>(Sbk_QOpenGLVertexArrayObject_BinderFunc_rebind), METH_NOARGS, nullptr},
    {"release", reinterpret_cast<PyCFunction>(Sbk_QOpenGLVertexArrayObject_BinderFunc_release), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QOpenGLVertexArrayObject_Binder_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QOpenGLVertexArrayObject_Binder_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QOpenGLVertexArrayObject_Binder_Type = nullptr;
static PyTypeObject *Sbk_QOpenGLVertexArrayObject_Binder_TypeF(void)
{
    return _Sbk_QOpenGLVertexArrayObject_Binder_Type;
}

static PyType_Slot Sbk_QOpenGLVertexArrayObject_Binder_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QOpenGLVertexArrayObject_Binder_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QOpenGLVertexArrayObject_Binder_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QOpenGLVertexArrayObject_Binder_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QOpenGLVertexArrayObject_Binder_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QOpenGLVertexArrayObject_Binder_spec = {
    "2:PySide6.QtOpenGL.QOpenGLVertexArrayObject.Binder",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QOpenGLVertexArrayObject_Binder_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void Binder_PythonToCpp_Binder_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QOpenGLVertexArrayObject_Binder_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_Binder_PythonToCpp_Binder_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QOpenGLVertexArrayObject_Binder_TypeF()))
        return Binder_PythonToCpp_Binder_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *Binder_PTR_CppToPython_Binder(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QOpenGLVertexArrayObject_Binder_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QOpenGLVertexArrayObject_Binder_SignatureStrings[] = {
    "PySide6.QtOpenGL.QOpenGLVertexArrayObject.Binder(self,v:PySide6.QtOpenGL.QOpenGLVertexArrayObject)",
    "PySide6.QtOpenGL.QOpenGLVertexArrayObject.Binder.__enter__(self)->PySide6.QtOpenGL.QOpenGLVertexArrayObject.Binder",
    "PySide6.QtOpenGL.QOpenGLVertexArrayObject.Binder.__exit__(self,arg__1:PyObject,arg__2:PyObject,arg__3:PyObject)",
    "PySide6.QtOpenGL.QOpenGLVertexArrayObject.Binder.rebind(self)",
    "PySide6.QtOpenGL.QOpenGLVertexArrayObject.Binder.release(self)",
    nullptr}; // Sentinel
#else
static constexpr size_t QOpenGLVertexArrayObject_Binder_SignatureByteSize = 131;
static constexpr uint8_t QOpenGLVertexArrayObject_Binder_SignatureBytes[131] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0xf1, 0x2f, 0x48, 0xcd,
    0x73, 0xf7, 0xd1, 0x0b, 0x84, 0xd0, 0x61, 0xa9, 0x45, 0x25, 0xa9, 0x15, 0x8e, 0x45, 0x45, 0x89,
    0x95, 0xfe, 0x49, 0x59, 0xa9, 0xc9, 0x25, 0x7a, 0x4e, 0x99, 0x79, 0x29, 0xa9, 0x45, 0x1a, 0xc5,
    0xa9, 0x39, 0x69, 0x3a, 0x65, 0x56, 0x01, 0xc4, 0xea, 0xd3, 0xe4, 0x0a, 0x20, 0xd1, 0x0a, 0xbd,
    0xf8, 0xf8, 0xd4, 0xbc, 0x92, 0xd4, 0xa2, 0xf8, 0x78, 0xb0, 0x65, 0x9a, 0xba, 0x76, 0xa4, 0x9a,
    0x40, 0x96, 0x95, 0x15, 0x99, 0x25, 0x50, 0x1b, 0x75, 0x12, 0x8b, 0xd2, 0xe3, 0xe3, 0x0d, 0x81,
    0x7e, 0x84, 0x28, 0x82, 0xf0, 0x8d, 0xd0, 0xf8, 0xc6, 0x70, 0x3e, 0x19, 0x5e, 0x2c, 0x4a, 0x4d,
    0x02, 0x32, 0x20, 0xfe, 0x23, 0x47, 0x77, 0x4e, 0x6a, 0x62, 0x71, 0x2a, 0x54, 0x3b, 0x00, 0x23,
    0x3d, 0xa1, 0xe6
};
#endif

PyTypeObject *init_QOpenGLVertexArrayObject_Binder(PyObject *enclosingClass)
{
    if (SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLVertexArrayObject_Binder_IDX].type != nullptr)
        return SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLVertexArrayObject_Binder_IDX].type;

    Shiboken::AutoDecRef Sbk_QOpenGLVertexArrayObject_Binder_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QOpenGLVertexArrayObject_Binder_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "Binder",
        "QOpenGLVertexArrayObject::Binder*",
        &Sbk_QOpenGLVertexArrayObject_Binder_spec,
        &Shiboken::callCppDestructor< ::QOpenGLVertexArrayObject::Binder >,
        Sbk_QOpenGLVertexArrayObject_Binder_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
    auto *pyType = Sbk_QOpenGLVertexArrayObject_Binder_TypeF(); // references _Sbk_QOpenGLVertexArrayObject_Binder_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QOpenGLVertexArrayObject_Binder_SignatureStrings);
#else
    InitSignatureBytes(pyType, QOpenGLVertexArrayObject_Binder_SignatureBytes, QOpenGLVertexArrayObject_Binder_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QOpenGLVertexArrayObject_Binder_PropertyStrings);
    SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLVertexArrayObject_Binder_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        Binder_PythonToCpp_Binder_PTR,
        is_Binder_PythonToCpp_Binder_PTR_Convertible,
        Binder_PTR_CppToPython_Binder);

    Shiboken::Conversions::registerConverterName(converter, "QOpenGLVertexArrayObject::Binder");
    Shiboken::Conversions::registerConverterName(converter, "QOpenGLVertexArrayObject::Binder*");
    Shiboken::Conversions::registerConverterName(converter, "QOpenGLVertexArrayObject::Binder&");
    Shiboken::Conversions::registerConverterAlias(converter, "Binder");
    Shiboken::Conversions::registerConverterAlias(converter, "Binder*");
    Shiboken::Conversions::registerConverterAlias(converter, "Binder&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QOpenGLVertexArrayObject::Binder).name());

    qRegisterMetaType< ::QOpenGLVertexArrayObject::Binder *>();

    return pyType;
}
