// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtpdf_python.h"

// main header
#include "qpdfdocument_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QtGui/qimage.h>
#include <QtPdf/qpdfdocument.h>
#include <QtPdf/qpdfdocumentrenderoptions.h>
#include <QtPdf/qpdfselection.h>
#include <qabstractitemmodel.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qiodevice.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qsize.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QPdfDocumentWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QPdfDocumentWrapper::QPdfDocumentWrapper()
{
}

QPdfDocumentWrapper::QPdfDocumentWrapper(::QObject * parent) : QPdfDocument(parent)
{
}

void QPdfDocumentWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPdfDocument", funcName);
        return;
    }
}

void QPdfDocumentWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPdfDocument", funcName);
        return;
    }
}

void QPdfDocumentWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPdfDocument", funcName);
        return;
    }
}

void QPdfDocumentWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPdfDocument", funcName);
        return;
    }
}

bool QPdfDocumentWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPdfDocument", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QPdfDocument", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QPdfDocumentWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPdfDocument", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QPdfDocument", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QPdfDocumentWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPdfDocument", funcName);
        return;
    }
}

const QMetaObject *QPdfDocumentWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QPdfDocument::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QPdfDocumentWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QPdfDocument::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QPdfDocumentWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QPdfDocumentWrapper *>(this));
    return QPdfDocument::qt_metacast(_clname);
}

QPdfDocumentWrapper::~QPdfDocumentWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPdfDocument_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QPdfDocument >()))
        return -1;

    QPdfDocumentWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QPdfDocument", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QPdfDocument::QPdfDocument()
    // 1: QPdfDocument::QPdfDocument(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QPdfDocument()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QPdfDocument(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QPdfDocument()
        {

            // QPdfDocument()
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QPdfDocumentWrapper();
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QPdfDocumentWrapper();
            }

            break;
        }
        case 1: // QPdfDocument(QObject *parent)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QPdfDocument(QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QPdfDocumentWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QPdfDocumentWrapper(cppArg0);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QPdfDocument >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QPdfDocumentFunc_close(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // close()
        cppSelf->close();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPdfDocumentFunc_error(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // error()const
        QPdfDocument::Error cppResult = const_cast<const ::QPdfDocument *>(cppSelf)->error();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_Error_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPdfDocumentFunc_getAllText(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPdfDocument::getAllText(int)->QPdfSelection
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // getAllText(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "getAllText", errInfo, SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // getAllText(int)
            QPdfSelection* cppResult = new QPdfSelection(cppSelf->getAllText(cppArg0));
            pyResult = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfSelection_IDX]), cppResult, true, true);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPdfDocumentFunc_getSelection(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "getSelection", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPdfDocument::getSelection(int,QPointF,QPointF)->QPdfSelection
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[2])))) {
        overloadId = 0; // getSelection(int,QPointF,QPointF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "getSelection", errInfo, SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QPointF cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QPointF cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // getSelection(int,QPointF,QPointF)
            QPdfSelection* cppResult = new QPdfSelection(cppSelf->getSelection(cppArg0, cppArg1, cppArg2));
            pyResult = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfSelection_IDX]), cppResult, true, true);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPdfDocumentFunc_getSelectionAtIndex(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "getSelectionAtIndex", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPdfDocument::getSelectionAtIndex(int,int,int)->QPdfSelection
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        overloadId = 0; // getSelectionAtIndex(int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "getSelectionAtIndex", errInfo, SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // getSelectionAtIndex(int,int,int)
            QPdfSelection* cppResult = new QPdfSelection(cppSelf->getSelectionAtIndex(cppArg0, cppArg1, cppArg2));
            pyResult = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfSelection_IDX]), cppResult, true, true);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPdfDocumentFunc_load(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPdfDocument::load(QIODevice*)
    // 1: QPdfDocument::load(QString)->QPdfDocument::Error
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), (pyArg)))) {
        overloadId = 0; // load(QIODevice*)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 1; // load(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "load", errInfo, SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // load(QIODevice *device)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QIODevice *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // load(QIODevice*)
                cppSelf->load(cppArg0);
                pyResult = Py_None;
                Py_INCREF(Py_None);
            }
            break;
        }
        case 1: // load(const QString &fileName)
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // load(QString)
                QPdfDocument::Error cppResult = cppSelf->load(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_Error_IDX])))->converter, &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPdfDocumentFunc_metaData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPdfDocument::metaData(QPdfDocument::MetaDataField)const->QVariant
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_MetaDataField_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // metaData(QPdfDocument::MetaDataField)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "metaData", errInfo, SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_IDX]);

    // Call function/method
    {
        ::QPdfDocument::MetaDataField cppArg0{QPdfDocument::MetaDataField::Title};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // metaData(QPdfDocument::MetaDataField)const
            QVariant cppResult = const_cast<const ::QPdfDocument *>(cppSelf)->metaData(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPdfDocumentFunc_pageCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pageCount()const
        int cppResult = const_cast<const ::QPdfDocument *>(cppSelf)->pageCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPdfDocumentFunc_pageIndexForLabel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPdfDocument::pageIndexForLabel(QString)->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // pageIndexForLabel(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "pageIndexForLabel", errInfo, SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // pageIndexForLabel(QString)
            int cppResult = cppSelf->pageIndexForLabel(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPdfDocumentFunc_pageLabel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPdfDocument::pageLabel(int)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // pageLabel(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "pageLabel", errInfo, SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // pageLabel(int)
            QString cppResult = cppSelf->pageLabel(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPdfDocumentFunc_pageModel(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pageModel()
        QAbstractListModel * cppResult = cppSelf->pageModel();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractListModel_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPdfDocumentFunc_pagePointSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPdfDocument::pagePointSize(int)const->QSizeF
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // pagePointSize(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "pagePointSize", errInfo, SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // pagePointSize(int)const
            QSizeF cppResult = const_cast<const ::QPdfDocument *>(cppSelf)->pagePointSize(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPdfDocumentFunc_password(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // password()const
        QString cppResult = const_cast<const ::QPdfDocument *>(cppSelf)->password();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPdfDocumentFunc_render(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "render", errInfo, SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:render", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPdfDocument::render(int,QSize,QPdfDocumentRenderOptions=)->QImage
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // render(int,QSize,QPdfDocumentRenderOptions)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocumentRenderOptions_IDX]), (pyArgs[2])))) {
            overloadId = 0; // render(int,QSize,QPdfDocumentRenderOptions)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "render", errInfo, SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_options = Shiboken::String::createStaticString("options");
            if (PyDict_Contains(kwds, key_options) != 0) {
                value = PyDict_GetItem(kwds, key_options);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_options);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "render", errInfo, SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocumentRenderOptions_IDX]), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "render", errInfo, SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_options);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "render", errInfo, SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_IDX]);
            }
        }
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QSize cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QPdfDocumentRenderOptions cppArg2 = QPdfDocumentRenderOptions();
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // render(int,QSize,QPdfDocumentRenderOptions)
            QImage cppResult = cppSelf->render(cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImage_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPdfDocumentFunc_setPassword(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPdfDocument::setPassword(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setPassword(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPassword", errInfo, SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPassword(QString)
            cppSelf->setPassword(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPdfDocumentFunc_status(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // status()const
        QPdfDocument::Status cppResult = const_cast<const ::QPdfDocument *>(cppSelf)->status();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_Status_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QPdfDocument_PropertyStrings[] = {
    "pageCount:",
    "pageModel:",
    "password::",
    "status:",
    nullptr // Sentinel
};

static const char *Sbk_QPdfDocument_EnumFlagInfo[] = {
    "Error:Enum",
    "MetaDataField:Enum",
    "PageModelRole:Enum",
    "Status:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QPdfDocument_methods[] = {
    {"close", reinterpret_cast<PyCFunction>(Sbk_QPdfDocumentFunc_close), METH_NOARGS, nullptr},
    {"error", reinterpret_cast<PyCFunction>(Sbk_QPdfDocumentFunc_error), METH_NOARGS, nullptr},
    {"getAllText", reinterpret_cast<PyCFunction>(Sbk_QPdfDocumentFunc_getAllText), METH_O, nullptr},
    {"getSelection", reinterpret_cast<PyCFunction>(Sbk_QPdfDocumentFunc_getSelection), METH_VARARGS, nullptr},
    {"getSelectionAtIndex", reinterpret_cast<PyCFunction>(Sbk_QPdfDocumentFunc_getSelectionAtIndex), METH_VARARGS, nullptr},
    {"load", reinterpret_cast<PyCFunction>(Sbk_QPdfDocumentFunc_load), METH_O, nullptr},
    {"metaData", reinterpret_cast<PyCFunction>(Sbk_QPdfDocumentFunc_metaData), METH_O, nullptr},
    {"pageCount", reinterpret_cast<PyCFunction>(Sbk_QPdfDocumentFunc_pageCount), METH_NOARGS, nullptr},
    {"pageIndexForLabel", reinterpret_cast<PyCFunction>(Sbk_QPdfDocumentFunc_pageIndexForLabel), METH_O, nullptr},
    {"pageLabel", reinterpret_cast<PyCFunction>(Sbk_QPdfDocumentFunc_pageLabel), METH_O, nullptr},
    {"pageModel", reinterpret_cast<PyCFunction>(Sbk_QPdfDocumentFunc_pageModel), METH_NOARGS, nullptr},
    {"pagePointSize", reinterpret_cast<PyCFunction>(Sbk_QPdfDocumentFunc_pagePointSize), METH_O, nullptr},
    {"password", reinterpret_cast<PyCFunction>(Sbk_QPdfDocumentFunc_password), METH_NOARGS, nullptr},
    {"render", reinterpret_cast<PyCFunction>(Sbk_QPdfDocumentFunc_render), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setPassword", reinterpret_cast<PyCFunction>(Sbk_QPdfDocumentFunc_setPassword), METH_O, nullptr},
    {"status", reinterpret_cast<PyCFunction>(Sbk_QPdfDocumentFunc_status), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QPdfDocument_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QPdfDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QPdfDocumentWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QPdfDocument_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QPdfDocument_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QPdfDocument_Type = nullptr;
static PyTypeObject *Sbk_QPdfDocument_TypeF(void)
{
    return _Sbk_QPdfDocument_Type;
}

static PyType_Slot Sbk_QPdfDocument_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QPdfDocument_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QPdfDocument_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QPdfDocument_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QPdfDocument_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QPdfDocument_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QPdfDocument_spec = {
    "2:PySide6.QtPdf.QPdfDocument",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QPdfDocument_slots
};

} //extern "C"

static void *Sbk_QPdfDocument_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QPdfDocument *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QPdfDocument_Status(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QPdfDocument::Status>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QPdfDocument::Status *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QPdfDocument_Status_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_Status_IDX])))
        return Enum_PythonToCpp_QPdfDocument_Status;
    return {};
}

static PyObject *QPdfDocument_Status_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QPdfDocument::Status>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QPdfDocument::Status *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_Status_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QPdfDocument_Error(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QPdfDocument::Error>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QPdfDocument::Error *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QPdfDocument_Error_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_Error_IDX])))
        return Enum_PythonToCpp_QPdfDocument_Error;
    return {};
}

static PyObject *QPdfDocument_Error_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QPdfDocument::Error>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QPdfDocument::Error *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_Error_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QPdfDocument_MetaDataField(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QPdfDocument::MetaDataField>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QPdfDocument::MetaDataField *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QPdfDocument_MetaDataField_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_MetaDataField_IDX])))
        return Enum_PythonToCpp_QPdfDocument_MetaDataField;
    return {};
}

static PyObject *QPdfDocument_MetaDataField_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QPdfDocument::MetaDataField>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QPdfDocument::MetaDataField *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_MetaDataField_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QPdfDocument_PageModelRole(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QPdfDocument::PageModelRole>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QPdfDocument::PageModelRole *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QPdfDocument_PageModelRole_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_PageModelRole_IDX])))
        return Enum_PythonToCpp_QPdfDocument_PageModelRole;
    return {};
}

static PyObject *QPdfDocument_PageModelRole_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QPdfDocument::PageModelRole>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QPdfDocument::PageModelRole *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_PageModelRole_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QPdfDocument_PythonToCpp_QPdfDocument_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QPdfDocument_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QPdfDocument_PythonToCpp_QPdfDocument_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QPdfDocument_TypeF()))
        return QPdfDocument_PythonToCpp_QPdfDocument_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QPdfDocument_PTR_CppToPython_QPdfDocument(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QPdfDocument *>(const_cast<void *>(cppIn)), Sbk_QPdfDocument_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QPdfDocument_SignatureStrings[] = {
    "1:PySide6.QtPdf.QPdfDocument(self,*:KeywordOnly=None,pageCount:int=None,password:QString=None,status:QPdfDocument.Status=None,pageModel:QAbstractListModel=None)",
    "0:PySide6.QtPdf.QPdfDocument(self,parent:PySide6.QtCore.QObject,*:KeywordOnly=None,pageCount:int=None,password:QString=None,status:QPdfDocument.Status=None,pageModel:QAbstractListModel=None)",
    "PySide6.QtPdf.QPdfDocument.close(self)",
    "PySide6.QtPdf.QPdfDocument.error(self)->PySide6.QtPdf.QPdfDocument.Error",
    "PySide6.QtPdf.QPdfDocument.getAllText(self,page:int)->PySide6.QtPdf.QPdfSelection",
    "PySide6.QtPdf.QPdfDocument.getSelection(self,page:int,start:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],end:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element])->PySide6.QtPdf.QPdfSelection",
    "PySide6.QtPdf.QPdfDocument.getSelectionAtIndex(self,page:int,startIndex:int,maxLength:int)->PySide6.QtPdf.QPdfSelection",
    "1:PySide6.QtPdf.QPdfDocument.load(self,device:PySide6.QtCore.QIODevice)",
    "0:PySide6.QtPdf.QPdfDocument.load(self,fileName:QString)->PySide6.QtPdf.QPdfDocument.Error",
    "PySide6.QtPdf.QPdfDocument.metaData(self,field:PySide6.QtPdf.QPdfDocument.MetaDataField)->QVariant",
    "PySide6.QtPdf.QPdfDocument.pageCount(self)->int",
    "PySide6.QtPdf.QPdfDocument.pageIndexForLabel(self,label:QString)->int",
    "PySide6.QtPdf.QPdfDocument.pageLabel(self,page:int)->QString",
    "PySide6.QtPdf.QPdfDocument.pageModel(self)->PySide6.QtCore.QAbstractListModel",
    "PySide6.QtPdf.QPdfDocument.pagePointSize(self,page:int)->PySide6.QtCore.QSizeF",
    "PySide6.QtPdf.QPdfDocument.password(self)->QString",
    "PySide6.QtPdf.QPdfDocument.render(self,page:int,imageSize:PySide6.QtCore.QSize,options:PySide6.QtPdf.QPdfDocumentRenderOptions=QPdfDocumentRenderOptions())->PySide6.QtGui.QImage",
    "PySide6.QtPdf.QPdfDocument.setPassword(self,password:QString)",
    "PySide6.QtPdf.QPdfDocument.status(self)->PySide6.QtPdf.QPdfDocument.Status",
    nullptr}; // Sentinel
#else
static constexpr size_t QPdfDocument_SignatureByteSize = 468;
static constexpr uint8_t QPdfDocument_SignatureBytes[468] = {
    0x78, 0xda, 0xc5, 0x55, 0xcb, 0x4e, 0xc3, 0x30, 0x10, 0xbc, 0xf3, 0x15, 0x1c, 0x01, 0x85, 0x08,
    0x2e, 0x1c, 0x22, 0x81, 0x54, 0xd1, 0x16, 0x55, 0x14, 0x9a, 0x10, 0xe0, 0x82, 0x38, 0xb8, 0xf1,
    0x36, 0x18, 0x39, 0x76, 0x65, 0x6f, 0xa1, 0xe5, 0xeb, 0xf1, 0x83, 0x94, 0x40, 0x5b, 0xa7, 0x12,
    0x20, 0x2e, 0x91, 0xb3, 0x1e, 0xcf, 0x3e, 0xbc, 0xb3, 0x3e, 0x4e, 0xd2, 0x45, 0xce, 0x28, 0x9c,
    0xc4, 0x19, 0xa6, 0x74, 0x12, 0x67, 0xe6, 0xd3, 0x95, 0xc5, 0xac, 0x02, 0x81, 0x7b, 0x1a, 0xf8,
    0x24, 0x3a, 0x48, 0x2e, 0x61, 0xf1, 0x2a, 0x15, 0x1d, 0x09, 0xbe, 0x38, 0xbd, 0x96, 0x02, 0xa2,
    0x29, 0x29, 0xe1, 0x5c, 0xce, 0x04, 0x26, 0x4c, 0x60, 0x6d, 0xd2, 0xda, 0x82, 0x92, 0x2c, 0x47,
    0xc5, 0x44, 0xe9, 0xad, 0x1a, 0x09, 0xce, 0x74, 0xd2, 0x24, 0x8d, 0x73, 0x67, 0xfb, 0x24, 0xba,
    0x92, 0x14, 0x78, 0x92, 0x75, 0xc6, 0x1a, 0x15, 0x29, 0x70, 0xc8, 0x34, 0x3a, 0x93, 0x43, 0xec,
    0xef, 0x1c, 0xb5, 0x06, 0x38, 0x25, 0xca, 0xac, 0x1b, 0xb0, 0x73, 0xa9, 0x20, 0xce, 0x46, 0xe3,
    0x67, 0x28, 0xf0, 0xbf, 0xc3, 0xdf, 0x1c, 0x7c, 0x5c, 0x70, 0xa9, 0xc1, 0xa5, 0x10, 0x84, 0x81,
    0x52, 0x52, 0x79, 0xd8, 0xe1, 0x59, 0x00, 0xd7, 0xb3, 0xb8, 0x10, 0x51, 0x09, 0xd8, 0xe1, 0xfc,
    0x16, 0xe6, 0xcb, 0xba, 0x95, 0x60, 0x2b, 0xb0, 0x96, 0x36, 0x07, 0x6e, 0xaa, 0xc7, 0xa4, 0x68,
    0x61, 0x5c, 0xe2, 0xbe, 0x72, 0xda, 0xd2, 0x29, 0x4c, 0x70, 0x31, 0x35, 0xc5, 0x8c, 0xef, 0x84,
    0x01, 0x3c, 0x7c, 0xbf, 0xa0, 0x54, 0x1a, 0x60, 0x3f, 0xda, 0x5d, 0x6b, 0x6f, 0x9a, 0x2f, 0x66,
    0xcc, 0x58, 0x89, 0xb1, 0x82, 0x4a, 0x09, 0x3e, 0xc5, 0x3d, 0x0e, 0xd6, 0xff, 0x63, 0x04, 0x82,
    0xfe, 0xb5, 0x8f, 0xdf, 0xa9, 0x4e, 0x07, 0x07, 0x82, 0xc2, 0x7c, 0x5d, 0x91, 0xdc, 0x86, 0xfb,
    0xad, 0xc8, 0x7c, 0x08, 0xa2, 0xc4, 0xa7, 0x2d, 0x6e, 0xe5, 0x38, 0x20, 0x8b, 0x98, 0x4b, 0x42,
    0xbd, 0x2b, 0x0a, 0x2f, 0xac, 0x80, 0x15, 0x6d, 0x0c, 0x46, 0x5d, 0xb7, 0x11, 0x96, 0x57, 0x83,
    0x67, 0xc2, 0x38, 0x5c, 0x93, 0x0a, 0x6a, 0x7d, 0xfc, 0xb0, 0x15, 0x2b, 0x40, 0xd2, 0x25, 0x48,
    0x6a, 0x72, 0xe0, 0x34, 0x14, 0xc7, 0xd5, 0x07, 0xbc, 0x6f, 0x81, 0xc6, 0x75, 0x76, 0x4f, 0x14,
    0x23, 0x02, 0x43, 0x2e, 0x96, 0x22, 0xaf, 0xa5, 0xc3, 0xda, 0xf1, 0xee, 0x2a, 0xfa, 0x52, 0x0d,
    0xc9, 0x18, 0xb8, 0x8f, 0x8d, 0xdb, 0x65, 0x23, 0xeb, 0x2d, 0x58, 0x1a, 0xa7, 0x1b, 0x12, 0xfb,
    0xa0, 0x68, 0x3b, 0xec, 0x66, 0xc7, 0xaa, 0xda, 0xfd, 0xb5, 0xad, 0x0c, 0x99, 0x36, 0x36, 0xd7,
    0xe6, 0x39, 0x7b, 0x83, 0x80, 0xe2, 0x3d, 0xb5, 0x05, 0xf5, 0xc3, 0x74, 0x7e, 0x42, 0xd6, 0xb1,
    0x6d, 0x91, 0x8f, 0x19, 0xcb, 0x14, 0xd4, 0xb7, 0x9e, 0x67, 0x95, 0x59, 0x59, 0x6f, 0xc9, 0xba,
    0x10, 0x22, 0x39, 0xb5, 0xed, 0xad, 0x03, 0xdd, 0x70, 0xe3, 0x58, 0x47, 0x1e, 0x77, 0xba, 0x71,
    0x67, 0x6f, 0xff, 0x4b, 0x96, 0x4e, 0xdf, 0x03, 0xeb, 0x3b, 0x14, 0xb1, 0x06, 0x4c, 0x9b, 0x79,
    0xae, 0xbc, 0x0b, 0xc1, 0x49, 0xed, 0x9f, 0x8b, 0x2d, 0x46, 0xb5, 0x7f, 0x43, 0x76, 0xde, 0x01,
    0x11, 0x7e, 0xb0, 0x46
};
#endif

PyTypeObject *init_QPdfDocument(PyObject *module)
{
    if (SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_IDX].type != nullptr)
        return SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_IDX].type;

    Shiboken::AutoDecRef Sbk_QPdfDocument_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QPdfDocument_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QPdfDocument",
        "QPdfDocument*",
        &Sbk_QPdfDocument_spec,
        &Shiboken::callCppDestructor< QPdfDocument >,
        Sbk_QPdfDocument_Type_bases.object(),
        0);
    auto *pyType = Sbk_QPdfDocument_TypeF(); // references _Sbk_QPdfDocument_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QPdfDocument_SignatureStrings);
#else
    InitSignatureBytes(pyType, QPdfDocument_SignatureBytes, QPdfDocument_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QPdfDocument_PropertyStrings);
    SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QPdfDocument_PythonToCpp_QPdfDocument_PTR,
        is_QPdfDocument_PythonToCpp_QPdfDocument_PTR_Convertible,
        QPdfDocument_PTR_CppToPython_QPdfDocument);

    Shiboken::Conversions::registerConverterName(converter, "QPdfDocument");
    Shiboken::Conversions::registerConverterName(converter, "QPdfDocument*");
    Shiboken::Conversions::registerConverterName(converter, "QPdfDocument&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QPdfDocument).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QPdfDocumentWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QPdfDocument_TypeF(), &Sbk_QPdfDocument_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QPdfDocument_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Status'.
    const char *Status_Initializer[] = {
        "Null",
        "Loading",
        "Ready",
        "Unloading",
        "Error",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t Status_InitializerValues[] = {
        int8_t(QPdfDocument::Status::Null),      //  0x00  0
        int8_t(QPdfDocument::Status::Loading),   //  0x01  1
        int8_t(QPdfDocument::Status::Ready),     //  0x02  2
        int8_t(QPdfDocument::Status::Unloading), //  0x03  3
        int8_t(QPdfDocument::Status::Error)      //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QPdfDocument_TypeF(),
        "2:PySide6.QtPdf.QPdfDocument.Status",
        Status_Initializer, Status_InitializerValues);
    SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_Status_IDX].type = EType;
    // Register converter for enum 'QPdfDocument::Status'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QPdfDocument_Status_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QPdfDocument_Status,
            is_Enum_PythonToCpp_QPdfDocument_Status_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QPdfDocument::Status");
        Shiboken::Conversions::registerConverterAlias(converter, "Status");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Status' enum.

    // Initialization of enum 'Error'.
    const char *Error_Initializer[] = {
        "None_",
        "Unknown",
        "DataNotYetAvailable",
        "FileNotFound",
        "InvalidFileFormat",
        "IncorrectPassword",
        "UnsupportedSecurityScheme",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t Error_InitializerValues[] = {
        int8_t(QPdfDocument::Error::None),                     //  0x00  0
        int8_t(QPdfDocument::Error::Unknown),                  //  0x01  1
        int8_t(QPdfDocument::Error::DataNotYetAvailable),      //  0x02  2
        int8_t(QPdfDocument::Error::FileNotFound),             //  0x03  3
        int8_t(QPdfDocument::Error::InvalidFileFormat),        //  0x04  4
        int8_t(QPdfDocument::Error::IncorrectPassword),        //  0x05  5
        int8_t(QPdfDocument::Error::UnsupportedSecurityScheme) //  0x06  6
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QPdfDocument_TypeF(),
        "2:PySide6.QtPdf.QPdfDocument.Error",
        Error_Initializer, Error_InitializerValues);
    SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_Error_IDX].type = EType;
    // Register converter for enum 'QPdfDocument::Error'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QPdfDocument_Error_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QPdfDocument_Error,
            is_Enum_PythonToCpp_QPdfDocument_Error_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QPdfDocument::Error");
        Shiboken::Conversions::registerConverterAlias(converter, "Error");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Error' enum.

    // Initialization of enum 'MetaDataField'.
    const char *MetaDataField_Initializer[] = {
        "Title",
        "Subject",
        "Author",
        "Keywords",
        "Producer",
        "Creator",
        "CreationDate",
        "ModificationDate",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t MetaDataField_InitializerValues[] = {
        int8_t(QPdfDocument::MetaDataField::Title),           //  0x00  0
        int8_t(QPdfDocument::MetaDataField::Subject),         //  0x01  1
        int8_t(QPdfDocument::MetaDataField::Author),          //  0x02  2
        int8_t(QPdfDocument::MetaDataField::Keywords),        //  0x03  3
        int8_t(QPdfDocument::MetaDataField::Producer),        //  0x04  4
        int8_t(QPdfDocument::MetaDataField::Creator),         //  0x05  5
        int8_t(QPdfDocument::MetaDataField::CreationDate),    //  0x06  6
        int8_t(QPdfDocument::MetaDataField::ModificationDate) //  0x07  7
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QPdfDocument_TypeF(),
        "2:PySide6.QtPdf.QPdfDocument.MetaDataField",
        MetaDataField_Initializer, MetaDataField_InitializerValues);
    SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_MetaDataField_IDX].type = EType;
    // Register converter for enum 'QPdfDocument::MetaDataField'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QPdfDocument_MetaDataField_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QPdfDocument_MetaDataField,
            is_Enum_PythonToCpp_QPdfDocument_MetaDataField_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QPdfDocument::MetaDataField");
        Shiboken::Conversions::registerConverterAlias(converter, "MetaDataField");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'MetaDataField' enum.

    // Initialization of enum 'PageModelRole'.
    const char *PageModelRole_Initializer[] = {
        "Label",
        "PointSize",
        "NRoles",
        nullptr};
    // "int16_t" used instead of "int"
    constexpr int16_t PageModelRole_InitializerValues[] = {
        int16_t(QPdfDocument::PageModelRole::Label),     //  0x0100  256
        int16_t(QPdfDocument::PageModelRole::PointSize), //  0x0101  257
        int16_t(QPdfDocument::PageModelRole::NRoles)     //  0x0102  258
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QPdfDocument_TypeF(),
        "2:PySide6.QtPdf.QPdfDocument.PageModelRole",
        PageModelRole_Initializer, PageModelRole_InitializerValues);
    SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_PageModelRole_IDX].type = EType;
    // Register converter for enum 'QPdfDocument::PageModelRole'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QPdfDocument_PageModelRole_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QPdfDocument_PageModelRole,
            is_Enum_PythonToCpp_QPdfDocument_PageModelRole_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QPdfDocument::PageModelRole");
        Shiboken::Conversions::registerConverterAlias(converter, "PageModelRole");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'PageModelRole' enum.

    PySide::Signal::registerSignals(pyType, &::QPdfDocument::staticMetaObject);
    qRegisterMetaType< ::QPdfDocument::Status >("QPdfDocument::Status");
    qRegisterMetaType< ::QPdfDocument::Error >("QPdfDocument::Error");
    qRegisterMetaType< ::QPdfDocument::MetaDataField >("QPdfDocument::MetaDataField");
    qRegisterMetaType< ::QPdfDocument::PageModelRole >("QPdfDocument::PageModelRole");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QPdfDocument::staticMetaObject, sizeof(QPdfDocumentWrapper));

    return pyType;
}
