// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtpdf_python.h"

// main header
#include "qpdflink_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtGui/qclipboard.h>
#include <QtPdf/qpdflink.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qrect.h>
#include <qurl.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPdfLink_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QPdfLink >()))
        return -1;

    ::QPdfLink *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QPdfLink", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QPdfLink::QPdfLink()
    // 1: QPdfLink::QPdfLink(QPdfLink)
    if (numArgs == 0) {
        overloadId = 0; // QPdfLink()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfLink_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QPdfLink(QPdfLink)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtPdfTypeStructs[SBK_QPdfLink_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtPdfTypeStructs[SBK_QPdfLink_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QPdfLink()
        {

            // QPdfLink()
            cptr = new ::QPdfLink();
            break;
        }
        case 1: // QPdfLink(const QPdfLink &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPdfLink cppArg0_local;
            ::QPdfLink *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QPdfLink(QPdfLink)
                cptr = new ::QPdfLink(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QPdfLink >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtPdfTypeStructs[SBK_QPdfLink_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QPdfLinkFunc_contextAfter(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfLink *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfLink_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // contextAfter()const
        QString cppResult = const_cast<const ::QPdfLink *>(cppSelf)->contextAfter();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPdfLinkFunc_contextBefore(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfLink *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfLink_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // contextBefore()const
        QString cppResult = const_cast<const ::QPdfLink *>(cppSelf)->contextBefore();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPdfLinkFunc_copyToClipboard(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfLink *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfLink_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "copyToClipboard", errInfo, SbkPySide6_QtPdfTypeStructs[SBK_QPdfLink_IDX]);

    if (PyArg_ParseTuple(args, "|O:copyToClipboard", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPdfLink::copyToClipboard(QClipboard::Mode=)const
    if (numArgs == 0) {
        overloadId = 0; // copyToClipboard(QClipboard::Mode)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_Mode_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // copyToClipboard(QClipboard::Mode)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "copyToClipboard", errInfo, SbkPySide6_QtPdfTypeStructs[SBK_QPdfLink_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
            if (PyDict_Contains(kwds, key_mode) != 0) {
                value = PyDict_GetItem(kwds, key_mode);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_mode);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "copyToClipboard", errInfo, SbkPySide6_QtPdfTypeStructs[SBK_QPdfLink_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_Mode_IDX])))->converter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "copyToClipboard", errInfo, SbkPySide6_QtPdfTypeStructs[SBK_QPdfLink_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_mode);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "copyToClipboard", errInfo, SbkPySide6_QtPdfTypeStructs[SBK_QPdfLink_IDX]);
            }
        }
        ::QClipboard::Mode cppArg0(QClipboard::Clipboard);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // copyToClipboard(QClipboard::Mode)const
            const_cast<const ::QPdfLink *>(cppSelf)->copyToClipboard(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPdfLinkFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfLink *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfLink_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QPdfLink *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPdfLinkFunc_location(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfLink *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfLink_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // location()const
        QPointF cppResult = const_cast<const ::QPdfLink *>(cppSelf)->location();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPdfLinkFunc_page(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfLink *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfLink_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // page()const
        int cppResult = const_cast<const ::QPdfLink *>(cppSelf)->page();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPdfLinkFunc_rectangles(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfLink *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfLink_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rectangles()const
        QList<QRectF> cppResult = const_cast<const ::QPdfLink *>(cppSelf)->rectangles();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtPdfTypeConverters[SBK_QtPdf_QList_QRectF_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPdfLinkFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfLink *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfLink_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPdfLink::swap(QPdfLink&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfLink_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QPdfLink&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtPdfTypeStructs[SBK_QPdfLink_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPdfLink cppArg0_local;
        ::QPdfLink *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QPdfLink&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPdfLinkFunc_toString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfLink *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfLink_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toString()const
        QString cppResult = const_cast<const ::QPdfLink *>(cppSelf)->toString();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPdfLinkFunc_url(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfLink *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfLink_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // url()const
        QUrl cppResult = const_cast<const ::QPdfLink *>(cppSelf)->url();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPdfLinkFunc_zoom(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfLink *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfLink_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // zoom()const
        qreal cppResult = const_cast<const ::QPdfLink *>(cppSelf)->zoom();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPdfLink__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QPdfLink *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfLink_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfLink_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QPdfLink_PropertyStrings[] = {
    "contextAfter:",
    "contextBefore:",
    "location:",
    "page:",
    "rectangles:",
    "url:",
    "valid:isValid",
    "zoom:",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QPdfLink_methods[] = {
    {"contextAfter", reinterpret_cast<PyCFunction>(Sbk_QPdfLinkFunc_contextAfter), METH_NOARGS, nullptr},
    {"contextBefore", reinterpret_cast<PyCFunction>(Sbk_QPdfLinkFunc_contextBefore), METH_NOARGS, nullptr},
    {"copyToClipboard", reinterpret_cast<PyCFunction>(Sbk_QPdfLinkFunc_copyToClipboard), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QPdfLinkFunc_isValid), METH_NOARGS, nullptr},
    {"location", reinterpret_cast<PyCFunction>(Sbk_QPdfLinkFunc_location), METH_NOARGS, nullptr},
    {"page", reinterpret_cast<PyCFunction>(Sbk_QPdfLinkFunc_page), METH_NOARGS, nullptr},
    {"rectangles", reinterpret_cast<PyCFunction>(Sbk_QPdfLinkFunc_rectangles), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QPdfLinkFunc_swap), METH_O, nullptr},
    {"toString", reinterpret_cast<PyCFunction>(Sbk_QPdfLinkFunc_toString), METH_NOARGS, nullptr},
    {"url", reinterpret_cast<PyCFunction>(Sbk_QPdfLinkFunc_url), METH_NOARGS, nullptr},
    {"zoom", reinterpret_cast<PyCFunction>(Sbk_QPdfLinkFunc_zoom), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QPdfLink__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QPdfLink_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QPdfLink_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QPdfLink__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfLink *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfLink_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QPdfLink_Type = nullptr;
static PyTypeObject *Sbk_QPdfLink_TypeF(void)
{
    return _Sbk_QPdfLink_Type;
}

static PyType_Slot Sbk_QPdfLink_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QPdfLink__repr__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QPdfLink_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QPdfLink_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QPdfLink_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QPdfLink_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QPdfLink_spec = {
    "2:PySide6.QtPdf.QPdfLink",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QPdfLink_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QPdfLink_PythonToCpp_QPdfLink_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QPdfLink_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QPdfLink_PythonToCpp_QPdfLink_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QPdfLink_TypeF()))
        return QPdfLink_PythonToCpp_QPdfLink_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QPdfLink_PTR_CppToPython_QPdfLink(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QPdfLink_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QPdfLink_COPY_CppToPython_QPdfLink(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QPdfLink *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QPdfLink_TypeF(), new ::QPdfLink(*source), true, true);
}

// Python to C++ copy conversion.
static void QPdfLink_PythonToCpp_QPdfLink_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QPdfLink *>(cppOut) = *reinterpret_cast< ::QPdfLink *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfLink_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QPdfLink_PythonToCpp_QPdfLink_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QPdfLink_TypeF()))
        return QPdfLink_PythonToCpp_QPdfLink_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QPdfLink_SignatureStrings[] = {
    "1:PySide6.QtPdf.QPdfLink(self,*:KeywordOnly=None,valid:bool=None,page:int=None,location:QPointF=None,zoom:qreal=None,url:QUrl=None,contextBefore:QString=None,contextAfter:QString=None,rectangles:QList[PySide6.QtCore.QRectF]=None)",
    "0:PySide6.QtPdf.QPdfLink(self,other:PySide6.QtPdf.QPdfLink,*:KeywordOnly=None,valid:bool=None,page:int=None,location:QPointF=None,zoom:qreal=None,url:QUrl=None,contextBefore:QString=None,contextAfter:QString=None,rectangles:QList[PySide6.QtCore.QRectF]=None)",
    "PySide6.QtPdf.QPdfLink.contextAfter(self)->QString",
    "PySide6.QtPdf.QPdfLink.contextBefore(self)->QString",
    "PySide6.QtPdf.QPdfLink.copyToClipboard(self,mode:PySide6.QtGui.QClipboard.Mode=QClipboard.Clipboard)",
    "PySide6.QtPdf.QPdfLink.isValid(self)->bool",
    "PySide6.QtPdf.QPdfLink.location(self)->PySide6.QtCore.QPointF",
    "PySide6.QtPdf.QPdfLink.page(self)->int",
    "PySide6.QtPdf.QPdfLink.rectangles(self)->QList[PySide6.QtCore.QRectF]",
    "PySide6.QtPdf.QPdfLink.swap(self,other:PySide6.QtPdf.QPdfLink)",
    "PySide6.QtPdf.QPdfLink.toString(self)->QString",
    "PySide6.QtPdf.QPdfLink.url(self)->PySide6.QtCore.QUrl",
    "PySide6.QtPdf.QPdfLink.zoom(self)->qreal",
    "PySide6.QtPdf.QPdfLink.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QPdfLink_SignatureByteSize = 322;
static constexpr uint8_t QPdfLink_SignatureBytes[322] = {
    0x78, 0xda, 0xdd, 0x52, 0x41, 0x4e, 0xc3, 0x30, 0x10, 0xbc, 0xf7, 0x25, 0x14, 0x15, 0x0b, 0x2e,
    0x1c, 0x2c, 0x15, 0x09, 0x2a, 0x95, 0x03, 0x05, 0x62, 0x02, 0x5c, 0x50, 0x15, 0xb9, 0xc9, 0x26,
    0x58, 0xb8, 0xde, 0xe0, 0xb8, 0x94, 0xf0, 0x7a, 0x9c, 0x38, 0x49, 0x53, 0x54, 0xb7, 0x3d, 0x73,
    0x89, 0xb2, 0xf6, 0xcc, 0x7a, 0x77, 0x66, 0x2e, 0x68, 0x50, 0x86, 0x22, 0x81, 0x4b, 0xc2, 0x4c,
    0x90, 0xa4, 0x84, 0xd9, 0xcf, 0x4c, 0xa8, 0x8f, 0x93, 0x02, 0x64, 0x3a, 0x3a, 0xa5, 0x77, 0x50,
    0xae, 0x51, 0x27, 0x8f, 0x4a, 0x96, 0xe3, 0x07, 0x54, 0x30, 0xfa, 0xe2, 0x52, 0x24, 0x74, 0x81,
    0x28, 0x5d, 0x9d, 0xf3, 0x0c, 0xa8, 0x50, 0xc6, 0x55, 0x12, 0x63, 0x6e, 0x04, 0x2a, 0xca, 0x02,
    0xb4, 0x87, 0x53, 0x77, 0xfa, 0x83, 0xb8, 0xa4, 0x9f, 0x1a, 0x78, 0xc3, 0x59, 0x69, 0x49, 0xd9,
    0x8b, 0x6e, 0xaa, 0x18, 0x95, 0x81, 0x6f, 0x73, 0x03, 0x29, 0x6a, 0xa0, 0x2c, 0x34, 0x5a, 0xa8,
    0x6c, 0xeb, 0xea, 0x3a, 0x35, 0xa0, 0xb7, 0x6f, 0x34, 0xc4, 0x86, 0xab, 0x4c, 0x42, 0x41, 0xd9,
    0x4c, 0x14, 0xe6, 0x6d, 0xb3, 0xc6, 0xc4, 0xb6, 0x21, 0xec, 0xc9, 0x02, 0xa6, 0xf3, 0x1a, 0x3c,
    0x1c, 0x9c, 0xef, 0xdd, 0x12, 0xcd, 0xbb, 0x6d, 0xbf, 0x1b, 0xf1, 0x6f, 0x24, 0xd8, 0xbd, 0x1e,
    0xe9, 0xb7, 0xaf, 0xd5, 0x18, 0x9e, 0x5d, 0x35, 0xaf, 0x1c, 0xa0, 0xb8, 0x61, 0x8f, 0xe6, 0xe4,
    0xe5, 0x33, 0x4e, 0xa4, 0xc8, 0x17, 0xc8, 0x75, 0xe2, 0x74, 0x5f, 0x62, 0x02, 0x3d, 0xd9, 0x6f,
    0x57, 0x82, 0xb0, 0x0e, 0x42, 0xee, 0xed, 0xed, 0xb8, 0x57, 0x77, 0x7f, 0xde, 0x5d, 0x44, 0xf1,
    0x5a, 0x39, 0xd3, 0x8e, 0x54, 0x19, 0xe4, 0x83, 0xb6, 0x26, 0xb5, 0xd8, 0xbf, 0xd2, 0x39, 0xeb,
    0x7c, 0xec, 0xca, 0xf0, 0x96, 0x69, 0x71, 0x3e, 0xd8, 0xc6, 0xa0, 0x4e, 0xa5, 0x3d, 0x3e, 0xf9,
    0xba, 0x14, 0x6b, 0x9e, 0x1f, 0xce, 0xa9, 0x57, 0x14, 0x83, 0xce, 0x99, 0x23, 0x8d, 0xb2, 0xb9,
    0xf4, 0x69, 0x62, 0xd3, 0xea, 0x63, 0x55, 0xe9, 0x6e, 0x69, 0x75, 0xc8, 0x7d, 0xc0, 0x28, 0xaa,
    0x92, 0x10, 0x45, 0x2d, 0xd8, 0x94, 0xb9, 0x1d, 0x86, 0x84, 0xb6, 0x1a, 0xfc, 0x02, 0xf3, 0xc1,
    0x9d, 0xc5
};
#endif

PyTypeObject *init_QPdfLink(PyObject *module)
{
    if (SbkPySide6_QtPdfTypeStructs[SBK_QPdfLink_IDX].type != nullptr)
        return SbkPySide6_QtPdfTypeStructs[SBK_QPdfLink_IDX].type;

    Shiboken::AutoDecRef Sbk_QPdfLink_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QPdfLink_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QPdfLink",
        "QPdfLink",
        &Sbk_QPdfLink_spec,
        &Shiboken::callCppDestructor< ::QPdfLink >,
        Sbk_QPdfLink_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QPdfLink_TypeF(); // references _Sbk_QPdfLink_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QPdfLink_SignatureStrings);
#else
    InitSignatureBytes(pyType, QPdfLink_SignatureBytes, QPdfLink_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QPdfLink_PropertyStrings);
    SbkPySide6_QtPdfTypeStructs[SBK_QPdfLink_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QPdfLink_PythonToCpp_QPdfLink_PTR,
        is_QPdfLink_PythonToCpp_QPdfLink_PTR_Convertible,
        QPdfLink_PTR_CppToPython_QPdfLink,
        QPdfLink_COPY_CppToPython_QPdfLink);

    Shiboken::Conversions::registerConverterName(converter, "QPdfLink");
    Shiboken::Conversions::registerConverterName(converter, "QPdfLink*");
    Shiboken::Conversions::registerConverterName(converter, "QPdfLink&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QPdfLink).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QPdfLink_PythonToCpp_QPdfLink_COPY,
        is_QPdfLink_PythonToCpp_QPdfLink_COPY_Convertible);


    return pyType;
}
