// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtpositioning_python.h"

// main header
#include "qgeoaddress_wrapper.h"

// Argument includes
#include <QString>
#include <QtPositioning/qgeoaddress.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGeoAddress_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QGeoAddress >()))
        return -1;

    ::QGeoAddress *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QGeoAddress", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QGeoAddress::QGeoAddress()
    // 1: QGeoAddress::QGeoAddress(QGeoAddress)
    if (numArgs == 0) {
        overloadId = 0; // QGeoAddress()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QGeoAddress(QGeoAddress)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QGeoAddress()
        {

            // QGeoAddress()
            cptr = new ::QGeoAddress();
            break;
        }
        case 1: // QGeoAddress(const QGeoAddress &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QGeoAddress cppArg0_local;
            ::QGeoAddress *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QGeoAddress(QGeoAddress)
                cptr = new ::QGeoAddress(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QGeoAddress >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QGeoAddressFunc_city(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // city()const
        QString cppResult = const_cast<const ::QGeoAddress *>(cppSelf)->city();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoAddressFunc_clear(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clear()
        cppSelf->clear();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoAddressFunc_country(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // country()const
        QString cppResult = const_cast<const ::QGeoAddress *>(cppSelf)->country();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoAddressFunc_countryCode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // countryCode()const
        QString cppResult = const_cast<const ::QGeoAddress *>(cppSelf)->countryCode();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoAddressFunc_county(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // county()const
        QString cppResult = const_cast<const ::QGeoAddress *>(cppSelf)->county();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoAddressFunc_district(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // district()const
        QString cppResult = const_cast<const ::QGeoAddress *>(cppSelf)->district();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoAddressFunc_isEmpty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isEmpty()const
        bool cppResult = const_cast<const ::QGeoAddress *>(cppSelf)->isEmpty();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoAddressFunc_isTextGenerated(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isTextGenerated()const
        bool cppResult = const_cast<const ::QGeoAddress *>(cppSelf)->isTextGenerated();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoAddressFunc_postalCode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // postalCode()const
        QString cppResult = const_cast<const ::QGeoAddress *>(cppSelf)->postalCode();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoAddressFunc_setCity(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoAddress::setCity(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setCity(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCity", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCity(QString)
            cppSelf->setCity(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoAddressFunc_setCountry(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoAddress::setCountry(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setCountry(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCountry", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCountry(QString)
            cppSelf->setCountry(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoAddressFunc_setCountryCode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoAddress::setCountryCode(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setCountryCode(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCountryCode", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCountryCode(QString)
            cppSelf->setCountryCode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoAddressFunc_setCounty(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoAddress::setCounty(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setCounty(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCounty", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCounty(QString)
            cppSelf->setCounty(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoAddressFunc_setDistrict(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoAddress::setDistrict(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setDistrict(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDistrict", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDistrict(QString)
            cppSelf->setDistrict(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoAddressFunc_setPostalCode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoAddress::setPostalCode(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setPostalCode(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPostalCode", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPostalCode(QString)
            cppSelf->setPostalCode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoAddressFunc_setState(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoAddress::setState(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setState(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setState", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setState(QString)
            cppSelf->setState(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoAddressFunc_setStreet(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoAddress::setStreet(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setStreet(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStreet", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStreet(QString)
            cppSelf->setStreet(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoAddressFunc_setStreetNumber(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoAddress::setStreetNumber(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setStreetNumber(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStreetNumber", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStreetNumber(QString)
            cppSelf->setStreetNumber(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoAddressFunc_setText(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoAddress::setText(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setText(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setText", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setText(QString)
            cppSelf->setText(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoAddressFunc_state(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // state()const
        QString cppResult = const_cast<const ::QGeoAddress *>(cppSelf)->state();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoAddressFunc_street(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // street()const
        QString cppResult = const_cast<const ::QGeoAddress *>(cppSelf)->street();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoAddressFunc_streetNumber(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // streetNumber()const
        QString cppResult = const_cast<const ::QGeoAddress *>(cppSelf)->streetNumber();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoAddressFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoAddress::swap(QGeoAddress&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QGeoAddress&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGeoAddress cppArg0_local;
        ::QGeoAddress *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QGeoAddress&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoAddressFunc_text(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // text()const
        QString cppResult = const_cast<const ::QGeoAddress *>(cppSelf)->text();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoAddress__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QGeoAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QGeoAddress_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QGeoAddress_methods[] = {
    {"city", reinterpret_cast<PyCFunction>(Sbk_QGeoAddressFunc_city), METH_NOARGS, nullptr},
    {"clear", reinterpret_cast<PyCFunction>(Sbk_QGeoAddressFunc_clear), METH_NOARGS, nullptr},
    {"country", reinterpret_cast<PyCFunction>(Sbk_QGeoAddressFunc_country), METH_NOARGS, nullptr},
    {"countryCode", reinterpret_cast<PyCFunction>(Sbk_QGeoAddressFunc_countryCode), METH_NOARGS, nullptr},
    {"county", reinterpret_cast<PyCFunction>(Sbk_QGeoAddressFunc_county), METH_NOARGS, nullptr},
    {"district", reinterpret_cast<PyCFunction>(Sbk_QGeoAddressFunc_district), METH_NOARGS, nullptr},
    {"isEmpty", reinterpret_cast<PyCFunction>(Sbk_QGeoAddressFunc_isEmpty), METH_NOARGS, nullptr},
    {"isTextGenerated", reinterpret_cast<PyCFunction>(Sbk_QGeoAddressFunc_isTextGenerated), METH_NOARGS, nullptr},
    {"postalCode", reinterpret_cast<PyCFunction>(Sbk_QGeoAddressFunc_postalCode), METH_NOARGS, nullptr},
    {"setCity", reinterpret_cast<PyCFunction>(Sbk_QGeoAddressFunc_setCity), METH_O, nullptr},
    {"setCountry", reinterpret_cast<PyCFunction>(Sbk_QGeoAddressFunc_setCountry), METH_O, nullptr},
    {"setCountryCode", reinterpret_cast<PyCFunction>(Sbk_QGeoAddressFunc_setCountryCode), METH_O, nullptr},
    {"setCounty", reinterpret_cast<PyCFunction>(Sbk_QGeoAddressFunc_setCounty), METH_O, nullptr},
    {"setDistrict", reinterpret_cast<PyCFunction>(Sbk_QGeoAddressFunc_setDistrict), METH_O, nullptr},
    {"setPostalCode", reinterpret_cast<PyCFunction>(Sbk_QGeoAddressFunc_setPostalCode), METH_O, nullptr},
    {"setState", reinterpret_cast<PyCFunction>(Sbk_QGeoAddressFunc_setState), METH_O, nullptr},
    {"setStreet", reinterpret_cast<PyCFunction>(Sbk_QGeoAddressFunc_setStreet), METH_O, nullptr},
    {"setStreetNumber", reinterpret_cast<PyCFunction>(Sbk_QGeoAddressFunc_setStreetNumber), METH_O, nullptr},
    {"setText", reinterpret_cast<PyCFunction>(Sbk_QGeoAddressFunc_setText), METH_O, nullptr},
    {"state", reinterpret_cast<PyCFunction>(Sbk_QGeoAddressFunc_state), METH_NOARGS, nullptr},
    {"street", reinterpret_cast<PyCFunction>(Sbk_QGeoAddressFunc_street), METH_NOARGS, nullptr},
    {"streetNumber", reinterpret_cast<PyCFunction>(Sbk_QGeoAddressFunc_streetNumber), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QGeoAddressFunc_swap), METH_O, nullptr},
    {"text", reinterpret_cast<PyCFunction>(Sbk_QGeoAddressFunc_text), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QGeoAddress__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QGeoAddress_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QGeoAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]), (pyArg)))) {
                // operator!=(const QGeoAddress &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QGeoAddress cppArg0_local;
                ::QGeoAddress *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]), (pyArg)))) {
                // operator==(const QGeoAddress &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QGeoAddress cppArg0_local;
                ::QGeoAddress *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static Py_hash_t Sbk_QGeoAddress_HashFunc(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return Py_hash_t(qHash(*cppSelf));
}

static int Sbk_QGeoAddress_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QGeoAddress_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QGeoAddress_Type = nullptr;
static PyTypeObject *Sbk_QGeoAddress_TypeF(void)
{
    return _Sbk_QGeoAddress_Type;
}

static PyType_Slot Sbk_QGeoAddress_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_hash,        reinterpret_cast<void *>(&Sbk_QGeoAddress_HashFunc)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QGeoAddress_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QGeoAddress_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QGeoAddress_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QGeoAddress_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QGeoAddress_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QGeoAddress_spec = {
    "2:PySide6.QtPositioning.QGeoAddress",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QGeoAddress_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QGeoAddress_PythonToCpp_QGeoAddress_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QGeoAddress_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QGeoAddress_PythonToCpp_QGeoAddress_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QGeoAddress_TypeF()))
        return QGeoAddress_PythonToCpp_QGeoAddress_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QGeoAddress_PTR_CppToPython_QGeoAddress(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QGeoAddress_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QGeoAddress_COPY_CppToPython_QGeoAddress(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QGeoAddress *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QGeoAddress_TypeF(), new ::QGeoAddress(*source), true, true);
}

// Python to C++ copy conversion.
static void QGeoAddress_PythonToCpp_QGeoAddress_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QGeoAddress *>(cppOut) = *reinterpret_cast< ::QGeoAddress *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QGeoAddress_PythonToCpp_QGeoAddress_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QGeoAddress_TypeF()))
        return QGeoAddress_PythonToCpp_QGeoAddress_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QGeoAddress_SignatureStrings[] = {
    "1:PySide6.QtPositioning.QGeoAddress(self)",
    "0:PySide6.QtPositioning.QGeoAddress(self,other:PySide6.QtPositioning.QGeoAddress)",
    "PySide6.QtPositioning.QGeoAddress.city(self)->QString",
    "PySide6.QtPositioning.QGeoAddress.clear(self)",
    "PySide6.QtPositioning.QGeoAddress.country(self)->QString",
    "PySide6.QtPositioning.QGeoAddress.countryCode(self)->QString",
    "PySide6.QtPositioning.QGeoAddress.county(self)->QString",
    "PySide6.QtPositioning.QGeoAddress.district(self)->QString",
    "PySide6.QtPositioning.QGeoAddress.isEmpty(self)->bool",
    "PySide6.QtPositioning.QGeoAddress.isTextGenerated(self)->bool",
    "PySide6.QtPositioning.QGeoAddress.postalCode(self)->QString",
    "PySide6.QtPositioning.QGeoAddress.setCity(self,city:QString)",
    "PySide6.QtPositioning.QGeoAddress.setCountry(self,country:QString)",
    "PySide6.QtPositioning.QGeoAddress.setCountryCode(self,countryCode:QString)",
    "PySide6.QtPositioning.QGeoAddress.setCounty(self,county:QString)",
    "PySide6.QtPositioning.QGeoAddress.setDistrict(self,district:QString)",
    "PySide6.QtPositioning.QGeoAddress.setPostalCode(self,postalCode:QString)",
    "PySide6.QtPositioning.QGeoAddress.setState(self,state:QString)",
    "PySide6.QtPositioning.QGeoAddress.setStreet(self,street:QString)",
    "PySide6.QtPositioning.QGeoAddress.setStreetNumber(self,streetNumber:QString)",
    "PySide6.QtPositioning.QGeoAddress.setText(self,text:QString)",
    "PySide6.QtPositioning.QGeoAddress.state(self)->QString",
    "PySide6.QtPositioning.QGeoAddress.street(self)->QString",
    "PySide6.QtPositioning.QGeoAddress.streetNumber(self)->QString",
    "PySide6.QtPositioning.QGeoAddress.swap(self,other:PySide6.QtPositioning.QGeoAddress)",
    "PySide6.QtPositioning.QGeoAddress.text(self)->QString",
    "PySide6.QtPositioning.QGeoAddress.__copy__(self)->typing.Self",
    "PySide6.QtPositioning.QGeoAddress.__ne__(self,rhs:PySide6.QtPositioning.QGeoAddress)->bool",
    "PySide6.QtPositioning.QGeoAddress.__eq__(self,rhs:PySide6.QtPositioning.QGeoAddress)->bool",
    "PySide6.QtPositioning.QGeoAddress.__hash__(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t QGeoAddress_SignatureByteSize = 304;
static constexpr uint8_t QGeoAddress_SignatureBytes[304] = {
    0x78, 0xda, 0xb5, 0x94, 0x4d, 0x4f, 0x84, 0x30, 0x10, 0x86, 0xef, 0xfc, 0x12, 0x49, 0x2a, 0xd1,
    0x8b, 0x87, 0x3d, 0x98, 0x98, 0xd5, 0xec, 0xcd, 0x40, 0xf0, 0xde, 0xb0, 0x74, 0x94, 0x26, 0x6c,
    0x8b, 0x9d, 0xd9, 0x28, 0xff, 0x5e, 0x48, 0x61, 0xa9, 0xa7, 0xed, 0x34, 0x7a, 0x2b, 0x74, 0x9e,
    0x77, 0x3e, 0xde, 0x49, 0xef, 0x77, 0xe5, 0x58, 0x6b, 0x05, 0x0f, 0x45, 0x45, 0xa5, 0x45, 0x4d,
    0xda, 0x1a, 0x6d, 0x3e, 0x8a, 0xea, 0x00, 0xf6, 0x49, 0x29, 0x07, 0x88, 0x37, 0x08, 0xfd, 0x7b,
    0x9e, 0xdd, 0x45, 0x46, 0x0a, 0x4b, 0x1d, 0xb8, 0xeb, 0xc1, 0x79, 0x76, 0x35, 0xa4, 0x68, 0x35,
    0x8d, 0x3e, 0xfd, 0xed, 0x63, 0x55, 0x93, 0x9b, 0xee, 0x63, 0xa8, 0x1e, 0x1a, 0xb7, 0x54, 0x1d,
    0x11, 0x6d, 0xcf, 0x86, 0x5c, 0x4a, 0x1a, 0x0f, 0xee, 0xad, 0x82, 0x44, 0x38, 0x21, 0xa9, 0xd2,
    0x38, 0x85, 0xb6, 0xc4, 0x27, 0x35, 0xbe, 0x9c, 0x86, 0x2d, 0xe5, 0xd1, 0xda, 0x3e, 0x8a, 0x7a,
    0x83, 0x6f, 0x3a, 0x80, 0x01, 0xd7, 0x10, 0x28, 0x26, 0x3d, 0x58, 0xa4, 0xa6, 0x4f, 0x9b, 0x10,
    0x02, 0xed, 0x57, 0xfb, 0xc5, 0xbc, 0x08, 0xbb, 0x85, 0xcd, 0x23, 0xe1, 0xc0, 0x57, 0xb1, 0x78,
    0x95, 0x26, 0x71, 0xa9, 0x5f, 0x04, 0x96, 0xa7, 0x48, 0x85, 0xc5, 0x70, 0x6b, 0x79, 0x0e, 0x8d,
    0x17, 0xeb, 0x1a, 0x30, 0x45, 0xca, 0xdf, 0x7e, 0x88, 0xcd, 0x1f, 0xa6, 0x50, 0x4d, 0xd3, 0x36,
    0x78, 0x0d, 0x9c, 0x8f, 0x6c, 0xdc, 0x01, 0xd0, 0xca, 0xcf, 0xe7, 0x24, 0x81, 0xd7, 0xf3, 0xe9,
    0x08, 0x2e, 0x94, 0xf1, 0x7f, 0x98, 0x62, 0xf3, 0x86, 0x7b, 0x11, 0x9a, 0x4e, 0x2c, 0xf8, 0x32,
    0x06, 0xde, 0x6a, 0x6f, 0xed, 0x27, 0x70, 0x41, 0xd7, 0x3c, 0xfa, 0xab, 0x19, 0xfe, 0xfc, 0x85,
    0xa6, 0x75, 0x76, 0xac, 0x52, 0xa4, 0x6c, 0xed, 0x30, 0x4a, 0xb9, 0x92, 0x34, 0x0e, 0x73, 0x48,
    0x3d, 0x7d, 0x45, 0xd1, 0x06, 0x16, 0x56, 0xb8, 0x0e, 0x23, 0x1a, 0x89, 0x7e, 0xb0, 0xa4, 0x84,
    0xcf, 0x7f, 0x93, 0xee, 0x1a, 0xec, 0xb6, 0x9e, 0xb5, 0xa1, 0xec, 0x07, 0x40, 0x34, 0xbf, 0xf0
};
#endif

PyTypeObject *init_QGeoAddress(PyObject *module)
{
    if (SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX].type != nullptr)
        return SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX].type;

    Shiboken::AutoDecRef Sbk_QGeoAddress_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QGeoAddress_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QGeoAddress",
        "QGeoAddress",
        &Sbk_QGeoAddress_spec,
        &Shiboken::callCppDestructor< ::QGeoAddress >,
        Sbk_QGeoAddress_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QGeoAddress_TypeF(); // references _Sbk_QGeoAddress_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QGeoAddress_SignatureStrings);
#else
    InitSignatureBytes(pyType, QGeoAddress_SignatureBytes, QGeoAddress_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QGeoAddress_PropertyStrings);
    SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QGeoAddress_PythonToCpp_QGeoAddress_PTR,
        is_QGeoAddress_PythonToCpp_QGeoAddress_PTR_Convertible,
        QGeoAddress_PTR_CppToPython_QGeoAddress,
        QGeoAddress_COPY_CppToPython_QGeoAddress);

    Shiboken::Conversions::registerConverterName(converter, "QGeoAddress");
    Shiboken::Conversions::registerConverterName(converter, "QGeoAddress*");
    Shiboken::Conversions::registerConverterName(converter, "QGeoAddress&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QGeoAddress).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QGeoAddress_PythonToCpp_QGeoAddress_COPY,
        is_QGeoAddress_PythonToCpp_QGeoAddress_COPY_Convertible);

    qRegisterMetaType< ::QGeoAddress >("QGeoAddress");

    return pyType;
}
