// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtpositioning_python.h"

// main header
#include "qgeoareamonitorinfo_wrapper.h"

// Argument includes
#include <QMap>
#include <QString>
#include <QtPositioning/qgeoareamonitorinfo.h>
#include <QtPositioning/qgeoshape.h>
#include <qdatastream.h>
#include <qdatetime.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGeoAreaMonitorInfo_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QGeoAreaMonitorInfo >()))
        return -1;

    ::QGeoAreaMonitorInfo *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX]);

    if (PyArg_ParseTuple(args, "|O:QGeoAreaMonitorInfo", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QGeoAreaMonitorInfo::QGeoAreaMonitorInfo(QGeoAreaMonitorInfo)
    // 1: QGeoAreaMonitorInfo::QGeoAreaMonitorInfo(const QString&=)
    if (numArgs == 0) {
        overloadId = 1; // QGeoAreaMonitorInfo(QString)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 1; // QGeoAreaMonitorInfo(QString)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QGeoAreaMonitorInfo(QGeoAreaMonitorInfo)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QGeoAreaMonitorInfo(const QGeoAreaMonitorInfo &other)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QGeoAreaMonitorInfo cppArg0_local;
            ::QGeoAreaMonitorInfo *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QGeoAreaMonitorInfo(QGeoAreaMonitorInfo)
                cptr = new ::QGeoAreaMonitorInfo(*cppArg0);
            }
            break;
        }
        case 1: // QGeoAreaMonitorInfo(const QString &name)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_name = Shiboken::String::createStaticString("name");
                if (PyDict_Contains(kwds, key_name) != 0) {
                    value = PyDict_GetItem(kwds, key_name);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_name);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_name);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX]);
                }
            }
            ::QString cppArg0 = QString();
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QGeoAreaMonitorInfo(QString)
                cptr = new ::QGeoAreaMonitorInfo(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QGeoAreaMonitorInfo >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QGeoAreaMonitorInfoFunc_area(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoAreaMonitorInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // area()const
        QGeoShape cppResult = const_cast<const ::QGeoAreaMonitorInfo *>(cppSelf)->area();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoShape_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoAreaMonitorInfoFunc_expiration(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoAreaMonitorInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // expiration()const
        QDateTime cppResult = const_cast<const ::QGeoAreaMonitorInfo *>(cppSelf)->expiration();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoAreaMonitorInfoFunc_identifier(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoAreaMonitorInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // identifier()const
        QString cppResult = const_cast<const ::QGeoAreaMonitorInfo *>(cppSelf)->identifier();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoAreaMonitorInfoFunc_isPersistent(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoAreaMonitorInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isPersistent()const
        bool cppResult = const_cast<const ::QGeoAreaMonitorInfo *>(cppSelf)->isPersistent();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoAreaMonitorInfoFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoAreaMonitorInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QGeoAreaMonitorInfo *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoAreaMonitorInfoFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoAreaMonitorInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // name()const
        QString cppResult = const_cast<const ::QGeoAreaMonitorInfo *>(cppSelf)->name();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoAreaMonitorInfoFunc_notificationParameters(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoAreaMonitorInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // notificationParameters()const
        QMap<QString,QVariant> cppResult = const_cast<const ::QGeoAreaMonitorInfo *>(cppSelf)->notificationParameters();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtPositioningTypeConverters[SBK_QtPositioning_QMap_QString_QVariant_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoAreaMonitorInfoFunc_setArea(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoAreaMonitorInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoAreaMonitorInfo::setArea(QGeoShape)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoShape_IDX]), (pyArg)))) {
        overloadId = 0; // setArea(QGeoShape)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setArea", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGeoShape cppArg0_local;
        ::QGeoShape *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setArea(QGeoShape)
            cppSelf->setArea(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoAreaMonitorInfoFunc_setExpiration(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoAreaMonitorInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoAreaMonitorInfo::setExpiration(QDateTime)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // setExpiration(QDateTime)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setExpiration", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setExpiration(QDateTime)
            cppSelf->setExpiration(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoAreaMonitorInfoFunc_setName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoAreaMonitorInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoAreaMonitorInfo::setName(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setName", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setName(QString)
            cppSelf->setName(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoAreaMonitorInfoFunc_setNotificationParameters(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoAreaMonitorInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoAreaMonitorInfo::setNotificationParameters(QMap<QString,QVariant>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtPositioningTypeConverters[SBK_QtPositioning_QMap_QString_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // setNotificationParameters(QMap<QString,QVariant>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setNotificationParameters", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX]);

    // Call function/method
    {
        ::QMap<QString,QVariant> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setNotificationParameters(QMap<QString,QVariant>)
            cppSelf->setNotificationParameters(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoAreaMonitorInfoFunc_setPersistent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoAreaMonitorInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoAreaMonitorInfo::setPersistent(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setPersistent(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPersistent", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPersistent(bool)
            cppSelf->setPersistent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoAreaMonitorInfoFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoAreaMonitorInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoAreaMonitorInfo::swap(QGeoAreaMonitorInfo&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QGeoAreaMonitorInfo&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGeoAreaMonitorInfo cppArg0_local;
        ::QGeoAreaMonitorInfo *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QGeoAreaMonitorInfo&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoAreaMonitorInfo__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QGeoAreaMonitorInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QGeoAreaMonitorInfo_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QGeoAreaMonitorInfo_methods[] = {
    {"area", reinterpret_cast<PyCFunction>(Sbk_QGeoAreaMonitorInfoFunc_area), METH_NOARGS, nullptr},
    {"expiration", reinterpret_cast<PyCFunction>(Sbk_QGeoAreaMonitorInfoFunc_expiration), METH_NOARGS, nullptr},
    {"identifier", reinterpret_cast<PyCFunction>(Sbk_QGeoAreaMonitorInfoFunc_identifier), METH_NOARGS, nullptr},
    {"isPersistent", reinterpret_cast<PyCFunction>(Sbk_QGeoAreaMonitorInfoFunc_isPersistent), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QGeoAreaMonitorInfoFunc_isValid), METH_NOARGS, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_QGeoAreaMonitorInfoFunc_name), METH_NOARGS, nullptr},
    {"notificationParameters", reinterpret_cast<PyCFunction>(Sbk_QGeoAreaMonitorInfoFunc_notificationParameters), METH_NOARGS, nullptr},
    {"setArea", reinterpret_cast<PyCFunction>(Sbk_QGeoAreaMonitorInfoFunc_setArea), METH_O, nullptr},
    {"setExpiration", reinterpret_cast<PyCFunction>(Sbk_QGeoAreaMonitorInfoFunc_setExpiration), METH_O, nullptr},
    {"setName", reinterpret_cast<PyCFunction>(Sbk_QGeoAreaMonitorInfoFunc_setName), METH_O, nullptr},
    {"setNotificationParameters", reinterpret_cast<PyCFunction>(Sbk_QGeoAreaMonitorInfoFunc_setNotificationParameters), METH_O, nullptr},
    {"setPersistent", reinterpret_cast<PyCFunction>(Sbk_QGeoAreaMonitorInfoFunc_setPersistent), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QGeoAreaMonitorInfoFunc_swap), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QGeoAreaMonitorInfo__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QGeoAreaMonitorInfoFunc___lshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoAreaMonitorInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rlshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QGeoAreaMonitorInfo::operator<<(QDataStream&)->QDataStream&
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // operator<<(QDataStream&,QGeoAreaMonitorInfo)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator<<", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator<<(QDataStream&,QGeoAreaMonitorInfo) [reverse operator]
                QDataStream & cppResult = (*cppArg0) << (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoAreaMonitorInfoFunc___rshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoAreaMonitorInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rrshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QGeoAreaMonitorInfo::operator>>(QDataStream&)->QDataStream&
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // operator>>(QDataStream&,QGeoAreaMonitorInfo&)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator>>", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator>>(QDataStream&,QGeoAreaMonitorInfo&) [reverse operator]
                QDataStream & cppResult = (*cppArg0) >> (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

// Rich comparison
static PyObject * Sbk_QGeoAreaMonitorInfo_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QGeoAreaMonitorInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX]), (pyArg)))) {
                // operator!=(const QGeoAreaMonitorInfo &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QGeoAreaMonitorInfo cppArg0_local;
                ::QGeoAreaMonitorInfo *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX]), (pyArg)))) {
                // operator==(const QGeoAreaMonitorInfo &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QGeoAreaMonitorInfo cppArg0_local;
                ::QGeoAreaMonitorInfo *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static Py_hash_t Sbk_QGeoAreaMonitorInfo_HashFunc(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoAreaMonitorInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return Py_hash_t(qHash(*cppSelf));
}

static int Sbk_QGeoAreaMonitorInfo_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QGeoAreaMonitorInfo_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QGeoAreaMonitorInfo__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoAreaMonitorInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QGeoAreaMonitorInfo_Type = nullptr;
static PyTypeObject *Sbk_QGeoAreaMonitorInfo_TypeF(void)
{
    return _Sbk_QGeoAreaMonitorInfo_Type;
}

static PyType_Slot Sbk_QGeoAreaMonitorInfo_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QGeoAreaMonitorInfo__repr__)},
    {Py_tp_hash,        reinterpret_cast<void *>(&Sbk_QGeoAreaMonitorInfo_HashFunc)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QGeoAreaMonitorInfo_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QGeoAreaMonitorInfo_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QGeoAreaMonitorInfo_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QGeoAreaMonitorInfo_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QGeoAreaMonitorInfo_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_lshift,      reinterpret_cast<void *>(Sbk_QGeoAreaMonitorInfoFunc___lshift__)},
    {Py_nb_rshift,      reinterpret_cast<void *>(Sbk_QGeoAreaMonitorInfoFunc___rshift__)},
    {0, nullptr}
};
static PyType_Spec Sbk_QGeoAreaMonitorInfo_spec = {
    "2:PySide6.QtPositioning.QGeoAreaMonitorInfo",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QGeoAreaMonitorInfo_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QGeoAreaMonitorInfo_PythonToCpp_QGeoAreaMonitorInfo_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QGeoAreaMonitorInfo_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QGeoAreaMonitorInfo_PythonToCpp_QGeoAreaMonitorInfo_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QGeoAreaMonitorInfo_TypeF()))
        return QGeoAreaMonitorInfo_PythonToCpp_QGeoAreaMonitorInfo_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QGeoAreaMonitorInfo_PTR_CppToPython_QGeoAreaMonitorInfo(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QGeoAreaMonitorInfo_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QGeoAreaMonitorInfo_COPY_CppToPython_QGeoAreaMonitorInfo(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QGeoAreaMonitorInfo *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QGeoAreaMonitorInfo_TypeF(), new ::QGeoAreaMonitorInfo(*source), true, true);
}

// Python to C++ copy conversion.
static void QGeoAreaMonitorInfo_PythonToCpp_QGeoAreaMonitorInfo_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QGeoAreaMonitorInfo *>(cppOut) = *reinterpret_cast< ::QGeoAreaMonitorInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QGeoAreaMonitorInfo_PythonToCpp_QGeoAreaMonitorInfo_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QGeoAreaMonitorInfo_TypeF()))
        return QGeoAreaMonitorInfo_PythonToCpp_QGeoAreaMonitorInfo_COPY;
    return {};
}

// Implicit conversions.
static void PySide6_QtCore_constQStringREF_PythonToCpp_QGeoAreaMonitorInfo(PyObject *pyIn, void *cppOut)
{
    ::QString cppIn;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], pyIn, &cppIn);
    *reinterpret_cast<::QGeoAreaMonitorInfo *>(cppOut) = ::QGeoAreaMonitorInfo(cppIn);
}
static PythonToCppFunc is_PySide6_QtCore_constQStringREF_PythonToCpp_QGeoAreaMonitorInfo_Convertible(PyObject *pyIn)
{
    if (PyUnicode_Check(pyIn))
        return PySide6_QtCore_constQStringREF_PythonToCpp_QGeoAreaMonitorInfo;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QGeoAreaMonitorInfo_SignatureStrings[] = {
    "1:PySide6.QtPositioning.QGeoAreaMonitorInfo(self,other:PySide6.QtPositioning.QGeoAreaMonitorInfo)",
    "0:PySide6.QtPositioning.QGeoAreaMonitorInfo(self,name:QString=QString())",
    "PySide6.QtPositioning.QGeoAreaMonitorInfo.area(self)->PySide6.QtPositioning.QGeoShape",
    "PySide6.QtPositioning.QGeoAreaMonitorInfo.expiration(self)->PySide6.QtCore.QDateTime",
    "PySide6.QtPositioning.QGeoAreaMonitorInfo.identifier(self)->QString",
    "PySide6.QtPositioning.QGeoAreaMonitorInfo.isPersistent(self)->bool",
    "PySide6.QtPositioning.QGeoAreaMonitorInfo.isValid(self)->bool",
    "PySide6.QtPositioning.QGeoAreaMonitorInfo.name(self)->QString",
    "PySide6.QtPositioning.QGeoAreaMonitorInfo.notificationParameters(self)->QMap[QString, QVariant]",
    "PySide6.QtPositioning.QGeoAreaMonitorInfo.setArea(self,newShape:PySide6.QtPositioning.QGeoShape)",
    "PySide6.QtPositioning.QGeoAreaMonitorInfo.setExpiration(self,expiry:PySide6.QtCore.QDateTime)",
    "PySide6.QtPositioning.QGeoAreaMonitorInfo.setName(self,name:QString)",
    "PySide6.QtPositioning.QGeoAreaMonitorInfo.setNotificationParameters(self,parameters:QMap[QString, QVariant])",
    "PySide6.QtPositioning.QGeoAreaMonitorInfo.setPersistent(self,isPersistent:bool)",
    "PySide6.QtPositioning.QGeoAreaMonitorInfo.swap(self,other:typing.Union[PySide6.QtPositioning.QGeoAreaMonitorInfo, QString])",
    "PySide6.QtPositioning.QGeoAreaMonitorInfo.__copy__(self)->typing.Self",
    "PySide6.QtPositioning.QGeoAreaMonitorInfo.__lshift__(self,ds:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "PySide6.QtPositioning.QGeoAreaMonitorInfo.__rshift__(self,ds:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "PySide6.QtPositioning.QGeoAreaMonitorInfo.__ne__(self,rhs:typing.Union[PySide6.QtPositioning.QGeoAreaMonitorInfo, QString])->bool",
    "PySide6.QtPositioning.QGeoAreaMonitorInfo.__eq__(self,rhs:typing.Union[PySide6.QtPositioning.QGeoAreaMonitorInfo, QString])->bool",
    "PySide6.QtPositioning.QGeoAreaMonitorInfo.__hash__(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t QGeoAreaMonitorInfo_SignatureByteSize = 354;
static constexpr uint8_t QGeoAreaMonitorInfo_SignatureBytes[354] = {
    0x78, 0xda, 0xc5, 0x94, 0xc1, 0x4a, 0xc3, 0x40, 0x10, 0x86, 0xef, 0x7d, 0x0a, 0x8f, 0x0d, 0xac,
    0x41, 0x2f, 0x1e, 0x02, 0x0a, 0x45, 0x45, 0x3c, 0x54, 0x12, 0xa2, 0xbd, 0x14, 0x09, 0xd3, 0x66,
    0x62, 0x16, 0xd2, 0xdd, 0x75, 0x77, 0xa0, 0xe6, 0xed, 0xdd, 0xc4, 0xa4, 0xb6, 0xda, 0x60, 0xa7,
    0x1e, 0x7a, 0x0a, 0x43, 0x66, 0xbe, 0x7f, 0x66, 0xf6, 0xdf, 0xbd, 0x8c, 0xe2, 0x3a, 0x95, 0x39,
    0x5e, 0x85, 0x09, 0xc5, 0xda, 0x49, 0x92, 0x5a, 0x49, 0xf5, 0x16, 0x26, 0x0f, 0xa8, 0x27, 0x16,
    0x61, 0xea, 0x43, 0xd2, 0xf6, 0x51, 0x15, 0x7a, 0xec, 0xb0, 0x2a, 0x84, 0xa6, 0x12, 0xed, 0xe1,
    0x45, 0xc1, 0xe8, 0x82, 0xab, 0xa0, 0x60, 0x85, 0x51, 0x92, 0x92, 0xf5, 0x59, 0xd7, 0xdd, 0x77,
    0x1c, 0x04, 0xa3, 0x83, 0x31, 0x21, 0xf8, 0xb8, 0x65, 0x05, 0xe7, 0x37, 0xc3, 0x55, 0x69, 0x09,
    0x06, 0x19, 0x54, 0xfc, 0x30, 0xd2, 0x42, 0x93, 0xf1, 0x9b, 0x7d, 0xab, 0x2d, 0x86, 0xc9, 0x1d,
    0x10, 0x3e, 0xcb, 0x15, 0x07, 0xea, 0xd3, 0x14, 0xc9, 0x42, 0xa2, 0xed, 0xa1, 0xdd, 0xc4, 0x1c,
    0x86, 0x8b, 0xd1, 0x3a, 0xe9, 0xc8, 0xa3, 0x7a, 0xca, 0x42, 0xeb, 0x8a, 0x85, 0x98, 0x41, 0x25,
    0xf3, 0x23, 0xab, 0x9b, 0x13, 0x3b, 0xbe, 0x7d, 0xa5, 0x9b, 0x05, 0x2c, 0xdb, 0xcd, 0xc6, 0x60,
    0x3d, 0x8b, 0xfc, 0x38, 0x1b, 0xde, 0x14, 0xcc, 0xbc, 0x83, 0x8a, 0xb3, 0x64, 0x06, 0x56, 0x82,
    0xa2, 0x57, 0x06, 0xdf, 0x21, 0x4d, 0x7a, 0x43, 0x08, 0x85, 0xeb, 0xf6, 0xdc, 0xa3, 0x3f, 0x7c,
    0x11, 0xf0, 0x04, 0xee, 0x77, 0xbd, 0x21, 0x5a, 0xaf, 0xd4, 0xd1, 0x90, 0x41, 0x98, 0xf4, 0xa7,
    0x7e, 0xbf, 0x3b, 0x77, 0x83, 0x0b, 0x19, 0x5e, 0xb3, 0x30, 0x9b, 0x38, 0x1a, 0xd8, 0x37, 0x53,
    0xec, 0x87, 0x21, 0xc5, 0xb6, 0x45, 0xa3, 0xc6, 0x5d, 0x2c, 0xde, 0x1a, 0xcc, 0xf6, 0xe3, 0x43,
    0xb5, 0x69, 0x52, 0x5f, 0x94, 0xaf, 0x99, 0x1f, 0x8c, 0xf1, 0xc3, 0x7c, 0x4d, 0xc5, 0x9a, 0x25,
    0xcb, 0x96, 0xda, 0xd4, 0x59, 0xd6, 0xdb, 0xb1, 0xd3, 0x4e, 0x7d, 0xc4, 0xa2, 0x54, 0xae, 0x94,
    0x05, 0x75, 0x1c, 0x91, 0xbb, 0x7d, 0xd6, 0x00, 0xdf, 0x1f, 0xc2, 0x6a, 0xff, 0xc3, 0xd2, 0xfd,
    0x64, 0x89, 0xda, 0x53, 0x88, 0x2a, 0xec, 0x05, 0x6d, 0xe9, 0xfe, 0x7f, 0x56, 0xec, 0xc7, 0x28,
    0xcb, 0xf0, 0xfd, 0xd4, 0x1d, 0x94, 0xe0, 0xca, 0x6f, 0xcf, 0x48, 0x45, 0xa3, 0x4f, 0xbb, 0xaa,
    0xba, 0x12
};
#endif

PyTypeObject *init_QGeoAreaMonitorInfo(PyObject *module)
{
    if (SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX].type != nullptr)
        return SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX].type;

    Shiboken::AutoDecRef Sbk_QGeoAreaMonitorInfo_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QGeoAreaMonitorInfo_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QGeoAreaMonitorInfo",
        "QGeoAreaMonitorInfo",
        &Sbk_QGeoAreaMonitorInfo_spec,
        &Shiboken::callCppDestructor< ::QGeoAreaMonitorInfo >,
        Sbk_QGeoAreaMonitorInfo_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QGeoAreaMonitorInfo_TypeF(); // references _Sbk_QGeoAreaMonitorInfo_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QGeoAreaMonitorInfo_SignatureStrings);
#else
    InitSignatureBytes(pyType, QGeoAreaMonitorInfo_SignatureBytes, QGeoAreaMonitorInfo_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QGeoAreaMonitorInfo_PropertyStrings);
    SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAreaMonitorInfo_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QGeoAreaMonitorInfo_PythonToCpp_QGeoAreaMonitorInfo_PTR,
        is_QGeoAreaMonitorInfo_PythonToCpp_QGeoAreaMonitorInfo_PTR_Convertible,
        QGeoAreaMonitorInfo_PTR_CppToPython_QGeoAreaMonitorInfo,
        QGeoAreaMonitorInfo_COPY_CppToPython_QGeoAreaMonitorInfo);

    Shiboken::Conversions::registerConverterName(converter, "QGeoAreaMonitorInfo");
    Shiboken::Conversions::registerConverterName(converter, "QGeoAreaMonitorInfo*");
    Shiboken::Conversions::registerConverterName(converter, "QGeoAreaMonitorInfo&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QGeoAreaMonitorInfo).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QGeoAreaMonitorInfo_PythonToCpp_QGeoAreaMonitorInfo_COPY,
        is_QGeoAreaMonitorInfo_PythonToCpp_QGeoAreaMonitorInfo_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        PySide6_QtCore_constQStringREF_PythonToCpp_QGeoAreaMonitorInfo,
        is_PySide6_QtCore_constQStringREF_PythonToCpp_QGeoAreaMonitorInfo_Convertible);

    qRegisterMetaType< ::QGeoAreaMonitorInfo >("QGeoAreaMonitorInfo");

    return pyType;
}
