// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtpositioning_python.h"

// main header
#include "qgeocoordinate_wrapper.h"

// Argument includes
#include <QString>
#include <QtPositioning/qgeocoordinate.h>
#include <qdatastream.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGeoCoordinate_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QGeoCoordinate >()))
        return -1;

    ::QGeoCoordinate *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QGeoCoordinate", 0, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QGeoCoordinate::QGeoCoordinate()
    // 1: QGeoCoordinate::QGeoCoordinate(QGeoCoordinate)
    // 2: QGeoCoordinate::QGeoCoordinate(double,double)
    // 3: QGeoCoordinate::QGeoCoordinate(double,double,double)
    if (numArgs == 0) {
        overloadId = 0; // QGeoCoordinate()
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 2; // QGeoCoordinate(double,double)
        } else if (numArgs == 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[2])))) {
            overloadId = 3; // QGeoCoordinate(double,double,double)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QGeoCoordinate(QGeoCoordinate)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QGeoCoordinate()
        {

            // QGeoCoordinate()
            cptr = new ::QGeoCoordinate();
            break;
        }
        case 1: // QGeoCoordinate(const QGeoCoordinate &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QGeoCoordinate cppArg0_local;
            ::QGeoCoordinate *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QGeoCoordinate(QGeoCoordinate)
                cptr = new ::QGeoCoordinate(*cppArg0);
            }
            break;
        }
        case 2: // QGeoCoordinate(double latitude, double longitude)
        {
            double cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            double cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QGeoCoordinate(double,double)
                cptr = new ::QGeoCoordinate(cppArg0, cppArg1);
            }
            break;
        }
        case 3: // QGeoCoordinate(double latitude, double longitude, double altitude)
        {
            double cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            double cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            double cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QGeoCoordinate(double,double,double)
                cptr = new ::QGeoCoordinate(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QGeoCoordinate >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QGeoCoordinateFunc_altitude(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoCoordinate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // altitude()const
        double cppResult = const_cast<const ::QGeoCoordinate *>(cppSelf)->altitude();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<double>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoCoordinateFunc_atDistanceAndAzimuth(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoCoordinate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "atDistanceAndAzimuth", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:atDistanceAndAzimuth", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGeoCoordinate::atDistanceAndAzimuth(qreal,qreal,qreal=)const->QGeoCoordinate
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // atDistanceAndAzimuth(qreal,qreal,qreal)const
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[2])))) {
            overloadId = 0; // atDistanceAndAzimuth(qreal,qreal,qreal)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "atDistanceAndAzimuth", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_distanceUp = Shiboken::String::createStaticString("distanceUp");
            if (PyDict_Contains(kwds, key_distanceUp) != 0) {
                value = PyDict_GetItem(kwds, key_distanceUp);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_distanceUp);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "atDistanceAndAzimuth", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "atDistanceAndAzimuth", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_distanceUp);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "atDistanceAndAzimuth", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]);
            }
        }
        qreal cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qreal cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        qreal cppArg2 = 0.0;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // atDistanceAndAzimuth(qreal,qreal,qreal)const
            QGeoCoordinate cppResult = const_cast<const ::QGeoCoordinate *>(cppSelf)->atDistanceAndAzimuth(cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoCoordinateFunc_azimuthTo(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoCoordinate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoCoordinate::azimuthTo(QGeoCoordinate)const->qreal
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), (pyArg)))) {
        overloadId = 0; // azimuthTo(QGeoCoordinate)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "azimuthTo", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGeoCoordinate cppArg0_local;
        ::QGeoCoordinate *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // azimuthTo(QGeoCoordinate)const
            qreal cppResult = const_cast<const ::QGeoCoordinate *>(cppSelf)->azimuthTo(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoCoordinateFunc_distanceTo(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoCoordinate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoCoordinate::distanceTo(QGeoCoordinate)const->qreal
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), (pyArg)))) {
        overloadId = 0; // distanceTo(QGeoCoordinate)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "distanceTo", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGeoCoordinate cppArg0_local;
        ::QGeoCoordinate *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // distanceTo(QGeoCoordinate)const
            qreal cppResult = const_cast<const ::QGeoCoordinate *>(cppSelf)->distanceTo(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoCoordinateFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoCoordinate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QGeoCoordinate *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoCoordinateFunc_latitude(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoCoordinate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // latitude()const
        double cppResult = const_cast<const ::QGeoCoordinate *>(cppSelf)->latitude();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<double>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoCoordinateFunc_longitude(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoCoordinate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // longitude()const
        double cppResult = const_cast<const ::QGeoCoordinate *>(cppSelf)->longitude();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<double>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoCoordinateFunc_setAltitude(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoCoordinate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoCoordinate::setAltitude(double)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArg)))) {
        overloadId = 0; // setAltitude(double)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAltitude", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]);

    // Call function/method
    {
        double cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAltitude(double)
            cppSelf->setAltitude(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoCoordinateFunc_setLatitude(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoCoordinate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoCoordinate::setLatitude(double)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArg)))) {
        overloadId = 0; // setLatitude(double)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLatitude", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]);

    // Call function/method
    {
        double cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLatitude(double)
            cppSelf->setLatitude(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoCoordinateFunc_setLongitude(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoCoordinate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoCoordinate::setLongitude(double)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArg)))) {
        overloadId = 0; // setLongitude(double)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLongitude", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]);

    // Call function/method
    {
        double cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLongitude(double)
            cppSelf->setLongitude(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoCoordinateFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoCoordinate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoCoordinate::swap(QGeoCoordinate&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QGeoCoordinate&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGeoCoordinate cppArg0_local;
        ::QGeoCoordinate *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QGeoCoordinate&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoCoordinateFunc_toString(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoCoordinate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "toString", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]);

    if (PyArg_ParseTuple(args, "|O:toString", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGeoCoordinate::toString(QGeoCoordinate::CoordinateFormat=)const->QString
    if (numArgs == 0) {
        overloadId = 0; // toString(QGeoCoordinate::CoordinateFormat)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_CoordinateFormat_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // toString(QGeoCoordinate::CoordinateFormat)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "toString", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_format = Shiboken::String::createStaticString("format");
            if (PyDict_Contains(kwds, key_format) != 0) {
                value = PyDict_GetItem(kwds, key_format);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_format);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "toString", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_CoordinateFormat_IDX])))->converter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "toString", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_format);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "toString", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]);
            }
        }
        ::QGeoCoordinate::CoordinateFormat cppArg0(QGeoCoordinate::CoordinateFormat::DegreesMinutesSecondsWithHemisphere);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toString(QGeoCoordinate::CoordinateFormat)const
            QString cppResult = const_cast<const ::QGeoCoordinate *>(cppSelf)->toString(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoCoordinateFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoCoordinate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        QGeoCoordinate::CoordinateType cppResult = const_cast<const ::QGeoCoordinate *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_CoordinateType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoCoordinate__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QGeoCoordinate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QGeoCoordinate_PropertyStrings[] = {
    "altitude::",
    "isValid:",
    "latitude::",
    "longitude::",
    nullptr // Sentinel
};

static const char *Sbk_QGeoCoordinate_EnumFlagInfo[] = {
    "CoordinateFormat:Enum",
    "CoordinateType:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QGeoCoordinate_methods[] = {
    {"altitude", reinterpret_cast<PyCFunction>(Sbk_QGeoCoordinateFunc_altitude), METH_NOARGS, nullptr},
    {"atDistanceAndAzimuth", reinterpret_cast<PyCFunction>(Sbk_QGeoCoordinateFunc_atDistanceAndAzimuth), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"azimuthTo", reinterpret_cast<PyCFunction>(Sbk_QGeoCoordinateFunc_azimuthTo), METH_O, nullptr},
    {"distanceTo", reinterpret_cast<PyCFunction>(Sbk_QGeoCoordinateFunc_distanceTo), METH_O, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QGeoCoordinateFunc_isValid), METH_NOARGS, nullptr},
    {"latitude", reinterpret_cast<PyCFunction>(Sbk_QGeoCoordinateFunc_latitude), METH_NOARGS, nullptr},
    {"longitude", reinterpret_cast<PyCFunction>(Sbk_QGeoCoordinateFunc_longitude), METH_NOARGS, nullptr},
    {"setAltitude", reinterpret_cast<PyCFunction>(Sbk_QGeoCoordinateFunc_setAltitude), METH_O, nullptr},
    {"setLatitude", reinterpret_cast<PyCFunction>(Sbk_QGeoCoordinateFunc_setLatitude), METH_O, nullptr},
    {"setLongitude", reinterpret_cast<PyCFunction>(Sbk_QGeoCoordinateFunc_setLongitude), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QGeoCoordinateFunc_swap), METH_O, nullptr},
    {"toString", reinterpret_cast<PyCFunction>(Sbk_QGeoCoordinateFunc_toString), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QGeoCoordinateFunc_type), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QGeoCoordinate__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QGeoCoordinateFunc___lshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoCoordinate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rlshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QGeoCoordinate::operator<<(QDataStream&)->QDataStream&
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // operator<<(QDataStream&,QGeoCoordinate)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator<<", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator<<(QDataStream&,QGeoCoordinate) [reverse operator]
                QDataStream & cppResult = (*cppArg0) << (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoCoordinateFunc___rshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoCoordinate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rrshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QGeoCoordinate::operator>>(QDataStream&)->QDataStream&
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // operator>>(QDataStream&,QGeoCoordinate&)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator>>", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator>>(QDataStream&,QGeoCoordinate&) [reverse operator]
                QDataStream & cppResult = (*cppArg0) >> (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

// Rich comparison
static PyObject * Sbk_QGeoCoordinate_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QGeoCoordinate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), (pyArg)))) {
                // operator!=(const QGeoCoordinate &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QGeoCoordinate cppArg0_local;
                ::QGeoCoordinate *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), (pyArg)))) {
                // operator==(const QGeoCoordinate &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QGeoCoordinate cppArg0_local;
                ::QGeoCoordinate *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static Py_hash_t Sbk_QGeoCoordinate_HashFunc(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoCoordinate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return Py_hash_t(qHash(*cppSelf));
}

static int Sbk_QGeoCoordinate_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QGeoCoordinate_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QGeoCoordinate__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoCoordinate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QGeoCoordinate_Type = nullptr;
static PyTypeObject *Sbk_QGeoCoordinate_TypeF(void)
{
    return _Sbk_QGeoCoordinate_Type;
}

static PyType_Slot Sbk_QGeoCoordinate_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QGeoCoordinate__repr__)},
    {Py_tp_hash,        reinterpret_cast<void *>(&Sbk_QGeoCoordinate_HashFunc)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QGeoCoordinate_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QGeoCoordinate_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QGeoCoordinate_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QGeoCoordinate_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QGeoCoordinate_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_lshift,      reinterpret_cast<void *>(Sbk_QGeoCoordinateFunc___lshift__)},
    {Py_nb_rshift,      reinterpret_cast<void *>(Sbk_QGeoCoordinateFunc___rshift__)},
    {0, nullptr}
};
static PyType_Spec Sbk_QGeoCoordinate_spec = {
    "2:PySide6.QtPositioning.QGeoCoordinate",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QGeoCoordinate_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QGeoCoordinate_CoordinateType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QGeoCoordinate::CoordinateType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QGeoCoordinate::CoordinateType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QGeoCoordinate_CoordinateType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_CoordinateType_IDX])))
        return Enum_PythonToCpp_QGeoCoordinate_CoordinateType;
    return {};
}

static PyObject *QGeoCoordinate_CoordinateType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QGeoCoordinate::CoordinateType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QGeoCoordinate::CoordinateType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_CoordinateType_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QGeoCoordinate_CoordinateFormat(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QGeoCoordinate::CoordinateFormat>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QGeoCoordinate::CoordinateFormat *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QGeoCoordinate_CoordinateFormat_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_CoordinateFormat_IDX])))
        return Enum_PythonToCpp_QGeoCoordinate_CoordinateFormat;
    return {};
}

static PyObject *QGeoCoordinate_CoordinateFormat_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QGeoCoordinate::CoordinateFormat>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QGeoCoordinate::CoordinateFormat *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_CoordinateFormat_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QGeoCoordinate_PythonToCpp_QGeoCoordinate_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QGeoCoordinate_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QGeoCoordinate_PythonToCpp_QGeoCoordinate_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QGeoCoordinate_TypeF()))
        return QGeoCoordinate_PythonToCpp_QGeoCoordinate_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QGeoCoordinate_PTR_CppToPython_QGeoCoordinate(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QGeoCoordinate_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QGeoCoordinate_COPY_CppToPython_QGeoCoordinate(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QGeoCoordinate *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QGeoCoordinate_TypeF(), new ::QGeoCoordinate(*source), true, true);
}

// Python to C++ copy conversion.
static void QGeoCoordinate_PythonToCpp_QGeoCoordinate_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QGeoCoordinate *>(cppOut) = *reinterpret_cast< ::QGeoCoordinate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QGeoCoordinate_PythonToCpp_QGeoCoordinate_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QGeoCoordinate_TypeF()))
        return QGeoCoordinate_PythonToCpp_QGeoCoordinate_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QGeoCoordinate_SignatureStrings[] = {
    "3:PySide6.QtPositioning.QGeoCoordinate(self,*:KeywordOnly=None,latitude:double=None,longitude:double=None,altitude:double=None,isValid:bool=None)",
    "2:PySide6.QtPositioning.QGeoCoordinate(self,other:PySide6.QtPositioning.QGeoCoordinate,*:KeywordOnly=None,latitude:double=None,longitude:double=None,altitude:double=None,isValid:bool=None)",
    "1:PySide6.QtPositioning.QGeoCoordinate(self,latitude:double,longitude:double,*:KeywordOnly=None,latitude:double=None,longitude:double=None,altitude:double=None,isValid:bool=None)",
    "0:PySide6.QtPositioning.QGeoCoordinate(self,latitude:double,longitude:double,altitude:double,*:KeywordOnly=None,latitude:double=None,longitude:double=None,altitude:double=None,isValid:bool=None)",
    "PySide6.QtPositioning.QGeoCoordinate.altitude(self)->double",
    "PySide6.QtPositioning.QGeoCoordinate.atDistanceAndAzimuth(self,distance:qreal,azimuth:qreal,distanceUp:qreal=0.0)->PySide6.QtPositioning.QGeoCoordinate",
    "PySide6.QtPositioning.QGeoCoordinate.azimuthTo(self,other:PySide6.QtPositioning.QGeoCoordinate)->qreal",
    "PySide6.QtPositioning.QGeoCoordinate.distanceTo(self,other:PySide6.QtPositioning.QGeoCoordinate)->qreal",
    "PySide6.QtPositioning.QGeoCoordinate.isValid(self)->bool",
    "PySide6.QtPositioning.QGeoCoordinate.latitude(self)->double",
    "PySide6.QtPositioning.QGeoCoordinate.longitude(self)->double",
    "PySide6.QtPositioning.QGeoCoordinate.setAltitude(self,altitude:double)",
    "PySide6.QtPositioning.QGeoCoordinate.setLatitude(self,latitude:double)",
    "PySide6.QtPositioning.QGeoCoordinate.setLongitude(self,longitude:double)",
    "PySide6.QtPositioning.QGeoCoordinate.swap(self,other:PySide6.QtPositioning.QGeoCoordinate)",
    "PySide6.QtPositioning.QGeoCoordinate.toString(self,format:PySide6.QtPositioning.QGeoCoordinate.CoordinateFormat=QGeoCoordinate.CoordinateFormat.DegreesMinutesSecondsWithHemisphere)->QString",
    "PySide6.QtPositioning.QGeoCoordinate.type(self)->PySide6.QtPositioning.QGeoCoordinate.CoordinateType",
    "PySide6.QtPositioning.QGeoCoordinate.__copy__(self)->typing.Self",
    "PySide6.QtPositioning.QGeoCoordinate.__lshift__(self,stream:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "PySide6.QtPositioning.QGeoCoordinate.__rshift__(self,stream:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "PySide6.QtPositioning.QGeoCoordinate.__ne__(self,rhs:PySide6.QtPositioning.QGeoCoordinate)->bool",
    "PySide6.QtPositioning.QGeoCoordinate.__eq__(self,rhs:PySide6.QtPositioning.QGeoCoordinate)->bool",
    "PySide6.QtPositioning.QGeoCoordinate.__hash__(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t QGeoCoordinate_SignatureByteSize = 412;
static constexpr uint8_t QGeoCoordinate_SignatureBytes[412] = {
    0x78, 0xda, 0xc5, 0x54, 0x59, 0x6b, 0xc2, 0x40, 0x10, 0x7e, 0xf7, 0x97, 0xd4, 0x62, 0x83, 0x6d,
    0xa1, 0x0f, 0x01, 0x0b, 0xa2, 0xb4, 0x85, 0x5e, 0x4a, 0x7a, 0x3c, 0x86, 0xd5, 0x8c, 0x66, 0x61,
    0xdd, 0x89, 0xbb, 0x23, 0x92, 0xfe, 0xfa, 0xae, 0x39, 0x3c, 0x62, 0xa1, 0x13, 0xa9, 0xf6, 0x2d,
    0x3b, 0xb3, 0xf3, 0x1d, 0x3b, 0x33, 0xb9, 0xf6, 0x07, 0x69, 0x20, 0x23, 0xb8, 0xf1, 0x86, 0x34,
    0x40, 0x2b, 0x49, 0xa2, 0x96, 0x7a, 0xea, 0x0d, 0xef, 0x01, 0x7b, 0x88, 0x26, 0x92, 0x5a, 0x10,
    0x9c, 0x59, 0x50, 0x93, 0xd6, 0xb9, 0xff, 0x08, 0xe9, 0xd2, 0xc5, 0x5e, 0xb5, 0x4a, 0x3b, 0x2f,
    0xa8, 0xa1, 0xa5, 0x04, 0x49, 0x5a, 0x44, 0xe0, 0x47, 0xb8, 0x18, 0x29, 0x28, 0x82, 0xa8, 0xa7,
    0xfb, 0x51, 0xa1, 0x7e, 0xb8, 0x2a, 0xed, 0x87, 0x50, 0x32, 0xf2, 0x47, 0x88, 0x2a, 0x8b, 0x34,
    0x1b, 0x57, 0x35, 0x14, 0x21, 0xc5, 0x60, 0x58, 0xf7, 0x4f, 0x24, 0xfe, 0xb2, 0x86, 0xf8, 0x0a,
    0xfd, 0x1e, 0xf3, 0x89, 0x24, 0xb7, 0xff, 0x52, 0x72, 0x85, 0xf4, 0x44, 0x16, 0x38, 0x06, 0xbc,
    0x12, 0x2c, 0x73, 0xd2, 0xbc, 0xb8, 0xcd, 0x31, 0x99, 0xb5, 0xd4, 0x97, 0x96, 0x84, 0x1e, 0x43,
    0x57, 0x47, 0xdd, 0x2f, 0x39, 0x5b, 0x50, 0x9c, 0xbf, 0x48, 0x54, 0xc4, 0xfd, 0xb9, 0x01, 0xa1,
    0x5a, 0x22, 0xcf, 0x15, 0xa7, 0x32, 0xf9, 0x9e, 0xe4, 0x81, 0x4e, 0xdb, 0x6b, 0x3b, 0x66, 0x0e,
    0x25, 0x53, 0x57, 0x4e, 0xf7, 0x86, 0x75, 0xd7, 0xc1, 0xa9, 0xc8, 0x14, 0xf1, 0x68, 0x4a, 0x1f,
    0xc7, 0xe6, 0x29, 0x5a, 0x5b, 0x76, 0x68, 0xd5, 0x61, 0x5e, 0x61, 0x39, 0x53, 0x87, 0xf4, 0x76,
    0x3d, 0x7a, 0x87, 0x14, 0x5b, 0xa0, 0xee, 0xf6, 0x5c, 0x55, 0x47, 0xb6, 0xc9, 0x86, 0x79, 0xda,
    0xb6, 0x50, 0x5d, 0x92, 0x1a, 0x30, 0x3b, 0x6e, 0xf6, 0xf6, 0x8a, 0x0b, 0xb4, 0x14, 0x49, 0xed,
    0x56, 0xf3, 0xa0, 0x09, 0x03, 0x32, 0x2e, 0x9e, 0xc3, 0x4f, 0xd0, 0xcc, 0x04, 0xb1, 0xf0, 0xbd,
    0xcd, 0xe7, 0x5d, 0x56, 0xd5, 0xf9, 0x25, 0xef, 0xf5, 0x61, 0x6a, 0x00, 0xec, 0xb3, 0xd4, 0x0b,
    0x02, 0x1b, 0xc0, 0x18, 0x75, 0x64, 0x3f, 0x25, 0xc5, 0x0f, 0x30, 0x93, 0x36, 0x71, 0xc6, 0x56,
    0xf3, 0x39, 0xcc, 0xf5, 0x30, 0xd5, 0xa7, 0xc9, 0x7a, 0x4e, 0x6a, 0x8a, 0x7e, 0x73, 0xa5, 0x3c,
    0x92, 0x30, 0x1c, 0x63, 0x92, 0x86, 0x61, 0x49, 0xe4, 0x48, 0x57, 0xb7, 0x02, 0x77, 0xe2, 0x02,
    0x28, 0x1b, 0xcb, 0x09, 0x15, 0x10, 0x2d, 0x4b, 0x6e, 0x07, 0x67, 0x5b, 0xaf, 0xdc, 0x43, 0x03,
    0xde, 0xb0, 0x2f, 0x48, 0x04, 0x59, 0x6a, 0xc7, 0x4d, 0x35, 0xc9, 0xe5, 0x34, 0xff, 0xc0, 0xa9,
    0xa1, 0xe4, 0x33, 0xb1, 0xe5, 0xfe, 0x91, 0xf8, 0xff, 0x95, 0x30, 0x84, 0xf9, 0x91, 0x09, 0x62,
    0x61, 0xe3, 0x4d, 0xab, 0xa5, 0xa6, 0xc6, 0x37, 0x23, 0xdc, 0x8e, 0xbb
};
#endif

PyTypeObject *init_QGeoCoordinate(PyObject *module)
{
    if (SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX].type != nullptr)
        return SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX].type;

    Shiboken::AutoDecRef Sbk_QGeoCoordinate_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QGeoCoordinate_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QGeoCoordinate",
        "QGeoCoordinate",
        &Sbk_QGeoCoordinate_spec,
        &Shiboken::callCppDestructor< ::QGeoCoordinate >,
        Sbk_QGeoCoordinate_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QGeoCoordinate_TypeF(); // references _Sbk_QGeoCoordinate_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QGeoCoordinate_SignatureStrings);
#else
    InitSignatureBytes(pyType, QGeoCoordinate_SignatureBytes, QGeoCoordinate_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QGeoCoordinate_PropertyStrings);
    SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QGeoCoordinate_PythonToCpp_QGeoCoordinate_PTR,
        is_QGeoCoordinate_PythonToCpp_QGeoCoordinate_PTR_Convertible,
        QGeoCoordinate_PTR_CppToPython_QGeoCoordinate,
        QGeoCoordinate_COPY_CppToPython_QGeoCoordinate);

    Shiboken::Conversions::registerConverterName(converter, "QGeoCoordinate");
    Shiboken::Conversions::registerConverterName(converter, "QGeoCoordinate*");
    Shiboken::Conversions::registerConverterName(converter, "QGeoCoordinate&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QGeoCoordinate).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QGeoCoordinate_PythonToCpp_QGeoCoordinate_COPY,
        is_QGeoCoordinate_PythonToCpp_QGeoCoordinate_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QGeoCoordinate_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'CoordinateType'.
    const char *CoordinateType_Initializer[] = {
        "InvalidCoordinate",
        "Coordinate2D",
        "Coordinate3D",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t CoordinateType_InitializerValues[] = {
        uint8_t(QGeoCoordinate::CoordinateType::InvalidCoordinate), //  0x00  0
        uint8_t(QGeoCoordinate::CoordinateType::Coordinate2D),      //  0x01  1
        uint8_t(QGeoCoordinate::CoordinateType::Coordinate3D)       //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QGeoCoordinate_TypeF(),
        "2:PySide6.QtPositioning.QGeoCoordinate.CoordinateType",
        CoordinateType_Initializer, CoordinateType_InitializerValues);
    SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_CoordinateType_IDX].type = EType;
    // Register converter for enum 'QGeoCoordinate::CoordinateType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QGeoCoordinate_CoordinateType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QGeoCoordinate_CoordinateType,
            is_Enum_PythonToCpp_QGeoCoordinate_CoordinateType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QGeoCoordinate::CoordinateType");
        Shiboken::Conversions::registerConverterAlias(converter, "CoordinateType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'CoordinateType' enum.

    // Initialization of enum 'CoordinateFormat'.
    const char *CoordinateFormat_Initializer[] = {
        "Degrees",
        "DegreesWithHemisphere",
        "DegreesMinutes",
        "DegreesMinutesWithHemisphere",
        "DegreesMinutesSeconds",
        "DegreesMinutesSecondsWithHemisphere",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t CoordinateFormat_InitializerValues[] = {
        uint8_t(QGeoCoordinate::CoordinateFormat::Degrees),                            //  0x00  0
        uint8_t(QGeoCoordinate::CoordinateFormat::DegreesWithHemisphere),              //  0x01  1
        uint8_t(QGeoCoordinate::CoordinateFormat::DegreesMinutes),                     //  0x02  2
        uint8_t(QGeoCoordinate::CoordinateFormat::DegreesMinutesWithHemisphere),       //  0x03  3
        uint8_t(QGeoCoordinate::CoordinateFormat::DegreesMinutesSeconds),              //  0x04  4
        uint8_t(QGeoCoordinate::CoordinateFormat::DegreesMinutesSecondsWithHemisphere) //  0x05  5
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QGeoCoordinate_TypeF(),
        "2:PySide6.QtPositioning.QGeoCoordinate.CoordinateFormat",
        CoordinateFormat_Initializer, CoordinateFormat_InitializerValues);
    SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_CoordinateFormat_IDX].type = EType;
    // Register converter for enum 'QGeoCoordinate::CoordinateFormat'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QGeoCoordinate_CoordinateFormat_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QGeoCoordinate_CoordinateFormat,
            is_Enum_PythonToCpp_QGeoCoordinate_CoordinateFormat_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QGeoCoordinate::CoordinateFormat");
        Shiboken::Conversions::registerConverterAlias(converter, "CoordinateFormat");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'CoordinateFormat' enum.

    qRegisterMetaType< ::QGeoCoordinate >("QGeoCoordinate");
    qRegisterMetaType< ::QGeoCoordinate::CoordinateType >("QGeoCoordinate::CoordinateType");
    qRegisterMetaType< ::QGeoCoordinate::CoordinateFormat >("QGeoCoordinate::CoordinateFormat");

    return pyType;
}
