// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtpositioning_python.h"

// main header
#include "qgeolocation_wrapper.h"

// Argument includes
#include <QMap>
#include <QString>
#include <QtPositioning/qgeoaddress.h>
#include <QtPositioning/qgeocoordinate.h>
#include <QtPositioning/qgeolocation.h>
#include <QtPositioning/qgeoshape.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGeoLocation_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QGeoLocation >()))
        return -1;

    ::QGeoLocation *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QGeoLocation", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QGeoLocation::QGeoLocation()
    // 1: QGeoLocation::QGeoLocation(QGeoLocation)
    if (numArgs == 0) {
        overloadId = 0; // QGeoLocation()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoLocation_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QGeoLocation(QGeoLocation)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoLocation_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoLocation_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QGeoLocation()
        {

            // QGeoLocation()
            cptr = new ::QGeoLocation();
            break;
        }
        case 1: // QGeoLocation(const QGeoLocation &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QGeoLocation cppArg0_local;
            ::QGeoLocation *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QGeoLocation(QGeoLocation)
                cptr = new ::QGeoLocation(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QGeoLocation >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoLocation_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QGeoLocationFunc_address(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoLocation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoLocation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // address()const
        QGeoAddress cppResult = const_cast<const ::QGeoLocation *>(cppSelf)->address();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoLocationFunc_boundingShape(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoLocation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoLocation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // boundingShape()const
        QGeoShape cppResult = const_cast<const ::QGeoLocation *>(cppSelf)->boundingShape();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoShape_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoLocationFunc_coordinate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoLocation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoLocation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // coordinate()const
        QGeoCoordinate cppResult = const_cast<const ::QGeoLocation *>(cppSelf)->coordinate();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoLocationFunc_extendedAttributes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoLocation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoLocation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // extendedAttributes()const
        QMap<QString,QVariant> cppResult = const_cast<const ::QGeoLocation *>(cppSelf)->extendedAttributes();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtPositioningTypeConverters[SBK_QtPositioning_QMap_QString_QVariant_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoLocationFunc_isEmpty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoLocation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoLocation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isEmpty()const
        bool cppResult = const_cast<const ::QGeoLocation *>(cppSelf)->isEmpty();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoLocationFunc_setAddress(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoLocation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoLocation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoLocation::setAddress(QGeoAddress)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoAddress_IDX]), (pyArg)))) {
        overloadId = 0; // setAddress(QGeoAddress)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAddress", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoLocation_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGeoAddress cppArg0_local;
        ::QGeoAddress *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setAddress(QGeoAddress)
            cppSelf->setAddress(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoLocationFunc_setBoundingShape(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoLocation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoLocation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoLocation::setBoundingShape(QGeoShape)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoShape_IDX]), (pyArg)))) {
        overloadId = 0; // setBoundingShape(QGeoShape)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBoundingShape", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoLocation_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGeoShape cppArg0_local;
        ::QGeoShape *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setBoundingShape(QGeoShape)
            cppSelf->setBoundingShape(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoLocationFunc_setCoordinate(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoLocation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoLocation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoLocation::setCoordinate(QGeoCoordinate)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), (pyArg)))) {
        overloadId = 0; // setCoordinate(QGeoCoordinate)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCoordinate", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoLocation_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGeoCoordinate cppArg0_local;
        ::QGeoCoordinate *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setCoordinate(QGeoCoordinate)
            cppSelf->setCoordinate(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoLocationFunc_setExtendedAttributes(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoLocation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoLocation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoLocation::setExtendedAttributes(QMap<QString,QVariant>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtPositioningTypeConverters[SBK_QtPositioning_QMap_QString_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // setExtendedAttributes(QMap<QString,QVariant>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setExtendedAttributes", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoLocation_IDX]);

    // Call function/method
    {
        ::QMap<QString,QVariant> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setExtendedAttributes(QMap<QString,QVariant>)
            cppSelf->setExtendedAttributes(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoLocationFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoLocation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoLocation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoLocation::swap(QGeoLocation&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoLocation_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QGeoLocation&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoLocation_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGeoLocation cppArg0_local;
        ::QGeoLocation *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QGeoLocation&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoLocation__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QGeoLocation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoLocation_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoLocation_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QGeoLocation_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QGeoLocation_methods[] = {
    {"address", reinterpret_cast<PyCFunction>(Sbk_QGeoLocationFunc_address), METH_NOARGS, nullptr},
    {"boundingShape", reinterpret_cast<PyCFunction>(Sbk_QGeoLocationFunc_boundingShape), METH_NOARGS, nullptr},
    {"coordinate", reinterpret_cast<PyCFunction>(Sbk_QGeoLocationFunc_coordinate), METH_NOARGS, nullptr},
    {"extendedAttributes", reinterpret_cast<PyCFunction>(Sbk_QGeoLocationFunc_extendedAttributes), METH_NOARGS, nullptr},
    {"isEmpty", reinterpret_cast<PyCFunction>(Sbk_QGeoLocationFunc_isEmpty), METH_NOARGS, nullptr},
    {"setAddress", reinterpret_cast<PyCFunction>(Sbk_QGeoLocationFunc_setAddress), METH_O, nullptr},
    {"setBoundingShape", reinterpret_cast<PyCFunction>(Sbk_QGeoLocationFunc_setBoundingShape), METH_O, nullptr},
    {"setCoordinate", reinterpret_cast<PyCFunction>(Sbk_QGeoLocationFunc_setCoordinate), METH_O, nullptr},
    {"setExtendedAttributes", reinterpret_cast<PyCFunction>(Sbk_QGeoLocationFunc_setExtendedAttributes), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QGeoLocationFunc_swap), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QGeoLocation__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QGeoLocation_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QGeoLocation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoLocation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoLocation_IDX]), (pyArg)))) {
                // operator!=(const QGeoLocation &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QGeoLocation cppArg0_local;
                ::QGeoLocation *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoLocation_IDX]), (pyArg)))) {
                // operator==(const QGeoLocation &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QGeoLocation cppArg0_local;
                ::QGeoLocation *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static Py_hash_t Sbk_QGeoLocation_HashFunc(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoLocation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoLocation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return Py_hash_t(qHash(*cppSelf));
}

static int Sbk_QGeoLocation_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QGeoLocation_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QGeoLocation_Type = nullptr;
static PyTypeObject *Sbk_QGeoLocation_TypeF(void)
{
    return _Sbk_QGeoLocation_Type;
}

static PyType_Slot Sbk_QGeoLocation_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_hash,        reinterpret_cast<void *>(&Sbk_QGeoLocation_HashFunc)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QGeoLocation_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QGeoLocation_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QGeoLocation_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QGeoLocation_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QGeoLocation_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QGeoLocation_spec = {
    "2:PySide6.QtPositioning.QGeoLocation",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QGeoLocation_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QGeoLocation_PythonToCpp_QGeoLocation_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QGeoLocation_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QGeoLocation_PythonToCpp_QGeoLocation_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QGeoLocation_TypeF()))
        return QGeoLocation_PythonToCpp_QGeoLocation_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QGeoLocation_PTR_CppToPython_QGeoLocation(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QGeoLocation_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QGeoLocation_COPY_CppToPython_QGeoLocation(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QGeoLocation *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QGeoLocation_TypeF(), new ::QGeoLocation(*source), true, true);
}

// Python to C++ copy conversion.
static void QGeoLocation_PythonToCpp_QGeoLocation_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QGeoLocation *>(cppOut) = *reinterpret_cast< ::QGeoLocation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoLocation_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QGeoLocation_PythonToCpp_QGeoLocation_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QGeoLocation_TypeF()))
        return QGeoLocation_PythonToCpp_QGeoLocation_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QGeoLocation_SignatureStrings[] = {
    "1:PySide6.QtPositioning.QGeoLocation(self)",
    "0:PySide6.QtPositioning.QGeoLocation(self,other:PySide6.QtPositioning.QGeoLocation)",
    "PySide6.QtPositioning.QGeoLocation.address(self)->PySide6.QtPositioning.QGeoAddress",
    "PySide6.QtPositioning.QGeoLocation.boundingShape(self)->PySide6.QtPositioning.QGeoShape",
    "PySide6.QtPositioning.QGeoLocation.coordinate(self)->PySide6.QtPositioning.QGeoCoordinate",
    "PySide6.QtPositioning.QGeoLocation.extendedAttributes(self)->QMap[QString, QVariant]",
    "PySide6.QtPositioning.QGeoLocation.isEmpty(self)->bool",
    "PySide6.QtPositioning.QGeoLocation.setAddress(self,address:PySide6.QtPositioning.QGeoAddress)",
    "PySide6.QtPositioning.QGeoLocation.setBoundingShape(self,shape:PySide6.QtPositioning.QGeoShape)",
    "PySide6.QtPositioning.QGeoLocation.setCoordinate(self,position:PySide6.QtPositioning.QGeoCoordinate)",
    "PySide6.QtPositioning.QGeoLocation.setExtendedAttributes(self,data:QMap[QString, QVariant])",
    "PySide6.QtPositioning.QGeoLocation.swap(self,other:PySide6.QtPositioning.QGeoLocation)",
    "PySide6.QtPositioning.QGeoLocation.__copy__(self)->typing.Self",
    "PySide6.QtPositioning.QGeoLocation.__ne__(self,rhs:PySide6.QtPositioning.QGeoLocation)->bool",
    "PySide6.QtPositioning.QGeoLocation.__eq__(self,rhs:PySide6.QtPositioning.QGeoLocation)->bool",
    "PySide6.QtPositioning.QGeoLocation.__hash__(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t QGeoLocation_SignatureByteSize = 272;
static constexpr uint8_t QGeoLocation_SignatureBytes[272] = {
    0x78, 0xda, 0xb5, 0x93, 0xc1, 0x4a, 0xc4, 0x30, 0x10, 0x86, 0xef, 0x7d, 0x0a, 0x8f, 0x16, 0x62,
    0xd1, 0x8b, 0x87, 0x1e, 0x84, 0xba, 0x2c, 0x5e, 0x14, 0xb6, 0x14, 0xbc, 0x88, 0x84, 0x69, 0x33,
    0x6e, 0x02, 0x6b, 0x26, 0x26, 0xb3, 0x68, 0xdf, 0xde, 0xd6, 0xed, 0xae, 0x8a, 0x2e, 0x9d, 0xcb,
    0xde, 0x92, 0xf0, 0xcf, 0x97, 0x49, 0xbe, 0xe4, 0xaa, 0x5c, 0xf5, 0x8d, 0x33, 0x78, 0x5d, 0xd4,
    0xbc, 0xa2, 0xe4, 0xd8, 0x91, 0x77, 0x7e, 0x5d, 0xd4, 0x77, 0x48, 0xf7, 0xd4, 0xc1, 0x38, 0x3f,
    0x4f, 0xb8, 0x79, 0xc9, 0xb3, 0x4b, 0x69, 0x54, 0x11, 0x5b, 0x8c, 0x82, 0x74, 0x9e, 0xcd, 0x67,
    0x0a, 0x30, 0x26, 0x62, 0x4a, 0xbb, 0x26, 0x2e, 0x6e, 0x8e, 0x57, 0x54, 0xbb, 0xa0, 0x84, 0xd9,
    0xd2, 0xd6, 0x9b, 0x61, 0xb5, 0xb1, 0x10, 0x70, 0x9e, 0xfc, 0x15, 0x93, 0x70, 0x3b, 0xa2, 0x38,
    0x70, 0x81, 0x05, 0xd0, 0xc5, 0x21, 0x2b, 0x21, 0xe3, 0x07, 0xa3, 0x37, 0x68, 0x2a, 0xe6, 0xe8,
    0xda, 0x2d, 0xe3, 0xe1, 0x42, 0xea, 0x07, 0x08, 0x4f, 0x75, 0x33, 0x2c, 0xfb, 0xb5, 0x3a, 0xab,
    0x1f, 0x21, 0x3a, 0xf0, 0xfc, 0x2c, 0x81, 0xba, 0xb4, 0x7c, 0x0d, 0xdc, 0xef, 0x49, 0x2d, 0xd1,
    0x46, 0x52, 0x96, 0x90, 0xab, 0x1f, 0x52, 0xd4, 0x64, 0xa8, 0x9c, 0x55, 0x93, 0x0b, 0xe9, 0xb7,
    0x7f, 0xf4, 0xa8, 0x34, 0x0e, 0xcb, 0x19, 0x45, 0x52, 0xfe, 0xe2, 0xb7, 0x26, 0x15, 0xa6, 0x6c,
    0x29, 0xb1, 0x25, 0xdd, 0x64, 0xf9, 0xbf, 0x31, 0x65, 0x80, 0xa1, 0x3c, 0x22, 0x4d, 0xc6, 0x7e,
    0x87, 0x70, 0x82, 0x7f, 0xa6, 0x75, 0x47, 0xa1, 0xd7, 0x7a, 0xff, 0x1a, 0xb8, 0x0f, 0x63, 0xa6,
    0x19, 0x66, 0xb2, 0x72, 0x8f, 0x53, 0xb1, 0x8a, 0x36, 0x49, 0xba, 0x92, 0xbf, 0x38, 0xad, 0xf1,
    0xed, 0x84, 0x70, 0x0b, 0xc9, 0x7e, 0x1f, 0xdc, 0x79, 0xce, 0x3e, 0x01, 0x71, 0x45, 0xdf, 0x76
};
#endif

PyTypeObject *init_QGeoLocation(PyObject *module)
{
    if (SbkPySide6_QtPositioningTypeStructs[SBK_QGeoLocation_IDX].type != nullptr)
        return SbkPySide6_QtPositioningTypeStructs[SBK_QGeoLocation_IDX].type;

    Shiboken::AutoDecRef Sbk_QGeoLocation_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QGeoLocation_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QGeoLocation",
        "QGeoLocation",
        &Sbk_QGeoLocation_spec,
        &Shiboken::callCppDestructor< ::QGeoLocation >,
        Sbk_QGeoLocation_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QGeoLocation_TypeF(); // references _Sbk_QGeoLocation_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QGeoLocation_SignatureStrings);
#else
    InitSignatureBytes(pyType, QGeoLocation_SignatureBytes, QGeoLocation_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QGeoLocation_PropertyStrings);
    SbkPySide6_QtPositioningTypeStructs[SBK_QGeoLocation_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QGeoLocation_PythonToCpp_QGeoLocation_PTR,
        is_QGeoLocation_PythonToCpp_QGeoLocation_PTR_Convertible,
        QGeoLocation_PTR_CppToPython_QGeoLocation,
        QGeoLocation_COPY_CppToPython_QGeoLocation);

    Shiboken::Conversions::registerConverterName(converter, "QGeoLocation");
    Shiboken::Conversions::registerConverterName(converter, "QGeoLocation*");
    Shiboken::Conversions::registerConverterName(converter, "QGeoLocation&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QGeoLocation).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QGeoLocation_PythonToCpp_QGeoLocation_COPY,
        is_QGeoLocation_PythonToCpp_QGeoLocation_COPY_Convertible);

    qRegisterMetaType< ::QGeoLocation >("QGeoLocation");

    return pyType;
}
