// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtpositioning_python.h"

// main header
#include "qgeopolygon_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtPositioning/qgeocoordinate.h>
#include <QtPositioning/qgeopolygon.h>
#include <QtPositioning/qgeorectangle.h>
#include <QtPositioning/qgeoshape.h>
#include <qdatastream.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGeoPolygon_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QGeoPolygon >()))
        return -1;

    ::QGeoPolygon *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QGeoPolygon", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QGeoPolygon::QGeoPolygon()
    // 1: QGeoPolygon::QGeoPolygon(QGeoPolygon)
    // 2: QGeoPolygon::QGeoPolygon(QGeoShape)
    // 3: QGeoPolygon::QGeoPolygon(QList<QGeoCoordinate>)
    if (numArgs == 0) {
        overloadId = 0; // QGeoPolygon()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtPositioningTypeConverters[SBK_QtPositioning_QList_QGeoCoordinate_IDX], (pyArgs[0])))) {
        overloadId = 3; // QGeoPolygon(QList<QGeoCoordinate>)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QGeoPolygon(QGeoPolygon)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoShape_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QGeoPolygon(QGeoShape)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QGeoPolygon()
        {

            // QGeoPolygon()
            cptr = new ::QGeoPolygon();
            break;
        }
        case 1: // QGeoPolygon(const QGeoPolygon &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QGeoPolygon cppArg0_local;
            ::QGeoPolygon *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QGeoPolygon(QGeoPolygon)
                cptr = new ::QGeoPolygon(*cppArg0);
            }
            break;
        }
        case 2: // QGeoPolygon(const QGeoShape &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QGeoShape cppArg0_local;
            ::QGeoShape *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QGeoPolygon(QGeoShape)
                cptr = new ::QGeoPolygon(*cppArg0);
            }
            break;
        }
        case 3: // QGeoPolygon(const QList<QGeoCoordinate> &path)
        {
            ::QList<QGeoCoordinate> cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QGeoPolygon(QList<QGeoCoordinate>)
                cptr = new ::QGeoPolygon(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QGeoPolygon >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QGeoPolygonFunc_addCoordinate(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoPolygon *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoPolygon::addCoordinate(QGeoCoordinate)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), (pyArg)))) {
        overloadId = 0; // addCoordinate(QGeoCoordinate)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addCoordinate", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGeoCoordinate cppArg0_local;
        ::QGeoCoordinate *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // addCoordinate(QGeoCoordinate)
            cppSelf->addCoordinate(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoPolygonFunc_addHole(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoPolygon *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoPolygon::addHole(QList<QGeoCoordinate>)
    // 1: QGeoPolygon::addHole(QVariant)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtPositioningTypeConverters[SBK_QtPositioning_QList_QGeoCoordinate_IDX], (pyArg)))) {
        overloadId = 0; // addHole(QList<QGeoCoordinate>)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArg)))) {
        overloadId = 1; // addHole(QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addHole", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // addHole(const QList<QGeoCoordinate> &holePath)
        {
            ::QList<QGeoCoordinate> cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // addHole(QList<QGeoCoordinate>)
                cppSelf->addHole(cppArg0);
            }
            break;
        }
        case 1: // addHole(const QVariant &holePath)
        {
            ::QVariant cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // addHole(QVariant)
                cppSelf->addHole(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoPolygonFunc_containsCoordinate(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoPolygon *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoPolygon::containsCoordinate(QGeoCoordinate)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), (pyArg)))) {
        overloadId = 0; // containsCoordinate(QGeoCoordinate)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "containsCoordinate", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGeoCoordinate cppArg0_local;
        ::QGeoCoordinate *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // containsCoordinate(QGeoCoordinate)const
            bool cppResult = const_cast<const ::QGeoPolygon *>(cppSelf)->containsCoordinate(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoPolygonFunc_coordinateAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoPolygon *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoPolygon::coordinateAt(qsizetype)const->QGeoCoordinate
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // coordinateAt(qsizetype)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "coordinateAt", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // coordinateAt(qsizetype)const
            QGeoCoordinate cppResult = const_cast<const ::QGeoPolygon *>(cppSelf)->coordinateAt(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoPolygonFunc_hole(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoPolygon *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoPolygon::hole(qsizetype)const->const QList<QVariant>
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // hole(qsizetype)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "hole", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // hole(qsizetype)const
            const QList<QVariant> cppResult = const_cast<const ::QGeoPolygon *>(cppSelf)->hole(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtPositioningTypeConverters[SBK_QtPositioning_QList_QVariant_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoPolygonFunc_holePath(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoPolygon *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoPolygon::holePath(qsizetype)const->const QList<QGeoCoordinate>
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // holePath(qsizetype)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "holePath", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // holePath(qsizetype)const
            const QList<QGeoCoordinate> cppResult = const_cast<const ::QGeoPolygon *>(cppSelf)->holePath(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtPositioningTypeConverters[SBK_QtPositioning_QList_QGeoCoordinate_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoPolygonFunc_holesCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoPolygon *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // holesCount()const
        qsizetype cppResult = const_cast<const ::QGeoPolygon *>(cppSelf)->holesCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoPolygonFunc_insertCoordinate(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoPolygon *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "insertCoordinate", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGeoPolygon::insertCoordinate(qsizetype,QGeoCoordinate)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), (pyArgs[1])))) {
        overloadId = 0; // insertCoordinate(qsizetype,QGeoCoordinate)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "insertCoordinate", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QGeoCoordinate cppArg1_local;
        ::QGeoCoordinate *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // insertCoordinate(qsizetype,QGeoCoordinate)
            cppSelf->insertCoordinate(cppArg0, *cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoPolygonFunc_length(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoPolygon *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "length", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]);

    if (PyArg_ParseTuple(args, "|OO:length", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGeoPolygon::length(qsizetype=,qsizetype=)const->double
    if (numArgs == 0) {
        overloadId = 0; // length(qsizetype,qsizetype)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // length(qsizetype,qsizetype)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
            overloadId = 0; // length(qsizetype,qsizetype)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "length", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_indexFrom = Shiboken::String::createStaticString("indexFrom");
            if (PyDict_Contains(kwds, key_indexFrom) != 0) {
                value = PyDict_GetItem(kwds, key_indexFrom);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_indexFrom);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "length", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "length", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_indexFrom);
            }
            static PyObject *const key_indexTo = Shiboken::String::createStaticString("indexTo");
            if (PyDict_Contains(kwds, key_indexTo) != 0) {
                value = PyDict_GetItem(kwds, key_indexTo);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_indexTo);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "length", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "length", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_indexTo);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "length", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]);
            }
        }
        qsizetype cppArg0 = 0;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);
        qsizetype cppArg1 = -1;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // length(qsizetype,qsizetype)const
            double cppResult = const_cast<const ::QGeoPolygon *>(cppSelf)->length(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<double>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoPolygonFunc_perimeter(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoPolygon *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // perimeter()const
        const QList<QGeoCoordinate> & cppResult = const_cast<const ::QGeoPolygon *>(cppSelf)->perimeter();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtPositioningTypeConverters[SBK_QtPositioning_QList_QGeoCoordinate_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoPolygonFunc_removeCoordinate(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoPolygon *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoPolygon::removeCoordinate(QGeoCoordinate)
    // 1: QGeoPolygon::removeCoordinate(qsizetype)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 1; // removeCoordinate(qsizetype)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), (pyArg)))) {
        overloadId = 0; // removeCoordinate(QGeoCoordinate)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeCoordinate", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // removeCoordinate(const QGeoCoordinate &coordinate)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QGeoCoordinate cppArg0_local;
            ::QGeoCoordinate *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // removeCoordinate(QGeoCoordinate)
                cppSelf->removeCoordinate(*cppArg0);
            }
            break;
        }
        case 1: // removeCoordinate(qsizetype index)
        {
            qsizetype cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // removeCoordinate(qsizetype)
                cppSelf->removeCoordinate(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoPolygonFunc_removeHole(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoPolygon *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoPolygon::removeHole(qsizetype)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // removeHole(qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeHole", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeHole(qsizetype)
            cppSelf->removeHole(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoPolygonFunc_replaceCoordinate(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoPolygon *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "replaceCoordinate", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGeoPolygon::replaceCoordinate(qsizetype,QGeoCoordinate)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), (pyArgs[1])))) {
        overloadId = 0; // replaceCoordinate(qsizetype,QGeoCoordinate)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "replaceCoordinate", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QGeoCoordinate cppArg1_local;
        ::QGeoCoordinate *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // replaceCoordinate(qsizetype,QGeoCoordinate)
            cppSelf->replaceCoordinate(cppArg0, *cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoPolygonFunc_setPerimeter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoPolygon *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoPolygon::setPerimeter(QList<QGeoCoordinate>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtPositioningTypeConverters[SBK_QtPositioning_QList_QGeoCoordinate_IDX], (pyArg)))) {
        overloadId = 0; // setPerimeter(QList<QGeoCoordinate>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPerimeter", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]);

    // Call function/method
    {
        ::QList<QGeoCoordinate> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPerimeter(QList<QGeoCoordinate>)
            cppSelf->setPerimeter(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoPolygonFunc_size(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoPolygon *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // size()const
        qsizetype cppResult = const_cast<const ::QGeoPolygon *>(cppSelf)->size();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoPolygonFunc_toString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoPolygon *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toString()const
        QString cppResult = const_cast<const ::QGeoPolygon *>(cppSelf)->toString();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoPolygonFunc_translate(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoPolygon *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "translate", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGeoPolygon::translate(double,double)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[1])))) {
        overloadId = 0; // translate(double,double)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "translate", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]);

    // Call function/method
    {
        double cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        double cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // translate(double,double)
            cppSelf->translate(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoPolygonFunc_translated(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoPolygon *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "translated", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGeoPolygon::translated(double,double)const->QGeoPolygon
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[1])))) {
        overloadId = 0; // translated(double,double)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "translated", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]);

    // Call function/method
    {
        double cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        double cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // translated(double,double)const
            QGeoPolygon cppResult = const_cast<const ::QGeoPolygon *>(cppSelf)->translated(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoPolygon__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QGeoPolygon *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QGeoPolygon_PropertyStrings[] = {
    "perimeter::",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QGeoPolygon_methods[] = {
    {"addCoordinate", reinterpret_cast<PyCFunction>(Sbk_QGeoPolygonFunc_addCoordinate), METH_O, nullptr},
    {"addHole", reinterpret_cast<PyCFunction>(Sbk_QGeoPolygonFunc_addHole), METH_O, nullptr},
    {"containsCoordinate", reinterpret_cast<PyCFunction>(Sbk_QGeoPolygonFunc_containsCoordinate), METH_O, nullptr},
    {"coordinateAt", reinterpret_cast<PyCFunction>(Sbk_QGeoPolygonFunc_coordinateAt), METH_O, nullptr},
    {"hole", reinterpret_cast<PyCFunction>(Sbk_QGeoPolygonFunc_hole), METH_O, nullptr},
    {"holePath", reinterpret_cast<PyCFunction>(Sbk_QGeoPolygonFunc_holePath), METH_O, nullptr},
    {"holesCount", reinterpret_cast<PyCFunction>(Sbk_QGeoPolygonFunc_holesCount), METH_NOARGS, nullptr},
    {"insertCoordinate", reinterpret_cast<PyCFunction>(Sbk_QGeoPolygonFunc_insertCoordinate), METH_VARARGS, nullptr},
    {"length", reinterpret_cast<PyCFunction>(Sbk_QGeoPolygonFunc_length), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"perimeter", reinterpret_cast<PyCFunction>(Sbk_QGeoPolygonFunc_perimeter), METH_NOARGS, nullptr},
    {"removeCoordinate", reinterpret_cast<PyCFunction>(Sbk_QGeoPolygonFunc_removeCoordinate), METH_O, nullptr},
    {"removeHole", reinterpret_cast<PyCFunction>(Sbk_QGeoPolygonFunc_removeHole), METH_O, nullptr},
    {"replaceCoordinate", reinterpret_cast<PyCFunction>(Sbk_QGeoPolygonFunc_replaceCoordinate), METH_VARARGS, nullptr},
    {"setPerimeter", reinterpret_cast<PyCFunction>(Sbk_QGeoPolygonFunc_setPerimeter), METH_O, nullptr},
    {"size", reinterpret_cast<PyCFunction>(Sbk_QGeoPolygonFunc_size), METH_NOARGS, nullptr},
    {"toString", reinterpret_cast<PyCFunction>(Sbk_QGeoPolygonFunc_toString), METH_NOARGS, nullptr},
    {"translate", reinterpret_cast<PyCFunction>(Sbk_QGeoPolygonFunc_translate), METH_VARARGS, nullptr},
    {"translated", reinterpret_cast<PyCFunction>(Sbk_QGeoPolygonFunc_translated), METH_VARARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QGeoPolygon__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QGeoPolygonFunc___lshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoPolygon *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rlshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QGeoPolygon::operator<<(QDataStream&)->QDataStream&
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // operator<<(QDataStream&,QGeoPolygon)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator<<", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator<<(QDataStream&,QGeoPolygon) [reverse operator]
                QDataStream & cppResult = (*cppArg0) << (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoPolygonFunc___rshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoPolygon *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rrshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QGeoPolygon::operator>>(QDataStream&)->QDataStream&
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // operator>>(QDataStream&,QGeoPolygon&)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator>>", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator>>(QDataStream&,QGeoPolygon&) [reverse operator]
                QDataStream & cppResult = (*cppArg0) >> (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

} // extern "C"

static int Sbk_QGeoPolygon_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QGeoPolygon_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QGeoPolygon_Type = nullptr;
static PyTypeObject *Sbk_QGeoPolygon_TypeF(void)
{
    return _Sbk_QGeoPolygon_Type;
}

static PyType_Slot Sbk_QGeoPolygon_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QGeoPolygon_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QGeoPolygon_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QGeoPolygon_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QGeoPolygon_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_lshift,      reinterpret_cast<void *>(Sbk_QGeoPolygonFunc___lshift__)},
    {Py_nb_rshift,      reinterpret_cast<void *>(Sbk_QGeoPolygonFunc___rshift__)},
    {0, nullptr}
};
static PyType_Spec Sbk_QGeoPolygon_spec = {
    "2:PySide6.QtPositioning.QGeoPolygon",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QGeoPolygon_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QGeoPolygon_PythonToCpp_QGeoPolygon_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QGeoPolygon_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QGeoPolygon_PythonToCpp_QGeoPolygon_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QGeoPolygon_TypeF()))
        return QGeoPolygon_PythonToCpp_QGeoPolygon_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QGeoPolygon_PTR_CppToPython_QGeoPolygon(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QGeoPolygon_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QGeoPolygon_COPY_CppToPython_QGeoPolygon(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QGeoPolygon *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QGeoPolygon_TypeF(), new ::QGeoPolygon(*source), true, true);
}

// Python to C++ copy conversion.
static void QGeoPolygon_PythonToCpp_QGeoPolygon_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QGeoPolygon *>(cppOut) = *reinterpret_cast< ::QGeoPolygon *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QGeoPolygon_PythonToCpp_QGeoPolygon_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QGeoPolygon_TypeF()))
        return QGeoPolygon_PythonToCpp_QGeoPolygon_COPY;
    return {};
}

// Implicit conversions.
static void constQGeoShapeREF_PythonToCpp_QGeoPolygon(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QGeoPolygon *>(cppOut) = ::QGeoPolygon( *reinterpret_cast< ::QGeoShape *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoShape_IDX]), reinterpret_cast<SbkObject *>(pyIn))));
}
static PythonToCppFunc is_constQGeoShapeREF_PythonToCpp_QGeoPolygon_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoShape_IDX]), pyIn))
        return constQGeoShapeREF_PythonToCpp_QGeoPolygon;
    return {};
}

static void _constQList_QGeoCoordinate_REF_PythonToCpp_QGeoPolygon(PyObject *pyIn, void *cppOut)
{
    ::QList<QGeoCoordinate> cppIn;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtPositioningTypeConverters[SBK_QtPositioning_QList_QGeoCoordinate_IDX], pyIn, &cppIn);
    *reinterpret_cast<::QGeoPolygon *>(cppOut) = ::QGeoPolygon(cppIn);
}
static PythonToCppFunc is__constQList_QGeoCoordinate_REF_PythonToCpp_QGeoPolygon_Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), pyIn))
        return _constQList_QGeoCoordinate_REF_PythonToCpp_QGeoPolygon;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QGeoPolygon_SignatureStrings[] = {
    "3:PySide6.QtPositioning.QGeoPolygon(self,*:KeywordOnly=None,perimeter:QList[PySide6.QtPositioning.QGeoCoordinate]=None)",
    "2:PySide6.QtPositioning.QGeoPolygon(self,other:PySide6.QtPositioning.QGeoPolygon,*:KeywordOnly=None,perimeter:QList[PySide6.QtPositioning.QGeoCoordinate]=None)",
    "1:PySide6.QtPositioning.QGeoPolygon(self,other:PySide6.QtPositioning.QGeoShape,*:KeywordOnly=None,perimeter:QList[PySide6.QtPositioning.QGeoCoordinate]=None)",
    "0:PySide6.QtPositioning.QGeoPolygon(self,path:QList[PySide6.QtPositioning.QGeoCoordinate],*:KeywordOnly=None,perimeter:QList[PySide6.QtPositioning.QGeoCoordinate]=None)",
    "PySide6.QtPositioning.QGeoPolygon.addCoordinate(self,coordinate:PySide6.QtPositioning.QGeoCoordinate)",
    "1:PySide6.QtPositioning.QGeoPolygon.addHole(self,holePath:QList[PySide6.QtPositioning.QGeoCoordinate])",
    "0:PySide6.QtPositioning.QGeoPolygon.addHole(self,holePath:QVariant)",
    "PySide6.QtPositioning.QGeoPolygon.containsCoordinate(self,coordinate:PySide6.QtPositioning.QGeoCoordinate)->bool",
    "PySide6.QtPositioning.QGeoPolygon.coordinateAt(self,index:qsizetype)->PySide6.QtPositioning.QGeoCoordinate",
    "PySide6.QtPositioning.QGeoPolygon.hole(self,index:qsizetype)->QList[QVariant]",
    "PySide6.QtPositioning.QGeoPolygon.holePath(self,index:qsizetype)->QList[PySide6.QtPositioning.QGeoCoordinate]",
    "PySide6.QtPositioning.QGeoPolygon.holesCount(self)->qsizetype",
    "PySide6.QtPositioning.QGeoPolygon.insertCoordinate(self,index:qsizetype,coordinate:PySide6.QtPositioning.QGeoCoordinate)",
    "PySide6.QtPositioning.QGeoPolygon.length(self,indexFrom:qsizetype=0,indexTo:qsizetype=-1)->double",
    "PySide6.QtPositioning.QGeoPolygon.perimeter(self)->QList[PySide6.QtPositioning.QGeoCoordinate]",
    "1:PySide6.QtPositioning.QGeoPolygon.removeCoordinate(self,coordinate:PySide6.QtPositioning.QGeoCoordinate)",
    "0:PySide6.QtPositioning.QGeoPolygon.removeCoordinate(self,index:qsizetype)",
    "PySide6.QtPositioning.QGeoPolygon.removeHole(self,index:qsizetype)",
    "PySide6.QtPositioning.QGeoPolygon.replaceCoordinate(self,index:qsizetype,coordinate:PySide6.QtPositioning.QGeoCoordinate)",
    "PySide6.QtPositioning.QGeoPolygon.setPerimeter(self,path:QList[PySide6.QtPositioning.QGeoCoordinate])",
    "PySide6.QtPositioning.QGeoPolygon.size(self)->qsizetype",
    "PySide6.QtPositioning.QGeoPolygon.toString(self)->QString",
    "PySide6.QtPositioning.QGeoPolygon.translate(self,degreesLatitude:double,degreesLongitude:double)",
    "PySide6.QtPositioning.QGeoPolygon.translated(self,degreesLatitude:double,degreesLongitude:double)->PySide6.QtPositioning.QGeoPolygon",
    "PySide6.QtPositioning.QGeoPolygon.__copy__(self)->typing.Self",
    "PySide6.QtPositioning.QGeoPolygon.__lshift__(self,stream:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "PySide6.QtPositioning.QGeoPolygon.__rshift__(self,stream:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    nullptr}; // Sentinel
#else
static constexpr size_t QGeoPolygon_SignatureByteSize = 445;
static constexpr uint8_t QGeoPolygon_SignatureBytes[445] = {
    0x78, 0xda, 0xc5, 0x95, 0x51, 0x4b, 0xc3, 0x30, 0x10, 0xc7, 0xdf, 0xfd, 0x24, 0x2a, 0x73, 0x6c,
    0x0a, 0x3e, 0x14, 0x14, 0x64, 0xa2, 0x03, 0x87, 0xb6, 0x54, 0x7c, 0x91, 0x31, 0xe2, 0x72, 0xb6,
    0x81, 0x34, 0x57, 0x93, 0x9b, 0x5a, 0x3f, 0xbd, 0x99, 0xdd, 0xea, 0x36, 0xd9, 0x76, 0xdd, 0x0a,
    0xbe, 0x35, 0x97, 0xde, 0xfd, 0xfe, 0xf9, 0xdf, 0x35, 0x3d, 0x0b, 0xc2, 0x22, 0x56, 0x12, 0xce,
    0xdb, 0x11, 0x85, 0xe8, 0x14, 0x29, 0x34, 0xca, 0x24, 0xed, 0xe8, 0x16, 0x30, 0x44, 0x5d, 0x24,
    0x68, 0x0e, 0x1d, 0xe8, 0xd7, 0xd6, 0x71, 0x70, 0x07, 0xc5, 0x07, 0x5a, 0xf9, 0x60, 0x74, 0x71,
    0x71, 0x8f, 0x06, 0x5a, 0x39, 0x58, 0x95, 0x01, 0x81, 0x0d, 0xa2, 0x81, 0x72, 0xf4, 0xbc, 0xbe,
    0x52, 0x0f, 0x7d, 0xa2, 0x32, 0x82, 0x60, 0xf8, 0x93, 0x7a, 0x74, 0x70, 0xca, 0xe5, 0x22, 0xa5,
    0x1e, 0xb0, 0xf5, 0xe5, 0xa6, 0xf5, 0x75, 0x9b, 0xd2, 0x17, 0xa7, 0x22, 0x87, 0xa6, 0xd5, 0x75,
    0xb8, 0xea, 0x72, 0x41, 0x69, 0x9d, 0xfa, 0x4d, 0x0b, 0xdd, 0x2a, 0xb3, 0x2d, 0xa4, 0xfc, 0x4d,
    0x2b, 0x45, 0x8f, 0xab, 0x75, 0xc0, 0x61, 0xb1, 0x9a, 0x35, 0xe5, 0xf4, 0x51, 0xcf, 0x08, 0xa9,
    0x7f, 0x0a, 0x6b, 0x5a, 0xc3, 0x72, 0x7d, 0x1d, 0xe6, 0x49, 0x58, 0x25, 0x0c, 0x71, 0x0c, 0x19,
    0xa3, 0x21, 0xa1, 0x8c, 0xdb, 0xd7, 0x95, 0x93, 0xcb, 0x17, 0x44, 0xcd, 0x02, 0xce, 0x73, 0xae,
    0xa8, 0x44, 0x29, 0x23, 0xe1, 0x33, 0x78, 0x73, 0xea, 0x0b, 0xa8, 0xc8, 0xa7, 0xa5, 0x38, 0x44,
    0x06, 0x2a, 0xad, 0xac, 0xf9, 0x8b, 0x28, 0x5b, 0x31, 0x77, 0x6a, 0xc8, 0xac, 0x36, 0xb5, 0x77,
    0x73, 0x45, 0x56, 0x73, 0x99, 0x34, 0xdf, 0x94, 0x89, 0x29, 0x4d, 0xf2, 0xf5, 0x2b, 0x16, 0x23,
    0xdb, 0x37, 0x14, 0x2c, 0xad, 0xf6, 0x74, 0x45, 0x73, 0xfd, 0xc9, 0xdf, 0x0e, 0xd6, 0x60, 0x92,
    0x25, 0x8b, 0x6e, 0x2c, 0x66, 0xbf, 0xc8, 0x8b, 0x4e, 0x19, 0x7d, 0xc4, 0x85, 0xd8, 0x49, 0xd7,
    0x9f, 0x4e, 0xe2, 0xe4, 0x45, 0x73, 0x8e, 0x56, 0xdd, 0x0f, 0x73, 0x5f, 0xea, 0xf8, 0xce, 0xf9,
    0x74, 0x2d, 0x64, 0xf8, 0x0e, 0x7b, 0xdf, 0x12, 0x9d, 0x9d, 0x51, 0xab, 0xa3, 0x75, 0xc0, 0x2d,
    0xd4, 0x5f, 0x3b, 0xef, 0xac, 0x12, 0xb9, 0x16, 0x63, 0xf8, 0x87, 0x99, 0x71, 0x40, 0xe1, 0x52,
    0x53, 0x6b, 0xff, 0x47, 0x58, 0x14, 0x7f, 0x82, 0x5d, 0x3e, 0x25, 0xc2, 0x98, 0xac, 0x0f, 0x56,
    0xe3, 0x56, 0x2e, 0x39, 0x99, 0x56, 0x18, 0xa7, 0x2b, 0x27, 0x25, 0x24, 0x16, 0xc0, 0x0d, 0x04,
    0x29, 0x9a, 0x48, 0x08, 0xca, 0x89, 0xaf, 0xc2, 0x68, 0x92, 0xc5, 0xf8, 0x51, 0x1d, 0x80, 0xdc,
    0x89, 0xb0, 0xe9, 0x9e, 0x9d, 0x21, 0x18, 0x22, 0x46, 0xa3, 0x31, 0xe6, 0xc5, 0x68, 0x34, 0xf7,
    0xc7, 0xdb, 0x3a, 0x7d, 0x25, 0xf6, 0x2b, 0x56, 0xb6, 0x76, 0xa9, 0x7a, 0xa5, 0x59, 0x7e, 0xcb,
    0x91, 0x05, 0x91, 0x2d, 0x8c, 0x56, 0x0f, 0x2d, 0xb4, 0xa3, 0x6b, 0x41, 0x22, 0xfe, 0xd9, 0x5a,
    0x52, 0xbd, 0xba, 0xc9, 0x02, 0xda, 0x26, 0x81, 0xdf, 0x8b, 0xfb, 0x06, 0x82
};
#endif

PyTypeObject *init_QGeoPolygon(PyObject *module)
{
    if (SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX].type != nullptr)
        return SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX].type;

    Shiboken::AutoDecRef Sbk_QGeoPolygon_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoShape_IDX]))));

    _Sbk_QGeoPolygon_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QGeoPolygon",
        "QGeoPolygon",
        &Sbk_QGeoPolygon_spec,
        &Shiboken::callCppDestructor< ::QGeoPolygon >,
        Sbk_QGeoPolygon_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QGeoPolygon_TypeF(); // references _Sbk_QGeoPolygon_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QGeoPolygon_SignatureStrings);
#else
    InitSignatureBytes(pyType, QGeoPolygon_SignatureBytes, QGeoPolygon_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QGeoPolygon_PropertyStrings);
    SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPolygon_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QGeoPolygon_PythonToCpp_QGeoPolygon_PTR,
        is_QGeoPolygon_PythonToCpp_QGeoPolygon_PTR_Convertible,
        QGeoPolygon_PTR_CppToPython_QGeoPolygon,
        QGeoPolygon_COPY_CppToPython_QGeoPolygon);

    Shiboken::Conversions::registerConverterName(converter, "QGeoPolygon");
    Shiboken::Conversions::registerConverterName(converter, "QGeoPolygon*");
    Shiboken::Conversions::registerConverterName(converter, "QGeoPolygon&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QGeoPolygon).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QGeoPolygon_PythonToCpp_QGeoPolygon_COPY,
        is_QGeoPolygon_PythonToCpp_QGeoPolygon_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        constQGeoShapeREF_PythonToCpp_QGeoPolygon,
        is_constQGeoShapeREF_PythonToCpp_QGeoPolygon_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        _constQList_QGeoCoordinate_REF_PythonToCpp_QGeoPolygon,
        is__constQList_QGeoCoordinate_REF_PythonToCpp_QGeoPolygon_Convertible);

    qRegisterMetaType< ::QGeoPolygon >("QGeoPolygon");

    return pyType;
}
