// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtpositioning_python.h"

// main header
#include "qgeopositioninfo_wrapper.h"

// Argument includes
#include <QtPositioning/qgeocoordinate.h>
#include <QtPositioning/qgeopositioninfo.h>
#include <qdatastream.h>
#include <qdatetime.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGeoPositionInfo_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QGeoPositionInfo >()))
        return -1;

    ::QGeoPositionInfo *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QGeoPositionInfo", 0, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QGeoPositionInfo::QGeoPositionInfo()
    // 1: QGeoPositionInfo::QGeoPositionInfo(QGeoCoordinate,QDateTime)
    // 2: QGeoPositionInfo::QGeoPositionInfo(QGeoPositionInfo)
    if (numArgs == 0) {
        overloadId = 0; // QGeoPositionInfo()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QGeoPositionInfo(QGeoPositionInfo)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArgs[1])))) {
        overloadId = 1; // QGeoPositionInfo(QGeoCoordinate,QDateTime)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QGeoPositionInfo()
        {

            // QGeoPositionInfo()
            cptr = new ::QGeoPositionInfo();
            break;
        }
        case 1: // QGeoPositionInfo(const QGeoCoordinate &coordinate, const QDateTime &updateTime)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QGeoCoordinate cppArg0_local;
            ::QGeoCoordinate *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QDateTime cppArg1_local;
            ::QDateTime *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QGeoPositionInfo(QGeoCoordinate,QDateTime)
                cptr = new ::QGeoPositionInfo(*cppArg0, *cppArg1);
            }
            break;
        }
        case 2: // QGeoPositionInfo(const QGeoPositionInfo &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QGeoPositionInfo cppArg0_local;
            ::QGeoPositionInfo *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QGeoPositionInfo(QGeoPositionInfo)
                cptr = new ::QGeoPositionInfo(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QGeoPositionInfo >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QGeoPositionInfoFunc_attribute(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoPositionInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoPositionInfo::attribute(QGeoPositionInfo::Attribute)const->qreal
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_Attribute_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // attribute(QGeoPositionInfo::Attribute)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "attribute", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX]);

    // Call function/method
    {
        ::QGeoPositionInfo::Attribute cppArg0{QGeoPositionInfo::Direction};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // attribute(QGeoPositionInfo::Attribute)const
            qreal cppResult = const_cast<const ::QGeoPositionInfo *>(cppSelf)->attribute(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoPositionInfoFunc_coordinate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoPositionInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // coordinate()const
        QGeoCoordinate cppResult = const_cast<const ::QGeoPositionInfo *>(cppSelf)->coordinate();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoPositionInfoFunc_hasAttribute(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoPositionInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoPositionInfo::hasAttribute(QGeoPositionInfo::Attribute)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_Attribute_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // hasAttribute(QGeoPositionInfo::Attribute)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "hasAttribute", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX]);

    // Call function/method
    {
        ::QGeoPositionInfo::Attribute cppArg0{QGeoPositionInfo::Direction};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // hasAttribute(QGeoPositionInfo::Attribute)const
            bool cppResult = const_cast<const ::QGeoPositionInfo *>(cppSelf)->hasAttribute(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoPositionInfoFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoPositionInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QGeoPositionInfo *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoPositionInfoFunc_removeAttribute(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoPositionInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoPositionInfo::removeAttribute(QGeoPositionInfo::Attribute)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_Attribute_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // removeAttribute(QGeoPositionInfo::Attribute)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeAttribute", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX]);

    // Call function/method
    {
        ::QGeoPositionInfo::Attribute cppArg0{QGeoPositionInfo::Direction};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeAttribute(QGeoPositionInfo::Attribute)
            cppSelf->removeAttribute(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoPositionInfoFunc_setAttribute(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoPositionInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setAttribute", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGeoPositionInfo::setAttribute(QGeoPositionInfo::Attribute,qreal)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_Attribute_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))) {
        overloadId = 0; // setAttribute(QGeoPositionInfo::Attribute,qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setAttribute", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX]);

    // Call function/method
    {
        ::QGeoPositionInfo::Attribute cppArg0{QGeoPositionInfo::Direction};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qreal cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAttribute(QGeoPositionInfo::Attribute,qreal)
            cppSelf->setAttribute(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoPositionInfoFunc_setCoordinate(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoPositionInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoPositionInfo::setCoordinate(QGeoCoordinate)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), (pyArg)))) {
        overloadId = 0; // setCoordinate(QGeoCoordinate)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCoordinate", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGeoCoordinate cppArg0_local;
        ::QGeoCoordinate *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setCoordinate(QGeoCoordinate)
            cppSelf->setCoordinate(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoPositionInfoFunc_setTimestamp(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoPositionInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoPositionInfo::setTimestamp(QDateTime)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // setTimestamp(QDateTime)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTimestamp", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setTimestamp(QDateTime)
            cppSelf->setTimestamp(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoPositionInfoFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoPositionInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoPositionInfo::swap(QGeoPositionInfo&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QGeoPositionInfo&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGeoPositionInfo cppArg0_local;
        ::QGeoPositionInfo *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QGeoPositionInfo&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoPositionInfoFunc_timestamp(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoPositionInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // timestamp()const
        QDateTime cppResult = const_cast<const ::QGeoPositionInfo *>(cppSelf)->timestamp();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoPositionInfo__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QGeoPositionInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QGeoPositionInfo_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QGeoPositionInfo_EnumFlagInfo[] = {
    "Attribute:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QGeoPositionInfo_methods[] = {
    {"attribute", reinterpret_cast<PyCFunction>(Sbk_QGeoPositionInfoFunc_attribute), METH_O, nullptr},
    {"coordinate", reinterpret_cast<PyCFunction>(Sbk_QGeoPositionInfoFunc_coordinate), METH_NOARGS, nullptr},
    {"hasAttribute", reinterpret_cast<PyCFunction>(Sbk_QGeoPositionInfoFunc_hasAttribute), METH_O, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QGeoPositionInfoFunc_isValid), METH_NOARGS, nullptr},
    {"removeAttribute", reinterpret_cast<PyCFunction>(Sbk_QGeoPositionInfoFunc_removeAttribute), METH_O, nullptr},
    {"setAttribute", reinterpret_cast<PyCFunction>(Sbk_QGeoPositionInfoFunc_setAttribute), METH_VARARGS, nullptr},
    {"setCoordinate", reinterpret_cast<PyCFunction>(Sbk_QGeoPositionInfoFunc_setCoordinate), METH_O, nullptr},
    {"setTimestamp", reinterpret_cast<PyCFunction>(Sbk_QGeoPositionInfoFunc_setTimestamp), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QGeoPositionInfoFunc_swap), METH_O, nullptr},
    {"timestamp", reinterpret_cast<PyCFunction>(Sbk_QGeoPositionInfoFunc_timestamp), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QGeoPositionInfo__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QGeoPositionInfoFunc___lshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoPositionInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rlshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QGeoPositionInfo::operator<<(QDataStream&)->QDataStream&
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // operator<<(QDataStream&,QGeoPositionInfo)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator<<", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator<<(QDataStream&,QGeoPositionInfo) [reverse operator]
                QDataStream & cppResult = (*cppArg0) << (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoPositionInfoFunc___rshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoPositionInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rrshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QGeoPositionInfo::operator>>(QDataStream&)->QDataStream&
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // operator>>(QDataStream&,QGeoPositionInfo&)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator>>", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator>>(QDataStream&,QGeoPositionInfo&) [reverse operator]
                QDataStream & cppResult = (*cppArg0) >> (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

// Rich comparison
static PyObject * Sbk_QGeoPositionInfo_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QGeoPositionInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX]), (pyArg)))) {
                // operator!=(const QGeoPositionInfo &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QGeoPositionInfo cppArg0_local;
                ::QGeoPositionInfo *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX]), (pyArg)))) {
                // operator==(const QGeoPositionInfo &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QGeoPositionInfo cppArg0_local;
                ::QGeoPositionInfo *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static Py_hash_t Sbk_QGeoPositionInfo_HashFunc(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoPositionInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return Py_hash_t(qHash(*cppSelf));
}

static int Sbk_QGeoPositionInfo_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QGeoPositionInfo_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QGeoPositionInfo__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoPositionInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QGeoPositionInfo_Type = nullptr;
static PyTypeObject *Sbk_QGeoPositionInfo_TypeF(void)
{
    return _Sbk_QGeoPositionInfo_Type;
}

static PyType_Slot Sbk_QGeoPositionInfo_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QGeoPositionInfo__repr__)},
    {Py_tp_hash,        reinterpret_cast<void *>(&Sbk_QGeoPositionInfo_HashFunc)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QGeoPositionInfo_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QGeoPositionInfo_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QGeoPositionInfo_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QGeoPositionInfo_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QGeoPositionInfo_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_lshift,      reinterpret_cast<void *>(Sbk_QGeoPositionInfoFunc___lshift__)},
    {Py_nb_rshift,      reinterpret_cast<void *>(Sbk_QGeoPositionInfoFunc___rshift__)},
    {0, nullptr}
};
static PyType_Spec Sbk_QGeoPositionInfo_spec = {
    "2:PySide6.QtPositioning.QGeoPositionInfo",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QGeoPositionInfo_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QGeoPositionInfo_Attribute(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QGeoPositionInfo::Attribute>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QGeoPositionInfo::Attribute *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QGeoPositionInfo_Attribute_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_Attribute_IDX])))
        return Enum_PythonToCpp_QGeoPositionInfo_Attribute;
    return {};
}

static PyObject *QGeoPositionInfo_Attribute_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QGeoPositionInfo::Attribute>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QGeoPositionInfo::Attribute *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_Attribute_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QGeoPositionInfo_PythonToCpp_QGeoPositionInfo_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QGeoPositionInfo_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QGeoPositionInfo_PythonToCpp_QGeoPositionInfo_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QGeoPositionInfo_TypeF()))
        return QGeoPositionInfo_PythonToCpp_QGeoPositionInfo_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QGeoPositionInfo_PTR_CppToPython_QGeoPositionInfo(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QGeoPositionInfo_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QGeoPositionInfo_COPY_CppToPython_QGeoPositionInfo(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QGeoPositionInfo *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QGeoPositionInfo_TypeF(), new ::QGeoPositionInfo(*source), true, true);
}

// Python to C++ copy conversion.
static void QGeoPositionInfo_PythonToCpp_QGeoPositionInfo_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QGeoPositionInfo *>(cppOut) = *reinterpret_cast< ::QGeoPositionInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QGeoPositionInfo_PythonToCpp_QGeoPositionInfo_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QGeoPositionInfo_TypeF()))
        return QGeoPositionInfo_PythonToCpp_QGeoPositionInfo_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QGeoPositionInfo_SignatureStrings[] = {
    "2:PySide6.QtPositioning.QGeoPositionInfo(self)",
    "1:PySide6.QtPositioning.QGeoPositionInfo(self,coordinate:PySide6.QtPositioning.QGeoCoordinate,updateTime:PySide6.QtCore.QDateTime)",
    "0:PySide6.QtPositioning.QGeoPositionInfo(self,other:PySide6.QtPositioning.QGeoPositionInfo)",
    "PySide6.QtPositioning.QGeoPositionInfo.attribute(self,attribute:PySide6.QtPositioning.QGeoPositionInfo.Attribute)->qreal",
    "PySide6.QtPositioning.QGeoPositionInfo.coordinate(self)->PySide6.QtPositioning.QGeoCoordinate",
    "PySide6.QtPositioning.QGeoPositionInfo.hasAttribute(self,attribute:PySide6.QtPositioning.QGeoPositionInfo.Attribute)->bool",
    "PySide6.QtPositioning.QGeoPositionInfo.isValid(self)->bool",
    "PySide6.QtPositioning.QGeoPositionInfo.removeAttribute(self,attribute:PySide6.QtPositioning.QGeoPositionInfo.Attribute)",
    "PySide6.QtPositioning.QGeoPositionInfo.setAttribute(self,attribute:PySide6.QtPositioning.QGeoPositionInfo.Attribute,value:qreal)",
    "PySide6.QtPositioning.QGeoPositionInfo.setCoordinate(self,coordinate:PySide6.QtPositioning.QGeoCoordinate)",
    "PySide6.QtPositioning.QGeoPositionInfo.setTimestamp(self,timestamp:PySide6.QtCore.QDateTime)",
    "PySide6.QtPositioning.QGeoPositionInfo.swap(self,other:PySide6.QtPositioning.QGeoPositionInfo)",
    "PySide6.QtPositioning.QGeoPositionInfo.timestamp(self)->PySide6.QtCore.QDateTime",
    "PySide6.QtPositioning.QGeoPositionInfo.__copy__(self)->typing.Self",
    "PySide6.QtPositioning.QGeoPositionInfo.__lshift__(self,stream:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "PySide6.QtPositioning.QGeoPositionInfo.__rshift__(self,stream:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "PySide6.QtPositioning.QGeoPositionInfo.__ne__(self,rhs:PySide6.QtPositioning.QGeoPositionInfo)->bool",
    "PySide6.QtPositioning.QGeoPositionInfo.__eq__(self,rhs:PySide6.QtPositioning.QGeoPositionInfo)->bool",
    "PySide6.QtPositioning.QGeoPositionInfo.__hash__(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t QGeoPositionInfo_SignatureByteSize = 302;
static constexpr uint8_t QGeoPositionInfo_SignatureBytes[302] = {
    0x78, 0xda, 0xc5, 0x54, 0x4d, 0x6b, 0x83, 0x40, 0x10, 0xbd, 0xfb, 0x4b, 0x2a, 0x18, 0x69, 0x7b,
    0xe8, 0x21, 0x87, 0x40, 0xb0, 0x50, 0x7a, 0x8b, 0x58, 0x7a, 0x5d, 0x36, 0x71, 0xac, 0x0b, 0xba,
    0x63, 0x76, 0xc7, 0x14, 0xff, 0x7d, 0x4d, 0x74, 0x93, 0x0a, 0x21, 0xcc, 0x82, 0x6d, 0x4e, 0xcb,
    0x30, 0x33, 0xef, 0xbd, 0xf9, 0xda, 0xe7, 0xe5, 0xa6, 0xcb, 0x54, 0x0e, 0x2f, 0x71, 0x4a, 0x1b,
    0xb4, 0x8a, 0x14, 0x6a, 0xa5, 0xbf, 0xe2, 0xf4, 0x0d, 0xd0, 0xd9, 0xef, 0xba, 0xc0, 0x07, 0x0b,
    0x55, 0x11, 0x06, 0x4f, 0x3e, 0xe1, 0xd1, 0x0e, 0xd1, 0xe4, 0x4a, 0x4b, 0x82, 0x1b, 0x69, 0xc9,
    0x39, 0x28, 0x6a, 0x9b, 0xbc, 0x7f, 0x3e, 0x54, 0xfd, 0x3b, 0x3e, 0x41, 0x03, 0x71, 0xfa, 0x3a,
    0x3a, 0xc2, 0xe0, 0xd1, 0x4b, 0x02, 0x52, 0x09, 0x86, 0x99, 0x11, 0x06, 0xbc, 0xb8, 0x58, 0x12,
    0x19, 0xb5, 0x6d, 0x09, 0x06, 0x8e, 0xb3, 0xc9, 0xe4, 0x89, 0xd7, 0x2e, 0x21, 0x5c, 0xac, 0xf6,
    0x06, 0x64, 0xc5, 0x25, 0xbe, 0x34, 0x74, 0x98, 0xc7, 0x62, 0xc5, 0xe9, 0x2b, 0x17, 0xbd, 0x94,
    0x76, 0x3d, 0x63, 0x65, 0x5b, 0x44, 0x76, 0x61, 0xca, 0x7e, 0xca, 0x4a, 0xe5, 0xae, 0x2a, 0x9f,
    0x54, 0x03, 0x35, 0x1e, 0x60, 0x3e, 0xe1, 0x5c, 0x5e, 0x0b, 0x34, 0x1b, 0x69, 0x74, 0x90, 0x55,
    0x0b, 0xcb, 0xd3, 0x2e, 0xf8, 0x08, 0x48, 0xa6, 0xfb, 0xe0, 0x7b, 0x70, 0x3e, 0x54, 0xc7, 0xe3,
    0xb3, 0x24, 0xeb, 0x66, 0x60, 0x22, 0x67, 0xde, 0xb8, 0x54, 0x2e, 0xf8, 0xb7, 0x6c, 0xfe, 0xf0,
    0x58, 0x69, 0x22, 0x7c, 0x72, 0x32, 0x53, 0xc1, 0x5c, 0x40, 0x21, 0x76, 0xd8, 0x74, 0x42, 0x38,
    0x3c, 0xea, 0x9a, 0x63, 0x5c, 0xd6, 0x5b, 0x7c, 0x88, 0xca, 0x96, 0xaa, 0xa0, 0x11, 0x24, 0xb2,
    0xd4, 0x4f, 0xbe, 0xbe, 0xd6, 0x4a, 0x99, 0x9d, 0x5c, 0xd7, 0x65, 0x8f, 0x4e, 0x3e, 0xab, 0xb9,
    0x0b, 0xab, 0x06, 0xc7, 0x68, 0x4a, 0xcb, 0x1d, 0xaf, 0xdf, 0x27, 0x20, 0x04, 0xec, 0xff, 0x81,
    0xa4, 0xff, 0x21, 0xcb, 0xcb, 0xe0, 0x95, 0xa6, 0xe0, 0x07, 0x90, 0x0e, 0xb0, 0xf5
};
#endif

PyTypeObject *init_QGeoPositionInfo(PyObject *module)
{
    if (SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX].type != nullptr)
        return SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX].type;

    Shiboken::AutoDecRef Sbk_QGeoPositionInfo_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QGeoPositionInfo_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QGeoPositionInfo",
        "QGeoPositionInfo",
        &Sbk_QGeoPositionInfo_spec,
        &Shiboken::callCppDestructor< ::QGeoPositionInfo >,
        Sbk_QGeoPositionInfo_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QGeoPositionInfo_TypeF(); // references _Sbk_QGeoPositionInfo_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QGeoPositionInfo_SignatureStrings);
#else
    InitSignatureBytes(pyType, QGeoPositionInfo_SignatureBytes, QGeoPositionInfo_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QGeoPositionInfo_PropertyStrings);
    SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QGeoPositionInfo_PythonToCpp_QGeoPositionInfo_PTR,
        is_QGeoPositionInfo_PythonToCpp_QGeoPositionInfo_PTR_Convertible,
        QGeoPositionInfo_PTR_CppToPython_QGeoPositionInfo,
        QGeoPositionInfo_COPY_CppToPython_QGeoPositionInfo);

    Shiboken::Conversions::registerConverterName(converter, "QGeoPositionInfo");
    Shiboken::Conversions::registerConverterName(converter, "QGeoPositionInfo*");
    Shiboken::Conversions::registerConverterName(converter, "QGeoPositionInfo&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QGeoPositionInfo).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QGeoPositionInfo_PythonToCpp_QGeoPositionInfo_COPY,
        is_QGeoPositionInfo_PythonToCpp_QGeoPositionInfo_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QGeoPositionInfo_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Attribute'.
    const char *Attribute_Initializer[] = {
        "Direction",
        "GroundSpeed",
        "VerticalSpeed",
        "MagneticVariation",
        "HorizontalAccuracy",
        "VerticalAccuracy",
        "DirectionAccuracy",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Attribute_InitializerValues[] = {
        uint8_t(QGeoPositionInfo::Attribute::Direction),          //  0x00  0
        uint8_t(QGeoPositionInfo::Attribute::GroundSpeed),        //  0x01  1
        uint8_t(QGeoPositionInfo::Attribute::VerticalSpeed),      //  0x02  2
        uint8_t(QGeoPositionInfo::Attribute::MagneticVariation),  //  0x03  3
        uint8_t(QGeoPositionInfo::Attribute::HorizontalAccuracy), //  0x04  4
        uint8_t(QGeoPositionInfo::Attribute::VerticalAccuracy),   //  0x05  5
        uint8_t(QGeoPositionInfo::Attribute::DirectionAccuracy)   //  0x06  6
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QGeoPositionInfo_TypeF(),
        "2:PySide6.QtPositioning.QGeoPositionInfo.Attribute",
        Attribute_Initializer, Attribute_InitializerValues);
    SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_Attribute_IDX].type = EType;
    // Register converter for enum 'QGeoPositionInfo::Attribute'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QGeoPositionInfo_Attribute_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QGeoPositionInfo_Attribute,
            is_Enum_PythonToCpp_QGeoPositionInfo_Attribute_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QGeoPositionInfo::Attribute");
        Shiboken::Conversions::registerConverterAlias(converter, "Attribute");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Attribute' enum.

    qRegisterMetaType< ::QGeoPositionInfo >("QGeoPositionInfo");
    qRegisterMetaType< ::QGeoPositionInfo::Attribute >("QGeoPositionInfo::Attribute");

    return pyType;
}
