// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtpositioning_python.h"

// main header
#include "qgeorectangle_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtPositioning/qgeocoordinate.h>
#include <QtPositioning/qgeorectangle.h>
#include <QtPositioning/qgeoshape.h>
#include <qdatastream.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGeoRectangle_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QGeoRectangle >()))
        return -1;

    ::QGeoRectangle *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QGeoRectangle", 0, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QGeoRectangle::QGeoRectangle()
    // 1: QGeoRectangle::QGeoRectangle(QGeoCoordinate,double,double)
    // 2: QGeoRectangle::QGeoRectangle(QGeoCoordinate,QGeoCoordinate)
    // 3: QGeoRectangle::QGeoRectangle(QGeoRectangle)
    // 4: QGeoRectangle::QGeoRectangle(QGeoShape)
    // 5: QGeoRectangle::QGeoRectangle(QList<QGeoCoordinate>)
    if (numArgs == 0) {
        overloadId = 0; // QGeoRectangle()
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), (pyArgs[0])))) {
        if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), (pyArgs[1])))) {
            overloadId = 2; // QGeoRectangle(QGeoCoordinate,QGeoCoordinate)
        } else if (numArgs == 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[2])))) {
            overloadId = 1; // QGeoRectangle(QGeoCoordinate,double,double)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtPositioningTypeConverters[SBK_QtPositioning_QList_QGeoCoordinate_IDX], (pyArgs[0])))) {
        overloadId = 5; // QGeoRectangle(QList<QGeoCoordinate>)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), (pyArgs[0])))) {
        overloadId = 3; // QGeoRectangle(QGeoRectangle)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoShape_IDX]), (pyArgs[0])))) {
        overloadId = 4; // QGeoRectangle(QGeoShape)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QGeoRectangle()
        {

            // QGeoRectangle()
            cptr = new ::QGeoRectangle();
            break;
        }
        case 1: // QGeoRectangle(const QGeoCoordinate &center, double degreesWidth, double degreesHeight)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QGeoCoordinate cppArg0_local;
            ::QGeoCoordinate *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            double cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            double cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QGeoRectangle(QGeoCoordinate,double,double)
                cptr = new ::QGeoRectangle(*cppArg0, cppArg1, cppArg2);
            }
            break;
        }
        case 2: // QGeoRectangle(const QGeoCoordinate &topLeft, const QGeoCoordinate &bottomRight)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QGeoCoordinate cppArg0_local;
            ::QGeoCoordinate *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QGeoCoordinate cppArg1_local;
            ::QGeoCoordinate *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QGeoRectangle(QGeoCoordinate,QGeoCoordinate)
                cptr = new ::QGeoRectangle(*cppArg0, *cppArg1);
            }
            break;
        }
        case 3: // QGeoRectangle(const QGeoRectangle &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QGeoRectangle cppArg0_local;
            ::QGeoRectangle *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QGeoRectangle(QGeoRectangle)
                cptr = new ::QGeoRectangle(*cppArg0);
            }
            break;
        }
        case 4: // QGeoRectangle(const QGeoShape &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QGeoShape cppArg0_local;
            ::QGeoShape *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QGeoRectangle(QGeoShape)
                cptr = new ::QGeoRectangle(*cppArg0);
            }
            break;
        }
        case 5: // QGeoRectangle(const QList<QGeoCoordinate> &coordinates)
        {
            ::QList<QGeoCoordinate> cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QGeoRectangle(QList<QGeoCoordinate>)
                cptr = new ::QGeoRectangle(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QGeoRectangle >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QGeoRectangleFunc_bottomLeft(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRectangle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // bottomLeft()const
        QGeoCoordinate cppResult = const_cast<const ::QGeoRectangle *>(cppSelf)->bottomLeft();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRectangleFunc_bottomRight(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRectangle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // bottomRight()const
        QGeoCoordinate cppResult = const_cast<const ::QGeoRectangle *>(cppSelf)->bottomRight();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRectangleFunc_center(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRectangle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // center()const
        QGeoCoordinate cppResult = const_cast<const ::QGeoRectangle *>(cppSelf)->center();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRectangleFunc_contains(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRectangle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRectangle::contains(QGeoRectangle)const->bool
    // 1: QGeoShape::contains(QGeoCoordinate)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), (pyArg)))) {
        overloadId = 1; // contains(QGeoCoordinate)const
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), (pyArg)))) {
        overloadId = 0; // contains(QGeoRectangle)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "contains", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // contains(const QGeoRectangle &rectangle) const
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QGeoRectangle cppArg0_local;
            ::QGeoRectangle *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // contains(QGeoRectangle)const
                bool cppResult = const_cast<const ::QGeoRectangle *>(cppSelf)->contains(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // contains(const QGeoCoordinate &coordinate) const
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QGeoCoordinate cppArg0_local;
            ::QGeoCoordinate *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // contains(QGeoCoordinate)const
                bool cppResult = const_cast<const ::QGeoShape *>(reinterpret_cast<QGeoShape *>(cppSelf))->contains(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRectangleFunc_extendRectangle(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRectangle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRectangle::extendRectangle(QGeoCoordinate)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), (pyArg)))) {
        overloadId = 0; // extendRectangle(QGeoCoordinate)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "extendRectangle", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGeoCoordinate cppArg0_local;
        ::QGeoCoordinate *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // extendRectangle(QGeoCoordinate)
            cppSelf->extendRectangle(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRectangleFunc_height(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRectangle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // height()const
        double cppResult = const_cast<const ::QGeoRectangle *>(cppSelf)->height();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<double>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRectangleFunc_intersects(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRectangle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRectangle::intersects(QGeoRectangle)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), (pyArg)))) {
        overloadId = 0; // intersects(QGeoRectangle)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "intersects", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGeoRectangle cppArg0_local;
        ::QGeoRectangle *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // intersects(QGeoRectangle)const
            bool cppResult = const_cast<const ::QGeoRectangle *>(cppSelf)->intersects(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRectangleFunc_setBottomLeft(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRectangle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRectangle::setBottomLeft(QGeoCoordinate)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), (pyArg)))) {
        overloadId = 0; // setBottomLeft(QGeoCoordinate)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBottomLeft", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGeoCoordinate cppArg0_local;
        ::QGeoCoordinate *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setBottomLeft(QGeoCoordinate)
            cppSelf->setBottomLeft(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRectangleFunc_setBottomRight(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRectangle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRectangle::setBottomRight(QGeoCoordinate)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), (pyArg)))) {
        overloadId = 0; // setBottomRight(QGeoCoordinate)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBottomRight", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGeoCoordinate cppArg0_local;
        ::QGeoCoordinate *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setBottomRight(QGeoCoordinate)
            cppSelf->setBottomRight(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRectangleFunc_setCenter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRectangle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRectangle::setCenter(QGeoCoordinate)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), (pyArg)))) {
        overloadId = 0; // setCenter(QGeoCoordinate)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCenter", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGeoCoordinate cppArg0_local;
        ::QGeoCoordinate *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setCenter(QGeoCoordinate)
            cppSelf->setCenter(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRectangleFunc_setHeight(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRectangle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRectangle::setHeight(double)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArg)))) {
        overloadId = 0; // setHeight(double)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHeight", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]);

    // Call function/method
    {
        double cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHeight(double)
            cppSelf->setHeight(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRectangleFunc_setTopLeft(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRectangle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRectangle::setTopLeft(QGeoCoordinate)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), (pyArg)))) {
        overloadId = 0; // setTopLeft(QGeoCoordinate)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTopLeft", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGeoCoordinate cppArg0_local;
        ::QGeoCoordinate *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setTopLeft(QGeoCoordinate)
            cppSelf->setTopLeft(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRectangleFunc_setTopRight(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRectangle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRectangle::setTopRight(QGeoCoordinate)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), (pyArg)))) {
        overloadId = 0; // setTopRight(QGeoCoordinate)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTopRight", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGeoCoordinate cppArg0_local;
        ::QGeoCoordinate *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setTopRight(QGeoCoordinate)
            cppSelf->setTopRight(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRectangleFunc_setWidth(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRectangle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRectangle::setWidth(double)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArg)))) {
        overloadId = 0; // setWidth(double)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setWidth", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]);

    // Call function/method
    {
        double cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setWidth(double)
            cppSelf->setWidth(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRectangleFunc_toString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRectangle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toString()const
        QString cppResult = const_cast<const ::QGeoRectangle *>(cppSelf)->toString();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRectangleFunc_topLeft(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRectangle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // topLeft()const
        QGeoCoordinate cppResult = const_cast<const ::QGeoRectangle *>(cppSelf)->topLeft();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRectangleFunc_topRight(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRectangle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // topRight()const
        QGeoCoordinate cppResult = const_cast<const ::QGeoRectangle *>(cppSelf)->topRight();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRectangleFunc_translate(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRectangle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "translate", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGeoRectangle::translate(double,double)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[1])))) {
        overloadId = 0; // translate(double,double)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "translate", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]);

    // Call function/method
    {
        double cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        double cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // translate(double,double)
            cppSelf->translate(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRectangleFunc_translated(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRectangle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "translated", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGeoRectangle::translated(double,double)const->QGeoRectangle
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[1])))) {
        overloadId = 0; // translated(double,double)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "translated", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]);

    // Call function/method
    {
        double cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        double cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // translated(double,double)const
            QGeoRectangle cppResult = const_cast<const ::QGeoRectangle *>(cppSelf)->translated(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRectangleFunc_united(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRectangle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRectangle::united(QGeoRectangle)const->QGeoRectangle
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), (pyArg)))) {
        overloadId = 0; // united(QGeoRectangle)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "united", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGeoRectangle cppArg0_local;
        ::QGeoRectangle *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // united(QGeoRectangle)const
            QGeoRectangle cppResult = const_cast<const ::QGeoRectangle *>(cppSelf)->united(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRectangleFunc_width(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRectangle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // width()const
        double cppResult = const_cast<const ::QGeoRectangle *>(cppSelf)->width();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<double>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRectangle__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QGeoRectangle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QGeoRectangle_PropertyStrings[] = {
    "bottomLeft::",
    "bottomRight::",
    "center::",
    "height::",
    "topLeft::",
    "topRight::",
    "width::",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QGeoRectangle_methods[] = {
    {"bottomLeft", reinterpret_cast<PyCFunction>(Sbk_QGeoRectangleFunc_bottomLeft), METH_NOARGS, nullptr},
    {"bottomRight", reinterpret_cast<PyCFunction>(Sbk_QGeoRectangleFunc_bottomRight), METH_NOARGS, nullptr},
    {"center", reinterpret_cast<PyCFunction>(Sbk_QGeoRectangleFunc_center), METH_NOARGS, nullptr},
    {"contains", reinterpret_cast<PyCFunction>(Sbk_QGeoRectangleFunc_contains), METH_O, nullptr},
    {"extendRectangle", reinterpret_cast<PyCFunction>(Sbk_QGeoRectangleFunc_extendRectangle), METH_O, nullptr},
    {"height", reinterpret_cast<PyCFunction>(Sbk_QGeoRectangleFunc_height), METH_NOARGS, nullptr},
    {"intersects", reinterpret_cast<PyCFunction>(Sbk_QGeoRectangleFunc_intersects), METH_O, nullptr},
    {"setBottomLeft", reinterpret_cast<PyCFunction>(Sbk_QGeoRectangleFunc_setBottomLeft), METH_O, nullptr},
    {"setBottomRight", reinterpret_cast<PyCFunction>(Sbk_QGeoRectangleFunc_setBottomRight), METH_O, nullptr},
    {"setCenter", reinterpret_cast<PyCFunction>(Sbk_QGeoRectangleFunc_setCenter), METH_O, nullptr},
    {"setHeight", reinterpret_cast<PyCFunction>(Sbk_QGeoRectangleFunc_setHeight), METH_O, nullptr},
    {"setTopLeft", reinterpret_cast<PyCFunction>(Sbk_QGeoRectangleFunc_setTopLeft), METH_O, nullptr},
    {"setTopRight", reinterpret_cast<PyCFunction>(Sbk_QGeoRectangleFunc_setTopRight), METH_O, nullptr},
    {"setWidth", reinterpret_cast<PyCFunction>(Sbk_QGeoRectangleFunc_setWidth), METH_O, nullptr},
    {"toString", reinterpret_cast<PyCFunction>(Sbk_QGeoRectangleFunc_toString), METH_NOARGS, nullptr},
    {"topLeft", reinterpret_cast<PyCFunction>(Sbk_QGeoRectangleFunc_topLeft), METH_NOARGS, nullptr},
    {"topRight", reinterpret_cast<PyCFunction>(Sbk_QGeoRectangleFunc_topRight), METH_NOARGS, nullptr},
    {"translate", reinterpret_cast<PyCFunction>(Sbk_QGeoRectangleFunc_translate), METH_VARARGS, nullptr},
    {"translated", reinterpret_cast<PyCFunction>(Sbk_QGeoRectangleFunc_translated), METH_VARARGS, nullptr},
    {"united", reinterpret_cast<PyCFunction>(Sbk_QGeoRectangleFunc_united), METH_O, nullptr},
    {"width", reinterpret_cast<PyCFunction>(Sbk_QGeoRectangleFunc_width), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QGeoRectangle__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QGeoRectangleFunc___lshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRectangle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rlshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QGeoRectangle::operator<<(QDataStream&)->QDataStream&
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // operator<<(QDataStream&,QGeoRectangle)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator<<", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator<<(QDataStream&,QGeoRectangle) [reverse operator]
                QDataStream & cppResult = (*cppArg0) << (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRectangleFunc___rshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRectangle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rrshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QGeoRectangle::operator>>(QDataStream&)->QDataStream&
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // operator>>(QDataStream&,QGeoRectangle&)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator>>", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator>>(QDataStream&,QGeoRectangle&) [reverse operator]
                QDataStream & cppResult = (*cppArg0) >> (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRectangleFunc___or__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRectangle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRectangle::operator|(QGeoRectangle)const->QGeoRectangle
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), (pyArg)))) {
        overloadId = 0; // operator|(QGeoRectangle)const
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator|", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGeoRectangle cppArg0_local;
        ::QGeoRectangle *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // operator|(QGeoRectangle)const
            QGeoRectangle cppResult = (*cppSelf) | (*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRectangleFunc___ior__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRectangle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRectangle::operator|=(QGeoRectangle)->QGeoRectangle&
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), (pyArg)))) {
        overloadId = 0; // operator|=(QGeoRectangle)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator|=", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGeoRectangle cppArg0_local;
        ::QGeoRectangle *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // operator|=(QGeoRectangle)
            (*cppSelf) |= (*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_INCREF(self);
    return self;
}

} // extern "C"

static int Sbk_QGeoRectangle_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QGeoRectangle_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QGeoRectangle_Type = nullptr;
static PyTypeObject *Sbk_QGeoRectangle_TypeF(void)
{
    return _Sbk_QGeoRectangle_Type;
}

static PyType_Slot Sbk_QGeoRectangle_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QGeoRectangle_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QGeoRectangle_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QGeoRectangle_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QGeoRectangle_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_inplace_or,  reinterpret_cast<void *>(Sbk_QGeoRectangleFunc___ior__)},
    {Py_nb_or,          reinterpret_cast<void *>(Sbk_QGeoRectangleFunc___or__)},
    {Py_nb_lshift,      reinterpret_cast<void *>(Sbk_QGeoRectangleFunc___lshift__)},
    {Py_nb_rshift,      reinterpret_cast<void *>(Sbk_QGeoRectangleFunc___rshift__)},
    {0, nullptr}
};
static PyType_Spec Sbk_QGeoRectangle_spec = {
    "2:PySide6.QtPositioning.QGeoRectangle",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QGeoRectangle_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QGeoRectangle_PythonToCpp_QGeoRectangle_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QGeoRectangle_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QGeoRectangle_PythonToCpp_QGeoRectangle_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QGeoRectangle_TypeF()))
        return QGeoRectangle_PythonToCpp_QGeoRectangle_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QGeoRectangle_PTR_CppToPython_QGeoRectangle(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QGeoRectangle_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QGeoRectangle_COPY_CppToPython_QGeoRectangle(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QGeoRectangle *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QGeoRectangle_TypeF(), new ::QGeoRectangle(*source), true, true);
}

// Python to C++ copy conversion.
static void QGeoRectangle_PythonToCpp_QGeoRectangle_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QGeoRectangle *>(cppOut) = *reinterpret_cast< ::QGeoRectangle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QGeoRectangle_PythonToCpp_QGeoRectangle_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QGeoRectangle_TypeF()))
        return QGeoRectangle_PythonToCpp_QGeoRectangle_COPY;
    return {};
}

// Implicit conversions.
static void constQGeoShapeREF_PythonToCpp_QGeoRectangle(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QGeoRectangle *>(cppOut) = ::QGeoRectangle( *reinterpret_cast< ::QGeoShape *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoShape_IDX]), reinterpret_cast<SbkObject *>(pyIn))));
}
static PythonToCppFunc is_constQGeoShapeREF_PythonToCpp_QGeoRectangle_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoShape_IDX]), pyIn))
        return constQGeoShapeREF_PythonToCpp_QGeoRectangle;
    return {};
}

static void _constQList_QGeoCoordinate_REF_PythonToCpp_QGeoRectangle(PyObject *pyIn, void *cppOut)
{
    ::QList<QGeoCoordinate> cppIn;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtPositioningTypeConverters[SBK_QtPositioning_QList_QGeoCoordinate_IDX], pyIn, &cppIn);
    *reinterpret_cast<::QGeoRectangle *>(cppOut) = ::QGeoRectangle(cppIn);
}
static PythonToCppFunc is__constQList_QGeoCoordinate_REF_PythonToCpp_QGeoRectangle_Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoCoordinate_IDX]), pyIn))
        return _constQList_QGeoCoordinate_REF_PythonToCpp_QGeoRectangle;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QGeoRectangle_SignatureStrings[] = {
    "5:PySide6.QtPositioning.QGeoRectangle(self,*:KeywordOnly=None,bottomLeft:QGeoCoordinate=None,bottomRight:QGeoCoordinate=None,topLeft:QGeoCoordinate=None,topRight:QGeoCoordinate=None,center:QGeoCoordinate=None,height:double=None,width:double=None)",
    "4:PySide6.QtPositioning.QGeoRectangle(self,center:PySide6.QtPositioning.QGeoCoordinate,degreesWidth:double,degreesHeight:double,*:KeywordOnly=None,bottomLeft:QGeoCoordinate=None,bottomRight:QGeoCoordinate=None,topLeft:QGeoCoordinate=None,topRight:QGeoCoordinate=None,center:QGeoCoordinate=None,height:double=None,width:double=None)",
    "3:PySide6.QtPositioning.QGeoRectangle(self,topLeft:PySide6.QtPositioning.QGeoCoordinate,bottomRight:PySide6.QtPositioning.QGeoCoordinate,*:KeywordOnly=None,bottomLeft:QGeoCoordinate=None,bottomRight:QGeoCoordinate=None,topLeft:QGeoCoordinate=None,topRight:QGeoCoordinate=None,center:QGeoCoordinate=None,height:double=None,width:double=None)",
    "2:PySide6.QtPositioning.QGeoRectangle(self,other:PySide6.QtPositioning.QGeoRectangle,*:KeywordOnly=None,bottomLeft:QGeoCoordinate=None,bottomRight:QGeoCoordinate=None,topLeft:QGeoCoordinate=None,topRight:QGeoCoordinate=None,center:QGeoCoordinate=None,height:double=None,width:double=None)",
    "1:PySide6.QtPositioning.QGeoRectangle(self,other:PySide6.QtPositioning.QGeoShape,*:KeywordOnly=None,bottomLeft:QGeoCoordinate=None,bottomRight:QGeoCoordinate=None,topLeft:QGeoCoordinate=None,topRight:QGeoCoordinate=None,center:QGeoCoordinate=None,height:double=None,width:double=None)",
    "0:PySide6.QtPositioning.QGeoRectangle(self,coordinates:QList[PySide6.QtPositioning.QGeoCoordinate],*:KeywordOnly=None,bottomLeft:QGeoCoordinate=None,bottomRight:QGeoCoordinate=None,topLeft:QGeoCoordinate=None,topRight:QGeoCoordinate=None,center:QGeoCoordinate=None,height:double=None,width:double=None)",
    "PySide6.QtPositioning.QGeoRectangle.bottomLeft(self)->PySide6.QtPositioning.QGeoCoordinate",
    "PySide6.QtPositioning.QGeoRectangle.bottomRight(self)->PySide6.QtPositioning.QGeoCoordinate",
    "PySide6.QtPositioning.QGeoRectangle.center(self)->PySide6.QtPositioning.QGeoCoordinate",
    "1:PySide6.QtPositioning.QGeoRectangle.contains(self,rectangle:typing.Union[PySide6.QtPositioning.QGeoRectangle, PySide6.QtPositioning.QGeoShape, QList[PySide6.QtPositioning.QGeoCoordinate]])->bool",
    "0:PySide6.QtPositioning.QGeoRectangle.contains(self,coordinate:PySide6.QtPositioning.QGeoCoordinate)->bool",
    "PySide6.QtPositioning.QGeoRectangle.extendRectangle(self,coordinate:PySide6.QtPositioning.QGeoCoordinate)",
    "PySide6.QtPositioning.QGeoRectangle.height(self)->double",
    "PySide6.QtPositioning.QGeoRectangle.intersects(self,rectangle:typing.Union[PySide6.QtPositioning.QGeoRectangle, PySide6.QtPositioning.QGeoShape, QList[PySide6.QtPositioning.QGeoCoordinate]])->bool",
    "PySide6.QtPositioning.QGeoRectangle.setBottomLeft(self,bottomLeft:PySide6.QtPositioning.QGeoCoordinate)",
    "PySide6.QtPositioning.QGeoRectangle.setBottomRight(self,bottomRight:PySide6.QtPositioning.QGeoCoordinate)",
    "PySide6.QtPositioning.QGeoRectangle.setCenter(self,center:PySide6.QtPositioning.QGeoCoordinate)",
    "PySide6.QtPositioning.QGeoRectangle.setHeight(self,degreesHeight:double)",
    "PySide6.QtPositioning.QGeoRectangle.setTopLeft(self,topLeft:PySide6.QtPositioning.QGeoCoordinate)",
    "PySide6.QtPositioning.QGeoRectangle.setTopRight(self,topRight:PySide6.QtPositioning.QGeoCoordinate)",
    "PySide6.QtPositioning.QGeoRectangle.setWidth(self,degreesWidth:double)",
    "PySide6.QtPositioning.QGeoRectangle.toString(self)->QString",
    "PySide6.QtPositioning.QGeoRectangle.topLeft(self)->PySide6.QtPositioning.QGeoCoordinate",
    "PySide6.QtPositioning.QGeoRectangle.topRight(self)->PySide6.QtPositioning.QGeoCoordinate",
    "PySide6.QtPositioning.QGeoRectangle.translate(self,degreesLatitude:double,degreesLongitude:double)",
    "PySide6.QtPositioning.QGeoRectangle.translated(self,degreesLatitude:double,degreesLongitude:double)->PySide6.QtPositioning.QGeoRectangle",
    "PySide6.QtPositioning.QGeoRectangle.united(self,rectangle:typing.Union[PySide6.QtPositioning.QGeoRectangle, PySide6.QtPositioning.QGeoShape, QList[PySide6.QtPositioning.QGeoCoordinate]])->PySide6.QtPositioning.QGeoRectangle",
    "PySide6.QtPositioning.QGeoRectangle.width(self)->double",
    "PySide6.QtPositioning.QGeoRectangle.__copy__(self)->typing.Self",
    "PySide6.QtPositioning.QGeoRectangle.__lshift__(self,stream:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "PySide6.QtPositioning.QGeoRectangle.__rshift__(self,stream:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "PySide6.QtPositioning.QGeoRectangle.__or__(self,rectangle:typing.Union[PySide6.QtPositioning.QGeoRectangle, PySide6.QtPositioning.QGeoShape, QList[PySide6.QtPositioning.QGeoCoordinate]])->PySide6.QtPositioning.QGeoRectangle",
    "PySide6.QtPositioning.QGeoRectangle.__ior__(self,rectangle:typing.Union[PySide6.QtPositioning.QGeoRectangle, PySide6.QtPositioning.QGeoShape, QList[PySide6.QtPositioning.QGeoCoordinate]])->PySide6.QtPositioning.QGeoRectangle",
    nullptr}; // Sentinel
#else
static constexpr size_t QGeoRectangle_SignatureByteSize = 528;
static constexpr uint8_t QGeoRectangle_SignatureBytes[528] = {
    0x78, 0xda, 0xdd, 0x57, 0xc1, 0x6e, 0xdb, 0x30, 0x0c, 0xbd, 0xf7, 0x2b, 0x7a, 0x6c, 0x8a, 0xd4,
    0xd8, 0xba, 0xae, 0x07, 0x03, 0xdb, 0x61, 0x29, 0xb0, 0x02, 0x0b, 0xb6, 0xba, 0x6e, 0xd1, 0x43,
    0x51, 0x18, 0x4a, 0xcc, 0xd8, 0x02, 0x5c, 0xd1, 0x90, 0x18, 0xa4, 0xfe, 0xfb, 0x39, 0x76, 0x6c,
    0x2b, 0x41, 0xd2, 0x51, 0x83, 0x37, 0xb4, 0x3e, 0x8a, 0x14, 0xf9, 0xf4, 0x9e, 0x49, 0x89, 0xfe,
    0xec, 0xdf, 0x14, 0xa1, 0x8c, 0xe1, 0xd2, 0x0b, 0xe8, 0x06, 0x8d, 0x24, 0x89, 0x4a, 0xaa, 0xc4,
    0x0b, 0xbe, 0x03, 0xde, 0xc2, 0x9c, 0x84, 0x4a, 0x32, 0x38, 0x31, 0x90, 0x2d, 0xc6, 0xa7, 0xfe,
    0x0f, 0x28, 0x56, 0xa8, 0xe3, 0x5f, 0x2a, 0x2b, 0xbe, 0xfc, 0x44, 0x05, 0xe3, 0x19, 0x12, 0xe1,
    0xf3, 0x14, 0x16, 0xe4, 0xaf, 0x03, 0x26, 0x58, 0x7a, 0xa5, 0x12, 0x04, 0xb6, 0xfb, 0x56, 0x26,
    0xe9, 0x7e, 0x3f, 0x61, 0x7e, 0x30, 0xb6, 0xf4, 0x1d, 0x0e, 0x9c, 0x83, 0x22, 0xd0, 0x7b, 0x5d,
    0x29, 0x54, 0x51, 0x31, 0x2e, 0x67, 0xd9, 0xc6, 0xb4, 0x92, 0x31, 0xa5, 0xb6, 0x65, 0x74, 0x74,
    0xc1, 0xa7, 0xbd, 0xc1, 0x3a, 0xbc, 0xbf, 0x3b, 0xc1, 0x38, 0x86, 0x44, 0x03, 0x98, 0x07, 0x0b,
    0xb0, 0xb1, 0x5d, 0xdb, 0xe7, 0x1a, 0x94, 0x96, 0x9f, 0xf8, 0x5a, 0x36, 0x87, 0x64, 0x89, 0x69,
    0x33, 0x66, 0x05, 0x0c, 0x49, 0xd4, 0x73, 0xbe, 0xa8, 0x48, 0xe9, 0xab, 0xf5, 0xd9, 0x6e, 0x1f,
    0x94, 0x40, 0x1f, 0xfb, 0x13, 0x28, 0x4c, 0x45, 0x3e, 0x2c, 0x71, 0x3e, 0x38, 0x5c, 0x6f, 0x2d,
    0x80, 0xf1, 0x83, 0xa9, 0x34, 0xf4, 0xc8, 0xe9, 0xb5, 0xa7, 0x41, 0xc9, 0xc5, 0x10, 0xcb, 0xeb,
    0xc8, 0x55, 0xba, 0x8d, 0xce, 0xbe, 0x72, 0x74, 0x72, 0x48, 0x5d, 0xf1, 0xeb, 0x3d, 0x77, 0xad,
    0x8d, 0x53, 0x5a, 0x56, 0x67, 0x79, 0x73, 0x54, 0x24, 0xa4, 0x32, 0x75, 0x15, 0xe9, 0xc6, 0xee,
    0x53, 0x91, 0xaf, 0x37, 0xdf, 0xab, 0x32, 0xea, 0x91, 0x73, 0x29, 0x1d, 0xff, 0xa9, 0x31, 0x8f,
    0x1d, 0xca, 0xf2, 0xa9, 0x24, 0x39, 0x43, 0xcc, 0x78, 0x1d, 0xb0, 0x43, 0xa2, 0x6b, 0x05, 0xd6,
    0x7b, 0xd3, 0x40, 0x71, 0x80, 0xe0, 0x85, 0x40, 0xc5, 0x07, 0x5b, 0x8f, 0x87, 0xc7, 0x42, 0xaa,
    0x2b, 0xbe, 0xf9, 0xe0, 0x75, 0x99, 0xb3, 0x02, 0xe5, 0xba, 0x50, 0x4c, 0xb9, 0x7c, 0xab, 0x9f,
    0x94, 0x43, 0xc2, 0x00, 0x7d, 0xdb, 0x6e, 0x54, 0xfb, 0x56, 0xea, 0x4f, 0xe5, 0x16, 0xa7, 0xeb,
    0x5a, 0xe7, 0x79, 0x85, 0x8d, 0x34, 0xe9, 0x7a, 0xd8, 0x65, 0x1a, 0x65, 0xe7, 0xbf, 0xee, 0x4a,
    0x66, 0xef, 0xb4, 0xca, 0x4e, 0x74, 0x57, 0xdf, 0xe0, 0xee, 0xb3, 0x9e, 0x0b, 0x82, 0xa5, 0x78,
    0xfb, 0x2a, 0xf4, 0x8a, 0x51, 0x4d, 0xef, 0x5b, 0x6a, 0xd8, 0xf3, 0x3c, 0x2f, 0x0d, 0x61, 0x48,
    0xba, 0x34, 0x37, 0x7d, 0x18, 0xd4, 0x4b, 0x66, 0x6c, 0xfe, 0x4f, 0x9e, 0x19, 0xb2, 0xb5, 0xeb,
    0x35, 0xb1, 0x16, 0xca, 0x64, 0xe5, 0xee, 0x2d, 0xd1, 0xa6, 0x82, 0x24, 0x2d, 0x63, 0xd8, 0xf9,
    0x0f, 0x9a, 0xa2, 0x4a, 0x6c, 0xfb, 0xc8, 0x0d, 0x22, 0xfe, 0x2b, 0x8c, 0xd7, 0xc8, 0xb6, 0x20,
    0xac, 0x83, 0x2c, 0x95, 0x6c, 0x0f, 0xf1, 0x96, 0x6e, 0xc8, 0xbe, 0xf8, 0xad, 0xda, 0xe2, 0x77,
    0x7b, 0x3d, 0xa2, 0x68, 0x8e, 0x79, 0x11, 0x45, 0x4d, 0xe8, 0x46, 0x91, 0xb0, 0x5c, 0x31, 0xe3,
    0x33, 0x93, 0xca, 0x05, 0x6d, 0x32, 0x8c, 0x0d, 0x69, 0x10, 0xcf, 0x56, 0x63, 0x4f, 0x50, 0x83,
    0x17, 0x5c, 0x09, 0x12, 0x61, 0xe5, 0xda, 0xe2, 0xbc, 0xeb, 0x64, 0x42, 0xea, 0xff, 0x0f, 0x89,
    0xba, 0x81, 0x1b, 0x62, 0xf5, 0x44, 0x91, 0x7c, 0xbf, 0x04, 0x7f, 0x03, 0x50, 0x50, 0x14, 0x5e
};
#endif

PyTypeObject *init_QGeoRectangle(PyObject *module)
{
    if (SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX].type != nullptr)
        return SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX].type;

    Shiboken::AutoDecRef Sbk_QGeoRectangle_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoShape_IDX]))));

    _Sbk_QGeoRectangle_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QGeoRectangle",
        "QGeoRectangle",
        &Sbk_QGeoRectangle_spec,
        &Shiboken::callCppDestructor< ::QGeoRectangle >,
        Sbk_QGeoRectangle_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QGeoRectangle_TypeF(); // references _Sbk_QGeoRectangle_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QGeoRectangle_SignatureStrings);
#else
    InitSignatureBytes(pyType, QGeoRectangle_SignatureBytes, QGeoRectangle_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QGeoRectangle_PropertyStrings);
    SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QGeoRectangle_PythonToCpp_QGeoRectangle_PTR,
        is_QGeoRectangle_PythonToCpp_QGeoRectangle_PTR_Convertible,
        QGeoRectangle_PTR_CppToPython_QGeoRectangle,
        QGeoRectangle_COPY_CppToPython_QGeoRectangle);

    Shiboken::Conversions::registerConverterName(converter, "QGeoRectangle");
    Shiboken::Conversions::registerConverterName(converter, "QGeoRectangle*");
    Shiboken::Conversions::registerConverterName(converter, "QGeoRectangle&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QGeoRectangle).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QGeoRectangle_PythonToCpp_QGeoRectangle_COPY,
        is_QGeoRectangle_PythonToCpp_QGeoRectangle_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        constQGeoShapeREF_PythonToCpp_QGeoRectangle,
        is_constQGeoShapeREF_PythonToCpp_QGeoRectangle_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        _constQList_QGeoCoordinate_REF_PythonToCpp_QGeoRectangle,
        is__constQList_QGeoCoordinate_REF_PythonToCpp_QGeoRectangle_Convertible);

    qRegisterMetaType< ::QGeoRectangle >("QGeoRectangle");

    return pyType;
}
