// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtpositioning_python.h"

// main header
#include "qnmeapositioninfosource_wrapper.h"

// Argument includes
#include <QMap>
#include <QString>
#include <QStringList>
#include <QtPositioning/qgeopositioninfo.h>
#include <QtPositioning/qgeopositioninfosource.h>
#include <QtPositioning/qnmeapositioninfosource.h>
#include <qbytearrayview.h>
#include <qcoreevent.h>
#include <qiodevice.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QNmeaPositionInfoSourceWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QNmeaPositionInfoSourceWrapper::QNmeaPositionInfoSourceWrapper(::QNmeaPositionInfoSource::UpdateMode updateMode, ::QObject * parent) : QNmeaPositionInfoSource(updateMode, parent)
{
}

::QVariant QNmeaPositionInfoSourceWrapper::backendProperty(const ::QString & name) const
{
    if (m_PyMethodCache[0])
        return this->::QGeoPositionInfoSource::backendProperty(name);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return ::QVariant();
    static PyObject *nameCache[2] = {};
    static const char *funcName = "backendProperty";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QGeoPositionInfoSource::backendProperty(name);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &name)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &name)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QNmeaPositionInfoSource", funcName);
        return ::QVariant();
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QNmeaPositionInfoSource", funcName, "QVariant", Py_TYPE(pyResult)->tp_name);
        return ::QVariant();
    }
    ::QVariant cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QNmeaPositionInfoSourceWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QNmeaPositionInfoSource", funcName);
        return;
    }
}

void QNmeaPositionInfoSourceWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QNmeaPositionInfoSource", funcName);
        return;
    }
}

void QNmeaPositionInfoSourceWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QNmeaPositionInfoSource", funcName);
        return;
    }
}

void QNmeaPositionInfoSourceWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[4]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QNmeaPositionInfoSource", funcName);
        return;
    }
}

::QGeoPositionInfoSource::Error QNmeaPositionInfoSourceWrapper::error() const
{
    if (m_PyMethodCache[5])
        return this->::QNmeaPositionInfoSource::error();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return QGeoPositionInfoSource::AccessError;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "error";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QNmeaPositionInfoSource::error();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QNmeaPositionInfoSource", funcName);
        return QGeoPositionInfoSource::AccessError;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfoSource_Error_IDX])))->converter, pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QNmeaPositionInfoSource", funcName, Shiboken::SbkType< QGeoPositionInfoSource::Error >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return QGeoPositionInfoSource::AccessError;
    }
    ::QGeoPositionInfoSource::Error cppResult{QGeoPositionInfoSource::AccessError};
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QNmeaPositionInfoSourceWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[6])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QNmeaPositionInfoSource", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QNmeaPositionInfoSource", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QNmeaPositionInfoSourceWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[7])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[7] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QNmeaPositionInfoSource", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QNmeaPositionInfoSource", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QGeoPositionInfo QNmeaPositionInfoSourceWrapper::lastKnownPosition(bool fromSatellitePositioningMethodsOnly) const
{
    if (m_PyMethodCache[8])
        return this->::QNmeaPositionInfoSource::lastKnownPosition(fromSatellitePositioningMethodsOnly);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return {};
    static PyObject *nameCache[2] = {};
    static const char *funcName = "lastKnownPosition";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[8] = true;
        gil.release();
        return this->::QNmeaPositionInfoSource::lastKnownPosition(fromSatellitePositioningMethodsOnly);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &fromSatellitePositioningMethodsOnly)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &fromSatellitePositioningMethodsOnly)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QNmeaPositionInfoSource", funcName);
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QNmeaPositionInfoSource", funcName, Shiboken::SbkType< QGeoPositionInfo >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QGeoPositionInfo cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

int QNmeaPositionInfoSourceWrapper::minimumUpdateInterval() const
{
    if (m_PyMethodCache[9])
        return this->::QNmeaPositionInfoSource::minimumUpdateInterval();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return 0;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "minimumUpdateInterval";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[9] = true;
        gil.release();
        return this->::QNmeaPositionInfoSource::minimumUpdateInterval();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QNmeaPositionInfoSource", funcName);
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QNmeaPositionInfoSource", funcName, "int", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    int cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QNmeaPositionInfoSourceWrapper::parsePosInfoFromNmeaData(const char * data, int size, ::QGeoPositionInfo * posInfo, bool * hasFix)
{
    if (m_PyMethodCache[10])
        return this->::QNmeaPositionInfoSource::parsePosInfoFromNmeaData(data, size, posInfo, hasFix);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "parsePosInfoFromNmeaData";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[10] = true;
        gil.release();
        return this->::QNmeaPositionInfoSource::parsePosInfoFromNmeaData(data, size, posInfo, hasFix);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[4] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), data),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &size),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX]), posInfo),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), hasFix)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NiNN)",
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), data),
        size,
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX]), posInfo),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), hasFix)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 4, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
    Py_DECREF(pyArgArray[3]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QNmeaPositionInfoSource", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QNmeaPositionInfoSource", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QNmeaPositionInfoSourceWrapper::requestUpdate(int timeout)
{
    if (m_PyMethodCache[11]) {
        return this->::QNmeaPositionInfoSource::requestUpdate(timeout);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "requestUpdate";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[11] = true;
        gil.release();
        return this->::QNmeaPositionInfoSource::requestUpdate(timeout);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &timeout)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(i)",
        timeout
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QNmeaPositionInfoSource", funcName);
        return;
    }
}

bool QNmeaPositionInfoSourceWrapper::setBackendProperty(const ::QString & name, const ::QVariant & value)
{
    if (m_PyMethodCache[12])
        return this->::QGeoPositionInfoSource::setBackendProperty(name, value);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setBackendProperty";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[12] = true;
        gil.release();
        return this->::QGeoPositionInfoSource::setBackendProperty(name, value);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &name),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &value)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &name),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &value)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QNmeaPositionInfoSource", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QNmeaPositionInfoSource", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QNmeaPositionInfoSourceWrapper::setPreferredPositioningMethods(::QFlags<QGeoPositionInfoSource::PositioningMethod> methods)
{
    if (m_PyMethodCache[13]) {
        return this->::QGeoPositionInfoSource::setPreferredPositioningMethods(methods);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    // This method belongs to a property.
    static const char *funcName = "2:setPreferredPositioningMethods";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[13] = true;
        gil.release();
        return this->::QGeoPositionInfoSource::setPreferredPositioningMethods(methods);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QFlags_QGeoPositionInfoSource_PositioningMethod_IDX])))->flagsConverter, &methods)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QFlags_QGeoPositionInfoSource_PositioningMethod_IDX])))->flagsConverter, &methods)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QNmeaPositionInfoSource", funcName);
        return;
    }
}

void QNmeaPositionInfoSourceWrapper::setUpdateInterval(int msec)
{
    if (m_PyMethodCache[14]) {
        return this->::QNmeaPositionInfoSource::setUpdateInterval(msec);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setUpdateInterval";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[14] = true;
        gil.release();
        return this->::QNmeaPositionInfoSource::setUpdateInterval(msec);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &msec)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(i)",
        msec
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QNmeaPositionInfoSource", funcName);
        return;
    }
}

void QNmeaPositionInfoSourceWrapper::startUpdates()
{
    if (m_PyMethodCache[15]) {
        return this->::QNmeaPositionInfoSource::startUpdates();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "startUpdates";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[15] = true;
        gil.release();
        return this->::QNmeaPositionInfoSource::startUpdates();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QNmeaPositionInfoSource", funcName);
        return;
    }
}

void QNmeaPositionInfoSourceWrapper::stopUpdates()
{
    if (m_PyMethodCache[16]) {
        return this->::QNmeaPositionInfoSource::stopUpdates();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "stopUpdates";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[16] = true;
        gil.release();
        return this->::QNmeaPositionInfoSource::stopUpdates();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QNmeaPositionInfoSource", funcName);
        return;
    }
}

::QFlags<QGeoPositionInfoSource::PositioningMethod> QNmeaPositionInfoSourceWrapper::supportedPositioningMethods() const
{
    if (m_PyMethodCache[17])
        return this->::QNmeaPositionInfoSource::supportedPositioningMethods();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return QFlags<QGeoPositionInfoSource::PositioningMethod>(0);
    static PyObject *nameCache[2] = {};
    static const char *funcName = "supportedPositioningMethods";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[17] = true;
        gil.release();
        return this->::QNmeaPositionInfoSource::supportedPositioningMethods();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QNmeaPositionInfoSource", funcName);
        return QFlags<QGeoPositionInfoSource::PositioningMethod>(0);
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QFlags_QGeoPositionInfoSource_PositioningMethod_IDX])))->flagsConverter, pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QNmeaPositionInfoSource", funcName, Shiboken::SbkType< QFlags<QGeoPositionInfoSource::PositioningMethod> >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return QFlags<QGeoPositionInfoSource::PositioningMethod>(0);
    }
    ::QFlags<QGeoPositionInfoSource::PositioningMethod> cppResult = QFlags<QGeoPositionInfoSource::PositioningMethod>(0);
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QNmeaPositionInfoSourceWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[18]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[18] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QNmeaPositionInfoSource", funcName);
        return;
    }
}

const QMetaObject *QNmeaPositionInfoSourceWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QNmeaPositionInfoSource::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QNmeaPositionInfoSourceWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QNmeaPositionInfoSource::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QNmeaPositionInfoSourceWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QNmeaPositionInfoSourceWrapper *>(this));
    return QNmeaPositionInfoSource::qt_metacast(_clname);
}

QNmeaPositionInfoSourceWrapper::~QNmeaPositionInfoSourceWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QNmeaPositionInfoSource_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QNmeaPositionInfoSource >()))
        return -1;

    QNmeaPositionInfoSourceWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:QNmeaPositionInfoSource", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QNmeaPositionInfoSource::QNmeaPositionInfoSource(QNmeaPositionInfoSource::UpdateMode,QObject*=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_UpdateMode_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // QNmeaPositionInfoSource(QNmeaPositionInfoSource::UpdateMode,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 0; // QNmeaPositionInfoSource(QNmeaPositionInfoSource::UpdateMode,QObject*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                // fall through to handle extra keyword signals and properties
            }
        }
        ::QNmeaPositionInfoSource::UpdateMode cppArg0 = static_cast< ::QNmeaPositionInfoSource::UpdateMode>(0);
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return -1;
        ::QObject *cppArg1 = nullptr;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QNmeaPositionInfoSource(QNmeaPositionInfoSource::UpdateMode,QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QNmeaPositionInfoSourceWrapper(cppArg0, cppArg1);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QNmeaPositionInfoSourceWrapper(cppArg0, cppArg1);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[1], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QNmeaPositionInfoSource >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QNmeaPositionInfoSourceFunc_device(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNmeaPositionInfoSource *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // device()const
        QIODevice * cppResult = const_cast<const ::QNmeaPositionInfoSource *>(cppSelf)->device();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNmeaPositionInfoSourceFunc_error(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNmeaPositionInfoSource *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // error()const
        QGeoPositionInfoSource::Error cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QNmeaPositionInfoSource *>(cppSelf)->::QNmeaPositionInfoSource::error()
            : const_cast<const ::QNmeaPositionInfoSource *>(cppSelf)->error();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfoSource_Error_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNmeaPositionInfoSourceFunc_lastKnownPosition(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNmeaPositionInfoSource *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "lastKnownPosition", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_IDX]);

    if (PyArg_ParseTuple(args, "|O:lastKnownPosition", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGeoPositionInfoSource::lastKnownPosition(bool=)const->QGeoPositionInfo
    if (numArgs == 0) {
        overloadId = 0; // lastKnownPosition(bool)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))) {
        overloadId = 0; // lastKnownPosition(bool)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "lastKnownPosition", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_fromSatellitePositioningMethodsOnly = Shiboken::String::createStaticString("fromSatellitePositioningMethodsOnly");
            if (PyDict_Contains(kwds, key_fromSatellitePositioningMethodsOnly) != 0) {
                value = PyDict_GetItem(kwds, key_fromSatellitePositioningMethodsOnly);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_fromSatellitePositioningMethodsOnly);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "lastKnownPosition", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "lastKnownPosition", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_fromSatellitePositioningMethodsOnly);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "lastKnownPosition", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_IDX]);
            }
        }
        bool cppArg0 = false;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // lastKnownPosition(bool)const
            QGeoPositionInfo cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QNmeaPositionInfoSource *>(cppSelf)->::QNmeaPositionInfoSource::lastKnownPosition(cppArg0)
                : const_cast<const ::QNmeaPositionInfoSource *>(cppSelf)->lastKnownPosition(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNmeaPositionInfoSourceFunc_minimumUpdateInterval(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNmeaPositionInfoSource *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // minimumUpdateInterval()const
        int cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QNmeaPositionInfoSource *>(cppSelf)->::QNmeaPositionInfoSource::minimumUpdateInterval()
            : const_cast<const ::QNmeaPositionInfoSource *>(cppSelf)->minimumUpdateInterval();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNmeaPositionInfoSourceFunc_parsePosInfoFromNmeaData(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNmeaPositionInfoSource *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "parsePosInfoFromNmeaData", 3, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QNmeaPositionInfoSource::parsePosInfoFromNmeaData(const char*,int,QGeoPositionInfo*,bool*)->bool
    // 1: QNmeaPositionInfoSource::parsePosInfoFromNmeaData(QByteArrayView,QGeoPositionInfo*,bool*)->bool
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX]), (pyArgs[1])))
        && PyBool_Check(pyArgs[2]) && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[2])))) {
        overloadId = 1; // parsePosInfoFromNmeaData(QByteArrayView,QGeoPositionInfo*,bool*)
    } else if (numArgs == 4
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfo_IDX]), (pyArgs[2])))
        && PyBool_Check(pyArgs[3]) && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[3])))) {
        overloadId = 0; // parsePosInfoFromNmeaData(const char*,int,QGeoPositionInfo*,bool*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "parsePosInfoFromNmeaData", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // parsePosInfoFromNmeaData(const char *data, int size, QGeoPositionInfo *posInfo, bool *hasFix)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QGeoPositionInfo *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            bool *cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // parsePosInfoFromNmeaData(const char*,int,QGeoPositionInfo*,bool*)
                bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                    ? cppSelf->::QNmeaPositionInfoSource::parsePosInfoFromNmeaData(cppArg0, cppArg1, cppArg2, cppArg3)
                    : cppSelf->parsePosInfoFromNmeaData(cppArg0, cppArg1, cppArg2, cppArg3);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // parsePosInfoFromNmeaData(QByteArrayView data, QGeoPositionInfo *posInfo, bool *hasFix)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QByteArray cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QGeoPositionInfo *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            bool *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // parsePosInfoFromNmeaData(QByteArrayView,QGeoPositionInfo*,bool*)
                bool cppResult = cppSelf->parsePosInfoFromNmeaData(QByteArrayView(cppArg0), cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNmeaPositionInfoSourceFunc_requestUpdate(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNmeaPositionInfoSource *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "requestUpdate", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_IDX]);

    if (PyArg_ParseTuple(args, "|O:requestUpdate", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGeoPositionInfoSource::requestUpdate(int=)
    if (numArgs == 0) {
        overloadId = 0; // requestUpdate(int)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // requestUpdate(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "requestUpdate", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_timeout = Shiboken::String::createStaticString("timeout");
            if (PyDict_Contains(kwds, key_timeout) != 0) {
                value = PyDict_GetItem(kwds, key_timeout);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_timeout);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "requestUpdate", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "requestUpdate", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_timeout);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "requestUpdate", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_IDX]);
            }
        }
        int cppArg0 = 0;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // requestUpdate(int)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QNmeaPositionInfoSource::requestUpdate(cppArg0)
                : cppSelf->requestUpdate(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNmeaPositionInfoSourceFunc_setDevice(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNmeaPositionInfoSource *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNmeaPositionInfoSource::setDevice(QIODevice*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), (pyArg)))) {
        overloadId = 0; // setDevice(QIODevice*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDevice", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QIODevice *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDevice(QIODevice*)
            cppSelf->setDevice(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNmeaPositionInfoSourceFunc_setError(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNmeaPositionInfoSource *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNmeaPositionInfoSource::setError(QGeoPositionInfoSource::Error)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfoSource_Error_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setError(QGeoPositionInfoSource::Error)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setError", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_IDX]);

    // Call function/method
    {
        ::QGeoPositionInfoSource::Error cppArg0{QGeoPositionInfoSource::AccessError};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setError(QGeoPositionInfoSource::Error)
            cppSelf->setError(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNmeaPositionInfoSourceFunc_setUpdateInterval(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNmeaPositionInfoSource *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoPositionInfoSource::setUpdateInterval(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setUpdateInterval(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUpdateInterval", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setUpdateInterval(int)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QNmeaPositionInfoSource::setUpdateInterval(cppArg0)
                : cppSelf->setUpdateInterval(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNmeaPositionInfoSourceFunc_setUserEquivalentRangeError(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNmeaPositionInfoSource *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNmeaPositionInfoSource::setUserEquivalentRangeError(double)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArg)))) {
        overloadId = 0; // setUserEquivalentRangeError(double)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUserEquivalentRangeError", errInfo, SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_IDX]);

    // Call function/method
    {
        double cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setUserEquivalentRangeError(double)
            cppSelf->setUserEquivalentRangeError(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNmeaPositionInfoSourceFunc_startUpdates(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNmeaPositionInfoSource *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // startUpdates()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QNmeaPositionInfoSource::startUpdates()
            : cppSelf->startUpdates();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNmeaPositionInfoSourceFunc_stopUpdates(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNmeaPositionInfoSource *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // stopUpdates()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QNmeaPositionInfoSource::stopUpdates()
            : cppSelf->stopUpdates();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNmeaPositionInfoSourceFunc_supportedPositioningMethods(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNmeaPositionInfoSource *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // supportedPositioningMethods()const
        QFlags<QGeoPositionInfoSource::PositioningMethod> cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QNmeaPositionInfoSource *>(cppSelf)->::QNmeaPositionInfoSource::supportedPositioningMethods()
            : const_cast<const ::QNmeaPositionInfoSource *>(cppSelf)->supportedPositioningMethods();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QFlags_QGeoPositionInfoSource_PositioningMethod_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNmeaPositionInfoSourceFunc_updateMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNmeaPositionInfoSource *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // updateMode()const
        QNmeaPositionInfoSource::UpdateMode cppResult = const_cast<const ::QNmeaPositionInfoSource *>(cppSelf)->updateMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_UpdateMode_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNmeaPositionInfoSourceFunc_userEquivalentRangeError(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNmeaPositionInfoSource *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // userEquivalentRangeError()const
        double cppResult = const_cast<const ::QNmeaPositionInfoSource *>(cppSelf)->userEquivalentRangeError();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<double>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QNmeaPositionInfoSource_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QNmeaPositionInfoSource_EnumFlagInfo[] = {
    "UpdateMode:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QNmeaPositionInfoSource_methods[] = {
    {"device", reinterpret_cast<PyCFunction>(Sbk_QNmeaPositionInfoSourceFunc_device), METH_NOARGS, nullptr},
    {"error", reinterpret_cast<PyCFunction>(Sbk_QNmeaPositionInfoSourceFunc_error), METH_NOARGS, nullptr},
    {"lastKnownPosition", reinterpret_cast<PyCFunction>(Sbk_QNmeaPositionInfoSourceFunc_lastKnownPosition), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"minimumUpdateInterval", reinterpret_cast<PyCFunction>(Sbk_QNmeaPositionInfoSourceFunc_minimumUpdateInterval), METH_NOARGS, nullptr},
    {"parsePosInfoFromNmeaData", reinterpret_cast<PyCFunction>(Sbk_QNmeaPositionInfoSourceFunc_parsePosInfoFromNmeaData), METH_VARARGS, nullptr},
    {"requestUpdate", reinterpret_cast<PyCFunction>(Sbk_QNmeaPositionInfoSourceFunc_requestUpdate), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setDevice", reinterpret_cast<PyCFunction>(Sbk_QNmeaPositionInfoSourceFunc_setDevice), METH_O, nullptr},
    {"setError", reinterpret_cast<PyCFunction>(Sbk_QNmeaPositionInfoSourceFunc_setError), METH_O, nullptr},
    {"setUpdateInterval", reinterpret_cast<PyCFunction>(Sbk_QNmeaPositionInfoSourceFunc_setUpdateInterval), METH_O, nullptr},
    {"setUserEquivalentRangeError", reinterpret_cast<PyCFunction>(Sbk_QNmeaPositionInfoSourceFunc_setUserEquivalentRangeError), METH_O, nullptr},
    {"startUpdates", reinterpret_cast<PyCFunction>(Sbk_QNmeaPositionInfoSourceFunc_startUpdates), METH_NOARGS, nullptr},
    {"stopUpdates", reinterpret_cast<PyCFunction>(Sbk_QNmeaPositionInfoSourceFunc_stopUpdates), METH_NOARGS, nullptr},
    {"supportedPositioningMethods", reinterpret_cast<PyCFunction>(Sbk_QNmeaPositionInfoSourceFunc_supportedPositioningMethods), METH_NOARGS, nullptr},
    {"updateMode", reinterpret_cast<PyCFunction>(Sbk_QNmeaPositionInfoSourceFunc_updateMode), METH_NOARGS, nullptr},
    {"userEquivalentRangeError", reinterpret_cast<PyCFunction>(Sbk_QNmeaPositionInfoSourceFunc_userEquivalentRangeError), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QNmeaPositionInfoSource_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QNmeaPositionInfoSource *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QNmeaPositionInfoSourceWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QNmeaPositionInfoSource_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QNmeaPositionInfoSource_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QNmeaPositionInfoSource_Type = nullptr;
static PyTypeObject *Sbk_QNmeaPositionInfoSource_TypeF(void)
{
    return _Sbk_QNmeaPositionInfoSource_Type;
}

static PyType_Slot Sbk_QNmeaPositionInfoSource_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QNmeaPositionInfoSource_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QNmeaPositionInfoSource_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QNmeaPositionInfoSource_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QNmeaPositionInfoSource_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QNmeaPositionInfoSource_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QNmeaPositionInfoSource_spec = {
    "2:PySide6.QtPositioning.QNmeaPositionInfoSource",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QNmeaPositionInfoSource_slots
};

} //extern "C"

static void *Sbk_QNmeaPositionInfoSource_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QNmeaPositionInfoSource *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QNmeaPositionInfoSource_UpdateMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QNmeaPositionInfoSource::UpdateMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QNmeaPositionInfoSource::UpdateMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QNmeaPositionInfoSource_UpdateMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_UpdateMode_IDX])))
        return Enum_PythonToCpp_QNmeaPositionInfoSource_UpdateMode;
    return {};
}

static PyObject *QNmeaPositionInfoSource_UpdateMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QNmeaPositionInfoSource::UpdateMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QNmeaPositionInfoSource::UpdateMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_UpdateMode_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QNmeaPositionInfoSource_PythonToCpp_QNmeaPositionInfoSource_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QNmeaPositionInfoSource_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QNmeaPositionInfoSource_PythonToCpp_QNmeaPositionInfoSource_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QNmeaPositionInfoSource_TypeF()))
        return QNmeaPositionInfoSource_PythonToCpp_QNmeaPositionInfoSource_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QNmeaPositionInfoSource_PTR_CppToPython_QNmeaPositionInfoSource(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QNmeaPositionInfoSource *>(const_cast<void *>(cppIn)), Sbk_QNmeaPositionInfoSource_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QNmeaPositionInfoSource_SignatureStrings[] = {
    "PySide6.QtPositioning.QNmeaPositionInfoSource(self,updateMode:PySide6.QtPositioning.QNmeaPositionInfoSource.UpdateMode,parent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtPositioning.QNmeaPositionInfoSource.device(self)->PySide6.QtCore.QIODevice",
    "PySide6.QtPositioning.QNmeaPositionInfoSource.error(self)->PySide6.QtPositioning.QGeoPositionInfoSource.Error",
    "PySide6.QtPositioning.QNmeaPositionInfoSource.lastKnownPosition(self,fromSatellitePositioningMethodsOnly:bool=false)->PySide6.QtPositioning.QGeoPositionInfo",
    "PySide6.QtPositioning.QNmeaPositionInfoSource.minimumUpdateInterval(self)->int",
    "1:PySide6.QtPositioning.QNmeaPositionInfoSource.parsePosInfoFromNmeaData(self,data:char*,size:int,posInfo:PySide6.QtPositioning.QGeoPositionInfo,hasFix:bool*)->bool",
    "0:PySide6.QtPositioning.QNmeaPositionInfoSource.parsePosInfoFromNmeaData(self,data:typing.Union[PySide6.QtCore.QByteArray, char*],posInfo:PySide6.QtPositioning.QGeoPositionInfo,hasFix:bool*)->bool",
    "PySide6.QtPositioning.QNmeaPositionInfoSource.requestUpdate(self,timeout:int=0)",
    "PySide6.QtPositioning.QNmeaPositionInfoSource.setDevice(self,source:PySide6.QtCore.QIODevice)",
    "PySide6.QtPositioning.QNmeaPositionInfoSource.setError(self,positionError:PySide6.QtPositioning.QGeoPositionInfoSource.Error)",
    "PySide6.QtPositioning.QNmeaPositionInfoSource.setUpdateInterval(self,msec:int)",
    "PySide6.QtPositioning.QNmeaPositionInfoSource.setUserEquivalentRangeError(self,uere:double)",
    "PySide6.QtPositioning.QNmeaPositionInfoSource.startUpdates(self)",
    "PySide6.QtPositioning.QNmeaPositionInfoSource.stopUpdates(self)",
    "PySide6.QtPositioning.QNmeaPositionInfoSource.supportedPositioningMethods(self)->PySide6.QtPositioning.QGeoPositionInfoSource.PositioningMethod",
    "PySide6.QtPositioning.QNmeaPositionInfoSource.updateMode(self)->PySide6.QtPositioning.QNmeaPositionInfoSource.UpdateMode",
    "PySide6.QtPositioning.QNmeaPositionInfoSource.userEquivalentRangeError(self)->double",
    nullptr}; // Sentinel
#else
static constexpr size_t QNmeaPositionInfoSource_SignatureByteSize = 423;
static constexpr uint8_t QNmeaPositionInfoSource_SignatureBytes[423] = {
    0x78, 0xda, 0xad, 0x55, 0xc1, 0x4e, 0x02, 0x31, 0x10, 0xbd, 0xf3, 0x15, 0x1e, 0xc5, 0xac, 0x04,
    0x2f, 0x1e, 0x36, 0xc1, 0x44, 0x05, 0x0d, 0x31, 0x08, 0x48, 0x3c, 0x19, 0x0f, 0x65, 0x77, 0x90,
    0x9a, 0x6e, 0x67, 0x9d, 0x4e, 0xd1, 0xf5, 0xeb, 0x6d, 0x77, 0x41, 0x11, 0x50, 0x28, 0x7a, 0xda,
    0x64, 0xb6, 0xf3, 0xe6, 0xbd, 0x37, 0x33, 0xed, 0xa0, 0x18, 0xc9, 0x14, 0x4e, 0x1b, 0x43, 0x1e,
    0xa0, 0x91, 0x2c, 0x51, 0x4b, 0xfd, 0xd4, 0x18, 0xde, 0x66, 0x20, 0x16, 0x81, 0xae, 0x9e, 0xe0,
    0x08, 0x2d, 0x25, 0x70, 0x68, 0x40, 0x4d, 0x22, 0x9b, 0xa7, 0x82, 0xa1, 0x87, 0x29, 0xc4, 0x83,
    0x90, 0xec, 0xc6, 0xfd, 0x67, 0x62, 0x94, 0x0b, 0x02, 0xcd, 0x4b, 0xf9, 0x97, 0x48, 0xd0, 0x18,
    0xf6, 0xc7, 0xcf, 0x90, 0x70, 0x4b, 0x5b, 0xa5, 0x72, 0xa6, 0x7a, 0x2d, 0x0c, 0x3f, 0x85, 0x99,
    0x9c, 0x93, 0xac, 0x1f, 0x9f, 0xad, 0x62, 0x77, 0xfb, 0xed, 0xf2, 0x7f, 0x20, 0x28, 0x10, 0x21,
    0xad, 0x63, 0x7e, 0x4b, 0xbd, 0x06, 0xdc, 0x90, 0xd9, 0xf1, 0x99, 0x81, 0xd5, 0x94, 0x30, 0x7c,
    0xa3, 0xf1, 0x55, 0x2f, 0xfe, 0x55, 0x96, 0x4f, 0x08, 0xb3, 0x91, 0xf3, 0x4e, 0x29, 0xc9, 0xb0,
    0x84, 0xd3, 0x03, 0x9e, 0x62, 0x6a, 0xfa, 0x5a, 0x15, 0xf1, 0x18, 0x51, 0xb5, 0x26, 0x42, 0x19,
    0xd8, 0x99, 0x68, 0x20, 0xb9, 0x4c, 0x6a, 0x99, 0xd9, 0xac, 0x6a, 0x63, 0x57, 0x33, 0xd0, 0x4c,
    0xa8, 0x85, 0x35, 0x52, 0x73, 0xed, 0x24, 0x70, 0x20, 0xdc, 0x14, 0x18, 0x2f, 0xc7, 0x87, 0xae,
    0x9c, 0x44, 0x7f, 0xac, 0x2d, 0x58, 0x54, 0xa2, 0x5d, 0x15, 0x11, 0x27, 0x53, 0x41, 0x47, 0x91,
    0x91, 0xef, 0x10, 0xbb, 0x0a, 0x51, 0x5e, 0x1d, 0x8e, 0x77, 0xd3, 0x17, 0x4d, 0x85, 0xb9, 0x92,
    0x6f, 0xa5, 0x35, 0x47, 0x8e, 0xa3, 0xff, 0xd6, 0x9a, 0xff, 0x4f, 0x92, 0x8b, 0xdc, 0x23, 0xdc,
    0x6b, 0x97, 0xf9, 0xb0, 0x3a, 0x77, 0x17, 0x05, 0xc3, 0x39, 0x91, 0x28, 0xa2, 0x83, 0x52, 0xcc,
    0xe3, 0x7f, 0x88, 0x08, 0x93, 0x40, 0xf0, 0x62, 0xc1, 0x70, 0xd5, 0xb8, 0x8a, 0x37, 0xcb, 0x0c,
    0xd0, 0xb2, 0x37, 0xb5, 0xd5, 0x0c, 0x5d, 0x34, 0x03, 0xdc, 0xfe, 0xda, 0xb5, 0xc8, 0x94, 0xd1,
    0xf8, 0xa7, 0x85, 0xdb, 0x03, 0xbd, 0xf3, 0xb9, 0x74, 0xde, 0xac, 0xf2, 0x40, 0x19, 0x8a, 0xc3,
    0x17, 0x70, 0x8f, 0xea, 0x1b, 0x06, 0x3c, 0xca, 0x0c, 0x24, 0xde, 0xac, 0x7d, 0xe0, 0x0c, 0x50,
    0xe7, 0xc5, 0x4a, 0x87, 0xe5, 0xee, 0xbc, 0x3b, 0xa1, 0x9f, 0x60, 0x49, 0x9f, 0x05, 0x82, 0x38,
    0x45, 0x3b, 0x56, 0xe1, 0x46, 0xb1, 0xa0, 0x39, 0x59, 0x53, 0xad, 0x61, 0x30, 0x00, 0xe6, 0x7f,
    0xca, 0xb7, 0x79, 0x8e, 0xc4, 0x90, 0xae, 0x5f, 0x49, 0x7b, 0xdd, 0x98, 0x6b, 0x30, 0x81, 0x7c,
    0xbe, 0x5e, 0xa6, 0x2d, 0xe5, 0xb7, 0x3e, 0x50, 0xa1, 0x85, 0x7f, 0x6b, 0xb1, 0xa3, 0x51, 0xf5,
    0xb7, 0xf6, 0x01, 0x4f, 0xf8, 0xca, 0xf0
};
#endif

PyTypeObject *init_QNmeaPositionInfoSource(PyObject *module)
{
    if (SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_IDX].type != nullptr)
        return SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_IDX].type;

    Shiboken::AutoDecRef Sbk_QNmeaPositionInfoSource_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoPositionInfoSource_IDX]))));

    _Sbk_QNmeaPositionInfoSource_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QNmeaPositionInfoSource",
        "QNmeaPositionInfoSource*",
        &Sbk_QNmeaPositionInfoSource_spec,
        &Shiboken::callCppDestructor< QNmeaPositionInfoSource >,
        Sbk_QNmeaPositionInfoSource_Type_bases.object(),
        0);
    auto *pyType = Sbk_QNmeaPositionInfoSource_TypeF(); // references _Sbk_QNmeaPositionInfoSource_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QNmeaPositionInfoSource_SignatureStrings);
#else
    InitSignatureBytes(pyType, QNmeaPositionInfoSource_SignatureBytes, QNmeaPositionInfoSource_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QNmeaPositionInfoSource_PropertyStrings);
    SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QNmeaPositionInfoSource_PythonToCpp_QNmeaPositionInfoSource_PTR,
        is_QNmeaPositionInfoSource_PythonToCpp_QNmeaPositionInfoSource_PTR_Convertible,
        QNmeaPositionInfoSource_PTR_CppToPython_QNmeaPositionInfoSource);

    Shiboken::Conversions::registerConverterName(converter, "QNmeaPositionInfoSource");
    Shiboken::Conversions::registerConverterName(converter, "QNmeaPositionInfoSource*");
    Shiboken::Conversions::registerConverterName(converter, "QNmeaPositionInfoSource&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QNmeaPositionInfoSource).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QNmeaPositionInfoSourceWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QNmeaPositionInfoSource_TypeF(), &Sbk_QNmeaPositionInfoSource_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QNmeaPositionInfoSource_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'UpdateMode'.
    const char *UpdateMode_Initializer[] = {
        "RealTimeMode",
        "SimulationMode",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t UpdateMode_InitializerValues[] = {
        uint8_t(QNmeaPositionInfoSource::UpdateMode::RealTimeMode),  //  0x01  1
        uint8_t(QNmeaPositionInfoSource::UpdateMode::SimulationMode) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QNmeaPositionInfoSource_TypeF(),
        "2:PySide6.QtPositioning.QNmeaPositionInfoSource.UpdateMode",
        UpdateMode_Initializer, UpdateMode_InitializerValues);
    SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_UpdateMode_IDX].type = EType;
    // Register converter for enum 'QNmeaPositionInfoSource::UpdateMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QNmeaPositionInfoSource_UpdateMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QNmeaPositionInfoSource_UpdateMode,
            is_Enum_PythonToCpp_QNmeaPositionInfoSource_UpdateMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QNmeaPositionInfoSource::UpdateMode");
        Shiboken::Conversions::registerConverterAlias(converter, "UpdateMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'UpdateMode' enum.

    qRegisterMetaType< ::QNmeaPositionInfoSource::UpdateMode >("QNmeaPositionInfoSource::UpdateMode");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QNmeaPositionInfoSource::staticMetaObject, sizeof(QNmeaPositionInfoSourceWrapper));

    return pyType;
}
