// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtprintsupport_python.h"

// main header
#include "qprinterinfo_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QStringList>
#include <QtGui/qpagesize.h>
#include <QtPrintSupport/qprinter.h>
#include <QtPrintSupport/qprinterinfo.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPrinterInfo_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QPrinterInfo >()))
        return -1;

    ::QPrinterInfo *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QPrinterInfo", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QPrinterInfo::QPrinterInfo()
    // 1: QPrinterInfo::QPrinterInfo(QPrinter)
    // 2: QPrinterInfo::QPrinterInfo(QPrinterInfo)
    if (numArgs == 0) {
        overloadId = 0; // QPrinterInfo()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QPrinterInfo(QPrinterInfo)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QPrinterInfo(QPrinter)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QPrinterInfo()
        {

            // QPrinterInfo()
            cptr = new ::QPrinterInfo();
            break;
        }
        case 1: // QPrinterInfo(const QPrinter &printer)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPrinter *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QPrinterInfo(QPrinter)
                cptr = new ::QPrinterInfo(*cppArg0);
            }
            break;
        }
        case 2: // QPrinterInfo(const QPrinterInfo &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPrinterInfo cppArg0_local;
            ::QPrinterInfo *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QPrinterInfo(QPrinterInfo)
                cptr = new ::QPrinterInfo(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QPrinterInfo >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QPrinterInfoFunc_availablePrinterNames(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // availablePrinterNames()
        QStringList cppResult = ::QPrinterInfo::availablePrinterNames();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterInfoFunc_availablePrinters(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // availablePrinters()
        QList<QPrinterInfo> cppResult = ::QPrinterInfo::availablePrinters();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtPrintSupportTypeConverters[SBK_QtPrintSupport_QList_QPrinterInfo_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterInfoFunc_defaultColorMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinterInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // defaultColorMode()const
        QPrinter::ColorMode cppResult = const_cast<const ::QPrinterInfo *>(cppSelf)->defaultColorMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_ColorMode_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterInfoFunc_defaultDuplexMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinterInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // defaultDuplexMode()const
        QPrinter::DuplexMode cppResult = const_cast<const ::QPrinterInfo *>(cppSelf)->defaultDuplexMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_DuplexMode_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterInfoFunc_defaultPageSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinterInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // defaultPageSize()const
        QPageSize cppResult = const_cast<const ::QPrinterInfo *>(cppSelf)->defaultPageSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterInfoFunc_defaultPrinter(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // defaultPrinter()
        QPrinterInfo cppResult = ::QPrinterInfo::defaultPrinter();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterInfoFunc_defaultPrinterName(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // defaultPrinterName()
        QString cppResult = ::QPrinterInfo::defaultPrinterName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterInfoFunc_description(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinterInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // description()const
        QString cppResult = const_cast<const ::QPrinterInfo *>(cppSelf)->description();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterInfoFunc_isDefault(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinterInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isDefault()const
        bool cppResult = const_cast<const ::QPrinterInfo *>(cppSelf)->isDefault();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterInfoFunc_isNull(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinterInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isNull()const
        bool cppResult = const_cast<const ::QPrinterInfo *>(cppSelf)->isNull();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterInfoFunc_isRemote(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinterInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isRemote()const
        bool cppResult = const_cast<const ::QPrinterInfo *>(cppSelf)->isRemote();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterInfoFunc_location(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinterInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // location()const
        QString cppResult = const_cast<const ::QPrinterInfo *>(cppSelf)->location();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterInfoFunc_makeAndModel(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinterInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // makeAndModel()const
        QString cppResult = const_cast<const ::QPrinterInfo *>(cppSelf)->makeAndModel();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterInfoFunc_maximumPhysicalPageSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinterInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maximumPhysicalPageSize()const
        QPageSize cppResult = const_cast<const ::QPrinterInfo *>(cppSelf)->maximumPhysicalPageSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterInfoFunc_minimumPhysicalPageSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinterInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // minimumPhysicalPageSize()const
        QPageSize cppResult = const_cast<const ::QPrinterInfo *>(cppSelf)->minimumPhysicalPageSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterInfoFunc_printerInfo(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QPrinterInfo::printerInfo(QString)->QPrinterInfo
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // printerInfo(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "printerInfo", errInfo, SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // printerInfo(QString)
            QPrinterInfo cppResult = ::QPrinterInfo::printerInfo(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterInfoFunc_printerName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinterInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // printerName()const
        QString cppResult = const_cast<const ::QPrinterInfo *>(cppSelf)->printerName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterInfoFunc_state(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinterInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // state()const
        QPrinter::PrinterState cppResult = const_cast<const ::QPrinterInfo *>(cppSelf)->state();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_PrinterState_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterInfoFunc_supportedColorModes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinterInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // supportedColorModes()const
        QList<QPrinter::ColorMode> cppResult = const_cast<const ::QPrinterInfo *>(cppSelf)->supportedColorModes();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtPrintSupportTypeConverters[SBK_QtPrintSupport_QList_QPrinter_ColorMode_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterInfoFunc_supportedDuplexModes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinterInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // supportedDuplexModes()const
        QList<QPrinter::DuplexMode> cppResult = const_cast<const ::QPrinterInfo *>(cppSelf)->supportedDuplexModes();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtPrintSupportTypeConverters[SBK_QtPrintSupport_QList_QPrinter_DuplexMode_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterInfoFunc_supportedPageSizes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinterInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // supportedPageSizes()const
        QList<QPageSize> cppResult = const_cast<const ::QPrinterInfo *>(cppSelf)->supportedPageSizes();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtPrintSupportTypeConverters[SBK_QtPrintSupport_QList_QPageSize_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterInfoFunc_supportedResolutions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinterInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // supportedResolutions()const
        QList<int> cppResult = const_cast<const ::QPrinterInfo *>(cppSelf)->supportedResolutions();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtPrintSupportTypeConverters[SBK_QtPrintSupport_QList_int_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterInfoFunc_supportsCustomPageSizes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinterInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // supportsCustomPageSizes()const
        bool cppResult = const_cast<const ::QPrinterInfo *>(cppSelf)->supportsCustomPageSizes();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterInfo__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QPrinterInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QPrinterInfo_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QPrinterInfo_methods[] = {
    {"availablePrinterNames", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfoFunc_availablePrinterNames), METH_NOARGS|METH_STATIC, nullptr},
    {"availablePrinters", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfoFunc_availablePrinters), METH_NOARGS|METH_STATIC, nullptr},
    {"defaultColorMode", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfoFunc_defaultColorMode), METH_NOARGS, nullptr},
    {"defaultDuplexMode", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfoFunc_defaultDuplexMode), METH_NOARGS, nullptr},
    {"defaultPageSize", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfoFunc_defaultPageSize), METH_NOARGS, nullptr},
    {"defaultPrinter", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfoFunc_defaultPrinter), METH_NOARGS|METH_STATIC, nullptr},
    {"defaultPrinterName", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfoFunc_defaultPrinterName), METH_NOARGS|METH_STATIC, nullptr},
    {"description", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfoFunc_description), METH_NOARGS, nullptr},
    {"isDefault", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfoFunc_isDefault), METH_NOARGS, nullptr},
    {"isNull", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfoFunc_isNull), METH_NOARGS, nullptr},
    {"isRemote", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfoFunc_isRemote), METH_NOARGS, nullptr},
    {"location", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfoFunc_location), METH_NOARGS, nullptr},
    {"makeAndModel", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfoFunc_makeAndModel), METH_NOARGS, nullptr},
    {"maximumPhysicalPageSize", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfoFunc_maximumPhysicalPageSize), METH_NOARGS, nullptr},
    {"minimumPhysicalPageSize", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfoFunc_minimumPhysicalPageSize), METH_NOARGS, nullptr},
    {"printerInfo", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfoFunc_printerInfo), METH_O|METH_STATIC, nullptr},
    {"printerName", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfoFunc_printerName), METH_NOARGS, nullptr},
    {"state", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfoFunc_state), METH_NOARGS, nullptr},
    {"supportedColorModes", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfoFunc_supportedColorModes), METH_NOARGS, nullptr},
    {"supportedDuplexModes", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfoFunc_supportedDuplexModes), METH_NOARGS, nullptr},
    {"supportedPageSizes", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfoFunc_supportedPageSizes), METH_NOARGS, nullptr},
    {"supportedResolutions", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfoFunc_supportedResolutions), METH_NOARGS, nullptr},
    {"supportsCustomPageSizes", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfoFunc_supportsCustomPageSizes), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfo__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QPrinterInfo___nb_bool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QPrinterInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return !cppSelf->isNull() ? 1 : 0;
}

} // extern "C"

static int Sbk_QPrinterInfo_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QPrinterInfo_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QPrinterInfo_Type = nullptr;
static PyTypeObject *Sbk_QPrinterInfo_TypeF(void)
{
    return _Sbk_QPrinterInfo_Type;
}

static PyType_Slot Sbk_QPrinterInfo_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QPrinterInfo_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QPrinterInfo_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QPrinterInfo_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QPrinterInfo_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_bool,        reinterpret_cast<void *>(Sbk_QPrinterInfo___nb_bool)},
    {0, nullptr}
};
static PyType_Spec Sbk_QPrinterInfo_spec = {
    "2:PySide6.QtPrintSupport.QPrinterInfo",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QPrinterInfo_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QPrinterInfo_PythonToCpp_QPrinterInfo_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QPrinterInfo_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QPrinterInfo_PythonToCpp_QPrinterInfo_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QPrinterInfo_TypeF()))
        return QPrinterInfo_PythonToCpp_QPrinterInfo_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QPrinterInfo_PTR_CppToPython_QPrinterInfo(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QPrinterInfo_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QPrinterInfo_COPY_CppToPython_QPrinterInfo(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QPrinterInfo *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QPrinterInfo_TypeF(), new ::QPrinterInfo(*source), true, true);
}

// Python to C++ copy conversion.
static void QPrinterInfo_PythonToCpp_QPrinterInfo_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QPrinterInfo *>(cppOut) = *reinterpret_cast< ::QPrinterInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QPrinterInfo_PythonToCpp_QPrinterInfo_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QPrinterInfo_TypeF()))
        return QPrinterInfo_PythonToCpp_QPrinterInfo_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QPrinterInfo_SignatureStrings[] = {
    "2:PySide6.QtPrintSupport.QPrinterInfo(self)",
    "1:PySide6.QtPrintSupport.QPrinterInfo(self,printer:PySide6.QtPrintSupport.QPrinter)",
    "0:PySide6.QtPrintSupport.QPrinterInfo(self,other:PySide6.QtPrintSupport.QPrinterInfo)",
    "PySide6.QtPrintSupport.QPrinterInfo.availablePrinterNames()->QStringList",
    "PySide6.QtPrintSupport.QPrinterInfo.availablePrinters()->QList[PySide6.QtPrintSupport.QPrinterInfo]",
    "PySide6.QtPrintSupport.QPrinterInfo.defaultColorMode(self)->PySide6.QtPrintSupport.QPrinter.ColorMode",
    "PySide6.QtPrintSupport.QPrinterInfo.defaultDuplexMode(self)->PySide6.QtPrintSupport.QPrinter.DuplexMode",
    "PySide6.QtPrintSupport.QPrinterInfo.defaultPageSize(self)->PySide6.QtGui.QPageSize",
    "PySide6.QtPrintSupport.QPrinterInfo.defaultPrinter()->PySide6.QtPrintSupport.QPrinterInfo",
    "PySide6.QtPrintSupport.QPrinterInfo.defaultPrinterName()->QString",
    "PySide6.QtPrintSupport.QPrinterInfo.description(self)->QString",
    "PySide6.QtPrintSupport.QPrinterInfo.isDefault(self)->bool",
    "PySide6.QtPrintSupport.QPrinterInfo.isNull(self)->bool",
    "PySide6.QtPrintSupport.QPrinterInfo.isRemote(self)->bool",
    "PySide6.QtPrintSupport.QPrinterInfo.location(self)->QString",
    "PySide6.QtPrintSupport.QPrinterInfo.makeAndModel(self)->QString",
    "PySide6.QtPrintSupport.QPrinterInfo.maximumPhysicalPageSize(self)->PySide6.QtGui.QPageSize",
    "PySide6.QtPrintSupport.QPrinterInfo.minimumPhysicalPageSize(self)->PySide6.QtGui.QPageSize",
    "PySide6.QtPrintSupport.QPrinterInfo.printerInfo(printerName:QString)->PySide6.QtPrintSupport.QPrinterInfo",
    "PySide6.QtPrintSupport.QPrinterInfo.printerName(self)->QString",
    "PySide6.QtPrintSupport.QPrinterInfo.state(self)->PySide6.QtPrintSupport.QPrinter.PrinterState",
    "PySide6.QtPrintSupport.QPrinterInfo.supportedColorModes(self)->QList[PySide6.QtPrintSupport.QPrinter.ColorMode]",
    "PySide6.QtPrintSupport.QPrinterInfo.supportedDuplexModes(self)->QList[PySide6.QtPrintSupport.QPrinter.DuplexMode]",
    "PySide6.QtPrintSupport.QPrinterInfo.supportedPageSizes(self)->QList[PySide6.QtGui.QPageSize]",
    "PySide6.QtPrintSupport.QPrinterInfo.supportedResolutions(self)->QList[int]",
    "PySide6.QtPrintSupport.QPrinterInfo.supportsCustomPageSizes(self)->bool",
    "PySide6.QtPrintSupport.QPrinterInfo.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QPrinterInfo_SignatureByteSize = 363;
static constexpr uint8_t QPrinterInfo_SignatureBytes[363] = {
    0x78, 0xda, 0xb5, 0x94, 0x4f, 0x6b, 0x83, 0x40, 0x10, 0xc5, 0xef, 0x7e, 0x12, 0x85, 0x46, 0xda,
    0x1e, 0x7a, 0xc8, 0x21, 0x50, 0x12, 0x28, 0x85, 0x36, 0x68, 0x3c, 0x96, 0x20, 0x1b, 0x1d, 0x93,
    0xa5, 0xbb, 0xce, 0xe2, 0xee, 0x96, 0xd8, 0x4f, 0x5f, 0xb7, 0x6a, 0x4c, 0xff, 0xe1, 0xae, 0xa4,
    0x27, 0x71, 0x9c, 0xdf, 0x7b, 0xb3, 0xfa, 0x9c, 0xdb, 0x79, 0x54, 0x27, 0x34, 0x87, 0xbb, 0x30,
    0x56, 0x51, 0x45, 0x4b, 0x95, 0x68, 0x21, 0xb0, 0x52, 0x61, 0xfc, 0x79, 0x07, 0xd5, 0x63, 0x59,
    0xa0, 0x2f, 0x81, 0x15, 0x81, 0x77, 0x63, 0xdd, 0x7b, 0x25, 0xda, 0xc2, 0x18, 0x10, 0x78, 0xd7,
    0xf6, 0x9a, 0xa8, 0x0e, 0xe3, 0x8a, 0xa6, 0x3d, 0xf0, 0x2c, 0x9a, 0x42, 0xf2, 0x46, 0x28, 0x23,
    0x3b, 0x06, 0x5d, 0x71, 0x4d, 0x38, 0x48, 0x3f, 0x98, 0x2d, 0xe2, 0x44, 0x35, 0x95, 0xfd, 0x13,
    0x95, 0x6a, 0x92, 0x50, 0x2b, 0x62, 0xf0, 0x17, 0x0b, 0x7c, 0x6b, 0xe5, 0x91, 0x43, 0x41, 0x34,
    0x53, 0x4b, 0x64, 0x58, 0x3d, 0x63, 0x0e, 0xed, 0x17, 0x99, 0x2d, 0x46, 0xd8, 0xf0, 0x04, 0xb8,
    0xb8, 0xac, 0xb4, 0x60, 0x70, 0x74, 0xb1, 0x19, 0x08, 0x17, 0x9f, 0x88, 0xec, 0x21, 0xa1, 0xef,
    0xbf, 0xb8, 0x3c, 0x68, 0xda, 0x10, 0xdd, 0x63, 0x27, 0xc9, 0xb6, 0xe4, 0x8f, 0xcf, 0x6c, 0xa8,
    0x09, 0xca, 0x26, 0x25, 0x67, 0x21, 0xb1, 0x54, 0x90, 0x59, 0x45, 0x85, 0xa2, 0x58, 0xf6, 0x47,
    0x75, 0xc1, 0xa9, 0x5c, 0xb5, 0x23, 0xf4, 0xf0, 0x0e, 0x91, 0x59, 0x92, 0x6b, 0xcd, 0xd8, 0x04,
    0x6c, 0x03, 0x1c, 0x15, 0x38, 0x83, 0x0c, 0x33, 0x32, 0xf5, 0x94, 0x9c, 0xbc, 0xc2, 0x7d, 0x99,
    0x9b, 0x0c, 0xb1, 0x69, 0xfc, 0x91, 0x72, 0xcd, 0xa3, 0x43, 0x2d, 0x69, 0x46, 0xd8, 0x25, 0xb3,
    0xc5, 0x69, 0xf9, 0x5f, 0xd2, 0xe2, 0x6c, 0xc9, 0x89, 0x21, 0x61, 0xf3, 0xee, 0xe4, 0x17, 0x8c,
    0xf1, 0x99, 0xfa, 0x94, 0xd7, 0x2b, 0x15, 0x51, 0xd6, 0xeb, 0xa0, 0xbb, 0x26, 0x86, 0xb1, 0x53,
    0x6f, 0x8b, 0x90, 0x9f, 0xf6, 0x95, 0x3c, 0x0d, 0x69, 0xb3, 0x48, 0x87, 0x3d, 0xb7, 0x75, 0xf3,
    0x1b, 0x16, 0x97, 0xa3, 0xe1, 0x00, 0x3a, 0x3a, 0xf6, 0xf1, 0xf8, 0xd3, 0xef, 0x4b, 0x88, 0x1c,
    0xc5, 0x37, 0x20, 0x91, 0x69, 0xf3, 0x0b, 0x7e, 0x93, 0x6f, 0x7a, 0x9d, 0xa4, 0xe4, 0x52, 0x4b,
    0x85, 0xfc, 0xc7, 0xb0, 0xd6, 0xab, 0x20, 0x4d, 0x33, 0x14, 0x75, 0x9a, 0xf6, 0xa0, 0xaa, 0x45,
    0x13, 0xb5, 0x30, 0x69, 0xee, 0xbc, 0x0f, 0xdb, 0xc6, 0x25, 0x54
};
#endif

PyTypeObject *init_QPrinterInfo(PyObject *module)
{
    if (SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX].type != nullptr)
        return SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX].type;

    Shiboken::AutoDecRef Sbk_QPrinterInfo_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QPrinterInfo_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QPrinterInfo",
        "QPrinterInfo",
        &Sbk_QPrinterInfo_spec,
        &Shiboken::callCppDestructor< ::QPrinterInfo >,
        Sbk_QPrinterInfo_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QPrinterInfo_TypeF(); // references _Sbk_QPrinterInfo_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QPrinterInfo_SignatureStrings);
#else
    InitSignatureBytes(pyType, QPrinterInfo_SignatureBytes, QPrinterInfo_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QPrinterInfo_PropertyStrings);
    SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QPrinterInfo_PythonToCpp_QPrinterInfo_PTR,
        is_QPrinterInfo_PythonToCpp_QPrinterInfo_PTR_Convertible,
        QPrinterInfo_PTR_CppToPython_QPrinterInfo,
        QPrinterInfo_COPY_CppToPython_QPrinterInfo);

    Shiboken::Conversions::registerConverterName(converter, "QPrinterInfo");
    Shiboken::Conversions::registerConverterName(converter, "QPrinterInfo*");
    Shiboken::Conversions::registerConverterName(converter, "QPrinterInfo&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QPrinterInfo).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QPrinterInfo_PythonToCpp_QPrinterInfo_COPY,
        is_QPrinterInfo_PythonToCpp_QPrinterInfo_COPY_Convertible);


    return pyType;
}
