// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtqml_python.h"

// main header
#include "qjsengine_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QStringList>
#include <QtQml/qjsengine.h>
#include <QtQml/qjsmanagedvalue.h>
#include <QtQml/qjsprimitivevalue.h>
#include <QtQml/qjsvalue.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qdatetime.h>
#include <qmetaobject.h>
#include <qmetatype.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QJSEngineWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QJSEngineWrapper::QJSEngineWrapper()
{
}

QJSEngineWrapper::QJSEngineWrapper(::QObject * parent) : QJSEngine(parent)
{
}

void QJSEngineWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QJSEngine", funcName);
        return;
    }
}

void QJSEngineWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QJSEngine", funcName);
        return;
    }
}

void QJSEngineWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QJSEngine", funcName);
        return;
    }
}

void QJSEngineWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QJSEngine", funcName);
        return;
    }
}

bool QJSEngineWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QJSEngine", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QJSEngine", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QJSEngineWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QJSEngine", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QJSEngine", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QJSEngineWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QJSEngine", funcName);
        return;
    }
}

const QMetaObject *QJSEngineWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QJSEngine::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QJSEngineWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QJSEngine::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QJSEngineWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QJSEngineWrapper *>(this));
    return QJSEngine::qt_metacast(_clname);
}

QJSEngineWrapper::~QJSEngineWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QJSEngine_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QJSEngine >()))
        return -1;

    QJSEngineWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QJSEngine", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QJSEngine::QJSEngine()
    // 1: QJSEngine::QJSEngine(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QJSEngine()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QJSEngine(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QJSEngine()
        {

            // QJSEngine()
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QJSEngineWrapper();
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QJSEngineWrapper();
            }

            break;
        }
        case 1: // QJSEngine(QObject *parent)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QJSEngine(QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QJSEngineWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QJSEngineWrapper(cppArg0);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QJSEngine >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QJSEngineFunc_catchError(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // catchError()
        QJSValue cppResult = cppSelf->catchError();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSEngineFunc_collectGarbage(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // collectGarbage()
        cppSelf->collectGarbage();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QJSEngineFunc_evaluate(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "evaluate", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:evaluate", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QJSEngine::evaluate(QString,const QString&=,int=,QStringList*=)->QJSValue
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // evaluate(QString,QString,int,QStringList*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // evaluate(QString,QString,int,QStringList*)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // evaluate(QString,QString,int,QStringList*)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[3])))) {
                    overloadId = 0; // evaluate(QString,QString,int,QStringList*)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "evaluate", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_fileName = Shiboken::String::createStaticString("fileName");
            if (PyDict_Contains(kwds, key_fileName) != 0) {
                value = PyDict_GetItem(kwds, key_fileName);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_fileName);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "evaluate", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "evaluate", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_fileName);
            }
            static PyObject *const key_lineNumber = Shiboken::String::createStaticString("lineNumber");
            if (PyDict_Contains(kwds, key_lineNumber) != 0) {
                value = PyDict_GetItem(kwds, key_lineNumber);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_lineNumber);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "evaluate", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "evaluate", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_lineNumber);
            }
            static PyObject *const key_exceptionStackTrace = Shiboken::String::createStaticString("exceptionStackTrace");
            if (PyDict_Contains(kwds, key_exceptionStackTrace) != 0) {
                value = PyDict_GetItem(kwds, key_exceptionStackTrace);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_exceptionStackTrace);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "evaluate", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, "evaluate", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_exceptionStackTrace);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "evaluate", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1 = QString();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2 = 1;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);
        ::QStringList *cppArg3 = nullptr;
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // evaluate(QString,QString,int,QStringList*)
            QJSValue cppResult = cppSelf->evaluate(cppArg0, cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSEngineFunc_globalObject(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // globalObject()const
        QJSValue cppResult = const_cast<const ::QJSEngine *>(cppSelf)->globalObject();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSEngineFunc_hasError(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hasError()const
        bool cppResult = const_cast<const ::QJSEngine *>(cppSelf)->hasError();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSEngineFunc_importModule(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QJSEngine::importModule(QString)->QJSValue
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // importModule(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "importModule", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // importModule(QString)
            QJSValue cppResult = cppSelf->importModule(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSEngineFunc_installExtensions(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "installExtensions", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]);

    if (PyArg_ParseTuple(args, "|OO:installExtensions", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QJSEngine::installExtensions(QFlags<QJSEngine::Extension>,const QJSValue&=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QFlags_QJSEngine_Extension_IDX])))->flagsConverter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // installExtensions(QFlags<QJSEngine::Extension>,QJSValue)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), (pyArgs[1])))) {
            overloadId = 0; // installExtensions(QFlags<QJSEngine::Extension>,QJSValue)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "installExtensions", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_object = Shiboken::String::createStaticString("object");
            if (PyDict_Contains(kwds, key_object) != 0) {
                value = PyDict_GetItem(kwds, key_object);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_object);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "installExtensions", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "installExtensions", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_object);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "installExtensions", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]);
            }
        }
        ::QFlags<QJSEngine::Extension> cppArg0 = QFlags<QJSEngine::Extension>(0);
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QJSValue cppArg1_local = QJSValue();
        ::QJSValue *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1]) {
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // installExtensions(QFlags<QJSEngine::Extension>,QJSValue)
            cppSelf->installExtensions(cppArg0, *cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QJSEngineFunc_isInterrupted(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isInterrupted()const
        bool cppResult = const_cast<const ::QJSEngine *>(cppSelf)->isInterrupted();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSEngineFunc_newArray(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "newArray", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]);

    if (PyArg_ParseTuple(args, "|O:newArray", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QJSEngine::newArray(uint=)->QJSValue
    if (numArgs == 0) {
        overloadId = 0; // newArray(uint)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArgs[0])))) {
        overloadId = 0; // newArray(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "newArray", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_length = Shiboken::String::createStaticString("length");
            if (PyDict_Contains(kwds, key_length) != 0) {
                value = PyDict_GetItem(kwds, key_length);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_length);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "newArray", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "newArray", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_length);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "newArray", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]);
            }
        }
        uint cppArg0 = 0;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // newArray(uint)
            QJSValue cppResult = cppSelf->newArray(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSEngineFunc_newErrorObject(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "newErrorObject", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]);

    if (PyArg_ParseTuple(args, "|OO:newErrorObject", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QJSEngine::newErrorObject(QJSValue::ErrorType,const QString&=)->QJSValue
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_ErrorType_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // newErrorObject(QJSValue::ErrorType,QString)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 0; // newErrorObject(QJSValue::ErrorType,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "newErrorObject", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_message = Shiboken::String::createStaticString("message");
            if (PyDict_Contains(kwds, key_message) != 0) {
                value = PyDict_GetItem(kwds, key_message);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_message);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "newErrorObject", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "newErrorObject", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_message);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "newErrorObject", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]);
            }
        }
        ::QJSValue::ErrorType cppArg0{QJSValue::NoError};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1 = QString();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // newErrorObject(QJSValue::ErrorType,QString)
            QJSValue cppResult = cppSelf->newErrorObject(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSEngineFunc_newObject(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // newObject()
        QJSValue cppResult = cppSelf->newObject();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSEngineFunc_newQMetaObject(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QJSEngine::newQMetaObject(const QMetaObject*)->QJSValue
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_IDX]), (pyArg)))) {
        overloadId = 0; // newQMetaObject(const QMetaObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "newQMetaObject", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMetaObject *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // newQMetaObject(const QMetaObject*)
            QJSValue cppResult = cppSelf->newQMetaObject(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSEngineFunc_newQObject(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QJSEngine::newQObject(QObject*)->QJSValue
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArg)))) {
        overloadId = 0; // newQObject(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "newQObject", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QObject *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // newQObject(QObject*)
            QJSValue cppResult = cppSelf->newQObject(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSEngineFunc_newSymbol(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QJSEngine::newSymbol(QString)->QJSValue
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // newSymbol(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "newSymbol", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // newSymbol(QString)
            QJSValue cppResult = cppSelf->newSymbol(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSEngineFunc_objectOwnership(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QJSEngine::objectOwnership(QObject*)->QJSEngine::ObjectOwnership
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArg)))) {
        overloadId = 0; // objectOwnership(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "objectOwnership", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QObject *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // objectOwnership(QObject*)
            QJSEngine::ObjectOwnership cppResult = ::QJSEngine::objectOwnership(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_ObjectOwnership_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSEngineFunc_registerModule(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "registerModule", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QJSEngine::registerModule(QString,QJSValue)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), (pyArgs[1])))) {
        overloadId = 0; // registerModule(QString,QJSValue)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "registerModule", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QJSValue cppArg1_local;
        ::QJSValue *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // registerModule(QString,QJSValue)
            bool cppResult = cppSelf->registerModule(cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSEngineFunc_setInterrupted(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QJSEngine::setInterrupted(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setInterrupted(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setInterrupted", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setInterrupted(bool)
            cppSelf->setInterrupted(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QJSEngineFunc_setObjectOwnership(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setObjectOwnership", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QJSEngine::setObjectOwnership(QObject*,QJSEngine::ObjectOwnership)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_ObjectOwnership_IDX])))->converter, (pyArgs[1])))) {
        overloadId = 0; // setObjectOwnership(QObject*,QJSEngine::ObjectOwnership)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setObjectOwnership", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QObject *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QJSEngine::ObjectOwnership cppArg1{QJSEngine::CppOwnership};
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setObjectOwnership(QObject*,QJSEngine::ObjectOwnership)
            ::QJSEngine::setObjectOwnership(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QJSEngineFunc_setUiLanguage(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QJSEngine::setUiLanguage(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setUiLanguage(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUiLanguage", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setUiLanguage(QString)
            cppSelf->setUiLanguage(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QJSEngineFunc_throwError(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "throwError", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]);

    if (PyArg_ParseTuple(args, "|OO:throwError", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QJSEngine::throwError(QJSValue::ErrorType,const QString&=)
    // 1: QJSEngine::throwError(QJSValue)
    // 2: QJSEngine::throwError(QString)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 2; // throwError(QString)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_ErrorType_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // throwError(QJSValue::ErrorType,QString)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 0; // throwError(QJSValue::ErrorType,QString)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), (pyArgs[0])))) {
        overloadId = 1; // throwError(QJSValue)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "throwError", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // throwError(QJSValue::ErrorType errorType, const QString &message)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_message = Shiboken::String::createStaticString("message");
                if (PyDict_Contains(kwds, key_message) != 0) {
                    value = PyDict_GetItem(kwds, key_message);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_message);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "throwError", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "throwError", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_message);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "throwError", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]);
                }
            }
            ::QJSValue::ErrorType cppArg0{QJSValue::NoError};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1 = QString();
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // throwError(QJSValue::ErrorType,QString)
                cppSelf->throwError(cppArg0, cppArg1);
            }
            break;
        }
        case 1: // throwError(const QJSValue &error)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "throwError", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QJSValue cppArg0_local;
            ::QJSValue *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // throwError(QJSValue)
                cppSelf->throwError(*cppArg0);
            }
            break;
        }
        case 2: // throwError(const QString &message)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "throwError", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]);
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // throwError(QString)
                cppSelf->throwError(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QJSEngineFunc_toScriptValue(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QJSEngine::toScriptValue(QVariant)->QJSValue
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // toScriptValue(QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "toScriptValue", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]);

    // Call function/method
    {
        ::QVariant cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        SBK_UNUSED(cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // toScriptValue(QVariant)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtqml.cpp (qjsengine-toscriptvalue)]
            ::QJSValue retval = cppSelf->toScriptValue(cppArg0);
            return Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), &retval);
            // END of custom code block [file: ../glue/qtqml.cpp (qjsengine-toscriptvalue)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSEngineFunc_uiLanguage(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // uiLanguage()const
        QString cppResult = const_cast<const ::QJSEngine *>(cppSelf)->uiLanguage();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QJSEngine_PropertyStrings[] = {
    "uiLanguage::",
    nullptr // Sentinel
};

static const char *Sbk_QJSEngine_EnumFlagInfo[] = {
    "Extension:Flag:Extensions",
    "ObjectOwnership:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QJSEngine_methods[] = {
    {"catchError", reinterpret_cast<PyCFunction>(Sbk_QJSEngineFunc_catchError), METH_NOARGS, nullptr},
    {"collectGarbage", reinterpret_cast<PyCFunction>(Sbk_QJSEngineFunc_collectGarbage), METH_NOARGS, nullptr},
    {"evaluate", reinterpret_cast<PyCFunction>(Sbk_QJSEngineFunc_evaluate), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"globalObject", reinterpret_cast<PyCFunction>(Sbk_QJSEngineFunc_globalObject), METH_NOARGS, nullptr},
    {"hasError", reinterpret_cast<PyCFunction>(Sbk_QJSEngineFunc_hasError), METH_NOARGS, nullptr},
    {"importModule", reinterpret_cast<PyCFunction>(Sbk_QJSEngineFunc_importModule), METH_O, nullptr},
    {"installExtensions", reinterpret_cast<PyCFunction>(Sbk_QJSEngineFunc_installExtensions), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"isInterrupted", reinterpret_cast<PyCFunction>(Sbk_QJSEngineFunc_isInterrupted), METH_NOARGS, nullptr},
    {"newArray", reinterpret_cast<PyCFunction>(Sbk_QJSEngineFunc_newArray), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"newErrorObject", reinterpret_cast<PyCFunction>(Sbk_QJSEngineFunc_newErrorObject), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"newObject", reinterpret_cast<PyCFunction>(Sbk_QJSEngineFunc_newObject), METH_NOARGS, nullptr},
    {"newQMetaObject", reinterpret_cast<PyCFunction>(Sbk_QJSEngineFunc_newQMetaObject), METH_O, nullptr},
    {"newQObject", reinterpret_cast<PyCFunction>(Sbk_QJSEngineFunc_newQObject), METH_O, nullptr},
    {"newSymbol", reinterpret_cast<PyCFunction>(Sbk_QJSEngineFunc_newSymbol), METH_O, nullptr},
    {"objectOwnership", reinterpret_cast<PyCFunction>(Sbk_QJSEngineFunc_objectOwnership), METH_O|METH_STATIC, nullptr},
    {"registerModule", reinterpret_cast<PyCFunction>(Sbk_QJSEngineFunc_registerModule), METH_VARARGS, nullptr},
    {"setInterrupted", reinterpret_cast<PyCFunction>(Sbk_QJSEngineFunc_setInterrupted), METH_O, nullptr},
    {"setObjectOwnership", reinterpret_cast<PyCFunction>(Sbk_QJSEngineFunc_setObjectOwnership), METH_VARARGS|METH_STATIC, nullptr},
    {"setUiLanguage", reinterpret_cast<PyCFunction>(Sbk_QJSEngineFunc_setUiLanguage), METH_O, nullptr},
    {"throwError", reinterpret_cast<PyCFunction>(Sbk_QJSEngineFunc_throwError), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toScriptValue", reinterpret_cast<PyCFunction>(Sbk_QJSEngineFunc_toScriptValue), METH_O, nullptr},
    {"uiLanguage", reinterpret_cast<PyCFunction>(Sbk_QJSEngineFunc_uiLanguage), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QJSEngine_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QJSEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QJSEngineWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QJSEngine_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QJSEngine_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QJSEngine_Type = nullptr;
static PyTypeObject *Sbk_QJSEngine_TypeF(void)
{
    return _Sbk_QJSEngine_Type;
}

static PyType_Slot Sbk_QJSEngine_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QJSEngine_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QJSEngine_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QJSEngine_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QJSEngine_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QJSEngine_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QJSEngine_spec = {
    "2:PySide6.QtQml.QJSEngine",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QJSEngine_slots
};

} //extern "C"

static void *Sbk_QJSEngine_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QJSEngine *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QJSEngine_ObjectOwnership(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QJSEngine::ObjectOwnership>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QJSEngine::ObjectOwnership *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QJSEngine_ObjectOwnership_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_ObjectOwnership_IDX])))
        return Enum_PythonToCpp_QJSEngine_ObjectOwnership;
    return {};
}

static PyObject *QJSEngine_ObjectOwnership_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QJSEngine::ObjectOwnership>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QJSEngine::ObjectOwnership *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_ObjectOwnership_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QJSEngine_Extension(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QJSEngine::Extension>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QJSEngine::Extension *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QJSEngine_Extension_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_Extension_IDX])))
        return Enum_PythonToCpp_QJSEngine_Extension;
    return {};
}

static PyObject *QJSEngine_Extension_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QJSEngine::Extension>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QJSEngine::Extension *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_Extension_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QJSEngine_Extension(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QJSEngine::Extension>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QJSEngine::Extension> *>(cppOut) = value;

}

static PyObject *QJSEngine_Extension_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QJSEngine::Extension> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_Extension_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QJSEngine_PythonToCpp_QJSEngine_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QJSEngine_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QJSEngine_PythonToCpp_QJSEngine_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QJSEngine_TypeF()))
        return QJSEngine_PythonToCpp_QJSEngine_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QJSEngine_PTR_CppToPython_QJSEngine(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QJSEngine *>(const_cast<void *>(cppIn)), Sbk_QJSEngine_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QJSEngine_SignatureStrings[] = {
    "1:PySide6.QtQml.QJSEngine(self,*:KeywordOnly=None,uiLanguage:QString=None)",
    "0:PySide6.QtQml.QJSEngine(self,parent:PySide6.QtCore.QObject,*:KeywordOnly=None,uiLanguage:QString=None)",
    "PySide6.QtQml.QJSEngine.catchError(self)->PySide6.QtQml.QJSValue",
    "PySide6.QtQml.QJSEngine.collectGarbage(self)",
    "PySide6.QtQml.QJSEngine.evaluate(self,program:QString,fileName:QString=QString(),lineNumber:int=1,exceptionStackTrace:QStringList*=nullptr)->PySide6.QtQml.QJSValue",
    "PySide6.QtQml.QJSEngine.globalObject(self)->PySide6.QtQml.QJSValue",
    "PySide6.QtQml.QJSEngine.hasError(self)->bool",
    "PySide6.QtQml.QJSEngine.importModule(self,fileName:QString)->PySide6.QtQml.QJSValue",
    "PySide6.QtQml.QJSEngine.installExtensions(self,extensions:PySide6.QtQml.QJSEngine.Extension,object:typing.Union[PySide6.QtQml.QJSValue, PySide6.QtQml.QJSValue.SpecialValue, bool, QLatin1String, QString, char*, double, int, uint]=QJSValue())",
    "PySide6.QtQml.QJSEngine.isInterrupted(self)->bool",
    "PySide6.QtQml.QJSEngine.newArray(self,length:uint=0)->PySide6.QtQml.QJSValue",
    "PySide6.QtQml.QJSEngine.newErrorObject(self,errorType:PySide6.QtQml.QJSValue.ErrorType,message:QString=QString())->PySide6.QtQml.QJSValue",
    "PySide6.QtQml.QJSEngine.newObject(self)->PySide6.QtQml.QJSValue",
    "PySide6.QtQml.QJSEngine.newQMetaObject(self,metaObject:PySide6.QtCore.QMetaObject)->PySide6.QtQml.QJSValue",
    "PySide6.QtQml.QJSEngine.newQObject(self,object:PySide6.QtCore.QObject)->PySide6.QtQml.QJSValue",
    "PySide6.QtQml.QJSEngine.newSymbol(self,name:QString)->PySide6.QtQml.QJSValue",
    "PySide6.QtQml.QJSEngine.objectOwnership(arg__1:PySide6.QtCore.QObject)->PySide6.QtQml.QJSEngine.ObjectOwnership",
    "PySide6.QtQml.QJSEngine.registerModule(self,moduleName:QString,value:typing.Union[PySide6.QtQml.QJSValue, PySide6.QtQml.QJSValue.SpecialValue, bool, QLatin1String, QString, char*, double, int, uint])->bool",
    "PySide6.QtQml.QJSEngine.setInterrupted(self,interrupted:bool)",
    "PySide6.QtQml.QJSEngine.setObjectOwnership(arg__1:PySide6.QtCore.QObject,arg__2:PySide6.QtQml.QJSEngine.ObjectOwnership)",
    "PySide6.QtQml.QJSEngine.setUiLanguage(self,language:QString)",
    "2:PySide6.QtQml.QJSEngine.throwError(self,errorType:PySide6.QtQml.QJSValue.ErrorType,message:QString=QString())",
    "1:PySide6.QtQml.QJSEngine.throwError(self,error:typing.Union[PySide6.QtQml.QJSValue, PySide6.QtQml.QJSValue.SpecialValue, bool, QLatin1String, QString, char*, double, int, uint])",
    "0:PySide6.QtQml.QJSEngine.throwError(self,message:QString)",
    "PySide6.QtQml.QJSEngine.toScriptValue(self,value:QVariant)->PySide6.QtQml.QJSValue",
    "PySide6.QtQml.QJSEngine.uiLanguage(self)->QString",
    nullptr}; // Sentinel
#else
static constexpr size_t QJSEngine_SignatureByteSize = 578;
static constexpr uint8_t QJSEngine_SignatureBytes[578] = {
    0x78, 0xda, 0xcd, 0x56, 0x4b, 0x6f, 0x9b, 0x40, 0x10, 0xbe, 0xfb, 0x57, 0x70, 0x34, 0xd6, 0x16,
    0xc5, 0x3d, 0xf4, 0x80, 0xe4, 0x4a, 0x55, 0x65, 0x55, 0x6d, 0x1d, 0xbb, 0x88, 0x24, 0x97, 0xa8,
    0x8a, 0x16, 0x3c, 0x81, 0x6d, 0x97, 0x5d, 0x34, 0x0c, 0x75, 0xf8, 0xf7, 0x5d, 0xf3, 0x32, 0x7e,
    0xe0, 0x06, 0xbb, 0x52, 0x7b, 0xb1, 0xcd, 0x78, 0xe6, 0xfb, 0x66, 0xbf, 0x79, 0x2c, 0x53, 0xf7,
    0x5b, 0xe1, 0x8b, 0x35, 0xbc, 0x73, 0x3c, 0xf2, 0x12, 0xe9, 0x78, 0x5f, 0xfc, 0xb9, 0x8a, 0x84,
    0x82, 0x71, 0x06, 0xf2, 0x99, 0x4d, 0xdc, 0xaf, 0x50, 0x6c, 0x34, 0xae, 0x57, 0x4a, 0x16, 0xb3,
    0xa5, 0x56, 0xc0, 0x72, 0xb1, 0xe0, 0x2a, 0xca, 0x79, 0x04, 0xae, 0xe7, 0x13, 0x0a, 0x15, 0x95,
    0x76, 0x7b, 0x74, 0x73, 0x1e, 0x2a, 0xe5, 0x08, 0x8a, 0x3a, 0x3e, 0x1f, 0x35, 0x82, 0xe3, 0xad,
    0x82, 0x1f, 0x10, 0xd2, 0x20, 0xa2, 0x1e, 0x1a, 0x27, 0xe4, 0x14, 0xc6, 0x73, 0x44, 0x8d, 0x25,
    0xa3, 0xfd, 0xe6, 0xfd, 0x91, 0xe7, 0x03, 0x97, 0x39, 0xf4, 0x03, 0x68, 0x29, 0x4d, 0x32, 0x9f,
    0x38, 0x06, 0x86, 0xb5, 0x02, 0xe9, 0x75, 0x86, 0x5f, 0x06, 0x8b, 0x53, 0x73, 0x3a, 0xd4, 0x11,
    0xf2, 0xa4, 0xc9, 0x94, 0x3d, 0x0b, 0x09, 0x4b, 0x9e, 0xec, 0x52, 0xaf, 0xbf, 0xc7, 0x36, 0x93,
    0x26, 0x7a, 0x99, 0x27, 0x01, 0xa0, 0x2b, 0x14, 0xcd, 0xa6, 0x0c, 0x5e, 0x42, 0x48, 0x49, 0x68,
    0xe5, 0x13, 0x0f, 0x7f, 0xde, 0x21, 0x0f, 0xdb, 0xb0, 0x85, 0xc8, 0x68, 0x32, 0x53, 0xb9, 0x94,
    0x29, 0xe1, 0xf0, 0x03, 0x45, 0x52, 0x07, 0x5c, 0x56, 0x12, 0x5f, 0xa8, 0x49, 0xcc, 0xb3, 0x3d,
    0x49, 0x03, 0xad, 0x65, 0xaf, 0xb3, 0x48, 0x52, 0x8d, 0x74, 0xab, 0xd7, 0xb9, 0xac, 0x75, 0x39,
    0xd4, 0x61, 0x78, 0x02, 0x42, 0x65, 0xc4, 0xa5, 0x9c, 0xbf, 0x10, 0xa8, 0xcc, 0x88, 0x94, 0x55,
    0xc0, 0xd0, 0x3e, 0xf7, 0xb5, 0x9d, 0xd3, 0x86, 0x30, 0x5d, 0x2a, 0xe0, 0x52, 0x91, 0x9a, 0x14,
    0x9c, 0x7b, 0x65, 0x6c, 0x8f, 0xa7, 0xd3, 0x60, 0xd6, 0x69, 0xbb, 0xe3, 0xa7, 0x10, 0x0a, 0x2e,
    0x6b, 0xa7, 0xad, 0x0a, 0xcc, 0xf2, 0x16, 0x9c, 0x84, 0x9a, 0xd6, 0x25, 0xb7, 0x9a, 0xda, 0x5b,
    0x61, 0xcc, 0x71, 0xc2, 0xac, 0xb5, 0xce, 0x03, 0x69, 0x9c, 0x4d, 0x95, 0x99, 0x95, 0x9b, 0xcf,
    0xef, 0xb3, 0x06, 0x6e, 0x6c, 0xf7, 0x37, 0x96, 0xc8, 0x3e, 0x2b, 0x02, 0xc4, 0x3c, 0x25, 0x58,
    0xbf, 0x4a, 0x76, 0x05, 0x9b, 0x0f, 0x88, 0xbc, 0xa8, 0x94, 0x91, 0xa0, 0x22, 0x8a, 0xdd, 0x2d,
    0xe1, 0xec, 0x66, 0xb8, 0xde, 0x06, 0xac, 0x2c, 0x78, 0xa7, 0x6b, 0x18, 0x6c, 0x0d, 0x77, 0x45,
    0x0a, 0x6e, 0x8f, 0x3a, 0xf3, 0xc6, 0x81, 0x25, 0x90, 0x65, 0xdd, 0x91, 0x6d, 0xfb, 0xfe, 0xa2,
    0x4c, 0xae, 0x6a, 0x5d, 0x13, 0xef, 0xdd, 0x02, 0xf1, 0xee, 0x49, 0x92, 0xf6, 0xf9, 0x68, 0x13,
    0xed, 0x5c, 0x2f, 0xa3, 0xea, 0xd2, 0xe8, 0xd3, 0x14, 0x57, 0xc0, 0xfb, 0x45, 0x12, 0x68, 0x59,
    0xa1, 0xab, 0xab, 0x06, 0xaa, 0xca, 0x6d, 0xb5, 0x51, 0x80, 0x59, 0x2c, 0xd2, 0x31, 0xc7, 0xe8,
    0xe9, 0x69, 0x3a, 0x20, 0xd7, 0x1a, 0x67, 0xb5, 0x8f, 0xd3, 0xcb, 0x87, 0x10, 0x99, 0x2d, 0x06,
    0xd8, 0x5d, 0x0b, 0x49, 0xf9, 0xbb, 0xbb, 0x18, 0xd8, 0x76, 0x9d, 0xc2, 0xbf, 0x1f, 0xd1, 0x3f,
    0xcd, 0x5a, 0x06, 0x74, 0x38, 0x9e, 0x4c, 0xec, 0x0c, 0xee, 0x36, 0xd8, 0x3e, 0x17, 0xbd, 0x1a,
    0x22, 0x3f, 0x2b, 0xff, 0x7d, 0xeb, 0xbe, 0xb2, 0x06, 0x67, 0x89, 0xef, 0xdb, 0xfb, 0xb4, 0xde,
    0x13, 0x07, 0xb7, 0xab, 0x3d, 0xea, 0xe7, 0xa1, 0x18, 0xf5, 0x66, 0x77, 0x0f, 0xfc, 0x9d, 0x85,
    0x30, 0x9a, 0x0e, 0xe3, 0xfb, 0x0f, 0x9a, 0xa3, 0xff, 0x25, 0xe7, 0x28, 0xe5, 0x83, 0x73, 0xf7,
    0x97, 0x86, 0xb4, 0x1f, 0xa2, 0x48, 0xa9, 0xba, 0x18, 0xca, 0xd8, 0x6a, 0x16, 0xbc, 0x07, 0x8e,
    0x82, 0xab, 0x0b, 0xf6, 0x45, 0xbe, 0x5f, 0x6a, 0x03, 0x50, 0x67, 0x31, 0xfa, 0x0d, 0xfc, 0x46,
    0x84, 0x76
};
#endif

PyTypeObject *init_QJSEngine(PyObject *module)
{
    if (SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX].type != nullptr)
        return SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX].type;

    Shiboken::AutoDecRef Sbk_QJSEngine_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QJSEngine_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QJSEngine",
        "QJSEngine*",
        &Sbk_QJSEngine_spec,
        &Shiboken::callCppDestructor< QJSEngine >,
        Sbk_QJSEngine_Type_bases.object(),
        0);
    auto *pyType = Sbk_QJSEngine_TypeF(); // references _Sbk_QJSEngine_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QJSEngine_SignatureStrings);
#else
    InitSignatureBytes(pyType, QJSEngine_SignatureBytes, QJSEngine_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QJSEngine_PropertyStrings);
    SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QJSEngine_PythonToCpp_QJSEngine_PTR,
        is_QJSEngine_PythonToCpp_QJSEngine_PTR_Convertible,
        QJSEngine_PTR_CppToPython_QJSEngine);

    Shiboken::Conversions::registerConverterName(converter, "QJSEngine");
    Shiboken::Conversions::registerConverterName(converter, "QJSEngine*");
    Shiboken::Conversions::registerConverterName(converter, "QJSEngine&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QJSEngine).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QJSEngineWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QJSEngine_TypeF(), &Sbk_QJSEngine_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QJSEngine_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'ObjectOwnership'.
    const char *ObjectOwnership_Initializer[] = {
        "CppOwnership",
        "JavaScriptOwnership",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ObjectOwnership_InitializerValues[] = {
        uint8_t(QJSEngine::ObjectOwnership::CppOwnership),       //  0x00  0
        uint8_t(QJSEngine::ObjectOwnership::JavaScriptOwnership) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QJSEngine_TypeF(),
        "2:PySide6.QtQml.QJSEngine.ObjectOwnership",
        ObjectOwnership_Initializer, ObjectOwnership_InitializerValues);
    SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_ObjectOwnership_IDX].type = EType;
    // Register converter for enum 'QJSEngine::ObjectOwnership'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QJSEngine_ObjectOwnership_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QJSEngine_ObjectOwnership,
            is_Enum_PythonToCpp_QJSEngine_ObjectOwnership_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QJSEngine::ObjectOwnership");
        Shiboken::Conversions::registerConverterAlias(converter, "ObjectOwnership");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ObjectOwnership' enum.

    // Initialization of enum 'Extension'.
    const char *Extension_Initializer[] = {
        "TranslationExtension",
        "ConsoleExtension",
        "GarbageCollectionExtension",
        "AllExtensions",
        nullptr};
    // "uint32_t" used instead of "unsigned int"
    constexpr uint32_t Extension_InitializerValues[] = {
        uint32_t(QJSEngine::Extension::TranslationExtension),       //  0x00000001  1
        uint32_t(QJSEngine::Extension::ConsoleExtension),           //  0x00000002  2
        uint32_t(QJSEngine::Extension::GarbageCollectionExtension), //  0x00000004  4
        uint32_t(QJSEngine::Extension::AllExtensions)               //  0xffffffff  4294967295
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QJSEngine_TypeF(),
        "2:PySide6.QtQml.QJSEngine.Extension",
        Extension_Initializer, Extension_InitializerValues);
    SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_Extension_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtQmlTypeStructs[SBK_QFlags_QJSEngine_Extension_IDX].type =
        EType;
    // Register converter for enum 'QJSEngine::Extension'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QJSEngine_Extension_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QJSEngine_Extension,
            is_Enum_PythonToCpp_QJSEngine_Extension_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QJSEngine::Extension");
        Shiboken::Conversions::registerConverterAlias(converter, "Extension");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QJSEngine_Extension_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QJSEngine_Extension,
            is_Enum_PythonToCpp_QJSEngine_Extension_Convertible);
        // Register converter for flag 'QFlags<QJSEngine::Extension>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QJSEngine::Extension>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QJSEngine::Extensions");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'Extension' enum/flags.

    PySide::Signal::registerSignals(pyType, &::QJSEngine::staticMetaObject);
    qRegisterMetaType< ::QJSEngine::ObjectOwnership >("QJSEngine::ObjectOwnership");
    qRegisterMetaType< ::QJSEngine::Extension >("QJSEngine::Extension");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QJSEngine::staticMetaObject, sizeof(QJSEngineWrapper));

    return pyType;
}
