// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtqml_python.h"

// main header
#include "qjsmanagedvalue_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QStringList>
#include <QtQml/qjsengine.h>
#include <QtQml/qjsmanagedvalue.h>
#include <QtQml/qjsprimitivevalue.h>
#include <QtQml/qjsvalue.h>
#include <qdatetime.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qregularexpression.h>
#include <qurl.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QJSManagedValue_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QJSManagedValue >()))
        return -1;

    ::QJSManagedValue *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]);

    if (PyArg_UnpackTuple(args, "QJSManagedValue", 0, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QJSManagedValue::QJSManagedValue()
    // 1: QJSManagedValue::QJSManagedValue(QJSValue,QJSEngine*)
    // 2: QJSManagedValue::QJSManagedValue(QJSPrimitiveValue,QJSEngine*)
    // 3: QJSManagedValue::QJSManagedValue(QString,QJSEngine*)
    // 4: QJSManagedValue::QJSManagedValue(QVariant,QJSEngine*)
    if (numArgs == 0) {
        overloadId = 0; // QJSManagedValue()
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]), (pyArgs[1])))) {
        overloadId = 3; // QJSManagedValue(QString,QJSEngine*)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]), (pyArgs[1])))) {
        overloadId = 2; // QJSManagedValue(QJSPrimitiveValue,QJSEngine*)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]), (pyArgs[1])))) {
        overloadId = 1; // QJSManagedValue(QJSValue,QJSEngine*)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]), (pyArgs[1])))) {
        overloadId = 4; // QJSManagedValue(QVariant,QJSEngine*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QJSManagedValue()
        {

            // QJSManagedValue()
            cptr = new ::QJSManagedValue();
            break;
        }
        case 1: // QJSManagedValue(QJSValue value, QJSEngine *engine)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QJSValue cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QJSEngine *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QJSManagedValue(QJSValue,QJSEngine*)
                cptr = new ::QJSManagedValue(cppArg0, cppArg1);
            }
            break;
        }
        case 2: // QJSManagedValue(const QJSPrimitiveValue &value, QJSEngine *engine)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QJSPrimitiveValue cppArg0_local;
            ::QJSPrimitiveValue *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QJSEngine *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QJSManagedValue(QJSPrimitiveValue,QJSEngine*)
                cptr = new ::QJSManagedValue(*cppArg0, cppArg1);
            }
            break;
        }
        case 3: // QJSManagedValue(const QString &string, QJSEngine *engine)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QJSEngine *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QJSManagedValue(QString,QJSEngine*)
                cptr = new ::QJSManagedValue(cppArg0, cppArg1);
            }
            break;
        }
        case 4: // QJSManagedValue(const QVariant &variant, QJSEngine *engine)
        {
            ::QVariant cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QJSEngine *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QJSManagedValue(QVariant,QJSEngine*)
                cptr = new ::QJSManagedValue(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QJSManagedValue >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QJSManagedValueFunc_call(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "call", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]);

    if (PyArg_ParseTuple(args, "|O:call", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QJSManagedValue::call(const QList<QJSValue>&=)const->QJSValue
    if (numArgs == 0) {
        overloadId = 0; // call(QList<QJSValue>)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtQmlTypeConverters[SBK_QtQml_QList_QJSValue_IDX], (pyArgs[0])))) {
        overloadId = 0; // call(QList<QJSValue>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "call", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_arguments = Shiboken::String::createStaticString("arguments");
            if (PyDict_Contains(kwds, key_arguments) != 0) {
                value = PyDict_GetItem(kwds, key_arguments);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_arguments);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "call", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtQmlTypeConverters[SBK_QtQml_QList_QJSValue_IDX], (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "call", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_arguments);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "call", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]);
            }
        }
        ::QList<QJSValue> cppArg0{};
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // call(QList<QJSValue>)const
            QJSValue cppResult = const_cast<const ::QJSManagedValue *>(cppSelf)->call(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSManagedValueFunc_callAsConstructor(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "callAsConstructor", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]);

    if (PyArg_ParseTuple(args, "|O:callAsConstructor", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QJSManagedValue::callAsConstructor(const QList<QJSValue>&=)const->QJSValue
    if (numArgs == 0) {
        overloadId = 0; // callAsConstructor(QList<QJSValue>)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtQmlTypeConverters[SBK_QtQml_QList_QJSValue_IDX], (pyArgs[0])))) {
        overloadId = 0; // callAsConstructor(QList<QJSValue>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "callAsConstructor", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_arguments = Shiboken::String::createStaticString("arguments");
            if (PyDict_Contains(kwds, key_arguments) != 0) {
                value = PyDict_GetItem(kwds, key_arguments);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_arguments);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "callAsConstructor", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtQmlTypeConverters[SBK_QtQml_QList_QJSValue_IDX], (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "callAsConstructor", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_arguments);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "callAsConstructor", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]);
            }
        }
        ::QList<QJSValue> cppArg0{};
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // callAsConstructor(QList<QJSValue>)const
            QJSValue cppResult = const_cast<const ::QJSManagedValue *>(cppSelf)->callAsConstructor(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSManagedValueFunc_callWithInstance(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "callWithInstance", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]);

    if (PyArg_ParseTuple(args, "|OO:callWithInstance", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QJSManagedValue::callWithInstance(QJSValue,const QList<QJSValue>&=)const->QJSValue
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // callWithInstance(QJSValue,QList<QJSValue>)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtQmlTypeConverters[SBK_QtQml_QList_QJSValue_IDX], (pyArgs[1])))) {
            overloadId = 0; // callWithInstance(QJSValue,QList<QJSValue>)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "callWithInstance", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_arguments = Shiboken::String::createStaticString("arguments");
            if (PyDict_Contains(kwds, key_arguments) != 0) {
                value = PyDict_GetItem(kwds, key_arguments);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_arguments);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "callWithInstance", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtQmlTypeConverters[SBK_QtQml_QList_QJSValue_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "callWithInstance", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_arguments);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "callWithInstance", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QJSValue cppArg0_local;
        ::QJSValue *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QList<QJSValue> cppArg1{};
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // callWithInstance(QJSValue,QList<QJSValue>)const
            QJSValue cppResult = const_cast<const ::QJSManagedValue *>(cppSelf)->callWithInstance(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSManagedValueFunc_deleteProperty(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QJSManagedValue::deleteProperty(QString)->bool
    // 1: QJSManagedValue::deleteProperty(quint32)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArg)))) {
        overloadId = 1; // deleteProperty(quint32)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // deleteProperty(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "deleteProperty", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // deleteProperty(const QString &name)
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // deleteProperty(QString)
                bool cppResult = cppSelf->deleteProperty(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // deleteProperty(quint32 arrayIndex)
        {
            quint32 cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // deleteProperty(quint32)
                bool cppResult = cppSelf->deleteProperty(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSManagedValueFunc_engine(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // engine()const
        QJSEngine * cppResult = const_cast<const ::QJSManagedValue *>(cppSelf)->engine();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSManagedValueFunc_equals(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QJSManagedValue::equals(QJSManagedValue)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), (pyArg)))) {
        overloadId = 0; // equals(QJSManagedValue)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "equals", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QJSManagedValue *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // equals(QJSManagedValue)const
            bool cppResult = const_cast<const ::QJSManagedValue *>(cppSelf)->equals(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSManagedValueFunc_hasOwnProperty(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QJSManagedValue::hasOwnProperty(QString)const->bool
    // 1: QJSManagedValue::hasOwnProperty(quint32)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArg)))) {
        overloadId = 1; // hasOwnProperty(quint32)const
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // hasOwnProperty(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "hasOwnProperty", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // hasOwnProperty(const QString &name) const
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // hasOwnProperty(QString)const
                bool cppResult = const_cast<const ::QJSManagedValue *>(cppSelf)->hasOwnProperty(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // hasOwnProperty(quint32 arrayIndex) const
        {
            quint32 cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // hasOwnProperty(quint32)const
                bool cppResult = const_cast<const ::QJSManagedValue *>(cppSelf)->hasOwnProperty(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSManagedValueFunc_hasProperty(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QJSManagedValue::hasProperty(QString)const->bool
    // 1: QJSManagedValue::hasProperty(quint32)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArg)))) {
        overloadId = 1; // hasProperty(quint32)const
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // hasProperty(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "hasProperty", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // hasProperty(const QString &name) const
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // hasProperty(QString)const
                bool cppResult = const_cast<const ::QJSManagedValue *>(cppSelf)->hasProperty(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // hasProperty(quint32 arrayIndex) const
        {
            quint32 cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // hasProperty(quint32)const
                bool cppResult = const_cast<const ::QJSManagedValue *>(cppSelf)->hasProperty(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSManagedValueFunc_isArray(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isArray()const
        bool cppResult = const_cast<const ::QJSManagedValue *>(cppSelf)->isArray();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSManagedValueFunc_isBoolean(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isBoolean()const
        bool cppResult = const_cast<const ::QJSManagedValue *>(cppSelf)->isBoolean();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSManagedValueFunc_isDate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isDate()const
        bool cppResult = const_cast<const ::QJSManagedValue *>(cppSelf)->isDate();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSManagedValueFunc_isError(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isError()const
        bool cppResult = const_cast<const ::QJSManagedValue *>(cppSelf)->isError();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSManagedValueFunc_isFunction(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isFunction()const
        bool cppResult = const_cast<const ::QJSManagedValue *>(cppSelf)->isFunction();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSManagedValueFunc_isInteger(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isInteger()const
        bool cppResult = const_cast<const ::QJSManagedValue *>(cppSelf)->isInteger();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSManagedValueFunc_isJsMetaType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isJsMetaType()const
        bool cppResult = const_cast<const ::QJSManagedValue *>(cppSelf)->isJsMetaType();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSManagedValueFunc_isNull(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isNull()const
        bool cppResult = const_cast<const ::QJSManagedValue *>(cppSelf)->isNull();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSManagedValueFunc_isNumber(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isNumber()const
        bool cppResult = const_cast<const ::QJSManagedValue *>(cppSelf)->isNumber();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSManagedValueFunc_isObject(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isObject()const
        bool cppResult = const_cast<const ::QJSManagedValue *>(cppSelf)->isObject();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSManagedValueFunc_isQMetaObject(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isQMetaObject()const
        bool cppResult = const_cast<const ::QJSManagedValue *>(cppSelf)->isQMetaObject();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSManagedValueFunc_isQObject(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isQObject()const
        bool cppResult = const_cast<const ::QJSManagedValue *>(cppSelf)->isQObject();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSManagedValueFunc_isRegularExpression(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isRegularExpression()const
        bool cppResult = const_cast<const ::QJSManagedValue *>(cppSelf)->isRegularExpression();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSManagedValueFunc_isString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isString()const
        bool cppResult = const_cast<const ::QJSManagedValue *>(cppSelf)->isString();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSManagedValueFunc_isSymbol(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isSymbol()const
        bool cppResult = const_cast<const ::QJSManagedValue *>(cppSelf)->isSymbol();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSManagedValueFunc_isUndefined(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isUndefined()const
        bool cppResult = const_cast<const ::QJSManagedValue *>(cppSelf)->isUndefined();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSManagedValueFunc_isUrl(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isUrl()const
        bool cppResult = const_cast<const ::QJSManagedValue *>(cppSelf)->isUrl();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSManagedValueFunc_isVariant(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isVariant()const
        bool cppResult = const_cast<const ::QJSManagedValue *>(cppSelf)->isVariant();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSManagedValueFunc_jsMetaInstantiate(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "jsMetaInstantiate", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]);

    if (PyArg_ParseTuple(args, "|O:jsMetaInstantiate", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QJSManagedValue::jsMetaInstantiate(const QList<QJSValue>&=)const->QJSManagedValue
    if (numArgs == 0) {
        overloadId = 0; // jsMetaInstantiate(QList<QJSValue>)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtQmlTypeConverters[SBK_QtQml_QList_QJSValue_IDX], (pyArgs[0])))) {
        overloadId = 0; // jsMetaInstantiate(QList<QJSValue>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "jsMetaInstantiate", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_values = Shiboken::String::createStaticString("values");
            if (PyDict_Contains(kwds, key_values) != 0) {
                value = PyDict_GetItem(kwds, key_values);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_values);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "jsMetaInstantiate", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtQmlTypeConverters[SBK_QtQml_QList_QJSValue_IDX], (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "jsMetaInstantiate", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_values);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "jsMetaInstantiate", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]);
            }
        }
        ::QList<QJSValue> cppArg0{};
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // jsMetaInstantiate(QList<QJSValue>)const
            QJSManagedValue* cppResult = new QJSManagedValue(const_cast<const ::QJSManagedValue *>(cppSelf)->jsMetaInstantiate(cppArg0));
            pyResult = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), cppResult, true, true);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSManagedValueFunc_jsMetaMembers(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // jsMetaMembers()const
        QStringList cppResult = const_cast<const ::QJSManagedValue *>(cppSelf)->jsMetaMembers();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSManagedValueFunc_jsMetaType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // jsMetaType()const
        QJSManagedValue* cppResult = new QJSManagedValue(const_cast<const ::QJSManagedValue *>(cppSelf)->jsMetaType());
        pyResult = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), cppResult, true, true);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSManagedValueFunc_property(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QJSManagedValue::property(QString)const->QJSValue
    // 1: QJSManagedValue::property(quint32)const->QJSValue
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArg)))) {
        overloadId = 1; // property(quint32)const
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // property(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "property", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // property(const QString &name) const
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // property(QString)const
                QJSValue cppResult = const_cast<const ::QJSManagedValue *>(cppSelf)->property(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), &cppResult);
            }
            break;
        }
        case 1: // property(quint32 arrayIndex) const
        {
            quint32 cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // property(quint32)const
                QJSValue cppResult = const_cast<const ::QJSManagedValue *>(cppSelf)->property(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSManagedValueFunc_prototype(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // prototype()const
        QJSManagedValue* cppResult = new QJSManagedValue(const_cast<const ::QJSManagedValue *>(cppSelf)->prototype());
        pyResult = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), cppResult, true, true);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSManagedValueFunc_setProperty(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setProperty", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QJSManagedValue::setProperty(QString,QJSValue)
    // 1: QJSManagedValue::setProperty(quint32,QJSValue)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), (pyArgs[1])))) {
        overloadId = 1; // setProperty(quint32,QJSValue)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), (pyArgs[1])))) {
        overloadId = 0; // setProperty(QString,QJSValue)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setProperty", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setProperty(const QString &name, const QJSValue &value)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QJSValue cppArg1_local;
            ::QJSValue *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setProperty(QString,QJSValue)
                cppSelf->setProperty(cppArg0, *cppArg1);
            }
            break;
        }
        case 1: // setProperty(quint32 arrayIndex, const QJSValue &value)
        {
            quint32 cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QJSValue cppArg1_local;
            ::QJSValue *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setProperty(quint32,QJSValue)
                cppSelf->setProperty(cppArg0, *cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QJSManagedValueFunc_setPrototype(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QJSManagedValue::setPrototype(QJSManagedValue)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), (pyArg)))) {
        overloadId = 0; // setPrototype(QJSManagedValue)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPrototype", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QJSManagedValue *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPrototype(QJSManagedValue)
            cppSelf->setPrototype(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QJSManagedValueFunc_strictlyEquals(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QJSManagedValue::strictlyEquals(QJSManagedValue)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), (pyArg)))) {
        overloadId = 0; // strictlyEquals(QJSManagedValue)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "strictlyEquals", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QJSManagedValue *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // strictlyEquals(QJSManagedValue)const
            bool cppResult = const_cast<const ::QJSManagedValue *>(cppSelf)->strictlyEquals(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSManagedValueFunc_toBoolean(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toBoolean()const
        bool cppResult = const_cast<const ::QJSManagedValue *>(cppSelf)->toBoolean();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSManagedValueFunc_toDateTime(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toDateTime()const
        QDateTime cppResult = const_cast<const ::QJSManagedValue *>(cppSelf)->toDateTime();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSManagedValueFunc_toInteger(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toInteger()const
        int cppResult = const_cast<const ::QJSManagedValue *>(cppSelf)->toInteger();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSManagedValueFunc_toJSValue(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toJSValue()const
        QJSValue cppResult = const_cast<const ::QJSManagedValue *>(cppSelf)->toJSValue();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSManagedValueFunc_toNumber(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toNumber()const
        double cppResult = const_cast<const ::QJSManagedValue *>(cppSelf)->toNumber();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<double>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSManagedValueFunc_toPrimitive(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toPrimitive()const
        QJSPrimitiveValue cppResult = const_cast<const ::QJSManagedValue *>(cppSelf)->toPrimitive();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSManagedValueFunc_toQMetaObject(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toQMetaObject()const
        const QMetaObject * cppResult = const_cast<const ::QJSManagedValue *>(cppSelf)->toQMetaObject();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSManagedValueFunc_toQObject(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toQObject()const
        QObject * cppResult = const_cast<const ::QJSManagedValue *>(cppSelf)->toQObject();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSManagedValueFunc_toRegularExpression(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toRegularExpression()const
        QRegularExpression cppResult = const_cast<const ::QJSManagedValue *>(cppSelf)->toRegularExpression();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSManagedValueFunc_toString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toString()const
        QString cppResult = const_cast<const ::QJSManagedValue *>(cppSelf)->toString();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSManagedValueFunc_toUrl(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toUrl()const
        QUrl cppResult = const_cast<const ::QJSManagedValue *>(cppSelf)->toUrl();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSManagedValueFunc_toVariant(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toVariant()const
        QVariant cppResult = const_cast<const ::QJSManagedValue *>(cppSelf)->toVariant();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSManagedValueFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        QJSManagedValue::Type cppResult = const_cast<const ::QJSManagedValue *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_Type_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QJSManagedValue_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QJSManagedValue_EnumFlagInfo[] = {
    "Type:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QJSManagedValue_methods[] = {
    {"call", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_call), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"callAsConstructor", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_callAsConstructor), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"callWithInstance", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_callWithInstance), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"deleteProperty", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_deleteProperty), METH_O, nullptr},
    {"engine", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_engine), METH_NOARGS, nullptr},
    {"equals", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_equals), METH_O, nullptr},
    {"hasOwnProperty", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_hasOwnProperty), METH_O, nullptr},
    {"hasProperty", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_hasProperty), METH_O, nullptr},
    {"isArray", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_isArray), METH_NOARGS, nullptr},
    {"isBoolean", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_isBoolean), METH_NOARGS, nullptr},
    {"isDate", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_isDate), METH_NOARGS, nullptr},
    {"isError", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_isError), METH_NOARGS, nullptr},
    {"isFunction", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_isFunction), METH_NOARGS, nullptr},
    {"isInteger", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_isInteger), METH_NOARGS, nullptr},
    {"isJsMetaType", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_isJsMetaType), METH_NOARGS, nullptr},
    {"isNull", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_isNull), METH_NOARGS, nullptr},
    {"isNumber", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_isNumber), METH_NOARGS, nullptr},
    {"isObject", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_isObject), METH_NOARGS, nullptr},
    {"isQMetaObject", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_isQMetaObject), METH_NOARGS, nullptr},
    {"isQObject", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_isQObject), METH_NOARGS, nullptr},
    {"isRegularExpression", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_isRegularExpression), METH_NOARGS, nullptr},
    {"isString", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_isString), METH_NOARGS, nullptr},
    {"isSymbol", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_isSymbol), METH_NOARGS, nullptr},
    {"isUndefined", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_isUndefined), METH_NOARGS, nullptr},
    {"isUrl", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_isUrl), METH_NOARGS, nullptr},
    {"isVariant", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_isVariant), METH_NOARGS, nullptr},
    {"jsMetaInstantiate", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_jsMetaInstantiate), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"jsMetaMembers", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_jsMetaMembers), METH_NOARGS, nullptr},
    {"jsMetaType", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_jsMetaType), METH_NOARGS, nullptr},
    {"property", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_property), METH_O, nullptr},
    {"prototype", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_prototype), METH_NOARGS, nullptr},
    {"setProperty", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_setProperty), METH_VARARGS, nullptr},
    {"setPrototype", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_setPrototype), METH_O, nullptr},
    {"strictlyEquals", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_strictlyEquals), METH_O, nullptr},
    {"toBoolean", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_toBoolean), METH_NOARGS, nullptr},
    {"toDateTime", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_toDateTime), METH_NOARGS, nullptr},
    {"toInteger", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_toInteger), METH_NOARGS, nullptr},
    {"toJSValue", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_toJSValue), METH_NOARGS, nullptr},
    {"toNumber", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_toNumber), METH_NOARGS, nullptr},
    {"toPrimitive", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_toPrimitive), METH_NOARGS, nullptr},
    {"toQMetaObject", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_toQMetaObject), METH_NOARGS, nullptr},
    {"toQObject", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_toQObject), METH_NOARGS, nullptr},
    {"toRegularExpression", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_toRegularExpression), METH_NOARGS, nullptr},
    {"toString", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_toString), METH_NOARGS, nullptr},
    {"toUrl", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_toUrl), METH_NOARGS, nullptr},
    {"toVariant", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_toVariant), METH_NOARGS, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QJSManagedValueFunc_type), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QJSManagedValue___nb_bool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QJSManagedValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return !cppSelf->isNull() ? 1 : 0;
}

} // extern "C"

static int Sbk_QJSManagedValue_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QJSManagedValue_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QJSManagedValue_Type = nullptr;
static PyTypeObject *Sbk_QJSManagedValue_TypeF(void)
{
    return _Sbk_QJSManagedValue_Type;
}

static PyType_Slot Sbk_QJSManagedValue_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QJSManagedValue_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QJSManagedValue_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QJSManagedValue_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QJSManagedValue_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_bool,        reinterpret_cast<void *>(Sbk_QJSManagedValue___nb_bool)},
    {0, nullptr}
};
static PyType_Spec Sbk_QJSManagedValue_spec = {
    "2:PySide6.QtQml.QJSManagedValue",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QJSManagedValue_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QJSManagedValue_Type(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QJSManagedValue::Type>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QJSManagedValue::Type *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QJSManagedValue_Type_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_Type_IDX])))
        return Enum_PythonToCpp_QJSManagedValue_Type;
    return {};
}

static PyObject *QJSManagedValue_Type_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QJSManagedValue::Type>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QJSManagedValue::Type *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_Type_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QJSManagedValue_PythonToCpp_QJSManagedValue_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QJSManagedValue_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QJSManagedValue_PythonToCpp_QJSManagedValue_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QJSManagedValue_TypeF()))
        return QJSManagedValue_PythonToCpp_QJSManagedValue_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QJSManagedValue_PTR_CppToPython_QJSManagedValue(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QJSManagedValue_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QJSManagedValue_SignatureStrings[] = {
    "4:PySide6.QtQml.QJSManagedValue(self)",
    "3:PySide6.QtQml.QJSManagedValue(self,value:typing.Union[PySide6.QtQml.QJSValue, PySide6.QtQml.QJSValue.SpecialValue, bool, QLatin1String, QString, char*, double, int, uint],engine:PySide6.QtQml.QJSEngine)",
    "2:PySide6.QtQml.QJSManagedValue(self,value:typing.Union[PySide6.QtQml.QJSPrimitiveValue, QString, bool, double, int],engine:PySide6.QtQml.QJSEngine)",
    "1:PySide6.QtQml.QJSManagedValue(self,string:QString,engine:PySide6.QtQml.QJSEngine)",
    "0:PySide6.QtQml.QJSManagedValue(self,variant:QVariant,engine:PySide6.QtQml.QJSEngine)",
    "PySide6.QtQml.QJSManagedValue.call(self,arguments:QList[PySide6.QtQml.QJSValue]={})->PySide6.QtQml.QJSValue",
    "PySide6.QtQml.QJSManagedValue.callAsConstructor(self,arguments:QList[PySide6.QtQml.QJSValue]={})->PySide6.QtQml.QJSValue",
    "PySide6.QtQml.QJSManagedValue.callWithInstance(self,instance:typing.Union[PySide6.QtQml.QJSValue, PySide6.QtQml.QJSValue.SpecialValue, bool, QLatin1String, QString, char*, double, int, uint],arguments:QList[PySide6.QtQml.QJSValue]={})->PySide6.QtQml.QJSValue",
    "1:PySide6.QtQml.QJSManagedValue.deleteProperty(self,name:QString)->bool",
    "0:PySide6.QtQml.QJSManagedValue.deleteProperty(self,arrayIndex:quint32)->bool",
    "PySide6.QtQml.QJSManagedValue.engine(self)->PySide6.QtQml.QJSEngine",
    "PySide6.QtQml.QJSManagedValue.equals(self,other:PySide6.QtQml.QJSManagedValue)->bool",
    "1:PySide6.QtQml.QJSManagedValue.hasOwnProperty(self,name:QString)->bool",
    "0:PySide6.QtQml.QJSManagedValue.hasOwnProperty(self,arrayIndex:quint32)->bool",
    "1:PySide6.QtQml.QJSManagedValue.hasProperty(self,name:QString)->bool",
    "0:PySide6.QtQml.QJSManagedValue.hasProperty(self,arrayIndex:quint32)->bool",
    "PySide6.QtQml.QJSManagedValue.isArray(self)->bool",
    "PySide6.QtQml.QJSManagedValue.isBoolean(self)->bool",
    "PySide6.QtQml.QJSManagedValue.isDate(self)->bool",
    "PySide6.QtQml.QJSManagedValue.isError(self)->bool",
    "PySide6.QtQml.QJSManagedValue.isFunction(self)->bool",
    "PySide6.QtQml.QJSManagedValue.isInteger(self)->bool",
    "PySide6.QtQml.QJSManagedValue.isJsMetaType(self)->bool",
    "PySide6.QtQml.QJSManagedValue.isNull(self)->bool",
    "PySide6.QtQml.QJSManagedValue.isNumber(self)->bool",
    "PySide6.QtQml.QJSManagedValue.isObject(self)->bool",
    "PySide6.QtQml.QJSManagedValue.isQMetaObject(self)->bool",
    "PySide6.QtQml.QJSManagedValue.isQObject(self)->bool",
    "PySide6.QtQml.QJSManagedValue.isRegularExpression(self)->bool",
    "PySide6.QtQml.QJSManagedValue.isString(self)->bool",
    "PySide6.QtQml.QJSManagedValue.isSymbol(self)->bool",
    "PySide6.QtQml.QJSManagedValue.isUndefined(self)->bool",
    "PySide6.QtQml.QJSManagedValue.isUrl(self)->bool",
    "PySide6.QtQml.QJSManagedValue.isVariant(self)->bool",
    "PySide6.QtQml.QJSManagedValue.jsMetaInstantiate(self,values:QList[PySide6.QtQml.QJSValue]={})->PySide6.QtQml.QJSManagedValue",
    "PySide6.QtQml.QJSManagedValue.jsMetaMembers(self)->QStringList",
    "PySide6.QtQml.QJSManagedValue.jsMetaType(self)->PySide6.QtQml.QJSManagedValue",
    "1:PySide6.QtQml.QJSManagedValue.property(self,name:QString)->PySide6.QtQml.QJSValue",
    "0:PySide6.QtQml.QJSManagedValue.property(self,arrayIndex:quint32)->PySide6.QtQml.QJSValue",
    "PySide6.QtQml.QJSManagedValue.prototype(self)->PySide6.QtQml.QJSManagedValue",
    "1:PySide6.QtQml.QJSManagedValue.setProperty(self,name:QString,value:typing.Union[PySide6.QtQml.QJSValue, PySide6.QtQml.QJSValue.SpecialValue, bool, QLatin1String, QString, char*, double, int, uint])",
    "0:PySide6.QtQml.QJSManagedValue.setProperty(self,arrayIndex:quint32,value:typing.Union[PySide6.QtQml.QJSValue, PySide6.QtQml.QJSValue.SpecialValue, bool, QLatin1String, QString, char*, double, int, uint])",
    "PySide6.QtQml.QJSManagedValue.setPrototype(self,prototype:PySide6.QtQml.QJSManagedValue)",
    "PySide6.QtQml.QJSManagedValue.strictlyEquals(self,other:PySide6.QtQml.QJSManagedValue)->bool",
    "PySide6.QtQml.QJSManagedValue.toBoolean(self)->bool",
    "PySide6.QtQml.QJSManagedValue.toDateTime(self)->PySide6.QtCore.QDateTime",
    "PySide6.QtQml.QJSManagedValue.toInteger(self)->int",
    "PySide6.QtQml.QJSManagedValue.toJSValue(self)->PySide6.QtQml.QJSValue",
    "PySide6.QtQml.QJSManagedValue.toNumber(self)->double",
    "PySide6.QtQml.QJSManagedValue.toPrimitive(self)->PySide6.QtQml.QJSPrimitiveValue",
    "PySide6.QtQml.QJSManagedValue.toQMetaObject(self)->PySide6.QtCore.QMetaObject",
    "PySide6.QtQml.QJSManagedValue.toQObject(self)->PySide6.QtCore.QObject",
    "PySide6.QtQml.QJSManagedValue.toRegularExpression(self)->PySide6.QtCore.QRegularExpression",
    "PySide6.QtQml.QJSManagedValue.toString(self)->QString",
    "PySide6.QtQml.QJSManagedValue.toUrl(self)->PySide6.QtCore.QUrl",
    "PySide6.QtQml.QJSManagedValue.toVariant(self)->QVariant",
    "PySide6.QtQml.QJSManagedValue.type(self)->PySide6.QtQml.QJSManagedValue.Type",
    nullptr}; // Sentinel
#else
static constexpr size_t QJSManagedValue_SignatureByteSize = 680;
static constexpr uint8_t QJSManagedValue_SignatureBytes[680] = {
    0x78, 0xda, 0xcd, 0x57, 0xc9, 0x6e, 0xdb, 0x30, 0x10, 0xbd, 0xe7, 0x2b, 0x7c, 0xac, 0x0b, 0x55,
    0xc8, 0x52, 0xf4, 0x60, 0xa0, 0x05, 0xd2, 0xd4, 0x05, 0x1c, 0xc4, 0x8d, 0x55, 0x27, 0xe9, 0xa1,
    0xc8, 0x81, 0x96, 0x26, 0x32, 0x03, 0x89, 0x54, 0xc8, 0x51, 0x1a, 0x21, 0xe8, 0xbf, 0x97, 0x32,
    0x25, 0xd7, 0x8b, 0x24, 0x92, 0xae, 0x51, 0xf8, 0x62, 0xc8, 0x12, 0xdf, 0x9b, 0x37, 0xc3, 0x59,
    0xc8, 0xf7, 0x83, 0x49, 0x31, 0xa5, 0x11, 0x7c, 0xf0, 0x03, 0x0c, 0xd2, 0xc4, 0x0f, 0x2e, 0xa7,
    0x63, 0xc2, 0x48, 0x0c, 0xd1, 0x1d, 0x49, 0x72, 0x78, 0x23, 0x21, 0x79, 0xe8, 0x1f, 0x9d, 0x59,
    0xac, 0xf2, 0x9e, 0xcb, 0xc7, 0x01, 0x16, 0x19, 0x65, 0xb1, 0x7f, 0xcb, 0x28, 0x67, 0x3f, 0xb7,
    0x50, 0x8b, 0xe5, 0x5e, 0xaf, 0xf9, 0xbd, 0x3f, 0xcd, 0x20, 0xa4, 0x24, 0xa9, 0x16, 0xcd, 0x38,
    0x4f, 0xbc, 0x5e, 0x70, 0x45, 0x90, 0xb2, 0x93, 0x29, 0x0a, 0x45, 0xab, 0xfe, 0xd6, 0x0f, 0xe1,
    0x9c, 0x88, 0xb7, 0x5e, 0x2f, 0xe2, 0xf9, 0x2c, 0x51, 0x8b, 0x29, 0x43, 0xaf, 0x97, 0xab, 0xdf,
    0x7b, 0x0f, 0x58, 0x4c, 0x19, 0x6c, 0x2b, 0x1e, 0x2e, 0xde, 0xf7, 0x8f, 0x4e, 0xf7, 0xe5, 0xcc,
    0x44, 0xd0, 0x94, 0x22, 0x7d, 0x86, 0x4a, 0xf0, 0x52, 0x9b, 0x56, 0xbe, 0x22, 0xcd, 0x2c, 0xea,
    0xc4, 0x46, 0x94, 0x5c, 0xf0, 0x0f, 0x6a, 0x3b, 0x26, 0xce, 0x63, 0x3b, 0x47, 0x05, 0x25, 0x0c,
    0x07, 0xc1, 0x9d, 0x7e, 0x30, 0xb2, 0x76, 0x72, 0xfa, 0x21, 0x49, 0x12, 0x4d, 0x4c, 0x44, 0x9c,
    0xa7, 0xc0, 0x50, 0x0e, 0x82, 0x2b, 0x2a, 0xb1, 0x25, 0x17, 0xee, 0x3f, 0xbe, 0xfe, 0xee, 0xbf,
    0xfb, 0xd4, 0xfc, 0xd1, 0xc2, 0xd6, 0xb9, 0xbc, 0xe0, 0x4c, 0xc5, 0x25, 0x0f, 0x91, 0x8b, 0xff,
    0x69, 0xf8, 0x07, 0xc5, 0xf9, 0x48, 0x59, 0x26, 0x2c, 0xac, 0x22, 0x49, 0xab, 0x7f, 0x07, 0x50,
    0x02, 0xfb, 0x08, 0x81, 0x21, 0x23, 0xfd, 0x08, 0x12, 0x40, 0x98, 0x08, 0x9e, 0x81, 0xc0, 0x42,
    0x87, 0x80, 0x91, 0x14, 0xea, 0xf4, 0x54, 0xcc, 0xa5, 0x7c, 0x53, 0x16, 0x36, 0xf2, 0x10, 0x21,
    0x48, 0x31, 0x62, 0x11, 0xbc, 0x0c, 0x9e, 0x4a, 0x8f, 0xce, 0x4e, 0x6b, 0xb6, 0x6e, 0x2e, 0x9d,
    0xbb, 0xba, 0x69, 0x35, 0x38, 0xa6, 0x53, 0xd8, 0xc4, 0xf1, 0x94, 0x93, 0x44, 0x6a, 0x1d, 0x1c,
    0xe7, 0x20, 0xba, 0xf5, 0xd7, 0xc2, 0x4c, 0xe1, 0x9a, 0x13, 0x79, 0xfd, 0x8b, 0xfd, 0x7b, 0xb8,
    0x9a, 0x78, 0xda, 0xc3, 0x65, 0xa1, 0x6a, 0x2f, 0x92, 0xf6, 0xb3, 0x7d, 0x54, 0x9e, 0x97, 0xc8,
    0x7a, 0xff, 0xac, 0x10, 0x9f, 0xd5, 0x22, 0x20, 0xcc, 0x09, 0xf3, 0x85, 0x20, 0x38, 0x01, 0x86,
    0x42, 0x54, 0xdd, 0xc5, 0x16, 0xf1, 0x35, 0x67, 0x21, 0xaa, 0xfa, 0x77, 0x02, 0x8d, 0x18, 0x42,
    0x0c, 0x6e, 0x86, 0x2e, 0xe5, 0x18, 0x90, 0xdc, 0x14, 0x99, 0x9b, 0x47, 0xdf, 0xf2, 0xaa, 0x4f,
    0xdb, 0x03, 0xd2, 0x99, 0xa3, 0xb4, 0xeb, 0xd9, 0x23, 0x84, 0xe8, 0x04, 0x09, 0x4a, 0x67, 0x76,
    0xc1, 0xed, 0x80, 0xf9, 0x0e, 0x71, 0x9e, 0x10, 0x31, 0x7c, 0xc9, 0x04, 0x48, 0xe9, 0xba, 0x57,
    0xba, 0x44, 0xdc, 0x20, 0x45, 0x3a, 0xe3, 0x6e, 0x51, 0xbf, 0x55, 0x45, 0xf4, 0xa0, 0x7a, 0x56,
    0xe4, 0x86, 0x12, 0x6e, 0x56, 0xaa, 0xd1, 0xef, 0x80, 0x79, 0x5c, 0x64, 0x9d, 0x9e, 0x7f, 0x48,
    0xeb, 0x72, 0xd2, 0xa7, 0xa6, 0xdd, 0x86, 0xce, 0x2a, 0xbd, 0x95, 0xf1, 0x31, 0x94, 0x09, 0x29,
    0x6b, 0xd1, 0x55, 0xcf, 0x2a, 0x2d, 0x5b, 0xc1, 0x57, 0x2b, 0xa6, 0x5b, 0x8c, 0xa9, 0x87, 0x66,
    0x5d, 0x0d, 0xb4, 0x65, 0xb8, 0x1e, 0x3b, 0x71, 0x36, 0xf6, 0xd3, 0x9d, 0x4e, 0x2e, 0x8a, 0x17,
    0x39, 0xee, 0xcd, 0x75, 0x09, 0xd8, 0x3e, 0x3e, 0x0e, 0xe5, 0x42, 0x60, 0x3c, 0x08, 0x6f, 0xbb,
    0xb1, 0x1d, 0xf0, 0xc3, 0x71, 0xc6, 0xc6, 0x95, 0x95, 0x3d, 0xf6, 0x96, 0x5b, 0x6e, 0x38, 0xc7,
    0x98, 0x88, 0x95, 0xb2, 0x10, 0x93, 0x62, 0xb8, 0xdb, 0xf1, 0xa8, 0x9b, 0x1c, 0xb9, 0xfb, 0x18,
    0x47, 0x5e, 0x8e, 0xf1, 0x1b, 0x9a, 0x36, 0xe4, 0xf2, 0x05, 0x17, 0xe0, 0x07, 0xf5, 0x77, 0x23,
    0xd1, 0xc6, 0xdc, 0x55, 0x71, 0x36, 0x42, 0xaa, 0x4d, 0x6d, 0x2d, 0x23, 0x9b, 0x62, 0x44, 0xbe,
    0x3e, 0x54, 0xf5, 0x6e, 0x1b, 0x41, 0xcb, 0x6b, 0x67, 0xab, 0xf1, 0xf5, 0x8b, 0xa9, 0x91, 0xb0,
    0x61, 0xe8, 0x6e, 0x86, 0xf2, 0xef, 0x0a, 0x33, 0x5b, 0x37, 0x93, 0x25, 0x4b, 0xeb, 0x70, 0xde,
    0xe4, 0xdb, 0x5a, 0x68, 0xa4, 0x5e, 0x9f, 0xdc, 0x55, 0xc9, 0x19, 0x51, 0x2b, 0x33, 0x75, 0x53,
    0x82, 0xfa, 0x64, 0x84, 0x6f, 0x8c, 0xd8, 0xfa, 0xb6, 0x6d, 0xc2, 0xd9, 0x76, 0x6a, 0xbf, 0x1c,
    0x67, 0x47, 0x7f, 0x00, 0xe2, 0x84, 0x4c, 0xd3
};
#endif

PyTypeObject *init_QJSManagedValue(PyObject *module)
{
    if (SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX].type != nullptr)
        return SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX].type;

    Shiboken::AutoDecRef Sbk_QJSManagedValue_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QJSManagedValue_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QJSManagedValue",
        "QJSManagedValue*",
        &Sbk_QJSManagedValue_spec,
        &Shiboken::callCppDestructor< ::QJSManagedValue >,
        Sbk_QJSManagedValue_Type_bases.object(),
        0);
    auto *pyType = Sbk_QJSManagedValue_TypeF(); // references _Sbk_QJSManagedValue_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QJSManagedValue_SignatureStrings);
#else
    InitSignatureBytes(pyType, QJSManagedValue_SignatureBytes, QJSManagedValue_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QJSManagedValue_PropertyStrings);
    SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QJSManagedValue_PythonToCpp_QJSManagedValue_PTR,
        is_QJSManagedValue_PythonToCpp_QJSManagedValue_PTR_Convertible,
        QJSManagedValue_PTR_CppToPython_QJSManagedValue);

    Shiboken::Conversions::registerConverterName(converter, "QJSManagedValue");
    Shiboken::Conversions::registerConverterName(converter, "QJSManagedValue*");
    Shiboken::Conversions::registerConverterName(converter, "QJSManagedValue&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QJSManagedValue).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QJSManagedValue_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Type'.
    const char *Type_Initializer[] = {
        "Undefined",
        "Boolean",
        "Number",
        "String",
        "Object",
        "Symbol",
        "Function",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Type_InitializerValues[] = {
        uint8_t(QJSManagedValue::Type::Undefined), //  0x00  0
        uint8_t(QJSManagedValue::Type::Boolean),   //  0x01  1
        uint8_t(QJSManagedValue::Type::Number),    //  0x02  2
        uint8_t(QJSManagedValue::Type::String),    //  0x03  3
        uint8_t(QJSManagedValue::Type::Object),    //  0x04  4
        uint8_t(QJSManagedValue::Type::Symbol),    //  0x05  5
        uint8_t(QJSManagedValue::Type::Function)   //  0x06  6
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QJSManagedValue_TypeF(),
        "2:PySide6.QtQml.QJSManagedValue.Type",
        Type_Initializer, Type_InitializerValues);
    SbkPySide6_QtQmlTypeStructs[SBK_QJSManagedValue_Type_IDX].type = EType;
    // Register converter for enum 'QJSManagedValue::Type'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QJSManagedValue_Type_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QJSManagedValue_Type,
            is_Enum_PythonToCpp_QJSManagedValue_Type_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QJSManagedValue::Type");
        Shiboken::Conversions::registerConverterAlias(converter, "Type");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Type' enum.

    qRegisterMetaType< ::QJSManagedValue *>();
    qRegisterMetaType< ::QJSManagedValue::Type >("QJSManagedValue::Type");

    return pyType;
}
