// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtqml_python.h"

// main header
#include "qjsvalueiterator_wrapper.h"

// Argument includes
#include <QString>
#include <QtQml/qjsvalue.h>
#include <QtQml/qjsvalueiterator.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QJSValueIterator_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QJSValueIterator >()))
        return -1;

    ::QJSValueIterator *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QJSValueIterator", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QJSValueIterator::QJSValueIterator(QJSValue)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QJSValueIterator(QJSValue)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSValueIterator_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtQmlTypeStructs[SBK_QJSValueIterator_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QJSValue cppArg0_local;
        ::QJSValue *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // QJSValueIterator(QJSValue)
            cptr = new ::QJSValueIterator(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QJSValueIterator >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSValueIterator_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QJSValueIteratorFunc_hasNext(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSValueIterator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValueIterator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hasNext()const
        bool cppResult = const_cast<const ::QJSValueIterator *>(cppSelf)->hasNext();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSValueIteratorFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSValueIterator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValueIterator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // name()const
        QString cppResult = const_cast<const ::QJSValueIterator *>(cppSelf)->name();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSValueIteratorFunc_next(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSValueIterator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValueIterator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // next()
        bool cppResult = cppSelf->next();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSValueIteratorFunc_value(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSValueIterator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValueIterator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // value()const
        QJSValue cppResult = const_cast<const ::QJSValueIterator *>(cppSelf)->value();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QJSValueIterator_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QJSValueIterator_methods[] = {
    {"hasNext", reinterpret_cast<PyCFunction>(Sbk_QJSValueIteratorFunc_hasNext), METH_NOARGS, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_QJSValueIteratorFunc_name), METH_NOARGS, nullptr},
    {"next", reinterpret_cast<PyCFunction>(Sbk_QJSValueIteratorFunc_next), METH_NOARGS, nullptr},
    {"value", reinterpret_cast<PyCFunction>(Sbk_QJSValueIteratorFunc_value), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QJSValueIterator_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QJSValueIterator_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QJSValueIterator_Type = nullptr;
static PyTypeObject *Sbk_QJSValueIterator_TypeF(void)
{
    return _Sbk_QJSValueIterator_Type;
}

static PyType_Slot Sbk_QJSValueIterator_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QJSValueIterator_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QJSValueIterator_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QJSValueIterator_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QJSValueIterator_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QJSValueIterator_spec = {
    "2:PySide6.QtQml.QJSValueIterator",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QJSValueIterator_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QJSValueIterator_PythonToCpp_QJSValueIterator_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QJSValueIterator_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QJSValueIterator_PythonToCpp_QJSValueIterator_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QJSValueIterator_TypeF()))
        return QJSValueIterator_PythonToCpp_QJSValueIterator_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QJSValueIterator_PTR_CppToPython_QJSValueIterator(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QJSValueIterator_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QJSValueIterator_SignatureStrings[] = {
    "PySide6.QtQml.QJSValueIterator(self,value:typing.Union[PySide6.QtQml.QJSValue, PySide6.QtQml.QJSValue.SpecialValue, bool, QLatin1String, QString, char*, double, int, uint])",
    "PySide6.QtQml.QJSValueIterator.hasNext(self)->bool",
    "PySide6.QtQml.QJSValueIterator.name(self)->QString",
    "PySide6.QtQml.QJSValueIterator.next(self)->bool",
    "PySide6.QtQml.QJSValueIterator.value(self)->PySide6.QtQml.QJSValue",
    nullptr}; // Sentinel
#else
static constexpr size_t QJSValueIterator_SignatureByteSize = 166;
static constexpr uint8_t QJSValueIterator_SignatureBytes[166] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x09, 0xcc, 0xcd, 0xd1,
    0x0b, 0xf4, 0x0a, 0x0e, 0x4b, 0xcc, 0x29, 0x4d, 0xf5, 0x2c, 0x49, 0x2d, 0x4a, 0x2c, 0xc9, 0x2f,
    0xd2, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0x29, 0x03, 0x09, 0x59, 0x95, 0x54, 0x16, 0x64, 0xe6, 0xa5,
    0xeb, 0x85, 0xe6, 0x65, 0xe6, 0xe7, 0x45, 0x07, 0x60, 0xd5, 0xa6, 0xa3, 0x80, 0x5d, 0x5c, 0x2f,
    0xb8, 0x20, 0x35, 0x39, 0x33, 0x31, 0x07, 0xaa, 0x28, 0x29, 0x3f, 0x3f, 0x47, 0x47, 0x21, 0xd0,
    0x27, 0xb1, 0x24, 0x33, 0xcf, 0x30, 0xb8, 0xa4, 0x08, 0x68, 0x2c, 0x90, 0x0b, 0x63, 0x24, 0x67,
    0x24, 0x16, 0x69, 0xe9, 0x28, 0xa4, 0xe4, 0x97, 0x26, 0xe5, 0x00, 0x15, 0x67, 0xe6, 0x95, 0xe8,
    0x28, 0x94, 0x02, 0xc9, 0x58, 0x4d, 0xae, 0x00, 0xbc, 0x8e, 0xd5, 0xcb, 0x48, 0x2c, 0xf6, 0x4b,
    0xad, 0x28, 0x01, 0x3b, 0x5a, 0x53, 0xd7, 0x0e, 0x64, 0x0d, 0x21, 0x2d, 0x79, 0x89, 0xb9, 0xa9,
    0x30, 0xf5, 0x50, 0x17, 0x10, 0xd4, 0x42, 0xa2, 0x15, 0xe0, 0xd0, 0x83, 0x69, 0xc0, 0xae, 0x96,
    0x0b, 0x00, 0x47, 0x4b, 0x89, 0x44
};
#endif

PyTypeObject *init_QJSValueIterator(PyObject *module)
{
    if (SbkPySide6_QtQmlTypeStructs[SBK_QJSValueIterator_IDX].type != nullptr)
        return SbkPySide6_QtQmlTypeStructs[SBK_QJSValueIterator_IDX].type;

    Shiboken::AutoDecRef Sbk_QJSValueIterator_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QJSValueIterator_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QJSValueIterator",
        "QJSValueIterator*",
        &Sbk_QJSValueIterator_spec,
        &Shiboken::callCppDestructor< ::QJSValueIterator >,
        Sbk_QJSValueIterator_Type_bases.object(),
        0);
    auto *pyType = Sbk_QJSValueIterator_TypeF(); // references _Sbk_QJSValueIterator_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QJSValueIterator_SignatureStrings);
#else
    InitSignatureBytes(pyType, QJSValueIterator_SignatureBytes, QJSValueIterator_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QJSValueIterator_PropertyStrings);
    SbkPySide6_QtQmlTypeStructs[SBK_QJSValueIterator_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QJSValueIterator_PythonToCpp_QJSValueIterator_PTR,
        is_QJSValueIterator_PythonToCpp_QJSValueIterator_PTR_Convertible,
        QJSValueIterator_PTR_CppToPython_QJSValueIterator);

    Shiboken::Conversions::registerConverterName(converter, "QJSValueIterator");
    Shiboken::Conversions::registerConverterName(converter, "QJSValueIterator*");
    Shiboken::Conversions::registerConverterName(converter, "QJSValueIterator&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QJSValueIterator).name());

    qRegisterMetaType< ::QJSValueIterator *>();

    return pyType;
}
