// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtqml_python.h"

// main header
#include "qqmlabstracturlinterceptor_wrapper.h"

// Argument includes
#include <QtQml/qqmlabstracturlinterceptor.h>
#include <qurl.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QQmlAbstractUrlInterceptorWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QQmlAbstractUrlInterceptorWrapper::QQmlAbstractUrlInterceptorWrapper()
{
}

::QUrl QQmlAbstractUrlInterceptorWrapper::intercept(const ::QUrl & path, ::QQmlAbstractUrlInterceptor::DataType type)
{
    if (m_PyMethodCache[0]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QQmlAbstractUrlInterceptor.intercept");
        return {};
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return {};
    static PyObject *nameCache[2] = {};
    static const char *funcName = "intercept";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        Shiboken::Errors::setPureVirtualMethodError("QQmlAbstractUrlInterceptor.intercept");
        return {};
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &path),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlAbstractUrlInterceptor_DataType_IDX])))->converter, &type)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &path),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlAbstractUrlInterceptor_DataType_IDX])))->converter, &type)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQmlAbstractUrlInterceptor", funcName);
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QQmlAbstractUrlInterceptor", funcName, Shiboken::SbkType< QUrl >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QUrl cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QQmlAbstractUrlInterceptorWrapper::~QQmlAbstractUrlInterceptorWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QQmlAbstractUrlInterceptor_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlAbstractUrlInterceptor_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QQmlAbstractUrlInterceptor");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QQmlAbstractUrlInterceptor >()))
        return -1;

    QQmlAbstractUrlInterceptorWrapper *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtQmlTypeStructs[SBK_QQmlAbstractUrlInterceptor_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QQmlAbstractUrlInterceptor()
        cptr = new QQmlAbstractUrlInterceptorWrapper();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QQmlAbstractUrlInterceptor >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QQmlAbstractUrlInterceptorFunc_intercept(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlAbstractUrlInterceptor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlAbstractUrlInterceptor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "intercept", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QQmlAbstractUrlInterceptor::intercept(QUrl,QQmlAbstractUrlInterceptor::DataType)->QUrl
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlAbstractUrlInterceptor_DataType_IDX])))->converter, (pyArgs[1])))) {
        overloadId = 0; // intercept(QUrl,QQmlAbstractUrlInterceptor::DataType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "intercept", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlAbstractUrlInterceptor_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QQmlAbstractUrlInterceptor::DataType cppArg1{QQmlAbstractUrlInterceptor::QmlFile};
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // intercept(QUrl,QQmlAbstractUrlInterceptor::DataType)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QQmlAbstractUrlInterceptor.intercept");
                return {};
            }
            QUrl cppResult = cppSelf->intercept(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QQmlAbstractUrlInterceptor_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QQmlAbstractUrlInterceptor_EnumFlagInfo[] = {
    "DataType:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QQmlAbstractUrlInterceptor_methods[] = {
    {"intercept", reinterpret_cast<PyCFunction>(Sbk_QQmlAbstractUrlInterceptorFunc_intercept), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QQmlAbstractUrlInterceptor_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QQmlAbstractUrlInterceptor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlAbstractUrlInterceptor_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QQmlAbstractUrlInterceptorWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QQmlAbstractUrlInterceptor_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QQmlAbstractUrlInterceptor_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QQmlAbstractUrlInterceptor_Type = nullptr;
static PyTypeObject *Sbk_QQmlAbstractUrlInterceptor_TypeF(void)
{
    return _Sbk_QQmlAbstractUrlInterceptor_Type;
}

static PyType_Slot Sbk_QQmlAbstractUrlInterceptor_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QQmlAbstractUrlInterceptor_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QQmlAbstractUrlInterceptor_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QQmlAbstractUrlInterceptor_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QQmlAbstractUrlInterceptor_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QQmlAbstractUrlInterceptor_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QQmlAbstractUrlInterceptor_spec = {
    "2:PySide6.QtQml.QQmlAbstractUrlInterceptor",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QQmlAbstractUrlInterceptor_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QQmlAbstractUrlInterceptor_DataType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QQmlAbstractUrlInterceptor::DataType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QQmlAbstractUrlInterceptor::DataType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QQmlAbstractUrlInterceptor_DataType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlAbstractUrlInterceptor_DataType_IDX])))
        return Enum_PythonToCpp_QQmlAbstractUrlInterceptor_DataType;
    return {};
}

static PyObject *QQmlAbstractUrlInterceptor_DataType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QQmlAbstractUrlInterceptor::DataType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QQmlAbstractUrlInterceptor::DataType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlAbstractUrlInterceptor_DataType_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QQmlAbstractUrlInterceptor_PythonToCpp_QQmlAbstractUrlInterceptor_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QQmlAbstractUrlInterceptor_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QQmlAbstractUrlInterceptor_PythonToCpp_QQmlAbstractUrlInterceptor_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QQmlAbstractUrlInterceptor_TypeF()))
        return QQmlAbstractUrlInterceptor_PythonToCpp_QQmlAbstractUrlInterceptor_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QQmlAbstractUrlInterceptor_PTR_CppToPython_QQmlAbstractUrlInterceptor(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QQmlAbstractUrlInterceptor *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QQmlAbstractUrlInterceptor_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QQmlAbstractUrlInterceptor_SignatureStrings[] = {
    "PySide6.QtQml.QQmlAbstractUrlInterceptor(self)",
    "PySide6.QtQml.QQmlAbstractUrlInterceptor.intercept(self,path:typing.Union[PySide6.QtCore.QUrl, QString],type:PySide6.QtQml.QQmlAbstractUrlInterceptor.DataType)->PySide6.QtCore.QUrl",
    nullptr}; // Sentinel
#else
static constexpr size_t QQmlAbstractUrlInterceptor_SignatureByteSize = 121;
static constexpr uint8_t QQmlAbstractUrlInterceptor_SignatureBytes[121] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x09, 0xcc, 0xcd, 0xd1,
    0x0b, 0x04, 0x12, 0x8e, 0x49, 0xc5, 0x25, 0x45, 0x89, 0xc9, 0x25, 0xa1, 0x45, 0x39, 0x9e, 0x79,
    0x25, 0xa9, 0x45, 0xc9, 0xa9, 0x05, 0x25, 0xf9, 0x45, 0x1a, 0xc5, 0xa9, 0x39, 0x69, 0x9a, 0x5c,
    0x01, 0x44, 0x2a, 0xd7, 0xcb, 0x84, 0xb1, 0xc1, 0x1a, 0x75, 0x0a, 0x12, 0x4b, 0x32, 0xac, 0x4a,
    0x2a, 0x0b, 0x32, 0xf3, 0xd2, 0xf5, 0x42, 0xf3, 0x32, 0xf3, 0xf3, 0xa2, 0x11, 0x26, 0x39, 0xe7,
    0x17, 0xa5, 0xea, 0x05, 0x02, 0xf5, 0xeb, 0x28, 0x04, 0x06, 0x97, 0x14, 0x01, 0x95, 0xc4, 0xea,
    0x00, 0x95, 0xa6, 0x5a, 0x11, 0x6d, 0x99, 0x4b, 0x62, 0x49, 0x62, 0x08, 0x50, 0x87, 0xa6, 0xae,
    0x1d, 0x16, 0x63, 0xb9, 0x00, 0xd3, 0x8e, 0x53, 0xb9
};
#endif

PyTypeObject *init_QQmlAbstractUrlInterceptor(PyObject *module)
{
    if (SbkPySide6_QtQmlTypeStructs[SBK_QQmlAbstractUrlInterceptor_IDX].type != nullptr)
        return SbkPySide6_QtQmlTypeStructs[SBK_QQmlAbstractUrlInterceptor_IDX].type;

    Shiboken::AutoDecRef Sbk_QQmlAbstractUrlInterceptor_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QQmlAbstractUrlInterceptor_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QQmlAbstractUrlInterceptor",
        "QQmlAbstractUrlInterceptor*",
        &Sbk_QQmlAbstractUrlInterceptor_spec,
        &Shiboken::callCppDestructor< QQmlAbstractUrlInterceptor >,
        Sbk_QQmlAbstractUrlInterceptor_Type_bases.object(),
        0);
    auto *pyType = Sbk_QQmlAbstractUrlInterceptor_TypeF(); // references _Sbk_QQmlAbstractUrlInterceptor_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QQmlAbstractUrlInterceptor_SignatureStrings);
#else
    InitSignatureBytes(pyType, QQmlAbstractUrlInterceptor_SignatureBytes, QQmlAbstractUrlInterceptor_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QQmlAbstractUrlInterceptor_PropertyStrings);
    SbkPySide6_QtQmlTypeStructs[SBK_QQmlAbstractUrlInterceptor_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QQmlAbstractUrlInterceptor_PythonToCpp_QQmlAbstractUrlInterceptor_PTR,
        is_QQmlAbstractUrlInterceptor_PythonToCpp_QQmlAbstractUrlInterceptor_PTR_Convertible,
        QQmlAbstractUrlInterceptor_PTR_CppToPython_QQmlAbstractUrlInterceptor);

    Shiboken::Conversions::registerConverterName(converter, "QQmlAbstractUrlInterceptor");
    Shiboken::Conversions::registerConverterName(converter, "QQmlAbstractUrlInterceptor*");
    Shiboken::Conversions::registerConverterName(converter, "QQmlAbstractUrlInterceptor&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QQmlAbstractUrlInterceptor).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QQmlAbstractUrlInterceptorWrapper).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QQmlAbstractUrlInterceptor_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'DataType'.
    const char *DataType_Initializer[] = {
        "QmlFile",
        "JavaScriptFile",
        "QmldirFile",
        "UrlString",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t DataType_InitializerValues[] = {
        uint16_t(QQmlAbstractUrlInterceptor::DataType::QmlFile),        //  0x0000  0
        uint16_t(QQmlAbstractUrlInterceptor::DataType::JavaScriptFile), //  0x0001  1
        uint16_t(QQmlAbstractUrlInterceptor::DataType::QmldirFile),     //  0x0002  2
        uint16_t(QQmlAbstractUrlInterceptor::DataType::UrlString)       //  0x1000  4096
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QQmlAbstractUrlInterceptor_TypeF(),
        "2:PySide6.QtQml.QQmlAbstractUrlInterceptor.DataType",
        DataType_Initializer, DataType_InitializerValues);
    SbkPySide6_QtQmlTypeStructs[SBK_QQmlAbstractUrlInterceptor_DataType_IDX].type = EType;
    // Register converter for enum 'QQmlAbstractUrlInterceptor::DataType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QQmlAbstractUrlInterceptor_DataType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QQmlAbstractUrlInterceptor_DataType,
            is_Enum_PythonToCpp_QQmlAbstractUrlInterceptor_DataType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QQmlAbstractUrlInterceptor::DataType");
        Shiboken::Conversions::registerConverterAlias(converter, "DataType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'DataType' enum.

    qRegisterMetaType< ::QQmlAbstractUrlInterceptor *>();
    qRegisterMetaType< ::QQmlAbstractUrlInterceptor::DataType >("QQmlAbstractUrlInterceptor::DataType");

    return pyType;
}
