// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtqml_python.h"

// main header
#include "qqmlengine_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QStringList>
#include <QtNetwork/qnetworkaccessmanager.h>
#include <QtQml/qjsengine.h>
#include <QtQml/qjsmanagedvalue.h>
#include <QtQml/qjsprimitivevalue.h>
#include <QtQml/qjsvalue.h>
#include <QtQml/qqmlabstracturlinterceptor.h>
#include <QtQml/qqmlcontext.h>
#include <QtQml/qqmlengine.h>
#include <QtQml/qqmlerror.h>
#include <QtQml/qqmlincubator.h>
#include <QtQml/qqmlnetworkaccessmanagerfactory.h>
#include <qcoreevent.h>
#include <qdatetime.h>
#include <qmetaobject.h>
#include <qmetatype.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qurl.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QQmlEngineWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QQmlEngineWrapper::QQmlEngineWrapper(::QObject * p) : QQmlEngine(p)
{
}

void QQmlEngineWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQmlEngine", funcName);
        return;
    }
}

void QQmlEngineWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQmlEngine", funcName);
        return;
    }
}

void QQmlEngineWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQmlEngine", funcName);
        return;
    }
}

void QQmlEngineWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQmlEngine", funcName);
        return;
    }
}

bool QQmlEngineWrapper::event(::QEvent * arg__1)
{
    if (m_PyMethodCache[4])
        return this->::QQmlEngine::event(arg__1);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QQmlEngine::event(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), arg__1)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), arg__1)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQmlEngine", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QQmlEngine", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QQmlEngineWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQmlEngine", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QQmlEngine", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QQmlEngineWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQmlEngine", funcName);
        return;
    }
}

const QMetaObject *QQmlEngineWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QQmlEngine::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QQmlEngineWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QQmlEngine::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QQmlEngineWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QQmlEngineWrapper *>(this));
    return QQmlEngine::qt_metacast(_clname);
}

QQmlEngineWrapper::~QQmlEngineWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QQmlEngine_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QQmlEngine >()))
        return -1;

    QQmlEngineWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QQmlEngine", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QQmlEngine::QQmlEngine(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QQmlEngine(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QQmlEngine(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_p = Shiboken::String::createStaticString("p");
            if (PyDict_Contains(kwds, key_p) != 0) {
                value = PyDict_GetItem(kwds, key_p);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_p);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_p);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                // fall through to handle extra keyword signals and properties
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QQmlEngine(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QQmlEngineWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QQmlEngineWrapper(cppArg0);
            }

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QQmlEngine >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QQmlEngineFunc_addImageProvider(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "addImageProvider", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QQmlEngine::addImageProvider(QString,QQmlImageProviderBase*)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlImageProviderBase_IDX]), (pyArgs[1])))) {
        overloadId = 0; // addImageProvider(QString,QQmlImageProviderBase*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addImageProvider", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QQmlImageProviderBase *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addImageProvider(QString,QQmlImageProviderBase*)
            cppSelf->addImageProvider(cppArg0, cppArg1);

            // Ownership transferences.
            Shiboken::Object::releaseOwnership(pyArgs[1]);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQmlEngineFunc_addImportPath(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQmlEngine::addImportPath(PyPathLike)
    if (Shiboken::String::checkPath(pyArg)) {
        overloadId = 0; // addImportPath(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addImportPath", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]);

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // addImportPath(QString)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qfile-path-1)]
            auto cppArg0 = PySide::pyPathToQString(pyArg);
            // END of custom code block [file: ../glue/qtcore.cpp (qfile-path-1)]
            // ========================================================================
            // End of code injection

            cppSelf->addImportPath(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQmlEngineFunc_addNamedBundle(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "addNamedBundle", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QQmlEngine::addNamedBundle(QString,QString)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // addNamedBundle(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addNamedBundle", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]);

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QQmlEngine", "addNamedBundle(const QString &arg__1, const QString &arg__2)");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addNamedBundle(QString,QString)
            bool cppResult = cppSelf->addNamedBundle(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlEngineFunc_addPluginPath(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQmlEngine::addPluginPath(PyPathLike)
    if (Shiboken::String::checkPath(pyArg)) {
        overloadId = 0; // addPluginPath(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addPluginPath", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]);

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // addPluginPath(QString)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qfile-path-1)]
            auto cppArg0 = PySide::pyPathToQString(pyArg);
            // END of custom code block [file: ../glue/qtcore.cpp (qfile-path-1)]
            // ========================================================================
            // End of code injection

            cppSelf->addPluginPath(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQmlEngineFunc_addUrlInterceptor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQmlEngine::addUrlInterceptor(QQmlAbstractUrlInterceptor*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlAbstractUrlInterceptor_IDX]), (pyArg)))) {
        overloadId = 0; // addUrlInterceptor(QQmlAbstractUrlInterceptor*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addUrlInterceptor", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QQmlAbstractUrlInterceptor *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addUrlInterceptor(QQmlAbstractUrlInterceptor*)
            cppSelf->addUrlInterceptor(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQmlEngineFunc_baseUrl(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // baseUrl()const
        QUrl cppResult = const_cast<const ::QQmlEngine *>(cppSelf)->baseUrl();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlEngineFunc_captureProperty(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "captureProperty", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QQmlEngine::captureProperty(QObject*,QMetaProperty)const
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaProperty_IDX]), (pyArgs[1])))) {
        overloadId = 0; // captureProperty(QObject*,QMetaProperty)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "captureProperty", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QObject *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QMetaProperty cppArg1_local;
        ::QMetaProperty *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // captureProperty(QObject*,QMetaProperty)const
            const_cast<const ::QQmlEngine *>(cppSelf)->captureProperty(cppArg0, *cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQmlEngineFunc_clearComponentCache(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clearComponentCache()
        cppSelf->clearComponentCache();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQmlEngineFunc_clearSingletons(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clearSingletons()
        cppSelf->clearSingletons();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQmlEngineFunc_contextForObject(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QQmlEngine::contextForObject(const QObject*)->QQmlContext*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArg)))) {
        overloadId = 0; // contextForObject(const QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "contextForObject", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QObject *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // contextForObject(const QObject*)
            QQmlContext * cppResult = ::QQmlEngine::contextForObject(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlContext_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlEngineFunc_event(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::event(QEvent*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "event", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // event(QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QQmlEngine::event(cppArg0)
                : cppSelf->event(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlEngineFunc_imageProvider(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQmlEngine::imageProvider(QString)const->QQmlImageProviderBase*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // imageProvider(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "imageProvider", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // imageProvider(QString)const
            QQmlImageProviderBase * cppResult = const_cast<const ::QQmlEngine *>(cppSelf)->imageProvider(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlImageProviderBase_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlEngineFunc_importPathList(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // importPathList()const
        QStringList cppResult = const_cast<const ::QQmlEngine *>(cppSelf)->importPathList();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlEngineFunc_importPlugin(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "importPlugin", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QQmlEngine::importPlugin(QString,QString,QList<QQmlError>*)->bool
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtQmlTypeConverters[SBK_QtQml_QList_QQmlError_IDX], (pyArgs[2])))) {
        overloadId = 0; // importPlugin(QString,QString,QList<QQmlError>*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "importPlugin", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]);

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QQmlEngine", "importPlugin(const QString &filePath, const QString &uri, QList<QQmlError> *errors)");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QList<QQmlError> cppArg2_local;
        ::QList<QQmlError> *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2].isValue())
            pythonToCpp[2](pyArgs[2], &cppArg2_local);
        else
            pythonToCpp[2](pyArgs[2], &cppArg2);


        if (Shiboken::Errors::occurred() == nullptr) {
            // importPlugin(QString,QString,QList<QQmlError>*)
            bool cppResult = cppSelf->importPlugin(cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlEngineFunc_incubationController(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // incubationController()const
        QQmlIncubationController * cppResult = const_cast<const ::QQmlEngine *>(cppSelf)->incubationController();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlIncubationController_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlEngineFunc_interceptUrl(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "interceptUrl", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QQmlEngine::interceptUrl(QUrl,QQmlAbstractUrlInterceptor::DataType)const->QUrl
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlAbstractUrlInterceptor_DataType_IDX])))->converter, (pyArgs[1])))) {
        overloadId = 0; // interceptUrl(QUrl,QQmlAbstractUrlInterceptor::DataType)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "interceptUrl", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QQmlAbstractUrlInterceptor::DataType cppArg1{QQmlAbstractUrlInterceptor::QmlFile};
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // interceptUrl(QUrl,QQmlAbstractUrlInterceptor::DataType)const
            QUrl cppResult = const_cast<const ::QQmlEngine *>(cppSelf)->interceptUrl(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlEngineFunc_markCurrentFunctionAsTranslationBinding(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // markCurrentFunctionAsTranslationBinding()
        cppSelf->markCurrentFunctionAsTranslationBinding();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQmlEngineFunc_networkAccessManager(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // networkAccessManager()const
        QNetworkAccessManager * cppResult = const_cast<const ::QQmlEngine *>(cppSelf)->networkAccessManager();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAccessManager_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlEngineFunc_networkAccessManagerFactory(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // networkAccessManagerFactory()const
        QQmlNetworkAccessManagerFactory * cppResult = const_cast<const ::QQmlEngine *>(cppSelf)->networkAccessManagerFactory();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlNetworkAccessManagerFactory_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlEngineFunc_offlineStorageDatabaseFilePath(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQmlEngine::offlineStorageDatabaseFilePath(QString)const->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // offlineStorageDatabaseFilePath(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "offlineStorageDatabaseFilePath", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // offlineStorageDatabaseFilePath(QString)const
            QString cppResult = const_cast<const ::QQmlEngine *>(cppSelf)->offlineStorageDatabaseFilePath(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlEngineFunc_offlineStoragePath(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // offlineStoragePath()const
        QString cppResult = const_cast<const ::QQmlEngine *>(cppSelf)->offlineStoragePath();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlEngineFunc_outputWarningsToStandardError(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // outputWarningsToStandardError()const
        bool cppResult = const_cast<const ::QQmlEngine *>(cppSelf)->outputWarningsToStandardError();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlEngineFunc_pluginPathList(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pluginPathList()const
        QStringList cppResult = const_cast<const ::QQmlEngine *>(cppSelf)->pluginPathList();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlEngineFunc_removeImageProvider(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQmlEngine::removeImageProvider(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // removeImageProvider(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeImageProvider", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeImageProvider(QString)
            cppSelf->removeImageProvider(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQmlEngineFunc_removeUrlInterceptor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQmlEngine::removeUrlInterceptor(QQmlAbstractUrlInterceptor*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlAbstractUrlInterceptor_IDX]), (pyArg)))) {
        overloadId = 0; // removeUrlInterceptor(QQmlAbstractUrlInterceptor*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeUrlInterceptor", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QQmlAbstractUrlInterceptor *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeUrlInterceptor(QQmlAbstractUrlInterceptor*)
            cppSelf->removeUrlInterceptor(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQmlEngineFunc_retranslate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // retranslate()
        cppSelf->retranslate();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQmlEngineFunc_rootContext(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rootContext()const
        QQmlContext * cppResult = const_cast<const ::QQmlEngine *>(cppSelf)->rootContext();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlContext_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlEngineFunc_setBaseUrl(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQmlEngine::setBaseUrl(QUrl)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // setBaseUrl(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBaseUrl", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setBaseUrl(QUrl)
            cppSelf->setBaseUrl(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQmlEngineFunc_setContextForObject(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setContextForObject", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QQmlEngine::setContextForObject(QObject*,QQmlContext*)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlContext_IDX]), (pyArgs[1])))) {
        overloadId = 0; // setContextForObject(QObject*,QQmlContext*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setContextForObject", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QObject *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QQmlContext *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setContextForObject(QObject*,QQmlContext*)
            ::QQmlEngine::setContextForObject(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQmlEngineFunc_setImportPathList(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQmlEngine::setImportPathList(QStringList)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // setImportPathList(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setImportPathList", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setImportPathList(QStringList)
            cppSelf->setImportPathList(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQmlEngineFunc_setIncubationController(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQmlEngine::setIncubationController(QQmlIncubationController*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlIncubationController_IDX]), (pyArg)))) {
        overloadId = 0; // setIncubationController(QQmlIncubationController*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setIncubationController", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QQmlIncubationController *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setIncubationController(QQmlIncubationController*)
            cppSelf->setIncubationController(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQmlEngineFunc_setNetworkAccessManagerFactory(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQmlEngine::setNetworkAccessManagerFactory(QQmlNetworkAccessManagerFactory*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlNetworkAccessManagerFactory_IDX]), (pyArg)))) {
        overloadId = 0; // setNetworkAccessManagerFactory(QQmlNetworkAccessManagerFactory*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setNetworkAccessManagerFactory", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QQmlNetworkAccessManagerFactory *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setNetworkAccessManagerFactory(QQmlNetworkAccessManagerFactory*)
            cppSelf->setNetworkAccessManagerFactory(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQmlEngineFunc_setOfflineStoragePath(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQmlEngine::setOfflineStoragePath(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setOfflineStoragePath(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOfflineStoragePath", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOfflineStoragePath(QString)
            cppSelf->setOfflineStoragePath(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQmlEngineFunc_setOutputWarningsToStandardError(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQmlEngine::setOutputWarningsToStandardError(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setOutputWarningsToStandardError(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOutputWarningsToStandardError", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOutputWarningsToStandardError(bool)
            cppSelf->setOutputWarningsToStandardError(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQmlEngineFunc_setPluginPathList(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQmlEngine::setPluginPathList(QStringList)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // setPluginPathList(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPluginPathList", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPluginPathList(QStringList)
            cppSelf->setPluginPathList(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQmlEngineFunc_setUrlInterceptor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQmlEngine::setUrlInterceptor(QQmlAbstractUrlInterceptor*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlAbstractUrlInterceptor_IDX]), (pyArg)))) {
        overloadId = 0; // setUrlInterceptor(QQmlAbstractUrlInterceptor*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUrlInterceptor", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]);

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QQmlEngine", "setUrlInterceptor(QQmlAbstractUrlInterceptor *urlInterceptor)");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QQmlAbstractUrlInterceptor *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setUrlInterceptor(QQmlAbstractUrlInterceptor*)
            cppSelf->setUrlInterceptor(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQmlEngineFunc_singletonInstance(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "singletonInstance", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QQmlEngine::singletonInstance(QString,QString)->QObject*
    // 1: QQmlEngine::singletonInstance(int)->QObject*
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 1; // singletonInstance(int)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // singletonInstance(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "singletonInstance", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // singletonInstance(QString uri, QString typeName)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)

            if (Shiboken::Errors::occurred() == nullptr) {
                // singletonInstance(QString,QString)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtqml.cpp (qqmlengine-singletoninstance-typename)]
                QJSValue instance = cppSelf->singletonInstance<QJSValue>(cppArg0, cppArg1);
                if (instance.isNull()) {
                    Py_INCREF(Py_None);
                    pyResult = Py_None;
                } else if (instance.isQObject()) {
                    QObject *result = instance.toQObject();
                    pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), result);
                } else  {
                    pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), &instance);
                }
                // END of custom code block [file: ../glue/qtqml.cpp (qqmlengine-singletoninstance-typename)]
                // ========================================================================
                // End of code injection


                // Ownership transferences.
            }
            break;
        }
        case 1: // singletonInstance(int qmlTypeId)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)

            if (Shiboken::Errors::occurred() == nullptr) {
                // singletonInstance(int)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtqml.cpp (qqmlengine-singletoninstance-qmltypeid)]
                QJSValue instance = cppSelf->singletonInstance<QJSValue>(cppArg0);
                if (instance.isNull()) {
                    Py_INCREF(Py_None);
                    pyResult = Py_None;
                } else if (instance.isQObject()) {
                    QObject *result = instance.toQObject();
                    pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), result);
                } else  {
                    pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), &instance);
                }
                // END of custom code block [file: ../glue/qtqml.cpp (qqmlengine-singletoninstance-qmltypeid)]
                // ========================================================================
                // End of code injection


                // Ownership transferences.
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlEngineFunc_trimComponentCache(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // trimComponentCache()
        cppSelf->trimComponentCache();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQmlEngineFunc_urlInterceptor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QQmlEngine", "urlInterceptor() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // urlInterceptor()const
        QQmlAbstractUrlInterceptor * cppResult = const_cast<const ::QQmlEngine *>(cppSelf)->urlInterceptor();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlAbstractUrlInterceptor_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlEngineFunc_urlInterceptors(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // urlInterceptors()const
        QList<QQmlAbstractUrlInterceptor*> cppResult = const_cast<const ::QQmlEngine *>(cppSelf)->urlInterceptors();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtQmlTypeConverters[SBK_QtQml_QList_QQmlAbstractUrlInterceptorPTR_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QQmlEngine_PropertyStrings[] = {
    "offlineStoragePath::",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QQmlEngine_methods[] = {
    {"addImageProvider", reinterpret_cast<PyCFunction>(Sbk_QQmlEngineFunc_addImageProvider), METH_VARARGS, nullptr},
    {"addImportPath", reinterpret_cast<PyCFunction>(Sbk_QQmlEngineFunc_addImportPath), METH_O, nullptr},
    {"addNamedBundle", reinterpret_cast<PyCFunction>(Sbk_QQmlEngineFunc_addNamedBundle), METH_VARARGS, nullptr},
    {"addPluginPath", reinterpret_cast<PyCFunction>(Sbk_QQmlEngineFunc_addPluginPath), METH_O, nullptr},
    {"addUrlInterceptor", reinterpret_cast<PyCFunction>(Sbk_QQmlEngineFunc_addUrlInterceptor), METH_O, nullptr},
    {"baseUrl", reinterpret_cast<PyCFunction>(Sbk_QQmlEngineFunc_baseUrl), METH_NOARGS, nullptr},
    {"captureProperty", reinterpret_cast<PyCFunction>(Sbk_QQmlEngineFunc_captureProperty), METH_VARARGS, nullptr},
    {"clearComponentCache", reinterpret_cast<PyCFunction>(Sbk_QQmlEngineFunc_clearComponentCache), METH_NOARGS, nullptr},
    {"clearSingletons", reinterpret_cast<PyCFunction>(Sbk_QQmlEngineFunc_clearSingletons), METH_NOARGS, nullptr},
    {"contextForObject", reinterpret_cast<PyCFunction>(Sbk_QQmlEngineFunc_contextForObject), METH_O|METH_STATIC, nullptr},
    {"event", reinterpret_cast<PyCFunction>(Sbk_QQmlEngineFunc_event), METH_O, nullptr},
    {"imageProvider", reinterpret_cast<PyCFunction>(Sbk_QQmlEngineFunc_imageProvider), METH_O, nullptr},
    {"importPathList", reinterpret_cast<PyCFunction>(Sbk_QQmlEngineFunc_importPathList), METH_NOARGS, nullptr},
    {"importPlugin", reinterpret_cast<PyCFunction>(Sbk_QQmlEngineFunc_importPlugin), METH_VARARGS, nullptr},
    {"incubationController", reinterpret_cast<PyCFunction>(Sbk_QQmlEngineFunc_incubationController), METH_NOARGS, nullptr},
    {"interceptUrl", reinterpret_cast<PyCFunction>(Sbk_QQmlEngineFunc_interceptUrl), METH_VARARGS, nullptr},
    {"markCurrentFunctionAsTranslationBinding", reinterpret_cast<PyCFunction>(Sbk_QQmlEngineFunc_markCurrentFunctionAsTranslationBinding), METH_NOARGS, nullptr},
    {"networkAccessManager", reinterpret_cast<PyCFunction>(Sbk_QQmlEngineFunc_networkAccessManager), METH_NOARGS, nullptr},
    {"networkAccessManagerFactory", reinterpret_cast<PyCFunction>(Sbk_QQmlEngineFunc_networkAccessManagerFactory), METH_NOARGS, nullptr},
    {"offlineStorageDatabaseFilePath", reinterpret_cast<PyCFunction>(Sbk_QQmlEngineFunc_offlineStorageDatabaseFilePath), METH_O, nullptr},
    {"offlineStoragePath", reinterpret_cast<PyCFunction>(Sbk_QQmlEngineFunc_offlineStoragePath), METH_NOARGS, nullptr},
    {"outputWarningsToStandardError", reinterpret_cast<PyCFunction>(Sbk_QQmlEngineFunc_outputWarningsToStandardError), METH_NOARGS, nullptr},
    {"pluginPathList", reinterpret_cast<PyCFunction>(Sbk_QQmlEngineFunc_pluginPathList), METH_NOARGS, nullptr},
    {"removeImageProvider", reinterpret_cast<PyCFunction>(Sbk_QQmlEngineFunc_removeImageProvider), METH_O, nullptr},
    {"removeUrlInterceptor", reinterpret_cast<PyCFunction>(Sbk_QQmlEngineFunc_removeUrlInterceptor), METH_O, nullptr},
    {"retranslate", reinterpret_cast<PyCFunction>(Sbk_QQmlEngineFunc_retranslate), METH_NOARGS, nullptr},
    {"rootContext", reinterpret_cast<PyCFunction>(Sbk_QQmlEngineFunc_rootContext), METH_NOARGS, nullptr},
    {"setBaseUrl", reinterpret_cast<PyCFunction>(Sbk_QQmlEngineFunc_setBaseUrl), METH_O, nullptr},
    {"setContextForObject", reinterpret_cast<PyCFunction>(Sbk_QQmlEngineFunc_setContextForObject), METH_VARARGS|METH_STATIC, nullptr},
    {"setImportPathList", reinterpret_cast<PyCFunction>(Sbk_QQmlEngineFunc_setImportPathList), METH_O, nullptr},
    {"setIncubationController", reinterpret_cast<PyCFunction>(Sbk_QQmlEngineFunc_setIncubationController), METH_O, nullptr},
    {"setNetworkAccessManagerFactory", reinterpret_cast<PyCFunction>(Sbk_QQmlEngineFunc_setNetworkAccessManagerFactory), METH_O, nullptr},
    {"setOfflineStoragePath", reinterpret_cast<PyCFunction>(Sbk_QQmlEngineFunc_setOfflineStoragePath), METH_O, nullptr},
    {"setOutputWarningsToStandardError", reinterpret_cast<PyCFunction>(Sbk_QQmlEngineFunc_setOutputWarningsToStandardError), METH_O, nullptr},
    {"setPluginPathList", reinterpret_cast<PyCFunction>(Sbk_QQmlEngineFunc_setPluginPathList), METH_O, nullptr},
    {"setUrlInterceptor", reinterpret_cast<PyCFunction>(Sbk_QQmlEngineFunc_setUrlInterceptor), METH_O, nullptr},
    {"singletonInstance", reinterpret_cast<PyCFunction>(Sbk_QQmlEngineFunc_singletonInstance), METH_VARARGS, nullptr},
    {"trimComponentCache", reinterpret_cast<PyCFunction>(Sbk_QQmlEngineFunc_trimComponentCache), METH_NOARGS, nullptr},
    {"urlInterceptor", reinterpret_cast<PyCFunction>(Sbk_QQmlEngineFunc_urlInterceptor), METH_NOARGS, nullptr},
    {"urlInterceptors", reinterpret_cast<PyCFunction>(Sbk_QQmlEngineFunc_urlInterceptors), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QQmlEngine_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QQmlEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QQmlEngineWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QQmlEngine_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QQmlEngine_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QQmlEngine_Type = nullptr;
static PyTypeObject *Sbk_QQmlEngine_TypeF(void)
{
    return _Sbk_QQmlEngine_Type;
}

static PyType_Slot Sbk_QQmlEngine_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QQmlEngine_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QQmlEngine_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QQmlEngine_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QQmlEngine_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QQmlEngine_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QQmlEngine_spec = {
    "2:PySide6.QtQml.QQmlEngine",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QQmlEngine_slots
};

} //extern "C"

static void *Sbk_QQmlEngine_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QQmlEngine *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QQmlEngine_PythonToCpp_QQmlEngine_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QQmlEngine_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QQmlEngine_PythonToCpp_QQmlEngine_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QQmlEngine_TypeF()))
        return QQmlEngine_PythonToCpp_QQmlEngine_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QQmlEngine_PTR_CppToPython_QQmlEngine(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QQmlEngine *>(const_cast<void *>(cppIn)), Sbk_QQmlEngine_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QQmlEngine_SignatureStrings[] = {
    "PySide6.QtQml.QQmlEngine(self,p:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,offlineStoragePath:QString=None)",
    "PySide6.QtQml.QQmlEngine.addImageProvider(self,id:QString,arg__2:PySide6.QtQml.QQmlImageProviderBase)",
    "PySide6.QtQml.QQmlEngine.addImportPath(self,dir:PyPathLike)",
    "PySide6.QtQml.QQmlEngine.addNamedBundle(self,arg__1:QString,arg__2:QString)->bool",
    "PySide6.QtQml.QQmlEngine.addPluginPath(self,dir:PyPathLike)",
    "PySide6.QtQml.QQmlEngine.addUrlInterceptor(self,urlInterceptor:PySide6.QtQml.QQmlAbstractUrlInterceptor)",
    "PySide6.QtQml.QQmlEngine.baseUrl(self)->PySide6.QtCore.QUrl",
    "PySide6.QtQml.QQmlEngine.captureProperty(self,object:PySide6.QtCore.QObject,property:PySide6.QtCore.QMetaProperty)",
    "PySide6.QtQml.QQmlEngine.clearComponentCache(self)",
    "PySide6.QtQml.QQmlEngine.clearSingletons(self)",
    "PySide6.QtQml.QQmlEngine.contextForObject(arg__1:PySide6.QtCore.QObject)->PySide6.QtQml.QQmlContext",
    "PySide6.QtQml.QQmlEngine.event(self,arg__1:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtQml.QQmlEngine.imageProvider(self,id:QString)->PySide6.QtQml.QQmlImageProviderBase",
    "PySide6.QtQml.QQmlEngine.importPathList(self)->QStringList",
    "PySide6.QtQml.QQmlEngine.importPlugin(self,filePath:QString,uri:QString,errors:QList[PySide6.QtQml.QQmlError])->bool",
    "PySide6.QtQml.QQmlEngine.incubationController(self)->PySide6.QtQml.QQmlIncubationController",
    "PySide6.QtQml.QQmlEngine.interceptUrl(self,url:typing.Union[PySide6.QtCore.QUrl, QString],type:PySide6.QtQml.QQmlAbstractUrlInterceptor.DataType)->PySide6.QtCore.QUrl",
    "PySide6.QtQml.QQmlEngine.markCurrentFunctionAsTranslationBinding(self)",
    "PySide6.QtQml.QQmlEngine.networkAccessManager(self)->PySide6.QtNetwork.QNetworkAccessManager",
    "PySide6.QtQml.QQmlEngine.networkAccessManagerFactory(self)->PySide6.QtQml.QQmlNetworkAccessManagerFactory",
    "PySide6.QtQml.QQmlEngine.offlineStorageDatabaseFilePath(self,databaseName:QString)->QString",
    "PySide6.QtQml.QQmlEngine.offlineStoragePath(self)->QString",
    "PySide6.QtQml.QQmlEngine.outputWarningsToStandardError(self)->bool",
    "PySide6.QtQml.QQmlEngine.pluginPathList(self)->QStringList",
    "PySide6.QtQml.QQmlEngine.removeImageProvider(self,id:QString)",
    "PySide6.QtQml.QQmlEngine.removeUrlInterceptor(self,urlInterceptor:PySide6.QtQml.QQmlAbstractUrlInterceptor)",
    "PySide6.QtQml.QQmlEngine.retranslate(self)",
    "PySide6.QtQml.QQmlEngine.rootContext(self)->PySide6.QtQml.QQmlContext",
    "PySide6.QtQml.QQmlEngine.setBaseUrl(self,arg__1:typing.Union[PySide6.QtCore.QUrl, QString])",
    "PySide6.QtQml.QQmlEngine.setContextForObject(arg__1:PySide6.QtCore.QObject,arg__2:PySide6.QtQml.QQmlContext)",
    "PySide6.QtQml.QQmlEngine.setImportPathList(self,paths:QStringList)",
    "PySide6.QtQml.QQmlEngine.setIncubationController(self,arg__1:PySide6.QtQml.QQmlIncubationController)",
    "PySide6.QtQml.QQmlEngine.setNetworkAccessManagerFactory(self,arg__1:PySide6.QtQml.QQmlNetworkAccessManagerFactory)",
    "PySide6.QtQml.QQmlEngine.setOfflineStoragePath(self,dir:QString)",
    "PySide6.QtQml.QQmlEngine.setOutputWarningsToStandardError(self,arg__1:bool)",
    "PySide6.QtQml.QQmlEngine.setPluginPathList(self,paths:QStringList)",
    "PySide6.QtQml.QQmlEngine.setUrlInterceptor(self,urlInterceptor:PySide6.QtQml.QQmlAbstractUrlInterceptor)",
    "1:PySide6.QtQml.QQmlEngine.singletonInstance(self,uri:QString,typeName:QString)->Union[PySide6.QtCore.QObject, PySide6.QtQml.QJSValue, None]",
    "0:PySide6.QtQml.QQmlEngine.singletonInstance(self,qmlTypeId:int)->Union[PySide6.QtCore.QObject, PySide6.QtQml.QJSValue, None]",
    "PySide6.QtQml.QQmlEngine.trimComponentCache(self)",
    "PySide6.QtQml.QQmlEngine.urlInterceptor(self)->PySide6.QtQml.QQmlAbstractUrlInterceptor",
    "PySide6.QtQml.QQmlEngine.urlInterceptors(self)->QList[PySide6.QtQml.QQmlAbstractUrlInterceptor]",
    nullptr}; // Sentinel
#else
static constexpr size_t QQmlEngine_SignatureByteSize = 772;
static constexpr uint8_t QQmlEngine_SignatureBytes[772] = {
    0x78, 0xda, 0xbd, 0x57, 0x51, 0x6f, 0xd3, 0x30, 0x10, 0x7e, 0xdf, 0xaf, 0xd8, 0xe3, 0x8a, 0x42,
    0x04, 0x3c, 0xf0, 0x10, 0x69, 0x48, 0x6b, 0x59, 0xa5, 0xc2, 0xd6, 0x35, 0xea, 0x06, 0x0f, 0x53,
    0x35, 0xb9, 0x89, 0xdb, 0x85, 0x39, 0x76, 0x38, 0x3b, 0x83, 0xfe, 0x7b, 0xce, 0x89, 0x53, 0x96,
    0xc6, 0xb1, 0x1b, 0x40, 0xbc, 0x54, 0x49, 0x7c, 0xf7, 0xdd, 0xf9, 0xfc, 0x7d, 0x77, 0xee, 0x62,
    0xb7, 0xcc, 0x52, 0xfa, 0x3e, 0x8c, 0x55, 0x9c, 0xb3, 0x30, 0xc6, 0x9f, 0x4b, 0xbe, 0xcd, 0x38,
    0x3d, 0x93, 0x94, 0x6d, 0x82, 0x22, 0x5a, 0xec, 0xd7, 0x27, 0x02, 0x68, 0x18, 0xdf, 0xac, 0xbf,
    0xd1, 0x44, 0x9d, 0xf3, 0x92, 0xb1, 0x42, 0x41, 0xf0, 0x2a, 0xfa, 0x4c, 0x77, 0x3f, 0x04, 0xa4,
    0x37, 0x9c, 0xed, 0xce, 0xe7, 0x82, 0xd3, 0x40, 0x6c, 0x36, 0x0c, 0x01, 0x96, 0x4a, 0x00, 0xd9,
    0xd2, 0x05, 0x51, 0x8f, 0x51, 0xbc, 0x54, 0x90, 0xf1, 0x6d, 0xb5, 0x3e, 0x3a, 0x59, 0xf4, 0x84,
    0x0c, 0x49, 0x9a, 0xce, 0x72, 0xed, 0x03, 0xe2, 0x19, 0x2d, 0xa0, 0xce, 0x21, 0x4b, 0x1b, 0xff,
    0x80, 0xc0, 0xf6, 0xe1, 0xe1, 0x5d, 0xd4, 0x05, 0x68, 0xb9, 0x8d, 0x89, 0xf4, 0x46, 0x29, 0x04,
    0x28, 0x9d, 0x5a, 0x1d, 0x22, 0xcd, 0x00, 0x41, 0xf5, 0xfb, 0x55, 0xf6, 0xe4, 0xf1, 0x9d, 0x93,
    0x9c, 0xa6, 0xe3, 0x92, 0xa7, 0xcc, 0xd4, 0xa8, 0x4a, 0xea, 0xed, 0x61, 0x8e, 0xe6, 0x75, 0xf4,
    0xfa, 0xc3, 0x5a, 0x08, 0xe6, 0x44, 0x5c, 0xb0, 0x12, 0x1f, 0xff, 0x2c, 0x9b, 0x3b, 0x60, 0x33,
    0xae, 0x28, 0x24, 0xb4, 0xc0, 0x7a, 0xd7, 0xfe, 0x65, 0xeb, 0x9b, 0xa5, 0x5a, 0x17, 0x6b, 0xa9,
    0x80, 0x24, 0xaa, 0xed, 0xec, 0x08, 0xb4, 0xc6, 0x8a, 0xa2, 0x71, 0x05, 0x8f, 0x3b, 0x3a, 0xe4,
    0x04, 0x2e, 0xf5, 0xfb, 0x26, 0xa4, 0x50, 0x25, 0xe8, 0xc3, 0x29, 0x28, 0xa8, 0x5d, 0x9d, 0xa2,
    0xa8, 0x58, 0xd4, 0x43, 0xae, 0xa0, 0x30, 0xb6, 0x9d, 0xf5, 0x6b, 0xaa, 0x48, 0x03, 0xe4, 0x48,
    0x37, 0x61, 0x94, 0xc0, 0x44, 0xe0, 0x21, 0x73, 0xca, 0xd5, 0x84, 0x24, 0x8f, 0xf5, 0x51, 0xf9,
    0x5c, 0x96, 0x78, 0x60, 0x8c, 0x2a, 0xc1, 0xa5, 0xd7, 0x5c, 0x60, 0xdd, 0x7e, 0xaa, 0xa9, 0x80,
    0x3a, 0xe5, 0x33, 0x43, 0x02, 0xfb, 0x86, 0x5a, 0x25, 0x6b, 0x90, 0x26, 0x35, 0x44, 0x7f, 0x0c,
    0xfa, 0x8c, 0xc9, 0xb7, 0x28, 0x76, 0x88, 0x7e, 0xa9, 0x2d, 0xbc, 0x0c, 0xcb, 0x5c, 0x92, 0xb2,
    0xa6, 0xd6, 0x51, 0x93, 0x0b, 0xbc, 0x51, 0xd2, 0x55, 0x26, 0x55, 0x43, 0x10, 0x03, 0xae, 0x3f,
    0x79, 0x5d, 0x2b, 0xf2, 0xd7, 0x69, 0x6d, 0x32, 0xd6, 0xea, 0x17, 0xc8, 0xe4, 0x6c, 0xff, 0x4c,
    0x01, 0x04, 0xc8, 0x28, 0xd6, 0xa0, 0xf7, 0x16, 0x50, 0xbd, 0xbc, 0xf2, 0x17, 0x83, 0x27, 0xe5,
    0x9a, 0xa8, 0x4c, 0x70, 0x5d, 0x7f, 0x10, 0x8c, 0x99, 0x9a, 0xd8, 0x0b, 0x61, 0xb1, 0x76, 0x61,
    0x1b, 0x2d, 0x35, 0x52, 0xd1, 0x4a, 0x8c, 0xd4, 0xae, 0xc0, 0xf4, 0xc3, 0x3b, 0x8e, 0x28, 0xf7,
    0x16, 0xe5, 0x04, 0xa7, 0x66, 0x87, 0xab, 0x00, 0x4d, 0xe9, 0xd1, 0x72, 0x0d, 0x3f, 0x12, 0x45,
    0x6e, 0xd1, 0x63, 0xa8, 0x20, 0x73, 0x02, 0x4f, 0x93, 0x12, 0x00, 0xb9, 0x33, 0x2d, 0x79, 0xa2,
    0x77, 0x77, 0x21, 0x6f, 0x81, 0x70, 0xc9, 0xaa, 0xad, 0x8e, 0x33, 0x9e, 0x62, 0x3a, 0x3e, 0x09,
    0x70, 0xaa, 0xb0, 0xef, 0x3f, 0x5d, 0x24, 0x09, 0x95, 0xf2, 0x9a, 0x70, 0xa4, 0x8c, 0xa5, 0x92,
    0xf3, 0xda, 0x2a, 0x8c, 0xe7, 0x16, 0xf3, 0x61, 0xe0, 0x53, 0x2c, 0x81, 0x80, 0x5d, 0xff, 0x69,
    0xcd, 0xfb, 0x9d, 0xfa, 0x23, 0xb5, 0xa7, 0x95, 0xae, 0xa9, 0x6e, 0x76, 0x53, 0xc3, 0x44, 0xd3,
    0x90, 0xcd, 0x57, 0xdd, 0xfa, 0x5f, 0x08, 0xc7, 0x3c, 0x1d, 0x8b, 0xbd, 0xc7, 0x3b, 0xca, 0xb5,
    0x54, 0x45, 0xa9, 0xbe, 0x12, 0xe0, 0x68, 0x26, 0x6f, 0xc5, 0x52, 0x11, 0x9e, 0x12, 0x48, 0x2b,
    0x9a, 0x37, 0x28, 0x6e, 0xaa, 0x17, 0xfb, 0xb1, 0x32, 0x58, 0x9a, 0x40, 0x73, 0xf1, 0x4c, 0x9d,
    0xb3, 0x78, 0xe4, 0xf3, 0xfe, 0x3f, 0x93, 0x09, 0xa8, 0x32, 0xcc, 0xf5, 0xb6, 0x78, 0x10, 0x42,
    0x99, 0xa6, 0xdb, 0xcf, 0x21, 0x6f, 0x57, 0x96, 0x54, 0x8d, 0x5f, 0x4c, 0xc3, 0xa6, 0x35, 0x1f,
    0xaf, 0xf2, 0x91, 0x13, 0x7b, 0x32, 0x68, 0xb0, 0xf4, 0x5f, 0x88, 0x0c, 0x8e, 0x3b, 0xd8, 0xac,
    0xdb, 0xbc, 0x83, 0x02, 0xdf, 0x64, 0xf4, 0x82, 0x25, 0x1e, 0x88, 0xbe, 0x7e, 0xda, 0x9d, 0x59,
    0xae, 0xa6, 0xea, 0x0e, 0x32, 0xf7, 0x74, 0x83, 0xfe, 0x58, 0x0e, 0x4f, 0x77, 0xc8, 0x1b, 0xbb,
    0x74, 0xab, 0xbb, 0x99, 0x5f, 0x01, 0x1a, 0xc0, 0x2b, 0xe0, 0x26, 0x6b, 0xad, 0x62, 0x37, 0xd6,
    0xa2, 0xab, 0xe4, 0xa1, 0xe7, 0xf4, 0x4f, 0xd5, 0x68, 0xab, 0x74, 0x13, 0xaa, 0xb9, 0x42, 0xcd,
    0xb8, 0xc4, 0x1d, 0x27, 0xb4, 0x09, 0xf5, 0x7b, 0x90, 0xeb, 0x29, 0x77, 0xd0, 0x49, 0xed, 0xb2,
    0x31, 0x1c, 0x3f, 0x3d, 0x08, 0xf6, 0x69, 0xf9, 0x85, 0xb0, 0x92, 0x06, 0xa7, 0xfa, 0xdf, 0xc4,
    0xea, 0xe4, 0xcd, 0xe0, 0x64, 0xbe, 0xe7, 0x4c, 0xcf, 0xcd, 0x59, 0x1a, 0x65, 0xd5, 0xf5, 0xe9,
    0x6f, 0xa2, 0xf7, 0xc6, 0xc6, 0xad, 0xe5, 0xc3, 0xae, 0xa0, 0x65, 0xf7, 0x88, 0xac, 0x2d, 0xca,
    0x7e, 0x2a, 0xc7, 0xe2, 0xca, 0xfd, 0x20, 0xe8, 0xb9, 0x48, 0xd9, 0xe1, 0x57, 0x27, 0xbf, 0x00,
    0x26, 0x60, 0x26, 0xe9
};
#endif

PyTypeObject *init_QQmlEngine(PyObject *module)
{
    if (SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX].type != nullptr)
        return SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX].type;

    Shiboken::AutoDecRef Sbk_QQmlEngine_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSEngine_IDX]))));

    _Sbk_QQmlEngine_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QQmlEngine",
        "QQmlEngine*",
        &Sbk_QQmlEngine_spec,
        &Shiboken::callCppDestructor< QQmlEngine >,
        Sbk_QQmlEngine_Type_bases.object(),
        0);
    auto *pyType = Sbk_QQmlEngine_TypeF(); // references _Sbk_QQmlEngine_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QQmlEngine_SignatureStrings);
#else
    InitSignatureBytes(pyType, QQmlEngine_SignatureBytes, QQmlEngine_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QQmlEngine_PropertyStrings);
    SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QQmlEngine_PythonToCpp_QQmlEngine_PTR,
        is_QQmlEngine_PythonToCpp_QQmlEngine_PTR_Convertible,
        QQmlEngine_PTR_CppToPython_QQmlEngine);

    Shiboken::Conversions::registerConverterName(converter, "QQmlEngine");
    Shiboken::Conversions::registerConverterName(converter, "QQmlEngine*");
    Shiboken::Conversions::registerConverterName(converter, "QQmlEngine&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QQmlEngine).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QQmlEngineWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QQmlEngine_TypeF(), &Sbk_QQmlEngine_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::QQmlEngine::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QQmlEngine::staticMetaObject, sizeof(QQmlEngineWrapper));

    return pyType;
}
