// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtqml_python.h"

// main header
#include "qqmlerror_wrapper.h"

// Argument includes
#include <QString>
#include <QtQml/qqmlerror.h>
#include <qlogging.h>
#include <qobject.h>
#include <qurl.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QQmlError_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QQmlError >()))
        return -1;

    ::QQmlError *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QQmlError", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QQmlError::QQmlError()
    // 1: QQmlError::QQmlError(QQmlError)
    if (numArgs == 0) {
        overloadId = 0; // QQmlError()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QQmlError(QQmlError)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QQmlError()
        {

            // QQmlError()
            cptr = new ::QQmlError();
            break;
        }
        case 1: // QQmlError(const QQmlError &arg__1)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QQmlError cppArg0_local;
            ::QQmlError *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QQmlError(QQmlError)
                cptr = new ::QQmlError(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QQmlError >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QQmlErrorFunc___repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // __repr__()
        // Begin code injection
        // ========================================================================
        // START of custom code block [file: ../glue/qtqml.cpp (qmlerrror-repr)]
        const QByteArray message = cppSelf->toString().toUtf8();
        pyResult = Shiboken::String::fromCString(message.constData());
        // END of custom code block [file: ../glue/qtqml.cpp (qmlerrror-repr)]
        // ========================================================================
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlErrorFunc_column(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // column()const
        int cppResult = const_cast<const ::QQmlError *>(cppSelf)->column();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlErrorFunc_description(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // description()const
        QString cppResult = const_cast<const ::QQmlError *>(cppSelf)->description();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlErrorFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QQmlError *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlErrorFunc_line(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // line()const
        int cppResult = const_cast<const ::QQmlError *>(cppSelf)->line();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlErrorFunc_messageType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // messageType()const
        QtMsgType cppResult = const_cast<const ::QQmlError *>(cppSelf)->messageType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtMsgType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlErrorFunc_object(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // object()const
        QObject * cppResult = const_cast<const ::QQmlError *>(cppSelf)->object();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlErrorFunc_setColumn(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQmlError::setColumn(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setColumn(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setColumn", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setColumn(int)
            cppSelf->setColumn(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQmlErrorFunc_setDescription(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQmlError::setDescription(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setDescription(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDescription", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDescription(QString)
            cppSelf->setDescription(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQmlErrorFunc_setLine(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQmlError::setLine(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setLine(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLine", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLine(int)
            cppSelf->setLine(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQmlErrorFunc_setMessageType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQmlError::setMessageType(QtMsgType)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtMsgType_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setMessageType(QtMsgType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMessageType", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]);

    // Call function/method
    {
        ::QtMsgType cppArg0{QtDebugMsg};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMessageType(QtMsgType)
            cppSelf->setMessageType(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQmlErrorFunc_setObject(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQmlError::setObject(QObject*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArg)))) {
        overloadId = 0; // setObject(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setObject", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QObject *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setObject(QObject*)
            cppSelf->setObject(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQmlErrorFunc_setUrl(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQmlError::setUrl(QUrl)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // setUrl(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUrl", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setUrl(QUrl)
            cppSelf->setUrl(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQmlErrorFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQmlError::swap(QQmlError&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QQmlError&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QQmlError cppArg0_local;
        ::QQmlError *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QQmlError&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQmlErrorFunc_toString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toString()const
        QString cppResult = const_cast<const ::QQmlError *>(cppSelf)->toString();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlErrorFunc_url(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // url()const
        QUrl cppResult = const_cast<const ::QQmlError *>(cppSelf)->url();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlError__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QQmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QQmlError_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QQmlError_methods[] = {
    {"column", reinterpret_cast<PyCFunction>(Sbk_QQmlErrorFunc_column), METH_NOARGS, nullptr},
    {"description", reinterpret_cast<PyCFunction>(Sbk_QQmlErrorFunc_description), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QQmlErrorFunc_isValid), METH_NOARGS, nullptr},
    {"line", reinterpret_cast<PyCFunction>(Sbk_QQmlErrorFunc_line), METH_NOARGS, nullptr},
    {"messageType", reinterpret_cast<PyCFunction>(Sbk_QQmlErrorFunc_messageType), METH_NOARGS, nullptr},
    {"object", reinterpret_cast<PyCFunction>(Sbk_QQmlErrorFunc_object), METH_NOARGS, nullptr},
    {"setColumn", reinterpret_cast<PyCFunction>(Sbk_QQmlErrorFunc_setColumn), METH_O, nullptr},
    {"setDescription", reinterpret_cast<PyCFunction>(Sbk_QQmlErrorFunc_setDescription), METH_O, nullptr},
    {"setLine", reinterpret_cast<PyCFunction>(Sbk_QQmlErrorFunc_setLine), METH_O, nullptr},
    {"setMessageType", reinterpret_cast<PyCFunction>(Sbk_QQmlErrorFunc_setMessageType), METH_O, nullptr},
    {"setObject", reinterpret_cast<PyCFunction>(Sbk_QQmlErrorFunc_setObject), METH_O, nullptr},
    {"setUrl", reinterpret_cast<PyCFunction>(Sbk_QQmlErrorFunc_setUrl), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QQmlErrorFunc_swap), METH_O, nullptr},
    {"toString", reinterpret_cast<PyCFunction>(Sbk_QQmlErrorFunc_toString), METH_NOARGS, nullptr},
    {"url", reinterpret_cast<PyCFunction>(Sbk_QQmlErrorFunc_url), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QQmlError__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QQmlError_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QQmlError_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QQmlError_Type = nullptr;
static PyTypeObject *Sbk_QQmlError_TypeF(void)
{
    return _Sbk_QQmlError_Type;
}

static PyType_Slot Sbk_QQmlError_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QQmlErrorFunc___repr__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QQmlError_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QQmlError_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QQmlError_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QQmlError_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QQmlError_spec = {
    "2:PySide6.QtQml.QQmlError",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QQmlError_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QQmlError_PythonToCpp_QQmlError_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QQmlError_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QQmlError_PythonToCpp_QQmlError_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QQmlError_TypeF()))
        return QQmlError_PythonToCpp_QQmlError_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QQmlError_PTR_CppToPython_QQmlError(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QQmlError_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QQmlError_COPY_CppToPython_QQmlError(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QQmlError *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QQmlError_TypeF(), new ::QQmlError(*source), true, true);
}

// Python to C++ copy conversion.
static void QQmlError_PythonToCpp_QQmlError_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QQmlError *>(cppOut) = *reinterpret_cast< ::QQmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QQmlError_PythonToCpp_QQmlError_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QQmlError_TypeF()))
        return QQmlError_PythonToCpp_QQmlError_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QQmlError_SignatureStrings[] = {
    "1:PySide6.QtQml.QQmlError(self)",
    "0:PySide6.QtQml.QQmlError(self,arg__1:PySide6.QtQml.QQmlError)",
    "PySide6.QtQml.QQmlError.__repr__(self)->str",
    "PySide6.QtQml.QQmlError.column(self)->int",
    "PySide6.QtQml.QQmlError.description(self)->QString",
    "PySide6.QtQml.QQmlError.isValid(self)->bool",
    "PySide6.QtQml.QQmlError.line(self)->int",
    "PySide6.QtQml.QQmlError.messageType(self)->PySide6.QtCore.QtMsgType",
    "PySide6.QtQml.QQmlError.object(self)->PySide6.QtCore.QObject",
    "PySide6.QtQml.QQmlError.setColumn(self,arg__1:int)",
    "PySide6.QtQml.QQmlError.setDescription(self,arg__1:QString)",
    "PySide6.QtQml.QQmlError.setLine(self,arg__1:int)",
    "PySide6.QtQml.QQmlError.setMessageType(self,messageType:PySide6.QtCore.QtMsgType)",
    "PySide6.QtQml.QQmlError.setObject(self,arg__1:PySide6.QtCore.QObject)",
    "PySide6.QtQml.QQmlError.setUrl(self,arg__1:typing.Union[PySide6.QtCore.QUrl, QString])",
    "PySide6.QtQml.QQmlError.swap(self,other:PySide6.QtQml.QQmlError)",
    "PySide6.QtQml.QQmlError.toString(self)->QString",
    "PySide6.QtQml.QQmlError.url(self)->PySide6.QtCore.QUrl",
    "PySide6.QtQml.QQmlError.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QQmlError_SignatureByteSize = 280;
static constexpr uint8_t QQmlError_SignatureBytes[280] = {
    0x78, 0xda, 0x95, 0x93, 0xc1, 0x4e, 0x84, 0x40, 0x0c, 0x86, 0xef, 0x3c, 0x85, 0x47, 0x49, 0x90,
    0xb8, 0x17, 0x0f, 0x7b, 0xf0, 0xa2, 0xde, 0xdc, 0xec, 0x12, 0x5c, 0x2f, 0xc6, 0x4c, 0x58, 0xa8,
    0x38, 0x9b, 0x81, 0x4e, 0x3a, 0xb3, 0x31, 0xbc, 0xbd, 0xa3, 0x30, 0xb0, 0xa2, 0x9d, 0xe0, 0x05,
    0x42, 0xfa, 0xf5, 0x6f, 0xfb, 0xd3, 0xae, 0xd6, 0xbb, 0x2e, 0x97, 0x15, 0xdc, 0xa4, 0x99, 0xcd,
    0x1a, 0x95, 0x66, 0xee, 0xf1, 0x40, 0x84, 0x74, 0x69, 0x40, 0xbd, 0xc5, 0xd1, 0x75, 0x30, 0x9e,
    0x14, 0x54, 0x0b, 0xb1, 0xe2, 0x98, 0x38, 0x62, 0x02, 0xa9, 0x10, 0x04, 0x9a, 0x84, 0xe8, 0xab,
    0x5c, 0xdd, 0x1a, 0x4b, 0x2c, 0x5b, 0xa2, 0x3a, 0x35, 0xad, 0x27, 0x65, 0x6b, 0x59, 0xb2, 0x02,
    0x53, 0x92, 0xd4, 0x56, 0xe2, 0x88, 0x67, 0xb9, 0x25, 0xd9, 0xd6, 0x6c, 0x8a, 0x34, 0xcf, 0x85,
    0x92, 0x95, 0xc7, 0x0f, 0x88, 0x8a, 0x65, 0x95, 0x6c, 0x61, 0x49, 0x1b, 0x0d, 0x18, 0x53, 0xd4,
    0xf0, 0xd4, 0xe9, 0x11, 0x9f, 0xd0, 0x3b, 0x24, 0x70, 0xaf, 0x8d, 0xa9, 0xbf, 0xe2, 0xac, 0x06,
    0x1e, 0x8e, 0x50, 0x5a, 0x2e, 0x7d, 0xfb, 0x1d, 0x65, 0x93, 0x0d, 0x38, 0x6e, 0x34, 0xcd, 0xff,
    0x24, 0xd7, 0x72, 0x1c, 0x4a, 0xb9, 0x9f, 0xb9, 0xe7, 0xf3, 0x06, 0x0b, 0x83, 0xb9, 0x8f, 0xde,
    0x9a, 0xa5, 0xc5, 0x36, 0x33, 0x8f, 0x92, 0x33, 0xd3, 0xd6, 0x9c, 0x5b, 0x41, 0xc5, 0xed, 0xe4,
    0xd8, 0xef, 0xb5, 0x3c, 0xb7, 0x2d, 0xa8, 0xb2, 0x27, 0xf5, 0x43, 0xc2, 0x76, 0xda, 0xcd, 0x9e,
    0xee, 0x5b, 0xe7, 0xca, 0xcb, 0x5c, 0xcf, 0xc1, 0xc9, 0xc5, 0x60, 0xcf, 0x6b, 0x40, 0xf6, 0xa3,
    0xd0, 0xbd, 0x28, 0xda, 0x77, 0xa0, 0xff, 0x5f, 0x8b, 0xc5, 0xbe, 0xc6, 0xd2, 0xa5, 0x3e, 0x0d,
    0x43, 0xfc, 0xb1, 0x39, 0xae, 0xe5, 0xc0, 0x51, 0x96, 0xa8, 0xbb, 0xe9, 0x28, 0x87, 0xd9, 0x73,
    0xf7, 0x15, 0x7d, 0x02, 0x16, 0x24, 0x77, 0xe0
};
#endif

PyTypeObject *init_QQmlError(PyObject *module)
{
    if (SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX].type != nullptr)
        return SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX].type;

    Shiboken::AutoDecRef Sbk_QQmlError_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QQmlError_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QQmlError",
        "QQmlError",
        &Sbk_QQmlError_spec,
        &Shiboken::callCppDestructor< ::QQmlError >,
        Sbk_QQmlError_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QQmlError_TypeF(); // references _Sbk_QQmlError_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QQmlError_SignatureStrings);
#else
    InitSignatureBytes(pyType, QQmlError_SignatureBytes, QQmlError_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QQmlError_PropertyStrings);
    SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QQmlError_PythonToCpp_QQmlError_PTR,
        is_QQmlError_PythonToCpp_QQmlError_PTR_Convertible,
        QQmlError_PTR_CppToPython_QQmlError,
        QQmlError_COPY_CppToPython_QQmlError);

    Shiboken::Conversions::registerConverterName(converter, "QQmlError");
    Shiboken::Conversions::registerConverterName(converter, "QQmlError*");
    Shiboken::Conversions::registerConverterName(converter, "QQmlError&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QQmlError).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QQmlError_PythonToCpp_QQmlError_COPY,
        is_QQmlError_PythonToCpp_QQmlError_COPY_Convertible);

    qRegisterMetaType< ::QQmlError >("QQmlError");

    return pyType;
}
