// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtqml_python.h"

// main header
#include "qqmlfile_wrapper.h"

// Argument includes
#include <QString>
#include <QtQml/qqmlengine.h>
#include <QtQml/qqmlfile.h>
#include <qbytearray.h>
#include <qobject.h>
#include <qurl.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QQmlFile_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QQmlFile >()))
        return -1;

    ::QQmlFile *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlFile_IDX]);

    if (PyArg_UnpackTuple(args, "QQmlFile", 0, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QQmlFile::QQmlFile()
    // 1: QQmlFile::QQmlFile(QQmlEngine*,QString)
    // 2: QQmlFile::QQmlFile(QQmlEngine*,QUrl)
    if (numArgs == 0) {
        overloadId = 0; // QQmlFile()
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]), (pyArgs[0])))) {
        if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 1; // QQmlFile(QQmlEngine*,QString)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[1])))) {
            overloadId = 2; // QQmlFile(QQmlEngine*,QUrl)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlFile_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtQmlTypeStructs[SBK_QQmlFile_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QQmlFile()
        {

            // QQmlFile()
            cptr = new ::QQmlFile();
            break;
        }
        case 1: // QQmlFile(QQmlEngine *engine, const QString &url)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QQmlEngine *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QQmlFile(QQmlEngine*,QString)
                cptr = new ::QQmlFile(cppArg0, cppArg1);
            }
            break;
        }
        case 2: // QQmlFile(QQmlEngine *engine, const QUrl &url)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QQmlEngine *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QUrl cppArg1_local;
            ::QUrl *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QQmlFile(QQmlEngine*,QUrl)
                cptr = new ::QQmlFile(cppArg0, *cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QQmlFile >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlFile_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QQmlFileFunc_clear(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "clear", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QQmlFile::clear()
    // 1: QQmlFile::clear(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // clear()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 1; // clear(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "clear", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlFile_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // clear()
        {

            // clear()
            cppSelf->clear();
            break;
        }
        case 1: // clear(QObject *object)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // clear(QObject*)
                cppSelf->clear(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQmlFileFunc_connectDownloadProgress(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "connectDownloadProgress", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QQmlFile::connectDownloadProgress(QObject*,const char*)->bool
    // 1: QQmlFile::connectDownloadProgress(QObject*,int)->bool
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 1; // connectDownloadProgress(QObject*,int)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[1])))) {
            overloadId = 0; // connectDownloadProgress(QObject*,const char*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "connectDownloadProgress", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlFile_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // connectDownloadProgress(QObject *arg__1, const char *arg__2)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            const char* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // connectDownloadProgress(QObject*,const char*)
                bool cppResult = cppSelf->connectDownloadProgress(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // connectDownloadProgress(QObject *arg__1, int arg__2)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // connectDownloadProgress(QObject*,int)
                bool cppResult = cppSelf->connectDownloadProgress(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlFileFunc_connectFinished(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "connectFinished", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QQmlFile::connectFinished(QObject*,const char*)->bool
    // 1: QQmlFile::connectFinished(QObject*,int)->bool
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 1; // connectFinished(QObject*,int)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[1])))) {
            overloadId = 0; // connectFinished(QObject*,const char*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "connectFinished", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlFile_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // connectFinished(QObject *arg__1, const char *arg__2)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            const char* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // connectFinished(QObject*,const char*)
                bool cppResult = cppSelf->connectFinished(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // connectFinished(QObject *arg__1, int arg__2)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // connectFinished(QObject*,int)
                bool cppResult = cppSelf->connectFinished(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlFileFunc_data(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // data()const
        const char * cppResult = const_cast<const ::QQmlFile *>(cppSelf)->data();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlFileFunc_dataByteArray(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // dataByteArray()const
        QByteArray cppResult = const_cast<const ::QQmlFile *>(cppSelf)->dataByteArray();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlFileFunc_error(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // error()const
        QString cppResult = const_cast<const ::QQmlFile *>(cppSelf)->error();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlFileFunc_isError(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isError()const
        bool cppResult = const_cast<const ::QQmlFile *>(cppSelf)->isError();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlFileFunc_isLoading(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isLoading()const
        bool cppResult = const_cast<const ::QQmlFile *>(cppSelf)->isLoading();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlFileFunc_isLocalFile(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QQmlFile::isLocalFile(QString)->bool
    // 1: static QQmlFile::isLocalFile(QUrl)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // isLocalFile(QString)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 1; // isLocalFile(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isLocalFile", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlFile_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // isLocalFile(const QString &url)
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // isLocalFile(QString)
                bool cppResult = ::QQmlFile::isLocalFile(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // isLocalFile(const QUrl &url)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QUrl cppArg0_local;
            ::QUrl *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // isLocalFile(QUrl)
                bool cppResult = ::QQmlFile::isLocalFile(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlFileFunc_isNull(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isNull()const
        bool cppResult = const_cast<const ::QQmlFile *>(cppSelf)->isNull();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlFileFunc_isReady(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isReady()const
        bool cppResult = const_cast<const ::QQmlFile *>(cppSelf)->isReady();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlFileFunc_isSynchronous(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QQmlFile::isSynchronous(QString)->bool
    // 1: static QQmlFile::isSynchronous(QUrl)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // isSynchronous(QString)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 1; // isSynchronous(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isSynchronous", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlFile_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // isSynchronous(const QString &url)
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // isSynchronous(QString)
                bool cppResult = ::QQmlFile::isSynchronous(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // isSynchronous(const QUrl &url)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QUrl cppArg0_local;
            ::QUrl *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // isSynchronous(QUrl)
                bool cppResult = ::QQmlFile::isSynchronous(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlFileFunc_load(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "load", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QQmlFile::load(QQmlEngine*,QString)
    // 1: QQmlFile::load(QQmlEngine*,QUrl)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]), (pyArgs[0])))) {
        if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 0; // load(QQmlEngine*,QString)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[1])))) {
            overloadId = 1; // load(QQmlEngine*,QUrl)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "load", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlFile_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // load(QQmlEngine *arg__1, const QString &arg__2)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QQmlEngine *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // load(QQmlEngine*,QString)
                cppSelf->load(cppArg0, cppArg1);
            }
            break;
        }
        case 1: // load(QQmlEngine *arg__1, const QUrl &arg__2)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QQmlEngine *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QUrl cppArg1_local;
            ::QUrl *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // load(QQmlEngine*,QUrl)
                cppSelf->load(cppArg0, *cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQmlFileFunc_size(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // size()const
        qint64 cppResult = const_cast<const ::QQmlFile *>(cppSelf)->size();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlFileFunc_status(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // status()const
        QQmlFile::Status cppResult = const_cast<const ::QQmlFile *>(cppSelf)->status();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlFile_Status_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlFileFunc_url(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // url()const
        QUrl cppResult = const_cast<const ::QQmlFile *>(cppSelf)->url();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlFileFunc_urlToLocalFileOrQrc(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QQmlFile::urlToLocalFileOrQrc(QString)->QString
    // 1: static QQmlFile::urlToLocalFileOrQrc(QUrl)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // urlToLocalFileOrQrc(QString)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 1; // urlToLocalFileOrQrc(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "urlToLocalFileOrQrc", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlFile_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // urlToLocalFileOrQrc(const QString &arg__1)
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // urlToLocalFileOrQrc(QString)
                QString cppResult = ::QQmlFile::urlToLocalFileOrQrc(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
        case 1: // urlToLocalFileOrQrc(const QUrl &arg__1)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QUrl cppArg0_local;
            ::QUrl *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // urlToLocalFileOrQrc(QUrl)
                QString cppResult = ::QQmlFile::urlToLocalFileOrQrc(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QQmlFile_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QQmlFile_EnumFlagInfo[] = {
    "Status:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QQmlFile_methods[] = {
    {"clear", reinterpret_cast<PyCFunction>(Sbk_QQmlFileFunc_clear), METH_VARARGS, nullptr},
    {"connectDownloadProgress", reinterpret_cast<PyCFunction>(Sbk_QQmlFileFunc_connectDownloadProgress), METH_VARARGS, nullptr},
    {"connectFinished", reinterpret_cast<PyCFunction>(Sbk_QQmlFileFunc_connectFinished), METH_VARARGS, nullptr},
    {"data", reinterpret_cast<PyCFunction>(Sbk_QQmlFileFunc_data), METH_NOARGS, nullptr},
    {"dataByteArray", reinterpret_cast<PyCFunction>(Sbk_QQmlFileFunc_dataByteArray), METH_NOARGS, nullptr},
    {"error", reinterpret_cast<PyCFunction>(Sbk_QQmlFileFunc_error), METH_NOARGS, nullptr},
    {"isError", reinterpret_cast<PyCFunction>(Sbk_QQmlFileFunc_isError), METH_NOARGS, nullptr},
    {"isLoading", reinterpret_cast<PyCFunction>(Sbk_QQmlFileFunc_isLoading), METH_NOARGS, nullptr},
    {"isLocalFile", reinterpret_cast<PyCFunction>(Sbk_QQmlFileFunc_isLocalFile), METH_O|METH_STATIC, nullptr},
    {"isNull", reinterpret_cast<PyCFunction>(Sbk_QQmlFileFunc_isNull), METH_NOARGS, nullptr},
    {"isReady", reinterpret_cast<PyCFunction>(Sbk_QQmlFileFunc_isReady), METH_NOARGS, nullptr},
    {"isSynchronous", reinterpret_cast<PyCFunction>(Sbk_QQmlFileFunc_isSynchronous), METH_O|METH_STATIC, nullptr},
    {"load", reinterpret_cast<PyCFunction>(Sbk_QQmlFileFunc_load), METH_VARARGS, nullptr},
    {"size", reinterpret_cast<PyCFunction>(Sbk_QQmlFileFunc_size), METH_NOARGS, nullptr},
    {"status", reinterpret_cast<PyCFunction>(Sbk_QQmlFileFunc_status), METH_NOARGS, nullptr},
    {"url", reinterpret_cast<PyCFunction>(Sbk_QQmlFileFunc_url), METH_NOARGS, nullptr},
    {"urlToLocalFileOrQrc", reinterpret_cast<PyCFunction>(Sbk_QQmlFileFunc_urlToLocalFileOrQrc), METH_O|METH_STATIC, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QQmlFile___nb_bool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QQmlFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return !cppSelf->isNull() ? 1 : 0;
}

} // extern "C"

static int Sbk_QQmlFile_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QQmlFile_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QQmlFile_Type = nullptr;
static PyTypeObject *Sbk_QQmlFile_TypeF(void)
{
    return _Sbk_QQmlFile_Type;
}

static PyType_Slot Sbk_QQmlFile_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QQmlFile_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QQmlFile_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QQmlFile_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QQmlFile_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_bool,        reinterpret_cast<void *>(Sbk_QQmlFile___nb_bool)},
    {0, nullptr}
};
static PyType_Spec Sbk_QQmlFile_spec = {
    "2:PySide6.QtQml.QQmlFile",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QQmlFile_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QQmlFile_Status(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QQmlFile::Status>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QQmlFile::Status *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QQmlFile_Status_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlFile_Status_IDX])))
        return Enum_PythonToCpp_QQmlFile_Status;
    return {};
}

static PyObject *QQmlFile_Status_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QQmlFile::Status>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QQmlFile::Status *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlFile_Status_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QQmlFile_PythonToCpp_QQmlFile_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QQmlFile_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QQmlFile_PythonToCpp_QQmlFile_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QQmlFile_TypeF()))
        return QQmlFile_PythonToCpp_QQmlFile_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QQmlFile_PTR_CppToPython_QQmlFile(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QQmlFile_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QQmlFile_SignatureStrings[] = {
    "2:PySide6.QtQml.QQmlFile(self)",
    "1:PySide6.QtQml.QQmlFile(self,engine:PySide6.QtQml.QQmlEngine,url:QString)",
    "0:PySide6.QtQml.QQmlFile(self,engine:PySide6.QtQml.QQmlEngine,url:typing.Union[PySide6.QtCore.QUrl, QString])",
    "1:PySide6.QtQml.QQmlFile.clear(self)",
    "0:PySide6.QtQml.QQmlFile.clear(self,object:PySide6.QtCore.QObject)",
    "1:PySide6.QtQml.QQmlFile.connectDownloadProgress(self,arg__1:PySide6.QtCore.QObject,arg__2:char*)->bool",
    "0:PySide6.QtQml.QQmlFile.connectDownloadProgress(self,arg__1:PySide6.QtCore.QObject,arg__2:int)->bool",
    "1:PySide6.QtQml.QQmlFile.connectFinished(self,arg__1:PySide6.QtCore.QObject,arg__2:char*)->bool",
    "0:PySide6.QtQml.QQmlFile.connectFinished(self,arg__1:PySide6.QtCore.QObject,arg__2:int)->bool",
    "PySide6.QtQml.QQmlFile.data(self)->char*",
    "PySide6.QtQml.QQmlFile.dataByteArray(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtQml.QQmlFile.error(self)->QString",
    "PySide6.QtQml.QQmlFile.isError(self)->bool",
    "PySide6.QtQml.QQmlFile.isLoading(self)->bool",
    "1:PySide6.QtQml.QQmlFile.isLocalFile(url:QString)->bool",
    "0:PySide6.QtQml.QQmlFile.isLocalFile(url:typing.Union[PySide6.QtCore.QUrl, QString])->bool",
    "PySide6.QtQml.QQmlFile.isNull(self)->bool",
    "PySide6.QtQml.QQmlFile.isReady(self)->bool",
    "1:PySide6.QtQml.QQmlFile.isSynchronous(url:QString)->bool",
    "0:PySide6.QtQml.QQmlFile.isSynchronous(url:typing.Union[PySide6.QtCore.QUrl, QString])->bool",
    "1:PySide6.QtQml.QQmlFile.load(self,arg__1:PySide6.QtQml.QQmlEngine,arg__2:QString)",
    "0:PySide6.QtQml.QQmlFile.load(self,arg__1:PySide6.QtQml.QQmlEngine,arg__2:typing.Union[PySide6.QtCore.QUrl, QString])",
    "PySide6.QtQml.QQmlFile.size(self)->qint64",
    "PySide6.QtQml.QQmlFile.status(self)->PySide6.QtQml.QQmlFile.Status",
    "PySide6.QtQml.QQmlFile.url(self)->PySide6.QtCore.QUrl",
    "1:PySide6.QtQml.QQmlFile.urlToLocalFileOrQrc(arg__1:QString)->QString",
    "0:PySide6.QtQml.QQmlFile.urlToLocalFileOrQrc(arg__1:typing.Union[PySide6.QtCore.QUrl, QString])->QString",
    nullptr}; // Sentinel
#else
static constexpr size_t QQmlFile_SignatureByteSize = 380;
static constexpr uint8_t QQmlFile_SignatureBytes[380] = {
    0x78, 0xda, 0xb5, 0x54, 0xcb, 0x6e, 0xc2, 0x30, 0x10, 0xbc, 0xf3, 0x15, 0x3d, 0x92, 0x2a, 0x44,
    0x80, 0x2a, 0x0e, 0x39, 0x20, 0xf5, 0x01, 0xa7, 0xaa, 0x90, 0xa6, 0x9c, 0xaa, 0x0a, 0x99, 0x64,
    0x9b, 0xb8, 0x72, 0xed, 0x76, 0xed, 0xa8, 0x4a, 0xbf, 0xbe, 0x26, 0x0f, 0x08, 0x69, 0x9d, 0x10,
    0x50, 0x2f, 0x39, 0xc4, 0xb3, 0x33, 0x3b, 0xde, 0x1d, 0x8f, 0xdd, 0x65, 0xea, 0xd3, 0x10, 0x26,
    0x8e, 0xa7, 0xbc, 0x77, 0xe6, 0x78, 0xfa, 0x33, 0xa7, 0x0c, 0xfa, 0x12, 0xd8, 0xab, 0xd5, 0x1b,
    0x35, 0x1d, 0xdb, 0xc0, 0x23, 0xca, 0xe1, 0x0f, 0xc8, 0x2c, 0x3b, 0xb0, 0x13, 0x64, 0xae, 0xe7,
    0x2b, 0xa4, 0x3c, 0xb2, 0x7a, 0xc3, 0xb3, 0xa9, 0x54, 0xfa, 0xa1, 0x99, 0x9c, 0x15, 0xa7, 0x82,
    0x3f, 0xef, 0x91, 0xb7, 0x02, 0xc1, 0xf1, 0x56, 0xc8, 0xec, 0x8b, 0x42, 0xec, 0xc5, 0xdc, 0xb8,
    0x13, 0x30, 0x20, 0x58, 0xb8, 0x1b, 0xb6, 0x83, 0x6c, 0xb1, 0x79, 0x83, 0x40, 0xb9, 0x75, 0xb9,
    0x45, 0xf6, 0xbb, 0x49, 0x47, 0x70, 0xae, 0x11, 0x77, 0xe2, 0x8b, 0x33, 0x41, 0xc2, 0x25, 0x8a,
    0x08, 0x41, 0xca, 0x9c, 0x94, 0x60, 0xb4, 0x5e, 0x8f, 0x0c, 0xa4, 0xf9, 0xe9, 0xd8, 0x0d, 0x62,
    0x82, 0x97, 0xd6, 0x60, 0xba, 0x11, 0x82, 0x35, 0xb4, 0x7a, 0xb6, 0x0e, 0xe5, 0xaa, 0x54, 0x69,
    0x73, 0x33, 0xa7, 0x9c, 0xca, 0x18, 0xc2, 0xff, 0x72, 0x71, 0x02, 0x7f, 0xa5, 0x7b, 0x03, 0x77,
    0x48, 0x14, 0xc9, 0x07, 0x3e, 0x98, 0x66, 0xdd, 0x34, 0x01, 0x6f, 0x52, 0x05, 0xd7, 0x88, 0x24,
    0x2d, 0x2b, 0xea, 0xea, 0x3b, 0x80, 0x89, 0x05, 0x10, 0x05, 0x96, 0xd5, 0xc5, 0x42, 0x9a, 0xb0,
    0x54, 0xce, 0xaa, 0xe8, 0x26, 0x17, 0x54, 0xde, 0xeb, 0xf1, 0x6a, 0xae, 0x03, 0xb0, 0x71, 0x60,
    0x5b, 0x78, 0x40, 0xf2, 0x80, 0x55, 0x63, 0xd8, 0x36, 0x88, 0x7a, 0x5d, 0x87, 0xcc, 0xb5, 0xf5,
    0xff, 0x90, 0x30, 0x76, 0x9c, 0xd3, 0x47, 0x20, 0x61, 0x7a, 0xac, 0x4f, 0x3f, 0xe5, 0x41, 0x8c,
    0x82, 0x8b, 0x44, 0x76, 0x74, 0x5a, 0xaf, 0xec, 0xee, 0xd5, 0xd8, 0xd6, 0x36, 0x8a, 0x86, 0x25,
    0xae, 0x3d, 0x6c, 0xc5, 0x1a, 0xb7, 0x3e, 0x93, 0xdd, 0x29, 0xbb, 0x3c, 0x97, 0x06, 0x4d, 0x49,
    0xbf, 0xa1, 0x9c, 0xc3, 0xa7, 0x4e, 0xda, 0xe4, 0xca, 0x88, 0x54, 0x44, 0x25, 0xf2, 0x77, 0x68,
    0x0e, 0x40, 0x7e, 0x06, 0x32, 0x51, 0xe8, 0x11, 0x98, 0x42, 0xa7, 0xbb, 0x35, 0xdf, 0xb5, 0xae,
    0x7b, 0x12, 0xbb, 0xad, 0x5d, 0xa0, 0x87, 0x41, 0xbf, 0xb8, 0xa2, 0xfd, 0x2e, 0x94, 0x41, 0x1c,
    0x9e, 0xc0, 0xd2, 0x69, 0x2f, 0x4a, 0xa1, 0x1f, 0x60, 0x8c, 0x90, 0x90
};
#endif

PyTypeObject *init_QQmlFile(PyObject *module)
{
    if (SbkPySide6_QtQmlTypeStructs[SBK_QQmlFile_IDX].type != nullptr)
        return SbkPySide6_QtQmlTypeStructs[SBK_QQmlFile_IDX].type;

    Shiboken::AutoDecRef Sbk_QQmlFile_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QQmlFile_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QQmlFile",
        "QQmlFile*",
        &Sbk_QQmlFile_spec,
        &Shiboken::callCppDestructor< ::QQmlFile >,
        Sbk_QQmlFile_Type_bases.object(),
        0);
    auto *pyType = Sbk_QQmlFile_TypeF(); // references _Sbk_QQmlFile_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QQmlFile_SignatureStrings);
#else
    InitSignatureBytes(pyType, QQmlFile_SignatureBytes, QQmlFile_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QQmlFile_PropertyStrings);
    SbkPySide6_QtQmlTypeStructs[SBK_QQmlFile_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QQmlFile_PythonToCpp_QQmlFile_PTR,
        is_QQmlFile_PythonToCpp_QQmlFile_PTR_Convertible,
        QQmlFile_PTR_CppToPython_QQmlFile);

    Shiboken::Conversions::registerConverterName(converter, "QQmlFile");
    Shiboken::Conversions::registerConverterName(converter, "QQmlFile*");
    Shiboken::Conversions::registerConverterName(converter, "QQmlFile&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QQmlFile).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QQmlFile_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Status'.
    const char *Status_Initializer[] = {
        "Null",
        "Ready",
        "Error",
        "Loading",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Status_InitializerValues[] = {
        uint8_t(QQmlFile::Status::Null),   //  0x00  0
        uint8_t(QQmlFile::Status::Ready),  //  0x01  1
        uint8_t(QQmlFile::Status::Error),  //  0x02  2
        uint8_t(QQmlFile::Status::Loading) //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QQmlFile_TypeF(),
        "2:PySide6.QtQml.QQmlFile.Status",
        Status_Initializer, Status_InitializerValues);
    SbkPySide6_QtQmlTypeStructs[SBK_QQmlFile_Status_IDX].type = EType;
    // Register converter for enum 'QQmlFile::Status'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QQmlFile_Status_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QQmlFile_Status,
            is_Enum_PythonToCpp_QQmlFile_Status_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QQmlFile::Status");
        Shiboken::Conversions::registerConverterAlias(converter, "Status");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Status' enum.

    qRegisterMetaType< ::QQmlFile *>();
    qRegisterMetaType< ::QQmlFile::Status >("QQmlFile::Status");

    return pyType;
}
