// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtqml_python.h"

// main header
#include "qqmlincubationcontroller_wrapper.h"

// Extra includes
#include "pysideqmlvolatilebool.h"

// Argument includes
#include <QtQml/qqmlengine.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QQmlIncubationControllerWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QQmlIncubationControllerWrapper::QQmlIncubationControllerWrapper()
{
}

void QQmlIncubationControllerWrapper::incubatingObjectCountChanged(int arg__1)
{
    if (m_PyMethodCache[0]) {
        return this->::QQmlIncubationController::incubatingObjectCountChanged(arg__1);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "incubatingObjectCountChanged";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QQmlIncubationController::incubatingObjectCountChanged(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &arg__1)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(i)",
        arg__1
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQmlIncubationController", funcName);
        return;
    }
}

QQmlIncubationControllerWrapper::~QQmlIncubationControllerWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QQmlIncubationController_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QQmlIncubationController >()))
        return -1;

    QQmlIncubationControllerWrapper *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtQmlTypeStructs[SBK_QQmlIncubationController_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QQmlIncubationController()
        cptr = new QQmlIncubationControllerWrapper();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QQmlIncubationController >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QQmlIncubationControllerFunc_engine(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlIncubationController *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlIncubationController_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // engine()const
        QQmlEngine * cppResult = const_cast<const ::QQmlIncubationController *>(cppSelf)->engine();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlIncubationControllerFunc_incubateFor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlIncubationController *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlIncubationController_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQmlIncubationController::incubateFor(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // incubateFor(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "incubateFor", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlIncubationController_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // incubateFor(int)
            cppSelf->incubateFor(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQmlIncubationControllerFunc_incubateWhile(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlIncubationController *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlIncubationController_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "incubateWhile", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlIncubationController_IDX]);

    if (PyArg_ParseTuple(args, "|OO:incubateWhile", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QQmlIncubationController::incubateWhile(VolatileBool,int=)
    if (numArgs >= 1
        && VolatileBool_Check(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // incubateWhile(std::atomic<bool>*,int)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 0; // incubateWhile(std::atomic<bool>*,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "incubateWhile", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlIncubationController_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_msecs = Shiboken::String::createStaticString("msecs");
            if (PyDict_Contains(kwds, key_msecs) != 0) {
                value = PyDict_GetItem(kwds, key_msecs);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_msecs);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "incubateWhile", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlIncubationController_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "incubateWhile", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlIncubationController_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_msecs);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "incubateWhile", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlIncubationController_IDX]);
            }
        }
        int cppArg1 = 0;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // incubateWhile(std::atomic<bool>*,int)
            // Begin code injection
            auto volatileBool = reinterpret_cast<QtQml_VolatileBoolObject *>(pyArgs[1-1]);
            std::atomic<bool> *flag_out = volatileBool->flag;
            // End of code injection

            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->incubateWhile(flag_out, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQmlIncubationControllerFunc_incubatingObjectCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlIncubationController *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlIncubationController_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // incubatingObjectCount()const
        int cppResult = const_cast<const ::QQmlIncubationController *>(cppSelf)->incubatingObjectCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlIncubationControllerFunc_incubatingObjectCountChanged(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlIncubationController *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlIncubationController_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQmlIncubationController::incubatingObjectCountChanged(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // incubatingObjectCountChanged(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "incubatingObjectCountChanged", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlIncubationController_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // incubatingObjectCountChanged(int)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QQmlIncubationController::incubatingObjectCountChanged(cppArg0)
                : cppSelf->incubatingObjectCountChanged(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QQmlIncubationController_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QQmlIncubationController_methods[] = {
    {"engine", reinterpret_cast<PyCFunction>(Sbk_QQmlIncubationControllerFunc_engine), METH_NOARGS, nullptr},
    {"incubateFor", reinterpret_cast<PyCFunction>(Sbk_QQmlIncubationControllerFunc_incubateFor), METH_O, nullptr},
    {"incubateWhile", reinterpret_cast<PyCFunction>(Sbk_QQmlIncubationControllerFunc_incubateWhile), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"incubatingObjectCount", reinterpret_cast<PyCFunction>(Sbk_QQmlIncubationControllerFunc_incubatingObjectCount), METH_NOARGS, nullptr},
    {"incubatingObjectCountChanged", reinterpret_cast<PyCFunction>(Sbk_QQmlIncubationControllerFunc_incubatingObjectCountChanged), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QQmlIncubationController_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QQmlIncubationController *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlIncubationController_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QQmlIncubationControllerWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QQmlIncubationController_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QQmlIncubationController_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QQmlIncubationController_Type = nullptr;
static PyTypeObject *Sbk_QQmlIncubationController_TypeF(void)
{
    return _Sbk_QQmlIncubationController_Type;
}

static PyType_Slot Sbk_QQmlIncubationController_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QQmlIncubationController_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QQmlIncubationController_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QQmlIncubationController_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QQmlIncubationController_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QQmlIncubationController_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QQmlIncubationController_spec = {
    "2:PySide6.QtQml.QQmlIncubationController",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QQmlIncubationController_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QQmlIncubationController_PythonToCpp_QQmlIncubationController_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QQmlIncubationController_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QQmlIncubationController_PythonToCpp_QQmlIncubationController_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QQmlIncubationController_TypeF()))
        return QQmlIncubationController_PythonToCpp_QQmlIncubationController_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QQmlIncubationController_PTR_CppToPython_QQmlIncubationController(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QQmlIncubationController *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QQmlIncubationController_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QQmlIncubationController_SignatureStrings[] = {
    "PySide6.QtQml.QQmlIncubationController(self)",
    "PySide6.QtQml.QQmlIncubationController.engine(self)->PySide6.QtQml.QQmlEngine",
    "PySide6.QtQml.QQmlIncubationController.incubateFor(self,msecs:int)",
    "PySide6.QtQml.QQmlIncubationController.incubateWhile(self,flag:VolatileBool,msecs:int=0)",
    "PySide6.QtQml.QQmlIncubationController.incubatingObjectCount(self)->int",
    "PySide6.QtQml.QQmlIncubationController.incubatingObjectCountChanged(self,arg__1:int)",
    nullptr}; // Sentinel
#else
static constexpr size_t QQmlIncubationController_SignatureByteSize = 161;
static constexpr uint8_t QQmlIncubationController_SignatureBytes[161] = {
    0x78, 0xda, 0xa5, 0x8f, 0xb1, 0x0a, 0xc2, 0x40, 0x10, 0x44, 0x7b, 0xbf, 0xc4, 0x40, 0x0c, 0xda,
    0x58, 0x04, 0xb4, 0xf0, 0x50, 0xb0, 0x32, 0x41, 0xd0, 0x32, 0x5c, 0x2e, 0x9b, 0xcb, 0xca, 0x66,
    0x17, 0xee, 0x2e, 0x85, 0x7f, 0x6f, 0xf0, 0x10, 0x0b, 0x9b, 0x04, 0x9b, 0x2d, 0x66, 0x67, 0x1e,
    0x33, 0xc5, 0xf3, 0x8a, 0x0d, 0x6c, 0xb3, 0x32, 0x94, 0x3d, 0x65, 0xe5, 0x78, 0xce, 0x6c, 0x86,
    0x5a, 0x07, 0x14, 0x56, 0xc2, 0xc1, 0x09, 0x11, 0xb8, 0xa5, 0x07, 0x6a, 0x93, 0x45, 0x31, 0xc9,
    0x9c, 0x01, 0x5b, 0x64, 0x88, 0x99, 0xd5, 0xfe, 0x37, 0x74, 0x7c, 0xff, 0xa7, 0xd2, 0x30, 0x8a,
    0x70, 0x92, 0x58, 0x23, 0xed, 0x3d, 0x18, 0x9f, 0x23, 0x87, 0x64, 0x2e, 0xe2, 0xde, 0x21, 0xc5,
    0x5e, 0x69, 0x4b, 0xda, 0xe6, 0x37, 0xa1, 0xd1, 0x4a, 0x70, 0x10, 0xa1, 0x2f, 0x76, 0xb7, 0x9e,
    0x0b, 0x46, 0xb6, 0x97, 0xfa, 0x01, 0x26, 0x28, 0x19, 0x38, 0x7c, 0x86, 0x8f, 0xa8, 0xbf, 0x38,
    0xaa, 0xd3, 0x6c, 0xa1, 0x89, 0x7d, 0xb5, 0xb3, 0x55, 0xb5, 0x89, 0xab, 0x5f, 0x28, 0x09, 0xa1,
    0x2b
};
#endif

PyTypeObject *init_QQmlIncubationController(PyObject *module)
{
    if (SbkPySide6_QtQmlTypeStructs[SBK_QQmlIncubationController_IDX].type != nullptr)
        return SbkPySide6_QtQmlTypeStructs[SBK_QQmlIncubationController_IDX].type;

    Shiboken::AutoDecRef Sbk_QQmlIncubationController_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QQmlIncubationController_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QQmlIncubationController",
        "QQmlIncubationController*",
        &Sbk_QQmlIncubationController_spec,
        &Shiboken::callCppDestructor< QQmlIncubationController >,
        Sbk_QQmlIncubationController_Type_bases.object(),
        0);
    auto *pyType = Sbk_QQmlIncubationController_TypeF(); // references _Sbk_QQmlIncubationController_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QQmlIncubationController_SignatureStrings);
#else
    InitSignatureBytes(pyType, QQmlIncubationController_SignatureBytes, QQmlIncubationController_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QQmlIncubationController_PropertyStrings);
    SbkPySide6_QtQmlTypeStructs[SBK_QQmlIncubationController_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QQmlIncubationController_PythonToCpp_QQmlIncubationController_PTR,
        is_QQmlIncubationController_PythonToCpp_QQmlIncubationController_PTR_Convertible,
        QQmlIncubationController_PTR_CppToPython_QQmlIncubationController);

    Shiboken::Conversions::registerConverterName(converter, "QQmlIncubationController");
    Shiboken::Conversions::registerConverterName(converter, "QQmlIncubationController*");
    Shiboken::Conversions::registerConverterName(converter, "QQmlIncubationController&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QQmlIncubationController).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QQmlIncubationControllerWrapper).name());

    qRegisterMetaType< ::QQmlIncubationController *>();

    return pyType;
}
