// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtqml_python.h"

// main header
#include "qqmlparserstatus_wrapper.h"

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QQmlParserStatusWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QQmlParserStatusWrapper::QQmlParserStatusWrapper()
{
}

void QQmlParserStatusWrapper::classBegin()
{
    if (m_PyMethodCache[0]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QQmlParserStatus.classBegin");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "classBegin";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        Shiboken::Errors::setPureVirtualMethodError("QQmlParserStatus.classBegin");
        return;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQmlParserStatus", funcName);
        return;
    }
}

void QQmlParserStatusWrapper::componentComplete()
{
    if (m_PyMethodCache[1]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QQmlParserStatus.componentComplete");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "componentComplete";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        Shiboken::Errors::setPureVirtualMethodError("QQmlParserStatus.componentComplete");
        return;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQmlParserStatus", funcName);
        return;
    }
}

QQmlParserStatusWrapper::~QQmlParserStatusWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QQmlParserStatus_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlParserStatus_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QQmlParserStatus");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QQmlParserStatus >()))
        return -1;

    QQmlParserStatusWrapper *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtQmlTypeStructs[SBK_QQmlParserStatus_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QQmlParserStatus()
        cptr = new QQmlParserStatusWrapper();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QQmlParserStatus >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QQmlParserStatusFunc_classBegin(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlParserStatus *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlParserStatus_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // classBegin()
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QQmlParserStatus.classBegin");
            return {};
        }
        cppSelf->classBegin();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQmlParserStatusFunc_componentComplete(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlParserStatus *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlParserStatus_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // componentComplete()
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QQmlParserStatus.componentComplete");
            return {};
        }
        cppSelf->componentComplete();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QQmlParserStatus_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QQmlParserStatus_methods[] = {
    {"classBegin", reinterpret_cast<PyCFunction>(Sbk_QQmlParserStatusFunc_classBegin), METH_NOARGS, nullptr},
    {"componentComplete", reinterpret_cast<PyCFunction>(Sbk_QQmlParserStatusFunc_componentComplete), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QQmlParserStatus_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QQmlParserStatus *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlParserStatus_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QQmlParserStatusWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QQmlParserStatus_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QQmlParserStatus_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QQmlParserStatus_Type = nullptr;
static PyTypeObject *Sbk_QQmlParserStatus_TypeF(void)
{
    return _Sbk_QQmlParserStatus_Type;
}

static PyType_Slot Sbk_QQmlParserStatus_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QQmlParserStatus_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QQmlParserStatus_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QQmlParserStatus_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QQmlParserStatus_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QQmlParserStatus_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QQmlParserStatus_spec = {
    "2:PySide6.QtQml.QQmlParserStatus",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QQmlParserStatus_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QQmlParserStatus_PythonToCpp_QQmlParserStatus_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QQmlParserStatus_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QQmlParserStatus_PythonToCpp_QQmlParserStatus_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QQmlParserStatus_TypeF()))
        return QQmlParserStatus_PythonToCpp_QQmlParserStatus_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QQmlParserStatus_PTR_CppToPython_QQmlParserStatus(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QQmlParserStatus *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QQmlParserStatus_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QQmlParserStatus_SignatureStrings[] = {
    "PySide6.QtQml.QQmlParserStatus(self)",
    "PySide6.QtQml.QQmlParserStatus.classBegin(self)",
    "PySide6.QtQml.QQmlParserStatus.componentComplete(self)",
    nullptr}; // Sentinel
#else
static constexpr size_t QQmlParserStatus_SignatureByteSize = 77;
static constexpr uint8_t QQmlParserStatus_SignatureBytes[77] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x09, 0xcc, 0xcd, 0xd1,
    0x0b, 0x04, 0x12, 0x01, 0x89, 0x45, 0xc5, 0xa9, 0x45, 0xc1, 0x25, 0x89, 0x25, 0xa5, 0xc5, 0x1a,
    0xc5, 0xa9, 0x39, 0x69, 0x9a, 0x5c, 0x01, 0x78, 0x15, 0xe9, 0x25, 0xe7, 0x24, 0x16, 0x17, 0x3b,
    0xa5, 0xa6, 0x67, 0xe6, 0x11, 0xa9, 0x3e, 0x3f, 0xb7, 0x20, 0x3f, 0x2f, 0x35, 0xaf, 0xc4, 0x19,
    0xc8, 0xc8, 0x49, 0x2d, 0x49, 0x85, 0x6a, 0x03, 0x00, 0xfd, 0xa7, 0x33, 0x24
};
#endif

PyTypeObject *init_QQmlParserStatus(PyObject *module)
{
    if (SbkPySide6_QtQmlTypeStructs[SBK_QQmlParserStatus_IDX].type != nullptr)
        return SbkPySide6_QtQmlTypeStructs[SBK_QQmlParserStatus_IDX].type;

    Shiboken::AutoDecRef Sbk_QQmlParserStatus_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QQmlParserStatus_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QQmlParserStatus",
        "QQmlParserStatus*",
        &Sbk_QQmlParserStatus_spec,
        &Shiboken::callCppDestructor< QQmlParserStatus >,
        Sbk_QQmlParserStatus_Type_bases.object(),
        0);
    auto *pyType = Sbk_QQmlParserStatus_TypeF(); // references _Sbk_QQmlParserStatus_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QQmlParserStatus_SignatureStrings);
#else
    InitSignatureBytes(pyType, QQmlParserStatus_SignatureBytes, QQmlParserStatus_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QQmlParserStatus_PropertyStrings);
    SbkPySide6_QtQmlTypeStructs[SBK_QQmlParserStatus_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QQmlParserStatus_PythonToCpp_QQmlParserStatus_PTR,
        is_QQmlParserStatus_PythonToCpp_QQmlParserStatus_PTR_Convertible,
        QQmlParserStatus_PTR_CppToPython_QQmlParserStatus);

    Shiboken::Conversions::registerConverterName(converter, "QQmlParserStatus");
    Shiboken::Conversions::registerConverterName(converter, "QQmlParserStatus*");
    Shiboken::Conversions::registerConverterName(converter, "QQmlParserStatus&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QQmlParserStatus).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QQmlParserStatusWrapper).name());

    qRegisterMetaType< ::QQmlParserStatus *>();

    return pyType;
}
