// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtqml_python.h"

// main header
#include "qqmlscriptstring_wrapper.h"

// Argument includes
#include <QString>
#include <QtQml/qqmlscriptstring.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QQmlScriptString_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QQmlScriptString >()))
        return -1;

    ::QQmlScriptString *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QQmlScriptString", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QQmlScriptString::QQmlScriptString()
    // 1: QQmlScriptString::QQmlScriptString(QQmlScriptString)
    if (numArgs == 0) {
        overloadId = 0; // QQmlScriptString()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlScriptString_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QQmlScriptString(QQmlScriptString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlScriptString_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtQmlTypeStructs[SBK_QQmlScriptString_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QQmlScriptString()
        {

            // QQmlScriptString()
            cptr = new ::QQmlScriptString();
            break;
        }
        case 1: // QQmlScriptString(const QQmlScriptString &arg__1)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QQmlScriptString cppArg0_local;
            ::QQmlScriptString *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QQmlScriptString(QQmlScriptString)
                cptr = new ::QQmlScriptString(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QQmlScriptString >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlScriptString_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QQmlScriptStringFunc_booleanLiteral(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlScriptString *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlScriptString_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // booleanLiteral(bool*)const
            // Begin code injection
            // TEMPLATE - fix_bool* - START
            bool ok_;
            bool retval_ = cppSelf->booleanLiteral(&ok_);
            // TEMPLATE - tuple_retval_ok - START
            pyResult = PyTuple_New(2);
            PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &retval_));
            PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &ok_));
            // TEMPLATE - tuple_retval_ok - END
            // TEMPLATE - fix_bool* - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlScriptStringFunc_isEmpty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlScriptString *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlScriptString_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isEmpty()const
        bool cppResult = const_cast<const ::QQmlScriptString *>(cppSelf)->isEmpty();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlScriptStringFunc_isNullLiteral(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlScriptString *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlScriptString_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isNullLiteral()const
        bool cppResult = const_cast<const ::QQmlScriptString *>(cppSelf)->isNullLiteral();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlScriptStringFunc_isUndefinedLiteral(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlScriptString *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlScriptString_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isUndefinedLiteral()const
        bool cppResult = const_cast<const ::QQmlScriptString *>(cppSelf)->isUndefinedLiteral();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlScriptStringFunc_numberLiteral(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlScriptString *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlScriptString_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // numberLiteral(bool*)const
            // Begin code injection
            // TEMPLATE - fix_bool* - START
            bool ok_;
            qreal retval_ = cppSelf->numberLiteral(&ok_);
            // TEMPLATE - tuple_retval_ok - START
            pyResult = PyTuple_New(2);
            PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &retval_));
            PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &ok_));
            // TEMPLATE - tuple_retval_ok - END
            // TEMPLATE - fix_bool* - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlScriptStringFunc_stringLiteral(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlScriptString *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlScriptString_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // stringLiteral()const
        QString cppResult = const_cast<const ::QQmlScriptString *>(cppSelf)->stringLiteral();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlScriptString__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QQmlScriptString *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlScriptString_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlScriptString_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QQmlScriptString_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QQmlScriptString_methods[] = {
    {"booleanLiteral", reinterpret_cast<PyCFunction>(Sbk_QQmlScriptStringFunc_booleanLiteral), METH_NOARGS, nullptr},
    {"isEmpty", reinterpret_cast<PyCFunction>(Sbk_QQmlScriptStringFunc_isEmpty), METH_NOARGS, nullptr},
    {"isNullLiteral", reinterpret_cast<PyCFunction>(Sbk_QQmlScriptStringFunc_isNullLiteral), METH_NOARGS, nullptr},
    {"isUndefinedLiteral", reinterpret_cast<PyCFunction>(Sbk_QQmlScriptStringFunc_isUndefinedLiteral), METH_NOARGS, nullptr},
    {"numberLiteral", reinterpret_cast<PyCFunction>(Sbk_QQmlScriptStringFunc_numberLiteral), METH_NOARGS, nullptr},
    {"stringLiteral", reinterpret_cast<PyCFunction>(Sbk_QQmlScriptStringFunc_stringLiteral), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QQmlScriptString__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QQmlScriptString_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QQmlScriptString *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlScriptString_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlScriptString_IDX]), (pyArg)))) {
                // operator!=(const QQmlScriptString &arg__1) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QQmlScriptString cppArg0_local;
                ::QQmlScriptString *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlScriptString_IDX]), (pyArg)))) {
                // operator==(const QQmlScriptString &arg__1) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QQmlScriptString cppArg0_local;
                ::QQmlScriptString *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QQmlScriptString_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QQmlScriptString_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QQmlScriptString_Type = nullptr;
static PyTypeObject *Sbk_QQmlScriptString_TypeF(void)
{
    return _Sbk_QQmlScriptString_Type;
}

static PyType_Slot Sbk_QQmlScriptString_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QQmlScriptString_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QQmlScriptString_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QQmlScriptString_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QQmlScriptString_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QQmlScriptString_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QQmlScriptString_spec = {
    "2:PySide6.QtQml.QQmlScriptString",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QQmlScriptString_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QQmlScriptString_PythonToCpp_QQmlScriptString_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QQmlScriptString_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QQmlScriptString_PythonToCpp_QQmlScriptString_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QQmlScriptString_TypeF()))
        return QQmlScriptString_PythonToCpp_QQmlScriptString_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QQmlScriptString_PTR_CppToPython_QQmlScriptString(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QQmlScriptString_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QQmlScriptString_COPY_CppToPython_QQmlScriptString(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QQmlScriptString *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QQmlScriptString_TypeF(), new ::QQmlScriptString(*source), true, true);
}

// Python to C++ copy conversion.
static void QQmlScriptString_PythonToCpp_QQmlScriptString_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QQmlScriptString *>(cppOut) = *reinterpret_cast< ::QQmlScriptString *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlScriptString_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QQmlScriptString_PythonToCpp_QQmlScriptString_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QQmlScriptString_TypeF()))
        return QQmlScriptString_PythonToCpp_QQmlScriptString_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QQmlScriptString_SignatureStrings[] = {
    "1:PySide6.QtQml.QQmlScriptString(self)",
    "0:PySide6.QtQml.QQmlScriptString(self,arg__1:PySide6.QtQml.QQmlScriptString)",
    "PySide6.QtQml.QQmlScriptString.booleanLiteral(self)->Tuple[bool, bool]",
    "PySide6.QtQml.QQmlScriptString.isEmpty(self)->bool",
    "PySide6.QtQml.QQmlScriptString.isNullLiteral(self)->bool",
    "PySide6.QtQml.QQmlScriptString.isUndefinedLiteral(self)->bool",
    "PySide6.QtQml.QQmlScriptString.numberLiteral(self)->Tuple[float, bool]",
    "PySide6.QtQml.QQmlScriptString.stringLiteral(self)->QString",
    "PySide6.QtQml.QQmlScriptString.__copy__(self)->typing.Self",
    "PySide6.QtQml.QQmlScriptString.__ne__(self,arg__1:PySide6.QtQml.QQmlScriptString)->bool",
    "PySide6.QtQml.QQmlScriptString.__eq__(self,arg__1:PySide6.QtQml.QQmlScriptString)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QQmlScriptString_SignatureByteSize = 189;
static constexpr uint8_t QQmlScriptString_SignatureBytes[189] = {
    0x78, 0xda, 0x9d, 0x92, 0xb1, 0x0e, 0xc2, 0x20, 0x10, 0x86, 0xf7, 0x3e, 0x85, 0xa3, 0x4d, 0x6a,
    0x63, 0x17, 0x07, 0x07, 0x37, 0x37, 0x63, 0x24, 0xe8, 0x64, 0x0c, 0xa1, 0xed, 0xd5, 0x90, 0x5c,
    0x01, 0x29, 0x1d, 0x78, 0x7b, 0x8b, 0xb5, 0x4b, 0x63, 0x84, 0x74, 0x39, 0x72, 0xfc, 0xf7, 0xfd,
    0xc7, 0x91, 0x2b, 0xf6, 0x17, 0x47, 0x45, 0x0d, 0xbb, 0x9c, 0x58, 0xd2, 0x62, 0x4e, 0x86, 0x40,
    0x2b, 0x23, 0xb4, 0xa5, 0xd6, 0x08, 0xf9, 0x5c, 0x77, 0x80, 0x4d, 0x9a, 0x6c, 0x63, 0xca, 0x32,
    0x6e, 0x9e, 0x8c, 0x15, 0x81, 0xd2, 0x34, 0xf9, 0xaf, 0xe7, 0xa5, 0x52, 0x08, 0x5c, 0x9e, 0x84,
    0x05, 0xc3, 0x71, 0x7c, 0xc0, 0xe6, 0x70, 0xed, 0x35, 0xc2, 0xdd, 0x6b, 0xd9, 0xca, 0xc7, 0x47,
    0xc8, 0x46, 0x74, 0xc7, 0x56, 0x5b, 0x37, 0xf1, 0x9e, 0x09, 0x23, 0xe7, 0x1e, 0x71, 0xd6, 0x38,
    0x0e, 0xbc, 0xc9, 0x1a, 0x1a, 0x21, 0xa1, 0x5e, 0x40, 0xcb, 0xbe, 0x2d, 0xc1, 0xfc, 0x9c, 0xb7,
    0x41, 0xc5, 0x6d, 0xe4, 0xc0, 0xdd, 0xe7, 0x98, 0xd9, 0x90, 0x51, 0x0c, 0xb1, 0x8c, 0x55, 0x4a,
    0x3b, 0xc6, 0x26, 0xcc, 0x3a, 0xed, 0xaf, 0xe9, 0x90, 0x85, 0x51, 0x09, 0x5f, 0x30, 0x72, 0x01,
    0xe2, 0x7e, 0x85, 0x31, 0x78, 0x2d, 0xf2, 0x7d, 0x03, 0x83, 0x6c, 0x05, 0x74
};
#endif

PyTypeObject *init_QQmlScriptString(PyObject *module)
{
    if (SbkPySide6_QtQmlTypeStructs[SBK_QQmlScriptString_IDX].type != nullptr)
        return SbkPySide6_QtQmlTypeStructs[SBK_QQmlScriptString_IDX].type;

    Shiboken::AutoDecRef Sbk_QQmlScriptString_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QQmlScriptString_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QQmlScriptString",
        "QQmlScriptString",
        &Sbk_QQmlScriptString_spec,
        &Shiboken::callCppDestructor< ::QQmlScriptString >,
        Sbk_QQmlScriptString_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QQmlScriptString_TypeF(); // references _Sbk_QQmlScriptString_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QQmlScriptString_SignatureStrings);
#else
    InitSignatureBytes(pyType, QQmlScriptString_SignatureBytes, QQmlScriptString_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QQmlScriptString_PropertyStrings);
    SbkPySide6_QtQmlTypeStructs[SBK_QQmlScriptString_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QQmlScriptString_PythonToCpp_QQmlScriptString_PTR,
        is_QQmlScriptString_PythonToCpp_QQmlScriptString_PTR_Convertible,
        QQmlScriptString_PTR_CppToPython_QQmlScriptString,
        QQmlScriptString_COPY_CppToPython_QQmlScriptString);

    Shiboken::Conversions::registerConverterName(converter, "QQmlScriptString");
    Shiboken::Conversions::registerConverterName(converter, "QQmlScriptString*");
    Shiboken::Conversions::registerConverterName(converter, "QQmlScriptString&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QQmlScriptString).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QQmlScriptString_PythonToCpp_QQmlScriptString_COPY,
        is_QQmlScriptString_PythonToCpp_QQmlScriptString_COPY_Convertible);


    return pyType;
}
