// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtqml_python.h"

// main header
#include "qqmltypesextensioninterface_wrapper.h"

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QQmlTypesExtensionInterfaceWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QQmlTypesExtensionInterfaceWrapper::QQmlTypesExtensionInterfaceWrapper()
{
}

void QQmlTypesExtensionInterfaceWrapper::registerTypes(const char * uri)
{
    if (m_PyMethodCache[0]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QQmlTypesExtensionInterface.registerTypes");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "registerTypes";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        Shiboken::Errors::setPureVirtualMethodError("QQmlTypesExtensionInterface.registerTypes");
        return;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), uri)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), uri)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQmlTypesExtensionInterface", funcName);
        return;
    }
}

QQmlTypesExtensionInterfaceWrapper::~QQmlTypesExtensionInterfaceWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QQmlTypesExtensionInterface_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlTypesExtensionInterface_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QQmlTypesExtensionInterface");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QQmlTypesExtensionInterface >()))
        return -1;

    QQmlTypesExtensionInterfaceWrapper *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtQmlTypeStructs[SBK_QQmlTypesExtensionInterface_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QQmlTypesExtensionInterface()
        cptr = new QQmlTypesExtensionInterfaceWrapper();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QQmlTypesExtensionInterface >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QQmlTypesExtensionInterfaceFunc_registerTypes(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlTypesExtensionInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlTypesExtensionInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQmlTypesExtensionInterface::registerTypes(const char*)
    if (Shiboken::String::check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArg)))) {
        overloadId = 0; // registerTypes(const char*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "registerTypes", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlTypesExtensionInterface_IDX]);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // registerTypes(const char*)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QQmlTypesExtensionInterface.registerTypes");
                return {};
            }
            cppSelf->registerTypes(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QQmlTypesExtensionInterface_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QQmlTypesExtensionInterface_methods[] = {
    {"registerTypes", reinterpret_cast<PyCFunction>(Sbk_QQmlTypesExtensionInterfaceFunc_registerTypes), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QQmlTypesExtensionInterface_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QQmlTypesExtensionInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlTypesExtensionInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QQmlTypesExtensionInterfaceWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QQmlTypesExtensionInterface_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QQmlTypesExtensionInterface_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QQmlTypesExtensionInterface_Type = nullptr;
static PyTypeObject *Sbk_QQmlTypesExtensionInterface_TypeF(void)
{
    return _Sbk_QQmlTypesExtensionInterface_Type;
}

static PyType_Slot Sbk_QQmlTypesExtensionInterface_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QQmlTypesExtensionInterface_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QQmlTypesExtensionInterface_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QQmlTypesExtensionInterface_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QQmlTypesExtensionInterface_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QQmlTypesExtensionInterface_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QQmlTypesExtensionInterface_spec = {
    "2:PySide6.QtQml.QQmlTypesExtensionInterface",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QQmlTypesExtensionInterface_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QQmlTypesExtensionInterface_PythonToCpp_QQmlTypesExtensionInterface_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QQmlTypesExtensionInterface_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QQmlTypesExtensionInterface_PythonToCpp_QQmlTypesExtensionInterface_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QQmlTypesExtensionInterface_TypeF()))
        return QQmlTypesExtensionInterface_PythonToCpp_QQmlTypesExtensionInterface_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QQmlTypesExtensionInterface_PTR_CppToPython_QQmlTypesExtensionInterface(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QQmlTypesExtensionInterface *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QQmlTypesExtensionInterface_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QQmlTypesExtensionInterface_SignatureStrings[] = {
    "PySide6.QtQml.QQmlTypesExtensionInterface(self)",
    "PySide6.QtQml.QQmlTypesExtensionInterface.registerTypes(self,uri:char*)",
    nullptr}; // Sentinel
#else
static constexpr size_t QQmlTypesExtensionInterface_SignatureByteSize = 81;
static constexpr uint8_t QQmlTypesExtensionInterface_SignatureBytes[81] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x09, 0xcc, 0xcd, 0xd1,
    0x0b, 0x04, 0x12, 0x21, 0x95, 0x05, 0xa9, 0xc5, 0xae, 0x15, 0x25, 0xa9, 0x79, 0xc5, 0x99, 0xf9,
    0x79, 0x9e, 0x79, 0x25, 0xa9, 0x45, 0x69, 0x89, 0xc9, 0xa9, 0x1a, 0xc5, 0xa9, 0x39, 0x69, 0x9a,
    0x5c, 0x01, 0xc4, 0xaa, 0xd7, 0x2b, 0x4a, 0x4d, 0xcf, 0x2c, 0x06, 0x72, 0xc0, 0xf2, 0x60, 0xdd,
    0x3a, 0xa5, 0x45, 0x99, 0x56, 0xc9, 0x19, 0x89, 0x45, 0x5a, 0x9a, 0x5c, 0x00, 0x91, 0x3e, 0x2c,
    0x8b
};
#endif

PyTypeObject *init_QQmlTypesExtensionInterface(PyObject *module)
{
    if (SbkPySide6_QtQmlTypeStructs[SBK_QQmlTypesExtensionInterface_IDX].type != nullptr)
        return SbkPySide6_QtQmlTypeStructs[SBK_QQmlTypesExtensionInterface_IDX].type;

    Shiboken::AutoDecRef Sbk_QQmlTypesExtensionInterface_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QQmlTypesExtensionInterface_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QQmlTypesExtensionInterface",
        "QQmlTypesExtensionInterface*",
        &Sbk_QQmlTypesExtensionInterface_spec,
        &Shiboken::callCppDestructor< QQmlTypesExtensionInterface >,
        Sbk_QQmlTypesExtensionInterface_Type_bases.object(),
        0);
    auto *pyType = Sbk_QQmlTypesExtensionInterface_TypeF(); // references _Sbk_QQmlTypesExtensionInterface_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QQmlTypesExtensionInterface_SignatureStrings);
#else
    InitSignatureBytes(pyType, QQmlTypesExtensionInterface_SignatureBytes, QQmlTypesExtensionInterface_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QQmlTypesExtensionInterface_PropertyStrings);
    SbkPySide6_QtQmlTypeStructs[SBK_QQmlTypesExtensionInterface_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QQmlTypesExtensionInterface_PythonToCpp_QQmlTypesExtensionInterface_PTR,
        is_QQmlTypesExtensionInterface_PythonToCpp_QQmlTypesExtensionInterface_PTR_Convertible,
        QQmlTypesExtensionInterface_PTR_CppToPython_QQmlTypesExtensionInterface);

    Shiboken::Conversions::registerConverterName(converter, "QQmlTypesExtensionInterface");
    Shiboken::Conversions::registerConverterName(converter, "QQmlTypesExtensionInterface*");
    Shiboken::Conversions::registerConverterName(converter, "QQmlTypesExtensionInterface&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QQmlTypesExtensionInterface).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QQmlTypesExtensionInterfaceWrapper).name());

    qRegisterMetaType< ::QQmlTypesExtensionInterface *>();

    return pyType;
}
