// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtquick_python.h"

// main header
#include "qquickframebufferobject_renderer_wrapper.h"

// Argument includes
#include <QtOpenGL/qopenglframebufferobject.h>
#include <QtQuick/qquickframebufferobject.h>
#include <qsize.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void RendererWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

RendererWrapper::RendererWrapper()
{
}

::QOpenGLFramebufferObject * RendererWrapper::createFramebufferObject(const ::QSize & size)
{
    if (m_PyMethodCache[0])
        return this->::QQuickFramebufferObject::Renderer::createFramebufferObject(size);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "createFramebufferObject";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QQuickFramebufferObject::Renderer::createFramebufferObject(size);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &size)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &size)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("Renderer", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("Renderer", funcName, Shiboken::SbkType< QOpenGLFramebufferObject >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QOpenGLFramebufferObject *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void RendererWrapper::render()
{
    if (m_PyMethodCache[1]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("Renderer.render");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "render";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        Shiboken::Errors::setPureVirtualMethodError("Renderer.render");
        return;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("Renderer", funcName);
        return;
    }
}

void RendererWrapper::synchronize(::QQuickFramebufferObject * arg__1)
{
    if (m_PyMethodCache[2]) {
        return this->::QQuickFramebufferObject::Renderer::synchronize(arg__1);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "synchronize";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QQuickFramebufferObject::Renderer::synchronize(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickFramebufferObject_IDX]), arg__1)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickFramebufferObject_IDX]), arg__1)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("Renderer", funcName);
        return;
    }
}

RendererWrapper::~RendererWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QQuickFramebufferObject_Renderer_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickFramebufferObject_Renderer_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QQuickFramebufferObject::Renderer");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QQuickFramebufferObject::Renderer >()))
        return -1;

    RendererWrapper *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtQuickTypeStructs[SBK_QQuickFramebufferObject_Renderer_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // Renderer()
        cptr = new RendererWrapper();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QQuickFramebufferObject::Renderer >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QQuickFramebufferObject_RendererFunc_createFramebufferObject(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickFramebufferObject::Renderer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickFramebufferObject_Renderer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Renderer::createFramebufferObject(QSize)->QOpenGLFramebufferObject*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArg)))) {
        overloadId = 0; // createFramebufferObject(QSize)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "createFramebufferObject", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickFramebufferObject_Renderer_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSize cppArg0_local;
        ::QSize *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // createFramebufferObject(QSize)
            QOpenGLFramebufferObject * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QQuickFramebufferObject::Renderer::createFramebufferObject(*cppArg0)
                : cppSelf->createFramebufferObject(*cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickFramebufferObject_RendererFunc_framebufferObject(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickFramebufferObject::Renderer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickFramebufferObject_Renderer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // framebufferObject()const
        QOpenGLFramebufferObject * cppResult = const_cast<const ::QQuickFramebufferObject::Renderer *>(cppSelf)->framebufferObject();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFramebufferObject_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickFramebufferObject_RendererFunc_invalidateFramebufferObject(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickFramebufferObject::Renderer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickFramebufferObject_Renderer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // invalidateFramebufferObject()
        cppSelf->invalidateFramebufferObject();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickFramebufferObject_RendererFunc_render(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickFramebufferObject::Renderer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickFramebufferObject_Renderer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // render()
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("Renderer.render");
            return {};
        }
        cppSelf->render();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickFramebufferObject_RendererFunc_synchronize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickFramebufferObject::Renderer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickFramebufferObject_Renderer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Renderer::synchronize(QQuickFramebufferObject*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickFramebufferObject_IDX]), (pyArg)))) {
        overloadId = 0; // synchronize(QQuickFramebufferObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "synchronize", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickFramebufferObject_Renderer_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QQuickFramebufferObject *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // synchronize(QQuickFramebufferObject*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QQuickFramebufferObject::Renderer::synchronize(cppArg0)
                : cppSelf->synchronize(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickFramebufferObject_RendererFunc_update(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickFramebufferObject::Renderer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickFramebufferObject_Renderer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // update()
        cppSelf->update();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QQuickFramebufferObject_Renderer_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QQuickFramebufferObject_Renderer_methods[] = {
    {"createFramebufferObject", reinterpret_cast<PyCFunction>(Sbk_QQuickFramebufferObject_RendererFunc_createFramebufferObject), METH_O, nullptr},
    {"framebufferObject", reinterpret_cast<PyCFunction>(Sbk_QQuickFramebufferObject_RendererFunc_framebufferObject), METH_NOARGS, nullptr},
    {"invalidateFramebufferObject", reinterpret_cast<PyCFunction>(Sbk_QQuickFramebufferObject_RendererFunc_invalidateFramebufferObject), METH_NOARGS, nullptr},
    {"render", reinterpret_cast<PyCFunction>(Sbk_QQuickFramebufferObject_RendererFunc_render), METH_NOARGS, nullptr},
    {"synchronize", reinterpret_cast<PyCFunction>(Sbk_QQuickFramebufferObject_RendererFunc_synchronize), METH_O, nullptr},
    {"update", reinterpret_cast<PyCFunction>(Sbk_QQuickFramebufferObject_RendererFunc_update), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QQuickFramebufferObject_Renderer_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QQuickFramebufferObject::Renderer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickFramebufferObject_Renderer_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<RendererWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QQuickFramebufferObject_Renderer_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QQuickFramebufferObject_Renderer_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QQuickFramebufferObject_Renderer_Type = nullptr;
static PyTypeObject *Sbk_QQuickFramebufferObject_Renderer_TypeF(void)
{
    return _Sbk_QQuickFramebufferObject_Renderer_Type;
}

static PyType_Slot Sbk_QQuickFramebufferObject_Renderer_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QQuickFramebufferObject_Renderer_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QQuickFramebufferObject_Renderer_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QQuickFramebufferObject_Renderer_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QQuickFramebufferObject_Renderer_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QQuickFramebufferObject_Renderer_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QQuickFramebufferObject_Renderer_spec = {
    "2:PySide6.QtQuick.QQuickFramebufferObject.Renderer",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QQuickFramebufferObject_Renderer_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void Renderer_PythonToCpp_Renderer_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QQuickFramebufferObject_Renderer_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_Renderer_PythonToCpp_Renderer_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QQuickFramebufferObject_Renderer_TypeF()))
        return Renderer_PythonToCpp_Renderer_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *Renderer_PTR_CppToPython_Renderer(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QQuickFramebufferObject::Renderer *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QQuickFramebufferObject_Renderer_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QQuickFramebufferObject_Renderer_SignatureStrings[] = {
    "PySide6.QtQuick.QQuickFramebufferObject.Renderer(self)",
    "PySide6.QtQuick.QQuickFramebufferObject.Renderer.createFramebufferObject(self,size:PySide6.QtCore.QSize)->PySide6.QtOpenGL.QOpenGLFramebufferObject",
    "PySide6.QtQuick.QQuickFramebufferObject.Renderer.framebufferObject(self)->PySide6.QtOpenGL.QOpenGLFramebufferObject",
    "PySide6.QtQuick.QQuickFramebufferObject.Renderer.invalidateFramebufferObject(self)",
    "PySide6.QtQuick.QQuickFramebufferObject.Renderer.render(self)",
    "PySide6.QtQuick.QQuickFramebufferObject.Renderer.synchronize(self,arg__1:PySide6.QtQuick.QQuickFramebufferObject)",
    "PySide6.QtQuick.QQuickFramebufferObject.Renderer.update(self)",
    nullptr}; // Sentinel
#else
static constexpr size_t QQuickFramebufferObject_Renderer_SignatureByteSize = 165;
static constexpr uint8_t QQuickFramebufferObject_Renderer_SignatureBytes[165] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x09, 0x2c, 0xcd, 0x4c,
    0xce, 0xd6, 0x0b, 0x04, 0x53, 0x6e, 0x45, 0x89, 0xb9, 0xa9, 0x49, 0xa5, 0x69, 0x69, 0xa9, 0x45,
    0xfe, 0x49, 0x59, 0xa9, 0xc9, 0x25, 0x7a, 0x41, 0xa9, 0x79, 0x29, 0xa9, 0x45, 0xa9, 0x45, 0x1a,
    0xc5, 0xa9, 0x39, 0x69, 0x9a, 0x5c, 0x01, 0x24, 0x6a, 0xd3, 0x4b, 0x2e, 0x4a, 0x4d, 0x2c, 0x49,
    0xc5, 0x50, 0x00, 0x36, 0x4e, 0xa7, 0x38, 0xb3, 0x2a, 0xd5, 0x0a, 0x61, 0xa4, 0x73, 0x7e, 0x51,
    0xaa, 0x5e, 0x60, 0x30, 0x50, 0x50, 0x53, 0xd7, 0x0e, 0x21, 0xec, 0x5f, 0x90, 0x9a, 0xe7, 0xee,
    0xa3, 0x17, 0x08, 0xa1, 0x31, 0x8c, 0x22, 0xdd, 0x4d, 0x69, 0x58, 0x5d, 0x43, 0x5b, 0x3b, 0x33,
    0xf3, 0xca, 0x12, 0x73, 0x32, 0x53, 0x70, 0x86, 0x05, 0x19, 0x41, 0x5b, 0x04, 0x66, 0x90, 0xab,
    0xbb, 0xb8, 0x32, 0x2f, 0x39, 0xa3, 0x28, 0x3f, 0x0f, 0x18, 0xda, 0x90, 0xc8, 0x48, 0x2c, 0x4a,
    0x8f, 0x8f, 0x37, 0xb4, 0x22, 0xd2, 0x20, 0x32, 0x6c, 0x2c, 0x2d, 0x00, 0x79, 0x1f, 0xea, 0x5e,
    0x00, 0xbd, 0xa5, 0xeb, 0x9b
};
#endif

PyTypeObject *init_QQuickFramebufferObject_Renderer(PyObject *enclosingClass)
{
    if (SbkPySide6_QtQuickTypeStructs[SBK_QQuickFramebufferObject_Renderer_IDX].type != nullptr)
        return SbkPySide6_QtQuickTypeStructs[SBK_QQuickFramebufferObject_Renderer_IDX].type;

    Shiboken::AutoDecRef Sbk_QQuickFramebufferObject_Renderer_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QQuickFramebufferObject_Renderer_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "Renderer",
        "QQuickFramebufferObject::Renderer*",
        &Sbk_QQuickFramebufferObject_Renderer_spec,
        &Shiboken::callCppDestructor< QQuickFramebufferObject::Renderer >,
        Sbk_QQuickFramebufferObject_Renderer_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
    auto *pyType = Sbk_QQuickFramebufferObject_Renderer_TypeF(); // references _Sbk_QQuickFramebufferObject_Renderer_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QQuickFramebufferObject_Renderer_SignatureStrings);
#else
    InitSignatureBytes(pyType, QQuickFramebufferObject_Renderer_SignatureBytes, QQuickFramebufferObject_Renderer_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QQuickFramebufferObject_Renderer_PropertyStrings);
    SbkPySide6_QtQuickTypeStructs[SBK_QQuickFramebufferObject_Renderer_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        Renderer_PythonToCpp_Renderer_PTR,
        is_Renderer_PythonToCpp_Renderer_PTR_Convertible,
        Renderer_PTR_CppToPython_Renderer);

    Shiboken::Conversions::registerConverterName(converter, "QQuickFramebufferObject::Renderer");
    Shiboken::Conversions::registerConverterName(converter, "QQuickFramebufferObject::Renderer*");
    Shiboken::Conversions::registerConverterName(converter, "QQuickFramebufferObject::Renderer&");
    Shiboken::Conversions::registerConverterAlias(converter, "Renderer");
    Shiboken::Conversions::registerConverterAlias(converter, "Renderer*");
    Shiboken::Conversions::registerConverterAlias(converter, "Renderer&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QQuickFramebufferObject::Renderer).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(RendererWrapper).name());

    qRegisterMetaType< ::QQuickFramebufferObject::Renderer *>();

    return pyType;
}
