// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtquick_python.h"

// main header
#include "qquickrendertarget_wrapper.h"

// Argument includes
#include <QtGui/qpaintdevice.h>
#include <QtQuick/qquickrendertarget.h>
#include <qsize.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QQuickRenderTarget_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QQuickRenderTarget >()))
        return -1;

    ::QQuickRenderTarget *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QQuickRenderTarget", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QQuickRenderTarget::QQuickRenderTarget()
    // 1: QQuickRenderTarget::QQuickRenderTarget(QQuickRenderTarget)
    if (numArgs == 0) {
        overloadId = 0; // QQuickRenderTarget()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QQuickRenderTarget(QQuickRenderTarget)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QQuickRenderTarget()
        {

            // QQuickRenderTarget()
            cptr = new ::QQuickRenderTarget();
            break;
        }
        case 1: // QQuickRenderTarget(const QQuickRenderTarget &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QQuickRenderTarget cppArg0_local;
            ::QQuickRenderTarget *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QQuickRenderTarget(QQuickRenderTarget)
                cptr = new ::QQuickRenderTarget(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QQuickRenderTarget >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QQuickRenderTargetFunc_depthTexture(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickRenderTarget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // depthTexture()const
        QRhiTexture * cppResult = const_cast<const ::QQuickRenderTarget *>(cppSelf)->depthTexture();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickRenderTargetFunc_devicePixelRatio(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickRenderTarget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // devicePixelRatio()const
        qreal cppResult = const_cast<const ::QQuickRenderTarget *>(cppSelf)->devicePixelRatio();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickRenderTargetFunc_fromOpenGLRenderBuffer(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "fromOpenGLRenderBuffer", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:fromOpenGLRenderBuffer", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QQuickRenderTarget::fromOpenGLRenderBuffer(uint,QSize,int=)->QQuickRenderTarget
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // fromOpenGLRenderBuffer(uint,QSize,int)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
            overloadId = 0; // fromOpenGLRenderBuffer(uint,QSize,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fromOpenGLRenderBuffer", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_sampleCount = Shiboken::String::createStaticString("sampleCount");
            if (PyDict_Contains(kwds, key_sampleCount) != 0) {
                value = PyDict_GetItem(kwds, key_sampleCount);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_sampleCount);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "fromOpenGLRenderBuffer", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "fromOpenGLRenderBuffer", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_sampleCount);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "fromOpenGLRenderBuffer", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX]);
            }
        }
        uint cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QSize cppArg1_local;
        ::QSize *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        int cppArg2 = 1;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromOpenGLRenderBuffer(uint,QSize,int)
            QQuickRenderTarget cppResult = ::QQuickRenderTarget::fromOpenGLRenderBuffer(cppArg0, *cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickRenderTargetFunc_fromOpenGLTexture(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[6];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 6));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "fromOpenGLTexture", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX]);
    if (numArgs == 5)
        return Shiboken::returnWrongArguments(args, "fromOpenGLTexture", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOOO:fromOpenGLTexture", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QQuickRenderTarget::fromOpenGLTexture(uint,QSize,int=)->QQuickRenderTarget
    // 1: static QQuickRenderTarget::fromOpenGLTexture(uint,uint,QSize,int,int,QFlags<QQuickRenderTarget::Flag>)->QQuickRenderTarget
    // 2: static QQuickRenderTarget::fromOpenGLTexture(uint,uint,QSize,int=)->QQuickRenderTarget
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArgs[0])))) {
        if (numArgs >= 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 2; // fromOpenGLTexture(uint,uint,QSize,int)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
                if (numArgs == 4) {
                    overloadId = 2; // fromOpenGLTexture(uint,uint,QSize,int)
                } else if (numArgs == 6
                    && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))
                    && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QQuickRenderTarget_Flag_IDX])))->flagsConverter, (pyArgs[5])))) {
                    overloadId = 1; // fromOpenGLTexture(uint,uint,QSize,int,int,QFlags<QQuickRenderTarget::Flag>)
                }
            }
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // fromOpenGLTexture(uint,QSize,int)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
                overloadId = 0; // fromOpenGLTexture(uint,QSize,int)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fromOpenGLTexture", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // fromOpenGLTexture(uint textureId, const QSize &pixelSize, int sampleCount)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_sampleCount = Shiboken::String::createStaticString("sampleCount");
                if (PyDict_Contains(kwds, key_sampleCount) != 0) {
                    value = PyDict_GetItem(kwds, key_sampleCount);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_sampleCount);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "fromOpenGLTexture", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "fromOpenGLTexture", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_sampleCount);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "fromOpenGLTexture", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX]);
                }
            }
            uint cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QSize cppArg1_local;
            ::QSize *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            int cppArg2 = 1;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fromOpenGLTexture(uint,QSize,int)
                QQuickRenderTarget cppResult = ::QQuickRenderTarget::fromOpenGLTexture(cppArg0, *cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX]), &cppResult);
            }
            break;
        }
        case 1: // fromOpenGLTexture(uint textureId, uint format, QSize pixelSize, int sampleCount, int arraySize, QFlags<QQuickRenderTarget::Flag> flags)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "fromOpenGLTexture", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX]);
            }
            uint cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            uint cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QSize cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            ::QFlags<QQuickRenderTarget::Flag> cppArg5 = QFlags<QQuickRenderTarget::Flag>(0);
            pythonToCpp[5](pyArgs[5], &cppArg5);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fromOpenGLTexture(uint,uint,QSize,int,int,QFlags<QQuickRenderTarget::Flag>)
                QQuickRenderTarget cppResult = ::QQuickRenderTarget::fromOpenGLTexture(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX]), &cppResult);
            }
            break;
        }
        case 2: // fromOpenGLTexture(uint textureId, uint format, const QSize &pixelSize, int sampleCount)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_sampleCount = Shiboken::String::createStaticString("sampleCount");
                if (PyDict_Contains(kwds, key_sampleCount) != 0) {
                    value = PyDict_GetItem(kwds, key_sampleCount);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_sampleCount);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "fromOpenGLTexture", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "fromOpenGLTexture", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_sampleCount);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "fromOpenGLTexture", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX]);
                }
            }
            uint cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            uint cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QSize cppArg2_local;
            ::QSize *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);

            int cppArg3 = 1;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fromOpenGLTexture(uint,uint,QSize,int)
                QQuickRenderTarget cppResult = ::QQuickRenderTarget::fromOpenGLTexture(cppArg0, cppArg1, *cppArg2, cppArg3);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickRenderTargetFunc_fromPaintDevice(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QQuickRenderTarget::fromPaintDevice(QPaintDevice*)->QQuickRenderTarget
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]), (pyArg)))) {
        overloadId = 0; // fromPaintDevice(QPaintDevice*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fromPaintDevice", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPaintDevice *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromPaintDevice(QPaintDevice*)
            QQuickRenderTarget cppResult = ::QQuickRenderTarget::fromPaintDevice(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickRenderTargetFunc_fromRhiRenderTarget(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QQuickRenderTarget::fromRhiRenderTarget(QRhiRenderTarget*)->QQuickRenderTarget
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderTarget_IDX]), (pyArg)))) {
        overloadId = 0; // fromRhiRenderTarget(QRhiRenderTarget*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fromRhiRenderTarget", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRhiRenderTarget *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromRhiRenderTarget(QRhiRenderTarget*)
            QQuickRenderTarget cppResult = ::QQuickRenderTarget::fromRhiRenderTarget(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickRenderTargetFunc_isNull(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickRenderTarget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isNull()const
        bool cppResult = const_cast<const ::QQuickRenderTarget *>(cppSelf)->isNull();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickRenderTargetFunc_mirrorVertically(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickRenderTarget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // mirrorVertically()const
        bool cppResult = const_cast<const ::QQuickRenderTarget *>(cppSelf)->mirrorVertically();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickRenderTargetFunc_setDepthTexture(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickRenderTarget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickRenderTarget::setDepthTexture(QRhiTexture*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), (pyArg)))) {
        overloadId = 0; // setDepthTexture(QRhiTexture*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDepthTexture", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRhiTexture *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDepthTexture(QRhiTexture*)
            cppSelf->setDepthTexture(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickRenderTargetFunc_setDevicePixelRatio(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickRenderTarget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickRenderTarget::setDevicePixelRatio(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setDevicePixelRatio(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDevicePixelRatio", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDevicePixelRatio(qreal)
            cppSelf->setDevicePixelRatio(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickRenderTargetFunc_setMirrorVertically(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickRenderTarget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickRenderTarget::setMirrorVertically(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setMirrorVertically(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMirrorVertically", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMirrorVertically(bool)
            cppSelf->setMirrorVertically(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickRenderTarget__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QQuickRenderTarget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QQuickRenderTarget_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QQuickRenderTarget_EnumFlagInfo[] = {
    "Flag:Flag:Flags",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QQuickRenderTarget_methods[] = {
    {"depthTexture", reinterpret_cast<PyCFunction>(Sbk_QQuickRenderTargetFunc_depthTexture), METH_NOARGS, nullptr},
    {"devicePixelRatio", reinterpret_cast<PyCFunction>(Sbk_QQuickRenderTargetFunc_devicePixelRatio), METH_NOARGS, nullptr},
    {"fromOpenGLRenderBuffer", reinterpret_cast<PyCFunction>(Sbk_QQuickRenderTargetFunc_fromOpenGLRenderBuffer), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"fromOpenGLTexture", reinterpret_cast<PyCFunction>(Sbk_QQuickRenderTargetFunc_fromOpenGLTexture), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"fromPaintDevice", reinterpret_cast<PyCFunction>(Sbk_QQuickRenderTargetFunc_fromPaintDevice), METH_O|METH_STATIC, nullptr},
    {"fromRhiRenderTarget", reinterpret_cast<PyCFunction>(Sbk_QQuickRenderTargetFunc_fromRhiRenderTarget), METH_O|METH_STATIC, nullptr},
    {"isNull", reinterpret_cast<PyCFunction>(Sbk_QQuickRenderTargetFunc_isNull), METH_NOARGS, nullptr},
    {"mirrorVertically", reinterpret_cast<PyCFunction>(Sbk_QQuickRenderTargetFunc_mirrorVertically), METH_NOARGS, nullptr},
    {"setDepthTexture", reinterpret_cast<PyCFunction>(Sbk_QQuickRenderTargetFunc_setDepthTexture), METH_O, nullptr},
    {"setDevicePixelRatio", reinterpret_cast<PyCFunction>(Sbk_QQuickRenderTargetFunc_setDevicePixelRatio), METH_O, nullptr},
    {"setMirrorVertically", reinterpret_cast<PyCFunction>(Sbk_QQuickRenderTargetFunc_setMirrorVertically), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QQuickRenderTarget__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QQuickRenderTarget___nb_bool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QQuickRenderTarget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return !cppSelf->isNull() ? 1 : 0;
}

// Rich comparison
static PyObject * Sbk_QQuickRenderTarget_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QQuickRenderTarget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX]), (pyArg)))) {
                // operator!=(const QQuickRenderTarget &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QQuickRenderTarget cppArg0_local;
                ::QQuickRenderTarget *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX]), (pyArg)))) {
                // operator==(const QQuickRenderTarget &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QQuickRenderTarget cppArg0_local;
                ::QQuickRenderTarget *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QQuickRenderTarget_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QQuickRenderTarget_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QQuickRenderTarget_Type = nullptr;
static PyTypeObject *Sbk_QQuickRenderTarget_TypeF(void)
{
    return _Sbk_QQuickRenderTarget_Type;
}

static PyType_Slot Sbk_QQuickRenderTarget_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QQuickRenderTarget_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QQuickRenderTarget_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QQuickRenderTarget_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QQuickRenderTarget_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QQuickRenderTarget_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_bool,        reinterpret_cast<void *>(Sbk_QQuickRenderTarget___nb_bool)},
    {0, nullptr}
};
static PyType_Spec Sbk_QQuickRenderTarget_spec = {
    "2:PySide6.QtQuick.QQuickRenderTarget",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QQuickRenderTarget_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QQuickRenderTarget_Flag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QQuickRenderTarget::Flag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QQuickRenderTarget::Flag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QQuickRenderTarget_Flag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_Flag_IDX])))
        return Enum_PythonToCpp_QQuickRenderTarget_Flag;
    return {};
}

static PyObject *QQuickRenderTarget_Flag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QQuickRenderTarget::Flag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QQuickRenderTarget::Flag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_Flag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QQuickRenderTarget_Flag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QQuickRenderTarget::Flag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QQuickRenderTarget::Flag> *>(cppOut) = value;

}

static PyObject *QQuickRenderTarget_Flag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QQuickRenderTarget::Flag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_Flag_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QQuickRenderTarget_PythonToCpp_QQuickRenderTarget_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QQuickRenderTarget_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QQuickRenderTarget_PythonToCpp_QQuickRenderTarget_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QQuickRenderTarget_TypeF()))
        return QQuickRenderTarget_PythonToCpp_QQuickRenderTarget_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QQuickRenderTarget_PTR_CppToPython_QQuickRenderTarget(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QQuickRenderTarget_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QQuickRenderTarget_COPY_CppToPython_QQuickRenderTarget(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QQuickRenderTarget *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QQuickRenderTarget_TypeF(), new ::QQuickRenderTarget(*source), true, true);
}

// Python to C++ copy conversion.
static void QQuickRenderTarget_PythonToCpp_QQuickRenderTarget_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QQuickRenderTarget *>(cppOut) = *reinterpret_cast< ::QQuickRenderTarget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QQuickRenderTarget_PythonToCpp_QQuickRenderTarget_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QQuickRenderTarget_TypeF()))
        return QQuickRenderTarget_PythonToCpp_QQuickRenderTarget_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QQuickRenderTarget_SignatureStrings[] = {
    "1:PySide6.QtQuick.QQuickRenderTarget(self)",
    "0:PySide6.QtQuick.QQuickRenderTarget(self,other:PySide6.QtQuick.QQuickRenderTarget)",
    "PySide6.QtQuick.QQuickRenderTarget.depthTexture(self)->PySide6.QtGui.QRhiTexture",
    "PySide6.QtQuick.QQuickRenderTarget.devicePixelRatio(self)->qreal",
    "PySide6.QtQuick.QQuickRenderTarget.fromOpenGLRenderBuffer(renderbufferId:uint,pixelSize:PySide6.QtCore.QSize,sampleCount:int=1)->PySide6.QtQuick.QQuickRenderTarget",
    "2:PySide6.QtQuick.QQuickRenderTarget.fromOpenGLTexture(textureId:uint,pixelSize:PySide6.QtCore.QSize,sampleCount:int=1)->PySide6.QtQuick.QQuickRenderTarget",
    "1:PySide6.QtQuick.QQuickRenderTarget.fromOpenGLTexture(textureId:uint,format:uint,pixelSize:PySide6.QtCore.QSize,sampleCount:int,arraySize:int,flags:PySide6.QtQuick.QQuickRenderTarget.Flag)->PySide6.QtQuick.QQuickRenderTarget",
    "0:PySide6.QtQuick.QQuickRenderTarget.fromOpenGLTexture(textureId:uint,format:uint,pixelSize:PySide6.QtCore.QSize,sampleCount:int=1)->PySide6.QtQuick.QQuickRenderTarget",
    "PySide6.QtQuick.QQuickRenderTarget.fromPaintDevice(device:PySide6.QtGui.QPaintDevice)->PySide6.QtQuick.QQuickRenderTarget",
    "PySide6.QtQuick.QQuickRenderTarget.fromRhiRenderTarget(renderTarget:PySide6.QtGui.QRhiRenderTarget)->PySide6.QtQuick.QQuickRenderTarget",
    "PySide6.QtQuick.QQuickRenderTarget.isNull(self)->bool",
    "PySide6.QtQuick.QQuickRenderTarget.mirrorVertically(self)->bool",
    "PySide6.QtQuick.QQuickRenderTarget.setDepthTexture(self,texture:PySide6.QtGui.QRhiTexture)",
    "PySide6.QtQuick.QQuickRenderTarget.setDevicePixelRatio(self,ratio:qreal)",
    "PySide6.QtQuick.QQuickRenderTarget.setMirrorVertically(self,enable:bool)",
    "PySide6.QtQuick.QQuickRenderTarget.__copy__(self)->typing.Self",
    "PySide6.QtQuick.QQuickRenderTarget.__ne__(self,rhs:PySide6.QtQuick.QQuickRenderTarget)->bool",
    "PySide6.QtQuick.QQuickRenderTarget.__eq__(self,rhs:PySide6.QtQuick.QQuickRenderTarget)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QQuickRenderTarget_SignatureByteSize = 368;
static constexpr uint8_t QQuickRenderTarget_SignatureBytes[368] = {
    0x78, 0xda, 0xc5, 0x54, 0xcb, 0x6e, 0xc2, 0x30, 0x10, 0xbc, 0xf3, 0x25, 0x20, 0xb9, 0x11, 0xf4,
    0xd0, 0x83, 0xa5, 0xf6, 0x50, 0xaa, 0xa2, 0x4a, 0x7d, 0x10, 0x40, 0xbd, 0x46, 0x26, 0xd9, 0x10,
    0xab, 0x8e, 0x1d, 0x36, 0x76, 0x45, 0xfa, 0xf5, 0xcd, 0x83, 0xa8, 0x3c, 0xd5, 0x05, 0x51, 0xf5,
    0x64, 0xaf, 0x35, 0x3b, 0x9e, 0x5d, 0x7b, 0x67, 0xc0, 0xc7, 0xc5, 0x54, 0x46, 0x70, 0xe3, 0xf9,
    0xd6, 0x77, 0x32, 0xfc, 0xf0, 0xfc, 0x7a, 0x99, 0x80, 0x8e, 0x00, 0x67, 0x02, 0x17, 0x60, 0xbb,
    0x39, 0xa8, 0xb8, 0xd7, 0xe9, 0x53, 0xa1, 0xcc, 0xd8, 0x04, 0x90, 0x80, 0xee, 0x75, 0x7e, 0xc7,
    0x78, 0x11, 0x64, 0x36, 0x99, 0xc1, 0xca, 0x3a, 0x84, 0x46, 0xc9, 0xd5, 0xdd, 0x4f, 0xda, 0xc8,
    0x49, 0xcf, 0x9f, 0x24, 0x72, 0x0d, 0xa0, 0x11, 0x7e, 0xca, 0x10, 0xc6, 0x72, 0x05, 0x6a, 0x22,
    0xac, 0x34, 0x2d, 0xe9, 0x12, 0x41, 0x28, 0x0a, 0x41, 0x8c, 0x26, 0x7d, 0xcb, 0x40, 0x8f, 0x9e,
    0x9b, 0xe3, 0x7b, 0x17, 0xc7, 0x80, 0x5d, 0xac, 0x83, 0x79, 0x1d, 0x3c, 0x45, 0xdc, 0x49, 0x6d,
    0x59, 0x56, 0xdd, 0x32, 0x95, 0x5f, 0xb0, 0xd1, 0x8d, 0xa1, 0x41, 0xf0, 0xfc, 0xea, 0x90, 0xe5,
    0x22, 0xcd, 0x14, 0x0c, 0x8d, 0xd3, 0x96, 0x97, 0xf0, 0xdb, 0xc1, 0x56, 0x6d, 0xc7, 0x04, 0x74,
    0xae, 0xf9, 0x49, 0x2a, 0xdb, 0xe6, 0xd9, 0x66, 0xfd, 0x5b, 0x6d, 0x83, 0x8b, 0x68, 0x8b, 0x0d,
    0xa6, 0xc2, 0x9e, 0xa3, 0x93, 0x09, 0x44, 0x51, 0xd4, 0xf0, 0x9a, 0x48, 0x89, 0x45, 0x4e, 0x91,
    0xf4, 0x58, 0x02, 0x69, 0x15, 0xf6, 0xff, 0xb9, 0x42, 0xea, 0x4b, 0x10, 0x55, 0x8e, 0x45, 0xc9,
    0xf9, 0x50, 0xcf, 0x44, 0xb7, 0x19, 0x0d, 0xbe, 0x33, 0x5e, 0x1b, 0x88, 0x8b, 0xde, 0x5c, 0x8e,
    0xed, 0x96, 0x77, 0xe0, 0x46, 0xc0, 0xf7, 0x47, 0x7c, 0xcb, 0x39, 0x2e, 0xa5, 0x43, 0xe6, 0xaf,
    0x4e, 0xa9, 0xd6, 0x02, 0xe6, 0xc6, 0x90, 0x1c, 0x20, 0x95, 0x88, 0x06, 0xdf, 0x01, 0xad, 0x0c,
    0x85, 0x52, 0xc5, 0xa9, 0xf9, 0x39, 0x94, 0xfd, 0xdc, 0xb1, 0x35, 0xb6, 0xfe, 0x20, 0xfc, 0xa8,
    0xb9, 0xf5, 0xc8, 0xd4, 0x07, 0x0c, 0x8e, 0x61, 0xb5, 0xe5, 0xb5, 0xc9, 0x51, 0x89, 0x5e, 0x0e,
    0x95, 0xc9, 0x40, 0x8b, 0xb9, 0x02, 0x5e, 0xd5, 0x4a, 0x22, 0x0a, 0x82, 0xd0, 0x64, 0x45, 0x10,
    0xb4, 0x4d, 0xb2, 0x45, 0x26, 0xf5, 0xc2, 0x9b, 0x96, 0x11, 0x2d, 0x5d, 0xc3, 0x3a, 0x99, 0x61,
    0x42, 0x99, 0xe5, 0x13, 0x1e, 0x22, 0x08, 0x60, 0x79, 0x1e, 0xf9, 0x37, 0x41, 0xc7, 0xa6, 0xaa
};
#endif

PyTypeObject *init_QQuickRenderTarget(PyObject *module)
{
    if (SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX].type != nullptr)
        return SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX].type;

    Shiboken::AutoDecRef Sbk_QQuickRenderTarget_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QQuickRenderTarget_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QQuickRenderTarget",
        "QQuickRenderTarget",
        &Sbk_QQuickRenderTarget_spec,
        &Shiboken::callCppDestructor< ::QQuickRenderTarget >,
        Sbk_QQuickRenderTarget_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QQuickRenderTarget_TypeF(); // references _Sbk_QQuickRenderTarget_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QQuickRenderTarget_SignatureStrings);
#else
    InitSignatureBytes(pyType, QQuickRenderTarget_SignatureBytes, QQuickRenderTarget_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QQuickRenderTarget_PropertyStrings);
    SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QQuickRenderTarget_PythonToCpp_QQuickRenderTarget_PTR,
        is_QQuickRenderTarget_PythonToCpp_QQuickRenderTarget_PTR_Convertible,
        QQuickRenderTarget_PTR_CppToPython_QQuickRenderTarget,
        QQuickRenderTarget_COPY_CppToPython_QQuickRenderTarget);

    Shiboken::Conversions::registerConverterName(converter, "QQuickRenderTarget");
    Shiboken::Conversions::registerConverterName(converter, "QQuickRenderTarget*");
    Shiboken::Conversions::registerConverterName(converter, "QQuickRenderTarget&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QQuickRenderTarget).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QQuickRenderTarget_PythonToCpp_QQuickRenderTarget_COPY,
        is_QQuickRenderTarget_PythonToCpp_QQuickRenderTarget_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QQuickRenderTarget_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Flag'.
    const char *Flag_Initializer[] = {
        "MultisampleResolve",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t Flag_InitializerValues[] = {
        int8_t(QQuickRenderTarget::Flag::MultisampleResolve) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QQuickRenderTarget_TypeF(),
        "2:PySide6.QtQuick.QQuickRenderTarget.Flag",
        Flag_Initializer, Flag_InitializerValues);
    SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_Flag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QQuickRenderTarget_Flag_IDX].type =
        EType;
    // Register converter for enum 'QQuickRenderTarget::Flag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QQuickRenderTarget_Flag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QQuickRenderTarget_Flag,
            is_Enum_PythonToCpp_QQuickRenderTarget_Flag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QQuickRenderTarget::Flag");
        Shiboken::Conversions::registerConverterAlias(converter, "Flag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QQuickRenderTarget_Flag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QQuickRenderTarget_Flag,
            is_Enum_PythonToCpp_QQuickRenderTarget_Flag_Convertible);
        // Register converter for flag 'QFlags<QQuickRenderTarget::Flag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QQuickRenderTarget::Flag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QQuickRenderTarget::Flags");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'Flag' enum/flags.

    qRegisterMetaType< ::QQuickRenderTarget >("QQuickRenderTarget");
    qRegisterMetaType< ::QQuickRenderTarget::Flag >("QQuickRenderTarget::Flag");

    return pyType;
}
