// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtquick_python.h"

// main header
#include "qquickrhiitemrenderer_wrapper.h"

// Argument includes
#include <QtQuick/qquickrhiitem.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QQuickRhiItemRendererWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QQuickRhiItemRendererWrapper::QQuickRhiItemRendererWrapper()
{
}

void QQuickRhiItemRendererWrapper::initialize(::QRhiCommandBuffer * cb)
{
    if (m_PyMethodCache[0]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QQuickRhiItemRenderer.initialize");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "initialize";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        Shiboken::Errors::setPureVirtualMethodError("QQuickRhiItemRenderer.initialize");
        return;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]), cb)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]), cb)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickRhiItemRenderer", funcName);
        return;
    }
}

void QQuickRhiItemRendererWrapper::render(::QRhiCommandBuffer * cb)
{
    if (m_PyMethodCache[1]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QQuickRhiItemRenderer.render");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "render";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        Shiboken::Errors::setPureVirtualMethodError("QQuickRhiItemRenderer.render");
        return;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]), cb)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]), cb)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickRhiItemRenderer", funcName);
        return;
    }
}

void QQuickRhiItemRendererWrapper::synchronize(::QQuickRhiItem * item)
{
    if (m_PyMethodCache[2]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QQuickRhiItemRenderer.synchronize");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "synchronize";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        Shiboken::Errors::setPureVirtualMethodError("QQuickRhiItemRenderer.synchronize");
        return;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_IDX]), item)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_IDX]), item)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickRhiItemRenderer", funcName);
        return;
    }
}

QQuickRhiItemRendererWrapper::~QQuickRhiItemRendererWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QQuickRhiItemRenderer_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItemRenderer_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QQuickRhiItemRenderer");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QQuickRhiItemRenderer >()))
        return -1;

    QQuickRhiItemRendererWrapper *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItemRenderer_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QQuickRhiItemRenderer()
        cptr = new QQuickRhiItemRendererWrapper();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QQuickRhiItemRenderer >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QQuickRhiItemRendererFunc_colorTexture(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickRhiItemRenderer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItemRenderer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // colorTexture()const
        QRhiTexture * cppResult = const_cast<const ::QQuickRhiItemRenderer *>(cppSelf)->colorTexture();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickRhiItemRendererFunc_depthStencilBuffer(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickRhiItemRenderer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItemRenderer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // depthStencilBuffer()const
        QRhiRenderBuffer * cppResult = const_cast<const ::QQuickRhiItemRenderer *>(cppSelf)->depthStencilBuffer();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickRhiItemRendererFunc_initialize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickRhiItemRenderer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItemRenderer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickRhiItemRenderer::initialize(QRhiCommandBuffer*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]), (pyArg)))) {
        overloadId = 0; // initialize(QRhiCommandBuffer*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "initialize", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItemRenderer_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRhiCommandBuffer *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // initialize(QRhiCommandBuffer*)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QQuickRhiItemRenderer.initialize");
                return {};
            }
            cppSelf->initialize(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickRhiItemRendererFunc_msaaColorBuffer(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickRhiItemRenderer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItemRenderer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // msaaColorBuffer()const
        QRhiRenderBuffer * cppResult = const_cast<const ::QQuickRhiItemRenderer *>(cppSelf)->msaaColorBuffer();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickRhiItemRendererFunc_render(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickRhiItemRenderer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItemRenderer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickRhiItemRenderer::render(QRhiCommandBuffer*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]), (pyArg)))) {
        overloadId = 0; // render(QRhiCommandBuffer*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "render", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItemRenderer_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRhiCommandBuffer *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // render(QRhiCommandBuffer*)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QQuickRhiItemRenderer.render");
                return {};
            }
            cppSelf->render(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickRhiItemRendererFunc_renderTarget(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickRhiItemRenderer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItemRenderer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // renderTarget()const
        QRhiRenderTarget * cppResult = const_cast<const ::QQuickRhiItemRenderer *>(cppSelf)->renderTarget();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderTarget_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickRhiItemRendererFunc_resolveTexture(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickRhiItemRenderer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItemRenderer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // resolveTexture()const
        QRhiTexture * cppResult = const_cast<const ::QQuickRhiItemRenderer *>(cppSelf)->resolveTexture();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickRhiItemRendererFunc_rhi(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickRhiItemRenderer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItemRenderer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rhi()const
        QRhi * cppResult = const_cast<const ::QQuickRhiItemRenderer *>(cppSelf)->rhi();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickRhiItemRendererFunc_synchronize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickRhiItemRenderer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItemRenderer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickRhiItemRenderer::synchronize(QQuickRhiItem*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_IDX]), (pyArg)))) {
        overloadId = 0; // synchronize(QQuickRhiItem*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "synchronize", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItemRenderer_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QQuickRhiItem *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // synchronize(QQuickRhiItem*)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QQuickRhiItemRenderer.synchronize");
                return {};
            }
            cppSelf->synchronize(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickRhiItemRendererFunc_update(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickRhiItemRenderer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItemRenderer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // update()
        cppSelf->update();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QQuickRhiItemRenderer_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QQuickRhiItemRenderer_methods[] = {
    {"colorTexture", reinterpret_cast<PyCFunction>(Sbk_QQuickRhiItemRendererFunc_colorTexture), METH_NOARGS, nullptr},
    {"depthStencilBuffer", reinterpret_cast<PyCFunction>(Sbk_QQuickRhiItemRendererFunc_depthStencilBuffer), METH_NOARGS, nullptr},
    {"initialize", reinterpret_cast<PyCFunction>(Sbk_QQuickRhiItemRendererFunc_initialize), METH_O, nullptr},
    {"msaaColorBuffer", reinterpret_cast<PyCFunction>(Sbk_QQuickRhiItemRendererFunc_msaaColorBuffer), METH_NOARGS, nullptr},
    {"render", reinterpret_cast<PyCFunction>(Sbk_QQuickRhiItemRendererFunc_render), METH_O, nullptr},
    {"renderTarget", reinterpret_cast<PyCFunction>(Sbk_QQuickRhiItemRendererFunc_renderTarget), METH_NOARGS, nullptr},
    {"resolveTexture", reinterpret_cast<PyCFunction>(Sbk_QQuickRhiItemRendererFunc_resolveTexture), METH_NOARGS, nullptr},
    {"rhi", reinterpret_cast<PyCFunction>(Sbk_QQuickRhiItemRendererFunc_rhi), METH_NOARGS, nullptr},
    {"synchronize", reinterpret_cast<PyCFunction>(Sbk_QQuickRhiItemRendererFunc_synchronize), METH_O, nullptr},
    {"update", reinterpret_cast<PyCFunction>(Sbk_QQuickRhiItemRendererFunc_update), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QQuickRhiItemRenderer_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QQuickRhiItemRenderer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItemRenderer_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QQuickRhiItemRendererWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QQuickRhiItemRenderer_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QQuickRhiItemRenderer_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QQuickRhiItemRenderer_Type = nullptr;
static PyTypeObject *Sbk_QQuickRhiItemRenderer_TypeF(void)
{
    return _Sbk_QQuickRhiItemRenderer_Type;
}

static PyType_Slot Sbk_QQuickRhiItemRenderer_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QQuickRhiItemRenderer_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QQuickRhiItemRenderer_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QQuickRhiItemRenderer_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QQuickRhiItemRenderer_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QQuickRhiItemRenderer_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QQuickRhiItemRenderer_spec = {
    "2:PySide6.QtQuick.QQuickRhiItemRenderer",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QQuickRhiItemRenderer_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QQuickRhiItemRenderer_PythonToCpp_QQuickRhiItemRenderer_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QQuickRhiItemRenderer_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QQuickRhiItemRenderer_PythonToCpp_QQuickRhiItemRenderer_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QQuickRhiItemRenderer_TypeF()))
        return QQuickRhiItemRenderer_PythonToCpp_QQuickRhiItemRenderer_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QQuickRhiItemRenderer_PTR_CppToPython_QQuickRhiItemRenderer(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QQuickRhiItemRenderer *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QQuickRhiItemRenderer_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QQuickRhiItemRenderer_SignatureStrings[] = {
    "PySide6.QtQuick.QQuickRhiItemRenderer(self)",
    "PySide6.QtQuick.QQuickRhiItemRenderer.colorTexture(self)->PySide6.QtGui.QRhiTexture",
    "PySide6.QtQuick.QQuickRhiItemRenderer.depthStencilBuffer(self)->PySide6.QtGui.QRhiRenderBuffer",
    "PySide6.QtQuick.QQuickRhiItemRenderer.initialize(self,cb:PySide6.QtGui.QRhiCommandBuffer)",
    "PySide6.QtQuick.QQuickRhiItemRenderer.msaaColorBuffer(self)->PySide6.QtGui.QRhiRenderBuffer",
    "PySide6.QtQuick.QQuickRhiItemRenderer.render(self,cb:PySide6.QtGui.QRhiCommandBuffer)",
    "PySide6.QtQuick.QQuickRhiItemRenderer.renderTarget(self)->PySide6.QtGui.QRhiRenderTarget",
    "PySide6.QtQuick.QQuickRhiItemRenderer.resolveTexture(self)->PySide6.QtGui.QRhiTexture",
    "PySide6.QtQuick.QQuickRhiItemRenderer.rhi(self)->PySide6.QtGui.QRhi",
    "PySide6.QtQuick.QQuickRhiItemRenderer.synchronize(self,item:PySide6.QtQuick.QQuickRhiItem)",
    "PySide6.QtQuick.QQuickRhiItemRenderer.update(self)",
    nullptr}; // Sentinel
#else
static constexpr size_t QQuickRhiItemRenderer_SignatureByteSize = 202;
static constexpr uint8_t QQuickRhiItemRenderer_SignatureBytes[202] = {
    0x78, 0xda, 0xb5, 0x92, 0xb9, 0x0e, 0xc2, 0x30, 0x10, 0x44, 0xfb, 0x7c, 0x09, 0x48, 0x90, 0x92,
    0x22, 0x05, 0x05, 0x29, 0x10, 0x5d, 0xae, 0x1f, 0x30, 0xf6, 0x06, 0xaf, 0xf0, 0x11, 0x39, 0x36,
    0x22, 0x7c, 0x3d, 0x21, 0x0e, 0x50, 0x70, 0xb9, 0x08, 0x95, 0x57, 0xf2, 0xcc, 0xd3, 0x78, 0xbc,
    0x59, 0x57, 0x22, 0x83, 0x55, 0x9c, 0xdb, 0xdc, 0x21, 0x3d, 0xc6, 0xf9, 0x70, 0x14, 0x1c, 0x77,
    0x16, 0x64, 0x01, 0x8a, 0x81, 0x01, 0x33, 0x6b, 0x41, 0xd4, 0xf3, 0x28, 0x0b, 0xd1, 0xc6, 0x54,
    0x0b, 0x6d, 0x2a, 0x38, 0x5b, 0x67, 0xc0, 0x1b, 0x97, 0xeb, 0xa7, 0x73, 0xeb, 0x30, 0xce, 0x7b,
    0xcb, 0x28, 0x08, 0x64, 0x32, 0x68, 0x2c, 0x2f, 0x2d, 0x28, 0x8a, 0x62, 0xe3, 0xea, 0xfa, 0x1e,
    0xe9, 0x1d, 0xd9, 0x9b, 0xbc, 0x2a, 0x10, 0x8f, 0x0a, 0x2d, 0x12, 0x81, 0x17, 0x1f, 0x78, 0x41,
    0xf7, 0xc9, 0x2b, 0x37, 0xd5, 0x52, 0x12, 0xc5, 0x3c, 0x38, 0xb4, 0x0c, 0xd9, 0x12, 0x92, 0xde,
    0x0a, 0xf9, 0x43, 0x6a, 0x33, 0x0c, 0x53, 0x27, 0xf6, 0xd4, 0x8a, 0x98, 0x03, 0xd8, 0x5f, 0x71,
    0xbd, 0x2a, 0x18, 0xdc, 0x6a, 0x71, 0x82, 0x89, 0x37, 0xc3, 0x70, 0xfc, 0x8c, 0x0a, 0x64, 0xb4,
    0x9d, 0xa2, 0xdc, 0x68, 0xf5, 0xf8, 0x7f, 0xec, 0x6f, 0x93, 0xaf, 0xde, 0xd0, 0x36, 0x5d, 0xc3,
    0x88, 0x1d, 0x1f, 0x1b, 0x5d, 0x01, 0x6d, 0xc3, 0x3e, 0x8c
};
#endif

PyTypeObject *init_QQuickRhiItemRenderer(PyObject *module)
{
    if (SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItemRenderer_IDX].type != nullptr)
        return SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItemRenderer_IDX].type;

    Shiboken::AutoDecRef Sbk_QQuickRhiItemRenderer_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QQuickRhiItemRenderer_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QQuickRhiItemRenderer",
        "QQuickRhiItemRenderer*",
        &Sbk_QQuickRhiItemRenderer_spec,
        &Shiboken::callCppDestructor< QQuickRhiItemRenderer >,
        Sbk_QQuickRhiItemRenderer_Type_bases.object(),
        0);
    auto *pyType = Sbk_QQuickRhiItemRenderer_TypeF(); // references _Sbk_QQuickRhiItemRenderer_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QQuickRhiItemRenderer_SignatureStrings);
#else
    InitSignatureBytes(pyType, QQuickRhiItemRenderer_SignatureBytes, QQuickRhiItemRenderer_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QQuickRhiItemRenderer_PropertyStrings);
    SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItemRenderer_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QQuickRhiItemRenderer_PythonToCpp_QQuickRhiItemRenderer_PTR,
        is_QQuickRhiItemRenderer_PythonToCpp_QQuickRhiItemRenderer_PTR_Convertible,
        QQuickRhiItemRenderer_PTR_CppToPython_QQuickRhiItemRenderer);

    Shiboken::Conversions::registerConverterName(converter, "QQuickRhiItemRenderer");
    Shiboken::Conversions::registerConverterName(converter, "QQuickRhiItemRenderer*");
    Shiboken::Conversions::registerConverterName(converter, "QQuickRhiItemRenderer&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QQuickRhiItemRenderer).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QQuickRhiItemRendererWrapper).name());

    qRegisterMetaType< ::QQuickRhiItemRenderer *>();

    return pyType;
}
