// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtquick_python.h"

// main header
#include "qquickwindow_graphicsstateinfo_wrapper.h"

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QQuickWindow_GraphicsStateInfo_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QQuickWindow::GraphicsStateInfo >()))
        return -1;

    ::QQuickWindow::GraphicsStateInfo *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "GraphicsStateInfo", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: GraphicsStateInfo::GraphicsStateInfo()
    // 1: GraphicsStateInfo::GraphicsStateInfo(QQuickWindow::GraphicsStateInfo)
    if (numArgs == 0) {
        overloadId = 0; // GraphicsStateInfo()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickWindow_GraphicsStateInfo_IDX]), (pyArgs[0])))) {
        overloadId = 1; // GraphicsStateInfo(QQuickWindow::GraphicsStateInfo)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickWindow_GraphicsStateInfo_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtQuickTypeStructs[SBK_QQuickWindow_GraphicsStateInfo_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // GraphicsStateInfo()
        {

            // GraphicsStateInfo()
            cptr = new ::QQuickWindow::GraphicsStateInfo();
            break;
        }
        case 1: // GraphicsStateInfo(const QQuickWindow::GraphicsStateInfo &GraphicsStateInfo)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QQuickWindow::GraphicsStateInfo cppArg0_local;
            ::QQuickWindow::GraphicsStateInfo *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // GraphicsStateInfo(QQuickWindow::GraphicsStateInfo)
                cptr = new ::QQuickWindow::GraphicsStateInfo(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QQuickWindow::GraphicsStateInfo >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickWindow_GraphicsStateInfo_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QQuickWindow_GraphicsStateInfo__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QQuickWindow::GraphicsStateInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickWindow_GraphicsStateInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickWindow_GraphicsStateInfo_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QQuickWindow_GraphicsStateInfo_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QQuickWindow_GraphicsStateInfo_methods[] = {
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QQuickWindow_GraphicsStateInfo__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QQuickWindow_GraphicsStateInfo_get_currentFrameSlot(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickWindow::GraphicsStateInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickWindow_GraphicsStateInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int cppOut_local = cppSelf->currentFrameSlot;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QQuickWindow_GraphicsStateInfo_set_currentFrameSlot(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QQuickWindow::GraphicsStateInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickWindow_GraphicsStateInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("currentFrameSlot");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("currentFrameSlot", "int");
        return -1;
    }

    auto cppOut_local = cppSelf->currentFrameSlot;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->currentFrameSlot = cppOut_local;

    return 0;
}

static PyObject *Sbk_QQuickWindow_GraphicsStateInfo_get_framesInFlight(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickWindow::GraphicsStateInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickWindow_GraphicsStateInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int cppOut_local = cppSelf->framesInFlight;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QQuickWindow_GraphicsStateInfo_set_framesInFlight(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QQuickWindow::GraphicsStateInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickWindow_GraphicsStateInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("framesInFlight");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("framesInFlight", "int");
        return -1;
    }

    auto cppOut_local = cppSelf->framesInFlight;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->framesInFlight = cppOut_local;

    return 0;
}

// Getters and Setters for GraphicsStateInfo
static PyGetSetDef Sbk_QQuickWindow_GraphicsStateInfo_getsetlist[] = {
    {const_cast<char *>("currentFrameSlot"), Sbk_QQuickWindow_GraphicsStateInfo_get_currentFrameSlot, Sbk_QQuickWindow_GraphicsStateInfo_set_currentFrameSlot, nullptr, nullptr},
    {const_cast<char *>("framesInFlight"), Sbk_QQuickWindow_GraphicsStateInfo_get_framesInFlight, Sbk_QQuickWindow_GraphicsStateInfo_set_framesInFlight, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QQuickWindow_GraphicsStateInfo_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QQuickWindow_GraphicsStateInfo_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QQuickWindow_GraphicsStateInfo_Type = nullptr;
static PyTypeObject *Sbk_QQuickWindow_GraphicsStateInfo_TypeF(void)
{
    return _Sbk_QQuickWindow_GraphicsStateInfo_Type;
}

static PyType_Slot Sbk_QQuickWindow_GraphicsStateInfo_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QQuickWindow_GraphicsStateInfo_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QQuickWindow_GraphicsStateInfo_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QQuickWindow_GraphicsStateInfo_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QQuickWindow_GraphicsStateInfo_getsetlist)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QQuickWindow_GraphicsStateInfo_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QQuickWindow_GraphicsStateInfo_spec = {
    "2:PySide6.QtQuick.QQuickWindow.GraphicsStateInfo",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QQuickWindow_GraphicsStateInfo_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void GraphicsStateInfo_PythonToCpp_GraphicsStateInfo_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QQuickWindow_GraphicsStateInfo_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_GraphicsStateInfo_PythonToCpp_GraphicsStateInfo_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QQuickWindow_GraphicsStateInfo_TypeF()))
        return GraphicsStateInfo_PythonToCpp_GraphicsStateInfo_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *GraphicsStateInfo_PTR_CppToPython_GraphicsStateInfo(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QQuickWindow_GraphicsStateInfo_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *GraphicsStateInfo_COPY_CppToPython_GraphicsStateInfo(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QQuickWindow::GraphicsStateInfo *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QQuickWindow_GraphicsStateInfo_TypeF(), new ::QQuickWindow::GraphicsStateInfo(*source), true, true);
}

// Python to C++ copy conversion.
static void GraphicsStateInfo_PythonToCpp_GraphicsStateInfo_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QQuickWindow::GraphicsStateInfo *>(cppOut) = *reinterpret_cast< ::QQuickWindow::GraphicsStateInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickWindow_GraphicsStateInfo_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_GraphicsStateInfo_PythonToCpp_GraphicsStateInfo_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QQuickWindow_GraphicsStateInfo_TypeF()))
        return GraphicsStateInfo_PythonToCpp_GraphicsStateInfo_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QQuickWindow_GraphicsStateInfo_SignatureStrings[] = {
    "1:PySide6.QtQuick.QQuickWindow.GraphicsStateInfo(self)",
    "0:PySide6.QtQuick.QQuickWindow.GraphicsStateInfo(self,GraphicsStateInfo:PySide6.QtQuick.QQuickWindow.GraphicsStateInfo)",
    "PySide6.QtQuick.QQuickWindow.GraphicsStateInfo.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QQuickWindow_GraphicsStateInfo_SignatureByteSize = 97;
static constexpr uint8_t QQuickWindow_GraphicsStateInfo_SignatureBytes[97] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x09, 0x2c,
    0xcd, 0x4c, 0xce, 0xd6, 0x0b, 0x04, 0x53, 0xe1, 0x99, 0x79, 0x29, 0xf9, 0xe5, 0x7a, 0xee, 0x45,
    0x89, 0x05, 0x19, 0x99, 0xc9, 0xc5, 0xc1, 0x25, 0x89, 0x25, 0xa9, 0x9e, 0x79, 0x69, 0xf9, 0x1a,
    0xc5, 0xa9, 0x39, 0x69, 0x9a, 0x5c, 0x06, 0xe4, 0x68, 0xd3, 0xc1, 0x10, 0x26, 0xd1, 0x14, 0x4d,
    0x2e, 0xd2, 0xd4, 0xeb, 0xc5, 0xc7, 0x27, 0xe7, 0x17, 0x54, 0xc6, 0xc7, 0x43, 0x5c, 0xad, 0x6b,
    0x57, 0x52, 0x59, 0x90, 0x99, 0x97, 0xae, 0x17, 0x0c, 0xe4, 0x71, 0x01, 0x00, 0xb4, 0xb5, 0x5b,
    0x7c
};
#endif

PyTypeObject *init_QQuickWindow_GraphicsStateInfo(PyObject *enclosingClass)
{
    if (SbkPySide6_QtQuickTypeStructs[SBK_QQuickWindow_GraphicsStateInfo_IDX].type != nullptr)
        return SbkPySide6_QtQuickTypeStructs[SBK_QQuickWindow_GraphicsStateInfo_IDX].type;

    Shiboken::AutoDecRef Sbk_QQuickWindow_GraphicsStateInfo_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QQuickWindow_GraphicsStateInfo_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "GraphicsStateInfo",
        "QQuickWindow::GraphicsStateInfo",
        &Sbk_QQuickWindow_GraphicsStateInfo_spec,
        &Shiboken::callCppDestructor< ::QQuickWindow::GraphicsStateInfo >,
        Sbk_QQuickWindow_GraphicsStateInfo_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass | Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QQuickWindow_GraphicsStateInfo_TypeF(); // references _Sbk_QQuickWindow_GraphicsStateInfo_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QQuickWindow_GraphicsStateInfo_SignatureStrings);
#else
    InitSignatureBytes(pyType, QQuickWindow_GraphicsStateInfo_SignatureBytes, QQuickWindow_GraphicsStateInfo_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QQuickWindow_GraphicsStateInfo_PropertyStrings);
    SbkPySide6_QtQuickTypeStructs[SBK_QQuickWindow_GraphicsStateInfo_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        GraphicsStateInfo_PythonToCpp_GraphicsStateInfo_PTR,
        is_GraphicsStateInfo_PythonToCpp_GraphicsStateInfo_PTR_Convertible,
        GraphicsStateInfo_PTR_CppToPython_GraphicsStateInfo,
        GraphicsStateInfo_COPY_CppToPython_GraphicsStateInfo);

    Shiboken::Conversions::registerConverterName(converter, "QQuickWindow::GraphicsStateInfo");
    Shiboken::Conversions::registerConverterName(converter, "QQuickWindow::GraphicsStateInfo*");
    Shiboken::Conversions::registerConverterName(converter, "QQuickWindow::GraphicsStateInfo&");
    Shiboken::Conversions::registerConverterAlias(converter, "GraphicsStateInfo");
    Shiboken::Conversions::registerConverterAlias(converter, "GraphicsStateInfo*");
    Shiboken::Conversions::registerConverterAlias(converter, "GraphicsStateInfo&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QQuickWindow::GraphicsStateInfo).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        GraphicsStateInfo_PythonToCpp_GraphicsStateInfo_COPY,
        is_GraphicsStateInfo_PythonToCpp_GraphicsStateInfo_COPY_Convertible);

    qRegisterMetaType< ::QQuickWindow::GraphicsStateInfo >("GraphicsStateInfo");
    qRegisterMetaType< ::QQuickWindow::GraphicsStateInfo >("QQuickWindow::GraphicsStateInfo");

    return pyType;
}
