// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtquick_python.h"

// main header
#include "qsgbasicgeometrynode_wrapper.h"

// Argument includes
#include <QtGui/qmatrix4x4.h>
#include <QtQuick/qsggeometry.h>
#include <QtQuick/qsgnode.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QSGBasicGeometryNodeWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QSGBasicGeometryNodeWrapper::QSGBasicGeometryNodeWrapper(::QSGNode::NodeType type) : QSGBasicGeometryNode(type)
{
}

bool QSGBasicGeometryNodeWrapper::isSubtreeBlocked() const
{
    if (m_PyMethodCache[0])
        return this->::QSGNode::isSubtreeBlocked();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "isSubtreeBlocked";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QSGNode::isSubtreeBlocked();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSGBasicGeometryNode", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSGBasicGeometryNode", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QSGBasicGeometryNodeWrapper::preprocess()
{
    if (m_PyMethodCache[1]) {
        return this->::QSGNode::preprocess();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "preprocess";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QSGNode::preprocess();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSGBasicGeometryNode", funcName);
        return;
    }
}

QSGBasicGeometryNodeWrapper::~QSGBasicGeometryNodeWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSGBasicGeometryNode_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSGBasicGeometryNode >()))
        return -1;

    QSGBasicGeometryNodeWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QSGBasicGeometryNode", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QSGBasicGeometryNode::QSGBasicGeometryNode(QSGNode::NodeType)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_NodeType_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // QSGBasicGeometryNode(QSGNode::NodeType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGBasicGeometryNode_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtQuickTypeStructs[SBK_QSGBasicGeometryNode_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        ::QSGNode::NodeType cppArg0{QSGNode::BasicNodeType};
        pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QSGBasicGeometryNode(QSGNode::NodeType)
            cptr = new QSGBasicGeometryNodeWrapper(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QSGBasicGeometryNode >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGBasicGeometryNode_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSGBasicGeometryNodeFunc_clipList(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGBasicGeometryNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGBasicGeometryNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clipList()const
        const QSGClipNode * cppResult = const_cast<const ::QSGBasicGeometryNode *>(cppSelf)->clipList();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGClipNode_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGBasicGeometryNodeFunc_geometry(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGBasicGeometryNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGBasicGeometryNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // geometry()
        QSGGeometry * cppResult = cppSelf->geometry();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGBasicGeometryNodeFunc_matrix(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGBasicGeometryNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGBasicGeometryNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // matrix()const
        const QMatrix4x4 * cppResult = const_cast<const ::QSGBasicGeometryNode *>(cppSelf)->matrix();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGBasicGeometryNodeFunc_setGeometry(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGBasicGeometryNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGBasicGeometryNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGBasicGeometryNode::setGeometry(QSGGeometry*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]), (pyArg)))) {
        overloadId = 0; // setGeometry(QSGGeometry*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setGeometry", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGBasicGeometryNode_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSGGeometry *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setGeometry(QSGGeometry*)
            cppSelf->setGeometry(cppArg0);

            // Ownership transferences.
            Shiboken::Object::releaseOwnership(pyArg);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGBasicGeometryNodeFunc_setRendererClipList(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGBasicGeometryNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGBasicGeometryNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGBasicGeometryNode::setRendererClipList(const QSGClipNode*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGClipNode_IDX]), (pyArg)))) {
        overloadId = 0; // setRendererClipList(const QSGClipNode*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRendererClipList", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGBasicGeometryNode_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSGClipNode *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRendererClipList(const QSGClipNode*)
            cppSelf->setRendererClipList(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGBasicGeometryNodeFunc_setRendererMatrix(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGBasicGeometryNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGBasicGeometryNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGBasicGeometryNode::setRendererMatrix(const QMatrix4x4*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), (pyArg)))) {
        overloadId = 0; // setRendererMatrix(const QMatrix4x4*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRendererMatrix", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGBasicGeometryNode_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMatrix4x4 *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRendererMatrix(const QMatrix4x4*)
            cppSelf->setRendererMatrix(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QSGBasicGeometryNode_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSGBasicGeometryNode_methods[] = {
    {"clipList", reinterpret_cast<PyCFunction>(Sbk_QSGBasicGeometryNodeFunc_clipList), METH_NOARGS, nullptr},
    {"geometry", reinterpret_cast<PyCFunction>(Sbk_QSGBasicGeometryNodeFunc_geometry), METH_NOARGS, nullptr},
    {"matrix", reinterpret_cast<PyCFunction>(Sbk_QSGBasicGeometryNodeFunc_matrix), METH_NOARGS, nullptr},
    {"setGeometry", reinterpret_cast<PyCFunction>(Sbk_QSGBasicGeometryNodeFunc_setGeometry), METH_O, nullptr},
    {"setRendererClipList", reinterpret_cast<PyCFunction>(Sbk_QSGBasicGeometryNodeFunc_setRendererClipList), METH_O, nullptr},
    {"setRendererMatrix", reinterpret_cast<PyCFunction>(Sbk_QSGBasicGeometryNodeFunc_setRendererMatrix), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QSGBasicGeometryNode_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QSGBasicGeometryNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGBasicGeometryNode_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QSGBasicGeometryNodeWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QSGBasicGeometryNode_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSGBasicGeometryNode_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSGBasicGeometryNode_Type = nullptr;
static PyTypeObject *Sbk_QSGBasicGeometryNode_TypeF(void)
{
    return _Sbk_QSGBasicGeometryNode_Type;
}

static PyType_Slot Sbk_QSGBasicGeometryNode_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QSGBasicGeometryNode_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSGBasicGeometryNode_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSGBasicGeometryNode_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSGBasicGeometryNode_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSGBasicGeometryNode_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSGBasicGeometryNode_spec = {
    "2:PySide6.QtQuick.QSGBasicGeometryNode",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSGBasicGeometryNode_slots
};

} //extern "C"

static void *Sbk_QSGBasicGeometryNode_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QSGNode >())
        return dynamic_cast< ::QSGBasicGeometryNode *>(reinterpret_cast< ::QSGNode *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSGBasicGeometryNode_PythonToCpp_QSGBasicGeometryNode_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSGBasicGeometryNode_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSGBasicGeometryNode_PythonToCpp_QSGBasicGeometryNode_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSGBasicGeometryNode_TypeF()))
        return QSGBasicGeometryNode_PythonToCpp_QSGBasicGeometryNode_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSGBasicGeometryNode_PTR_CppToPython_QSGBasicGeometryNode(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QSGBasicGeometryNode *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QSGBasicGeometryNode_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSGBasicGeometryNode_SignatureStrings[] = {
    "PySide6.QtQuick.QSGBasicGeometryNode(self,type:PySide6.QtQuick.QSGNode.NodeType)",
    "PySide6.QtQuick.QSGBasicGeometryNode.clipList(self)->PySide6.QtQuick.QSGClipNode",
    "PySide6.QtQuick.QSGBasicGeometryNode.geometry(self)->PySide6.QtQuick.QSGGeometry",
    "PySide6.QtQuick.QSGBasicGeometryNode.matrix(self)->PySide6.QtGui.QMatrix4x4",
    "PySide6.QtQuick.QSGBasicGeometryNode.setGeometry(self,geometry:PySide6.QtQuick.QSGGeometry)",
    "PySide6.QtQuick.QSGBasicGeometryNode.setRendererClipList(self,c:PySide6.QtQuick.QSGClipNode)",
    "PySide6.QtQuick.QSGBasicGeometryNode.setRendererMatrix(self,m:typing.Union[PySide6.QtGui.QMatrix4x4, PySide6.QtGui.QTransform])",
    nullptr}; // Sentinel
#else
static constexpr size_t QSGBasicGeometryNode_SignatureByteSize = 196;
static constexpr uint8_t QSGBasicGeometryNode_SignatureBytes[196] = {
    0x78, 0xda, 0x95, 0x92, 0xb1, 0x0a, 0x83, 0x30, 0x10, 0x86, 0x77, 0x9f, 0xa2, 0x63, 0x03, 0x69,
    0x26, 0xe9, 0x90, 0xa1, 0x43, 0x1d, 0x5c, 0x6a, 0xd1, 0x6a, 0xa7, 0xd2, 0x41, 0xf4, 0x94, 0xa3,
    0x1a, 0x25, 0x89, 0xa0, 0x6f, 0x5f, 0x95, 0x4a, 0xa5, 0xb6, 0x92, 0x2e, 0x07, 0xc7, 0x7d, 0xf9,
    0xf8, 0xf9, 0x89, 0xdf, 0x85, 0x98, 0xc2, 0x9e, 0x05, 0x3a, 0x68, 0x30, 0x79, 0xb0, 0x20, 0x74,
    0x8f, 0xb1, 0xc2, 0xc4, 0x85, 0xaa, 0x04, 0x2d, 0xbb, 0x73, 0x95, 0xc2, 0x56, 0x41, 0x91, 0x51,
    0xdd, 0xd5, 0xc0, 0xfd, 0x25, 0x3e, 0x10, 0x6c, 0x18, 0x51, 0x0f, 0x10, 0xcb, 0x37, 0x10, 0xb2,
    0xa4, 0xc0, 0xfa, 0x84, 0x4a, 0x8f, 0x66, 0xb2, 0x3b, 0x7c, 0x79, 0xe4, 0xf4, 0xc8, 0xc0, 0x9a,
    0x09, 0xf3, 0xd7, 0xb2, 0x22, 0x9c, 0x78, 0x33, 0x61, 0x19, 0x6b, 0x89, 0xed, 0x52, 0xe7, 0x36,
    0xc8, 0x02, 0x6f, 0x3c, 0xda, 0xad, 0x6d, 0xe6, 0x52, 0xa0, 0xdd, 0x79, 0x3e, 0x3a, 0xa5, 0xe5,
    0x2b, 0x31, 0x89, 0xb1, 0xfb, 0x02, 0x22, 0x05, 0x09, 0xd2, 0x99, 0x97, 0x4a, 0x13, 0xbe, 0x52,
    0xea, 0xff, 0x72, 0xef, 0xdd, 0x07, 0x2d, 0x79, 0xff, 0x17, 0x50, 0xe4, 0xec, 0x2a, 0xb0, 0x12,
    0xb7, 0x5f, 0xe5, 0xd0, 0xcd, 0xc7, 0x25, 0x92, 0xb1, 0x50, 0x59, 0x25, 0xcb, 0x3b, 0xb1, 0x9e,
    0x6a, 0x39, 0xe3, 0x30
};
#endif

PyTypeObject *init_QSGBasicGeometryNode(PyObject *module)
{
    if (SbkPySide6_QtQuickTypeStructs[SBK_QSGBasicGeometryNode_IDX].type != nullptr)
        return SbkPySide6_QtQuickTypeStructs[SBK_QSGBasicGeometryNode_IDX].type;

    Shiboken::AutoDecRef Sbk_QSGBasicGeometryNode_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]))));

    _Sbk_QSGBasicGeometryNode_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSGBasicGeometryNode",
        "QSGBasicGeometryNode*",
        &Sbk_QSGBasicGeometryNode_spec,
        &Shiboken::callCppDestructor< QSGBasicGeometryNode >,
        Sbk_QSGBasicGeometryNode_Type_bases.object(),
        0);
    auto *pyType = Sbk_QSGBasicGeometryNode_TypeF(); // references _Sbk_QSGBasicGeometryNode_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSGBasicGeometryNode_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSGBasicGeometryNode_SignatureBytes, QSGBasicGeometryNode_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSGBasicGeometryNode_PropertyStrings);
    SbkPySide6_QtQuickTypeStructs[SBK_QSGBasicGeometryNode_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSGBasicGeometryNode_PythonToCpp_QSGBasicGeometryNode_PTR,
        is_QSGBasicGeometryNode_PythonToCpp_QSGBasicGeometryNode_PTR_Convertible,
        QSGBasicGeometryNode_PTR_CppToPython_QSGBasicGeometryNode);

    Shiboken::Conversions::registerConverterName(converter, "QSGBasicGeometryNode");
    Shiboken::Conversions::registerConverterName(converter, "QSGBasicGeometryNode*");
    Shiboken::Conversions::registerConverterName(converter, "QSGBasicGeometryNode&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSGBasicGeometryNode).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QSGBasicGeometryNodeWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QSGBasicGeometryNode_TypeF(), &Sbk_QSGBasicGeometryNode_typeDiscovery);

    qRegisterMetaType< ::QSGBasicGeometryNode *>();

    return pyType;
}
