// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtquick_python.h"

// main header
#include "qsgflatcolormaterial_wrapper.h"

// Argument includes
#include <QtGui/qcolor.h>
#include <QtQuick/qsgmaterial.h>
#include <QtQuick/qsgmaterialshader.h>
#include <QtQuick/qsgmaterialtype.h>
#include <QtQuick/qsgrendererinterface.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QSGFlatColorMaterialWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QSGFlatColorMaterialWrapper::QSGFlatColorMaterialWrapper()
{
}

int QSGFlatColorMaterialWrapper::compare(const ::QSGMaterial * other) const
{
    if (m_PyMethodCache[0])
        return this->::QSGFlatColorMaterial::compare(other);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return 0;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "compare";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QSGFlatColorMaterial::compare(other);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]), other)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]), other)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSGFlatColorMaterial", funcName);
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSGFlatColorMaterial", funcName, "int", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    int cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QSGMaterialShader * QSGFlatColorMaterialWrapper::createShader(::QSGRendererInterface::RenderMode renderMode) const
{
    if (m_PyMethodCache[1])
        return this->::QSGFlatColorMaterial::createShader(renderMode);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "createShader";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QSGFlatColorMaterial::createShader(renderMode);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_RenderMode_IDX])))->converter, &renderMode)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_RenderMode_IDX])))->converter, &renderMode)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSGFlatColorMaterial", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSGFlatColorMaterial", funcName, Shiboken::SbkType< QSGMaterialShader >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QSGMaterialShader *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QSGMaterialType * QSGFlatColorMaterialWrapper::type() const
{
    if (m_PyMethodCache[2])
        return this->::QSGFlatColorMaterial::type();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "type";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QSGFlatColorMaterial::type();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSGFlatColorMaterial", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialType_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSGFlatColorMaterial", funcName, Shiboken::SbkType< QSGMaterialType >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QSGMaterialType *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QSGFlatColorMaterialWrapper::~QSGFlatColorMaterialWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSGFlatColorMaterial_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSGFlatColorMaterial >()))
        return -1;

    QSGFlatColorMaterialWrapper *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtQuickTypeStructs[SBK_QSGFlatColorMaterial_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QSGFlatColorMaterial()
        cptr = new QSGFlatColorMaterialWrapper();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QSGFlatColorMaterial >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSGFlatColorMaterialFunc_color(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGFlatColorMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGFlatColorMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // color()const
        const QColor & cppResult = const_cast<const ::QSGFlatColorMaterial *>(cppSelf)->color();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGFlatColorMaterialFunc_compare(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGFlatColorMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGFlatColorMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGMaterial::compare(const QSGMaterial*)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]), (pyArg)))) {
        overloadId = 0; // compare(const QSGMaterial*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "compare", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGFlatColorMaterial_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSGMaterial *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // compare(const QSGMaterial*)const
            int cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QSGFlatColorMaterial *>(cppSelf)->::QSGFlatColorMaterial::compare(cppArg0)
                : const_cast<const ::QSGFlatColorMaterial *>(cppSelf)->compare(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGFlatColorMaterialFunc_createShader(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGFlatColorMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGFlatColorMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGMaterial::createShader(QSGRendererInterface::RenderMode)const->QSGMaterialShader*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_RenderMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // createShader(QSGRendererInterface::RenderMode)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "createShader", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGFlatColorMaterial_IDX]);

    // Call function/method
    {
        ::QSGRendererInterface::RenderMode cppArg0{QSGRendererInterface::RenderMode2D};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createShader(QSGRendererInterface::RenderMode)const
            QSGMaterialShader * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QSGFlatColorMaterial *>(cppSelf)->::QSGFlatColorMaterial::createShader(cppArg0)
                : const_cast<const ::QSGFlatColorMaterial *>(cppSelf)->createShader(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGFlatColorMaterialFunc_setColor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGFlatColorMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGFlatColorMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGFlatColorMaterial::setColor(QColor)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArg)))) {
        overloadId = 0; // setColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setColor", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGFlatColorMaterial_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QColor cppArg0_local;
        ::QColor *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setColor(QColor)
            cppSelf->setColor(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGFlatColorMaterialFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGFlatColorMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGFlatColorMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        QSGMaterialType * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QSGFlatColorMaterial *>(cppSelf)->::QSGFlatColorMaterial::type()
            : const_cast<const ::QSGFlatColorMaterial *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialType_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QSGFlatColorMaterial_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSGFlatColorMaterial_methods[] = {
    {"color", reinterpret_cast<PyCFunction>(Sbk_QSGFlatColorMaterialFunc_color), METH_NOARGS, nullptr},
    {"compare", reinterpret_cast<PyCFunction>(Sbk_QSGFlatColorMaterialFunc_compare), METH_O, nullptr},
    {"createShader", reinterpret_cast<PyCFunction>(Sbk_QSGFlatColorMaterialFunc_createShader), METH_O, nullptr},
    {"setColor", reinterpret_cast<PyCFunction>(Sbk_QSGFlatColorMaterialFunc_setColor), METH_O, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QSGFlatColorMaterialFunc_type), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QSGFlatColorMaterial_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QSGFlatColorMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGFlatColorMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QSGFlatColorMaterialWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QSGFlatColorMaterial_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSGFlatColorMaterial_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSGFlatColorMaterial_Type = nullptr;
static PyTypeObject *Sbk_QSGFlatColorMaterial_TypeF(void)
{
    return _Sbk_QSGFlatColorMaterial_Type;
}

static PyType_Slot Sbk_QSGFlatColorMaterial_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QSGFlatColorMaterial_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSGFlatColorMaterial_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSGFlatColorMaterial_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSGFlatColorMaterial_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSGFlatColorMaterial_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSGFlatColorMaterial_spec = {
    "2:PySide6.QtQuick.QSGFlatColorMaterial",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSGFlatColorMaterial_slots
};

} //extern "C"

static void *Sbk_QSGFlatColorMaterial_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QSGMaterial >())
        return dynamic_cast< ::QSGFlatColorMaterial *>(reinterpret_cast< ::QSGMaterial *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSGFlatColorMaterial_PythonToCpp_QSGFlatColorMaterial_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSGFlatColorMaterial_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSGFlatColorMaterial_PythonToCpp_QSGFlatColorMaterial_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSGFlatColorMaterial_TypeF()))
        return QSGFlatColorMaterial_PythonToCpp_QSGFlatColorMaterial_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSGFlatColorMaterial_PTR_CppToPython_QSGFlatColorMaterial(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QSGFlatColorMaterial *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QSGFlatColorMaterial_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSGFlatColorMaterial_SignatureStrings[] = {
    "PySide6.QtQuick.QSGFlatColorMaterial(self)",
    "PySide6.QtQuick.QSGFlatColorMaterial.color(self)->PySide6.QtGui.QColor",
    "PySide6.QtQuick.QSGFlatColorMaterial.compare(self,other:PySide6.QtQuick.QSGMaterial)->int",
    "PySide6.QtQuick.QSGFlatColorMaterial.createShader(self,renderMode:PySide6.QtQuick.QSGRendererInterface.RenderMode)->PySide6.QtQuick.QSGMaterialShader",
    "PySide6.QtQuick.QSGFlatColorMaterial.setColor(self,color:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])",
    "PySide6.QtQuick.QSGFlatColorMaterial.type(self)->PySide6.QtQuick.QSGMaterialType",
    nullptr}; // Sentinel
#else
static constexpr size_t QSGFlatColorMaterial_SignatureByteSize = 239;
static constexpr uint8_t QSGFlatColorMaterial_SignatureBytes[239] = {
    0x78, 0xda, 0x8d, 0x91, 0x3f, 0x6b, 0xc3, 0x30, 0x10, 0xc5, 0xf7, 0x7c, 0x0a, 0x8f, 0x0d, 0xb8,
    0x82, 0x42, 0xc8, 0x90, 0xa1, 0x4b, 0xa0, 0x26, 0xd0, 0x40, 0x64, 0xb7, 0x5d, 0x4a, 0x87, 0x8b,
    0x7d, 0x71, 0x8e, 0xaa, 0xa7, 0x20, 0x9f, 0x87, 0x7c, 0xfb, 0x5e, 0x2d, 0xdc, 0x7f, 0xf6, 0xa0,
    0x49, 0x27, 0xe9, 0x77, 0xef, 0x3d, 0x9d, 0x0e, 0xd7, 0x8a, 0x1a, 0x5c, 0x1b, 0x2b, 0xb6, 0xa7,
    0xfa, 0xdd, 0xd8, 0xaa, 0x78, 0x70, 0x20, 0x5b, 0xef, 0x7c, 0xd8, 0x83, 0x60, 0x20, 0x70, 0x37,
    0x1d, 0xba, 0xd3, 0x72, 0x71, 0x48, 0x40, 0x4d, 0xfd, 0xb5, 0x8b, 0x0d, 0xb7, 0xf7, 0x3f, 0x1d,
    0x45, 0x4f, 0xc6, 0x0e, 0x64, 0xaa, 0xcc, 0xc7, 0x05, 0x02, 0x0e, 0x42, 0xb9, 0x97, 0x33, 0x86,
    0xcd, 0x4c, 0xdf, 0x88, 0xab, 0x15, 0xb1, 0x24, 0x2a, 0x07, 0xd4, 0xb2, 0x3a, 0x43, 0x83, 0x31,
    0x67, 0x1e, 0x90, 0xb5, 0xde, 0xfb, 0x06, 0xe7, 0x3c, 0xca, 0xe1, 0x16, 0xc3, 0x8e, 0x55, 0xe0,
    0x04, 0x35, 0x9a, 0xf2, 0x9b, 0xff, 0xf3, 0xc4, 0x49, 0xaa, 0xe8, 0x91, 0x96, 0xaa, 0xc3, 0x78,
    0x10, 0x13, 0x0d, 0x43, 0xdc, 0xc8, 0xf5, 0x42, 0xdc, 0x9a, 0x67, 0x26, 0xcf, 0xaf, 0x73, 0xa3,
    0xcc, 0x33, 0xfb, 0x08, 0x42, 0x7c, 0x57, 0x49, 0x50, 0x32, 0xcf, 0xfe, 0x41, 0x65, 0x7b, 0x84,
    0xf5, 0x4a, 0xa9, 0x17, 0x50, 0x13, 0x96, 0xdf, 0xc0, 0xd6, 0x07, 0xd4, 0xc5, 0x14, 0xce, 0x1f,
    0xc1, 0x8d, 0x72, 0xa3, 0x50, 0xcf, 0x1d, 0xb5, 0x8c, 0x4d, 0xa6, 0x63, 0x7d, 0x4b, 0xfc, 0x79,
    0x8d, 0x8b, 0xd3, 0x8f, 0x9f, 0x4c, 0xe5, 0x49, 0xb1, 0xc5, 0x27, 0x8a, 0x20, 0xe1, 0x12
};
#endif

PyTypeObject *init_QSGFlatColorMaterial(PyObject *module)
{
    if (SbkPySide6_QtQuickTypeStructs[SBK_QSGFlatColorMaterial_IDX].type != nullptr)
        return SbkPySide6_QtQuickTypeStructs[SBK_QSGFlatColorMaterial_IDX].type;

    Shiboken::AutoDecRef Sbk_QSGFlatColorMaterial_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]))));

    _Sbk_QSGFlatColorMaterial_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSGFlatColorMaterial",
        "QSGFlatColorMaterial*",
        &Sbk_QSGFlatColorMaterial_spec,
        &Shiboken::callCppDestructor< QSGFlatColorMaterial >,
        Sbk_QSGFlatColorMaterial_Type_bases.object(),
        0);
    auto *pyType = Sbk_QSGFlatColorMaterial_TypeF(); // references _Sbk_QSGFlatColorMaterial_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSGFlatColorMaterial_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSGFlatColorMaterial_SignatureBytes, QSGFlatColorMaterial_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSGFlatColorMaterial_PropertyStrings);
    SbkPySide6_QtQuickTypeStructs[SBK_QSGFlatColorMaterial_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSGFlatColorMaterial_PythonToCpp_QSGFlatColorMaterial_PTR,
        is_QSGFlatColorMaterial_PythonToCpp_QSGFlatColorMaterial_PTR_Convertible,
        QSGFlatColorMaterial_PTR_CppToPython_QSGFlatColorMaterial);

    Shiboken::Conversions::registerConverterName(converter, "QSGFlatColorMaterial");
    Shiboken::Conversions::registerConverterName(converter, "QSGFlatColorMaterial*");
    Shiboken::Conversions::registerConverterName(converter, "QSGFlatColorMaterial&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSGFlatColorMaterial).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QSGFlatColorMaterialWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QSGFlatColorMaterial_TypeF(), &Sbk_QSGFlatColorMaterial_typeDiscovery);

    qRegisterMetaType< ::QSGFlatColorMaterial *>();

    return pyType;
}
