// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtquick_python.h"

// main header
#include "qsggeometry_attribute_wrapper.h"

// Argument includes
#include <QtQuick/qsggeometry.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSGGeometry_Attribute_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSGGeometry::Attribute >()))
        return -1;

    ::QSGGeometry::Attribute *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "Attribute", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: Attribute::Attribute()
    // 1: Attribute::Attribute(QSGGeometry::Attribute)
    if (numArgs == 0) {
        overloadId = 0; // Attribute()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Attribute_IDX]), (pyArgs[0])))) {
        overloadId = 1; // Attribute(QSGGeometry::Attribute)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Attribute_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Attribute_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // Attribute()
        {

            // Attribute()
            cptr = new ::QSGGeometry::Attribute();
            break;
        }
        case 1: // Attribute(const QSGGeometry::Attribute &Attribute)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QSGGeometry::Attribute cppArg0_local;
            ::QSGGeometry::Attribute *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // Attribute(QSGGeometry::Attribute)
                cptr = new ::QSGGeometry::Attribute(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QSGGeometry::Attribute >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Attribute_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSGGeometry_AttributeFunc_create(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "create", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Attribute_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:create", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static Attribute::create(int,int,int,bool=)->QSGGeometry::Attribute
    if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // create(int,int,int,bool)
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[3])))) {
            overloadId = 0; // create(int,int,int,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "create", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Attribute_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_isPosition = Shiboken::String::createStaticString("isPosition");
            if (PyDict_Contains(kwds, key_isPosition) != 0) {
                value = PyDict_GetItem(kwds, key_isPosition);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_isPosition);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "create", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Attribute_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, "create", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Attribute_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_isPosition);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "create", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Attribute_IDX]);
            }
        }
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        bool cppArg3 = false;
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // create(int,int,int,bool)
            QSGGeometry::Attribute cppResult = ::QSGGeometry::Attribute::create(cppArg0, cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Attribute_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGGeometry_AttributeFunc_createWithAttributeType(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "createWithAttributeType", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static Attribute::createWithAttributeType(int,int,int,QSGGeometry::AttributeType)->QSGGeometry::Attribute
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_AttributeType_IDX])))->converter, (pyArgs[3])))) {
        overloadId = 0; // createWithAttributeType(int,int,int,QSGGeometry::AttributeType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "createWithAttributeType", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Attribute_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        ::QSGGeometry::AttributeType cppArg3{QSGGeometry::UnknownAttribute};
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createWithAttributeType(int,int,int,QSGGeometry::AttributeType)
            QSGGeometry::Attribute cppResult = ::QSGGeometry::Attribute::createWithAttributeType(cppArg0, cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Attribute_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGGeometry_Attribute__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QSGGeometry::Attribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Attribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Attribute_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QSGGeometry_Attribute_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSGGeometry_Attribute_methods[] = {
    {"create", reinterpret_cast<PyCFunction>(Sbk_QSGGeometry_AttributeFunc_create), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"createWithAttributeType", reinterpret_cast<PyCFunction>(Sbk_QSGGeometry_AttributeFunc_createWithAttributeType), METH_VARARGS|METH_STATIC, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QSGGeometry_Attribute__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QSGGeometry_Attribute_get_position(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGGeometry::Attribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Attribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int cppOut_local = cppSelf->position;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QSGGeometry_Attribute_set_position(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QSGGeometry::Attribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Attribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("position");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("position", "int");
        return -1;
    }

    auto cppOut_local = cppSelf->position;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->position = cppOut_local;

    return 0;
}

static PyObject *Sbk_QSGGeometry_Attribute_get_tupleSize(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGGeometry::Attribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Attribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int cppOut_local = cppSelf->tupleSize;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QSGGeometry_Attribute_set_tupleSize(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QSGGeometry::Attribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Attribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("tupleSize");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("tupleSize", "int");
        return -1;
    }

    auto cppOut_local = cppSelf->tupleSize;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->tupleSize = cppOut_local;

    return 0;
}

static PyObject *Sbk_QSGGeometry_Attribute_get_type(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGGeometry::Attribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Attribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int cppOut_local = cppSelf->type;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QSGGeometry_Attribute_set_type(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QSGGeometry::Attribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Attribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("type");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("type", "int");
        return -1;
    }

    auto cppOut_local = cppSelf->type;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->type = cppOut_local;

    return 0;
}

static PyObject *Sbk_QSGGeometry_Attribute_get_isVertexCoordinate(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGGeometry::Attribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Attribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    uint cppOut_local = cppSelf->isVertexCoordinate;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QSGGeometry_Attribute_set_isVertexCoordinate(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QSGGeometry::Attribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Attribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("isVertexCoordinate");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("isVertexCoordinate", "uint");
        return -1;
    }

    auto cppOut_local = cppSelf->isVertexCoordinate;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->isVertexCoordinate = cppOut_local;

    return 0;
}

static PyObject *Sbk_QSGGeometry_Attribute_get_attributeType(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGGeometry::Attribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Attribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::QSGGeometry::AttributeType cppOut_local = cppSelf->attributeType;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_AttributeType_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QSGGeometry_Attribute_set_attributeType(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QSGGeometry::Attribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Attribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("attributeType");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_AttributeType_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("attributeType", "AttributeType");
        return -1;
    }

    auto cppOut_local = cppSelf->attributeType;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->attributeType = cppOut_local;

    return 0;
}

static PyObject *Sbk_QSGGeometry_Attribute_get_reserved(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGGeometry::Attribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Attribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    uint cppOut_local = cppSelf->reserved;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QSGGeometry_Attribute_set_reserved(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QSGGeometry::Attribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Attribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("reserved");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("reserved", "uint");
        return -1;
    }

    auto cppOut_local = cppSelf->reserved;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->reserved = cppOut_local;

    return 0;
}

// Getters and Setters for Attribute
static PyGetSetDef Sbk_QSGGeometry_Attribute_getsetlist[] = {
    {const_cast<char *>("position"), Sbk_QSGGeometry_Attribute_get_position, Sbk_QSGGeometry_Attribute_set_position, nullptr, nullptr},
    {const_cast<char *>("tupleSize"), Sbk_QSGGeometry_Attribute_get_tupleSize, Sbk_QSGGeometry_Attribute_set_tupleSize, nullptr, nullptr},
    {const_cast<char *>("type"), Sbk_QSGGeometry_Attribute_get_type, Sbk_QSGGeometry_Attribute_set_type, nullptr, nullptr},
    {const_cast<char *>("isVertexCoordinate"), Sbk_QSGGeometry_Attribute_get_isVertexCoordinate, Sbk_QSGGeometry_Attribute_set_isVertexCoordinate, nullptr, nullptr},
    {const_cast<char *>("attributeType"), Sbk_QSGGeometry_Attribute_get_attributeType, Sbk_QSGGeometry_Attribute_set_attributeType, nullptr, nullptr},
    {const_cast<char *>("reserved"), Sbk_QSGGeometry_Attribute_get_reserved, Sbk_QSGGeometry_Attribute_set_reserved, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QSGGeometry_Attribute_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSGGeometry_Attribute_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSGGeometry_Attribute_Type = nullptr;
static PyTypeObject *Sbk_QSGGeometry_Attribute_TypeF(void)
{
    return _Sbk_QSGGeometry_Attribute_Type;
}

static PyType_Slot Sbk_QSGGeometry_Attribute_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSGGeometry_Attribute_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSGGeometry_Attribute_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSGGeometry_Attribute_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QSGGeometry_Attribute_getsetlist)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSGGeometry_Attribute_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSGGeometry_Attribute_spec = {
    "2:PySide6.QtQuick.QSGGeometry.Attribute",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSGGeometry_Attribute_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void Attribute_PythonToCpp_Attribute_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSGGeometry_Attribute_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_Attribute_PythonToCpp_Attribute_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSGGeometry_Attribute_TypeF()))
        return Attribute_PythonToCpp_Attribute_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *Attribute_PTR_CppToPython_Attribute(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QSGGeometry_Attribute_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *Attribute_COPY_CppToPython_Attribute(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QSGGeometry::Attribute *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QSGGeometry_Attribute_TypeF(), new ::QSGGeometry::Attribute(*source), true, true);
}

// Python to C++ copy conversion.
static void Attribute_PythonToCpp_Attribute_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QSGGeometry::Attribute *>(cppOut) = *reinterpret_cast< ::QSGGeometry::Attribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Attribute_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_Attribute_PythonToCpp_Attribute_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QSGGeometry_Attribute_TypeF()))
        return Attribute_PythonToCpp_Attribute_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSGGeometry_Attribute_SignatureStrings[] = {
    "1:PySide6.QtQuick.QSGGeometry.Attribute(self)",
    "0:PySide6.QtQuick.QSGGeometry.Attribute(self,Attribute:PySide6.QtQuick.QSGGeometry.Attribute)",
    "PySide6.QtQuick.QSGGeometry.Attribute.create(pos:int,tupleSize:int,primitiveType:int,isPosition:bool=false)->PySide6.QtQuick.QSGGeometry.Attribute",
    "PySide6.QtQuick.QSGGeometry.Attribute.createWithAttributeType(pos:int,tupleSize:int,primitiveType:int,attributeType:PySide6.QtQuick.QSGGeometry.AttributeType)->PySide6.QtQuick.QSGGeometry.Attribute",
    "PySide6.QtQuick.QSGGeometry.Attribute.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QSGGeometry_Attribute_SignatureByteSize = 171;
static constexpr uint8_t QSGGeometry_Attribute_SignatureBytes[171] = {
    0x78, 0xda, 0xad, 0x51, 0xc1, 0x0a, 0x82, 0x40, 0x14, 0xbc, 0xfb, 0x25, 0x09, 0xba, 0xd4, 0xa5,
    0x83, 0x90, 0xd0, 0xc9, 0xab, 0xb2, 0x41, 0xc7, 0x45, 0xed, 0x59, 0x8f, 0x56, 0xdf, 0xb2, 0xfb,
    0x0c, 0xb6, 0xaf, 0x4f, 0x13, 0xa4, 0xe3, 0x0a, 0x1d, 0x67, 0x98, 0x61, 0xe6, 0xcd, 0x3b, 0x64,
    0xa5, 0x97, 0x78, 0x83, 0xa3, 0xa8, 0xb8, 0x1a, 0xb1, 0x7d, 0x8a, 0x4a, 0x16, 0x05, 0x50, 0x0f,
    0x6c, 0xbd, 0x38, 0x33, 0x5b, 0x6c, 0x46, 0x86, 0x9d, 0x03, 0xdd, 0xc5, 0xd1, 0x7e, 0x83, 0x3a,
    0x59, 0x61, 0x98, 0x29, 0x8e, 0x82, 0x64, 0xa2, 0xb5, 0x50, 0x4f, 0x11, 0x86, 0x5c, 0x86, 0x03,
    0x27, 0x3c, 0x1a, 0x0d, 0x12, 0xdf, 0xf0, 0x45, 0xc6, 0x62, 0x8f, 0x8c, 0x2f, 0xb8, 0x78, 0xb3,
    0x30, 0xe8, 0x4a, 0x72, 0x13, 0x45, 0x43, 0xd6, 0x10, 0xe9, 0x53, 0x57, 0x6b, 0x07, 0x71, 0x9a,
    0x07, 0x85, 0x6d, 0xaa, 0x74, 0x45, 0x7e, 0xac, 0xdc, 0x9c, 0x1f, 0xdc, 0xb1, 0xfe, 0x75, 0x85,
    0xad, 0x35, 0x2b, 0xff, 0x7c, 0x85, 0x52, 0x2d, 0x19, 0xaf, 0xd4, 0xf2, 0xeb, 0x34, 0x67, 0x6f,
    0x70, 0xb8, 0x0b, 0x39, 0xa1, 0xe8, 0x03, 0x5c, 0xe3, 0xcb, 0x72
};
#endif

PyTypeObject *init_QSGGeometry_Attribute(PyObject *enclosingClass)
{
    if (SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Attribute_IDX].type != nullptr)
        return SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Attribute_IDX].type;

    Shiboken::AutoDecRef Sbk_QSGGeometry_Attribute_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QSGGeometry_Attribute_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "Attribute",
        "QSGGeometry::Attribute",
        &Sbk_QSGGeometry_Attribute_spec,
        &Shiboken::callCppDestructor< ::QSGGeometry::Attribute >,
        Sbk_QSGGeometry_Attribute_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass | Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QSGGeometry_Attribute_TypeF(); // references _Sbk_QSGGeometry_Attribute_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSGGeometry_Attribute_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSGGeometry_Attribute_SignatureBytes, QSGGeometry_Attribute_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSGGeometry_Attribute_PropertyStrings);
    SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Attribute_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        Attribute_PythonToCpp_Attribute_PTR,
        is_Attribute_PythonToCpp_Attribute_PTR_Convertible,
        Attribute_PTR_CppToPython_Attribute,
        Attribute_COPY_CppToPython_Attribute);

    Shiboken::Conversions::registerConverterName(converter, "QSGGeometry::Attribute");
    Shiboken::Conversions::registerConverterName(converter, "QSGGeometry::Attribute*");
    Shiboken::Conversions::registerConverterName(converter, "QSGGeometry::Attribute&");
    Shiboken::Conversions::registerConverterAlias(converter, "Attribute");
    Shiboken::Conversions::registerConverterAlias(converter, "Attribute*");
    Shiboken::Conversions::registerConverterAlias(converter, "Attribute&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSGGeometry::Attribute).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        Attribute_PythonToCpp_Attribute_COPY,
        is_Attribute_PythonToCpp_Attribute_COPY_Convertible);

    qRegisterMetaType< ::QSGGeometry::Attribute >("Attribute");
    qRegisterMetaType< ::QSGGeometry::Attribute >("QSGGeometry::Attribute");

    return pyType;
}
