// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtquick_python.h"

// main header
#include "qsggeometry_point2d_wrapper.h"

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSGGeometry_Point2D_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSGGeometry::Point2D >()))
        return -1;

    ::QSGGeometry::Point2D *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "Point2D", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: Point2D::Point2D()
    // 1: Point2D::Point2D(QSGGeometry::Point2D)
    if (numArgs == 0) {
        overloadId = 0; // Point2D()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Point2D_IDX]), (pyArgs[0])))) {
        overloadId = 1; // Point2D(QSGGeometry::Point2D)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Point2D_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Point2D_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // Point2D()
        {

            // Point2D()
            cptr = new ::QSGGeometry::Point2D();
            break;
        }
        case 1: // Point2D(const QSGGeometry::Point2D &Point2D)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QSGGeometry::Point2D cppArg0_local;
            ::QSGGeometry::Point2D *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // Point2D(QSGGeometry::Point2D)
                cptr = new ::QSGGeometry::Point2D(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QSGGeometry::Point2D >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Point2D_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSGGeometry_Point2DFunc_set(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGGeometry::Point2D *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Point2D_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "set", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Point2D::set(float,float)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))) {
        overloadId = 0; // set(float,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "set", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Point2D_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // set(float,float)
            cppSelf->set(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGGeometry_Point2D__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QSGGeometry::Point2D *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Point2D_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Point2D_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QSGGeometry_Point2D_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSGGeometry_Point2D_methods[] = {
    {"set", reinterpret_cast<PyCFunction>(Sbk_QSGGeometry_Point2DFunc_set), METH_VARARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QSGGeometry_Point2D__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QSGGeometry_Point2D_get_x(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGGeometry::Point2D *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Point2D_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppSelf->x);
    return pyOut;
}
static int Sbk_QSGGeometry_Point2D_set_x(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QSGGeometry::Point2D *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Point2D_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("x");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("x", "float");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->x;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

static PyObject *Sbk_QSGGeometry_Point2D_get_y(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGGeometry::Point2D *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Point2D_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppSelf->y);
    return pyOut;
}
static int Sbk_QSGGeometry_Point2D_set_y(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QSGGeometry::Point2D *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Point2D_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("y");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("y", "float");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->y;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

// Getters and Setters for Point2D
static PyGetSetDef Sbk_QSGGeometry_Point2D_getsetlist[] = {
    {const_cast<char *>("x"), Sbk_QSGGeometry_Point2D_get_x, Sbk_QSGGeometry_Point2D_set_x, nullptr, nullptr},
    {const_cast<char *>("y"), Sbk_QSGGeometry_Point2D_get_y, Sbk_QSGGeometry_Point2D_set_y, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QSGGeometry_Point2D_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSGGeometry_Point2D_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSGGeometry_Point2D_Type = nullptr;
static PyTypeObject *Sbk_QSGGeometry_Point2D_TypeF(void)
{
    return _Sbk_QSGGeometry_Point2D_Type;
}

static PyType_Slot Sbk_QSGGeometry_Point2D_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSGGeometry_Point2D_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSGGeometry_Point2D_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSGGeometry_Point2D_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QSGGeometry_Point2D_getsetlist)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSGGeometry_Point2D_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSGGeometry_Point2D_spec = {
    "2:PySide6.QtQuick.QSGGeometry.Point2D",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSGGeometry_Point2D_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void Point2D_PythonToCpp_Point2D_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSGGeometry_Point2D_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_Point2D_PythonToCpp_Point2D_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSGGeometry_Point2D_TypeF()))
        return Point2D_PythonToCpp_Point2D_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *Point2D_PTR_CppToPython_Point2D(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QSGGeometry_Point2D_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *Point2D_COPY_CppToPython_Point2D(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QSGGeometry::Point2D *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QSGGeometry_Point2D_TypeF(), new ::QSGGeometry::Point2D(*source), true, true);
}

// Python to C++ copy conversion.
static void Point2D_PythonToCpp_Point2D_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QSGGeometry::Point2D *>(cppOut) = *reinterpret_cast< ::QSGGeometry::Point2D *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Point2D_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_Point2D_PythonToCpp_Point2D_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QSGGeometry_Point2D_TypeF()))
        return Point2D_PythonToCpp_Point2D_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSGGeometry_Point2D_SignatureStrings[] = {
    "1:PySide6.QtQuick.QSGGeometry.Point2D(self)",
    "0:PySide6.QtQuick.QSGGeometry.Point2D(self,Point2D:PySide6.QtQuick.QSGGeometry.Point2D)",
    "PySide6.QtQuick.QSGGeometry.Point2D.set(self,nx:float,ny:float)",
    "PySide6.QtQuick.QSGGeometry.Point2D.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QSGGeometry_Point2D_SignatureByteSize = 109;
static constexpr uint8_t QSGGeometry_Point2D_SignatureBytes[109] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x09, 0x2c,
    0xcd, 0x4c, 0xce, 0xd6, 0x0b, 0x0c, 0x76, 0x77, 0x4f, 0xcd, 0xcf, 0x4d, 0x2d, 0x29, 0xaa, 0xd4,
    0x0b, 0xc8, 0xcf, 0xcc, 0x2b, 0x31, 0x72, 0xd1, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0xe4, 0x32, 0x20,
    0x5a, 0xad, 0x0e, 0x94, 0x43, 0x8c, 0x06, 0x4d, 0x2e, 0x22, 0x14, 0xe9, 0x15, 0xa7, 0x96, 0x40,
    0x4c, 0xce, 0xab, 0xb0, 0x4a, 0xcb, 0xc9, 0x4f, 0x2c, 0xd1, 0xc9, 0xab, 0x84, 0x30, 0x88, 0xd3,
    0x1f, 0x1f, 0x9f, 0x9c, 0x5f, 0x50, 0x19, 0x1f, 0x0f, 0xf1, 0x8a, 0xae, 0x5d, 0x49, 0x65, 0x41,
    0x66, 0x5e, 0xba, 0x5e, 0x30, 0x90, 0xc7, 0x05, 0x00, 0xfc, 0x40, 0x5a, 0xd5
};
#endif

PyTypeObject *init_QSGGeometry_Point2D(PyObject *enclosingClass)
{
    if (SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Point2D_IDX].type != nullptr)
        return SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Point2D_IDX].type;

    Shiboken::AutoDecRef Sbk_QSGGeometry_Point2D_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QSGGeometry_Point2D_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "Point2D",
        "QSGGeometry::Point2D",
        &Sbk_QSGGeometry_Point2D_spec,
        &Shiboken::callCppDestructor< ::QSGGeometry::Point2D >,
        Sbk_QSGGeometry_Point2D_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass | Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QSGGeometry_Point2D_TypeF(); // references _Sbk_QSGGeometry_Point2D_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSGGeometry_Point2D_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSGGeometry_Point2D_SignatureBytes, QSGGeometry_Point2D_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSGGeometry_Point2D_PropertyStrings);
    SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Point2D_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        Point2D_PythonToCpp_Point2D_PTR,
        is_Point2D_PythonToCpp_Point2D_PTR_Convertible,
        Point2D_PTR_CppToPython_Point2D,
        Point2D_COPY_CppToPython_Point2D);

    Shiboken::Conversions::registerConverterName(converter, "QSGGeometry::Point2D");
    Shiboken::Conversions::registerConverterName(converter, "QSGGeometry::Point2D*");
    Shiboken::Conversions::registerConverterName(converter, "QSGGeometry::Point2D&");
    Shiboken::Conversions::registerConverterAlias(converter, "Point2D");
    Shiboken::Conversions::registerConverterAlias(converter, "Point2D*");
    Shiboken::Conversions::registerConverterAlias(converter, "Point2D&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSGGeometry::Point2D).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        Point2D_PythonToCpp_Point2D_COPY,
        is_Point2D_PythonToCpp_Point2D_COPY_Convertible);

    qRegisterMetaType< ::QSGGeometry::Point2D >("Point2D");
    qRegisterMetaType< ::QSGGeometry::Point2D >("QSGGeometry::Point2D");

    return pyType;
}
