// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtquick_python.h"

// main header
#include "qsggeometry_wrapper.h"

// inner classes
#include "qsggeometry_coloredpoint2d_wrapper.h"
#include "qsggeometry_texturedpoint2d_wrapper.h"
#include "qsggeometry_point2d_wrapper.h"
#include "qsggeometry_attribute_wrapper.h"
#include "qsggeometry_attributeset_wrapper.h"

// Extra includes
#include <algorithm>

// Argument includes
#include <QList>
#include <QtQuick/qsggeometry.h>
#include <qrect.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

QSGGeometryWrapper::QSGGeometryWrapper(const ::QSGGeometry::AttributeSet & attribs, int vertexCount, int indexCount, int indexType) : QSGGeometry(attribs, vertexCount, indexCount, indexType)
{
}

QSGGeometryWrapper::~QSGGeometryWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSGGeometry_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSGGeometry >()))
        return -1;

    QSGGeometryWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:QSGGeometry", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QSGGeometry::QSGGeometry(QSGGeometry::AttributeSet,int,int=,int=)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_AttributeSet_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // QSGGeometry(QSGGeometry::AttributeSet,int,int,int)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 0; // QSGGeometry(QSGGeometry::AttributeSet,int,int,int)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
                overloadId = 0; // QSGGeometry(QSGGeometry::AttributeSet,int,int,int)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_indexCount = Shiboken::String::createStaticString("indexCount");
            if (PyDict_Contains(kwds, key_indexCount) != 0) {
                value = PyDict_GetItem(kwds, key_indexCount);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_indexCount);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_indexCount);
            }
            static PyObject *const key_indexType = Shiboken::String::createStaticString("indexType");
            if (PyDict_Contains(kwds, key_indexType) != 0) {
                value = PyDict_GetItem(kwds, key_indexType);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_indexType);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_indexType);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QSGGeometry::AttributeSet cppArg0_local;
        ::QSGGeometry::AttributeSet *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2 = 0;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3 = QSGGeometry::Type::UnsignedShortType;
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QSGGeometry(QSGGeometry::AttributeSet,int,int,int)
            cptr = new QSGGeometryWrapper(*cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QSGGeometry >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSGGeometryFunc_allocate(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGGeometry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "allocate", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]);

    if (PyArg_ParseTuple(args, "|OO:allocate", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSGGeometry::allocate(int,int=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // allocate(int,int)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 0; // allocate(int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "allocate", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_indexCount = Shiboken::String::createStaticString("indexCount");
            if (PyDict_Contains(kwds, key_indexCount) != 0) {
                value = PyDict_GetItem(kwds, key_indexCount);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_indexCount);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "allocate", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "allocate", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_indexCount);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "allocate", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]);
            }
        }
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1 = 0;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // allocate(int,int)
            cppSelf->allocate(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGGeometryFunc_attributeCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGGeometry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // attributeCount()const
        int cppResult = const_cast<const ::QSGGeometry *>(cppSelf)->attributeCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGGeometryFunc_attributes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGGeometry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // attributes()const
        const QSGGeometry::Attribute * cppResult = const_cast<const ::QSGGeometry *>(cppSelf)->attributes();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Attribute_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGGeometryFunc_defaultAttributes_ColoredPoint2D(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // defaultAttributes_ColoredPoint2D()
        const QSGGeometry::AttributeSet & cppResult = ::QSGGeometry::defaultAttributes_ColoredPoint2D();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_AttributeSet_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGGeometryFunc_defaultAttributes_Point2D(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // defaultAttributes_Point2D()
        const QSGGeometry::AttributeSet & cppResult = ::QSGGeometry::defaultAttributes_Point2D();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_AttributeSet_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGGeometryFunc_defaultAttributes_TexturedPoint2D(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // defaultAttributes_TexturedPoint2D()
        const QSGGeometry::AttributeSet & cppResult = ::QSGGeometry::defaultAttributes_TexturedPoint2D();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_AttributeSet_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGGeometryFunc_drawingMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGGeometry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // drawingMode()const
        unsigned int cppResult = const_cast<const ::QSGGeometry *>(cppSelf)->drawingMode();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGGeometryFunc_indexCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGGeometry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // indexCount()const
        int cppResult = const_cast<const ::QSGGeometry *>(cppSelf)->indexCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGGeometryFunc_indexData(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGGeometry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // indexData()
        void * cppResult = cppSelf->indexData();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGGeometryFunc_indexDataAsUInt(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGGeometry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // indexDataAsUInt()
        uint * cppResult = cppSelf->indexDataAsUInt();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGGeometryFunc_indexDataAsUShort(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGGeometry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // indexDataAsUShort()
        quint16 * cppResult = cppSelf->indexDataAsUShort();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGGeometryFunc_indexDataPattern(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGGeometry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // indexDataPattern()const
        QSGGeometry::DataPattern cppResult = const_cast<const ::QSGGeometry *>(cppSelf)->indexDataPattern();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_DataPattern_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGGeometryFunc_indexType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGGeometry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // indexType()const
        int cppResult = const_cast<const ::QSGGeometry *>(cppSelf)->indexType();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGGeometryFunc_lineWidth(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGGeometry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lineWidth()const
        float cppResult = const_cast<const ::QSGGeometry *>(cppSelf)->lineWidth();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGGeometryFunc_markIndexDataDirty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGGeometry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // markIndexDataDirty()
        cppSelf->markIndexDataDirty();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGGeometryFunc_markVertexDataDirty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGGeometry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // markVertexDataDirty()
        cppSelf->markVertexDataDirty();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGGeometryFunc_setDrawingMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGGeometry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGGeometry::setDrawingMode(uint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // setDrawingMode(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDrawingMode", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDrawingMode(uint)
            cppSelf->setDrawingMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGGeometryFunc_setIndexDataPattern(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGGeometry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGGeometry::setIndexDataPattern(QSGGeometry::DataPattern)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_DataPattern_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setIndexDataPattern(QSGGeometry::DataPattern)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setIndexDataPattern", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]);

    // Call function/method
    {
        ::QSGGeometry::DataPattern cppArg0{QSGGeometry::AlwaysUploadPattern};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setIndexDataPattern(QSGGeometry::DataPattern)
            cppSelf->setIndexDataPattern(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGGeometryFunc_setLineWidth(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGGeometry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGGeometry::setLineWidth(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setLineWidth(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLineWidth", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLineWidth(float)
            cppSelf->setLineWidth(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGGeometryFunc_setVertexDataAsPoint2D(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGGeometry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGGeometry::setVertexDataAsPoint2D(QList<QSGGeometry::Point2D>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtQuickTypeConverters[SBK_QtQuick_QList_QSGGeometry_Point2D_IDX], (pyArg)))) {
        overloadId = 0; // setVertexDataAsPoint2D(QList<QSGGeometry::Point2D>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setVertexDataAsPoint2D", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]);

    // Call function/method
    {
        ::QList<QSGGeometry::Point2D> cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        SBK_UNUSED(cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // setVertexDataAsPoint2D(QList<QSGGeometry::Point2D>)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtquick.cpp (qsgeometry-setvertexdataaspoint2d)]
            const qsizetype vertexCount = cppSelf->vertexCount();
            if (vertexCount != cppArg0.size()) {
                PyErr_SetString(PyExc_RuntimeError, "size mismatch");
                return {};
            }

            QSGGeometry::Point2D *points = cppSelf->vertexDataAsPoint2D();
            std::copy(cppArg0.cbegin(), cppArg0.cend(), points);
            // END of custom code block [file: ../glue/qtquick.cpp (qsgeometry-setvertexdataaspoint2d)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGGeometryFunc_setVertexDataPattern(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGGeometry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGGeometry::setVertexDataPattern(QSGGeometry::DataPattern)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_DataPattern_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setVertexDataPattern(QSGGeometry::DataPattern)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setVertexDataPattern", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]);

    // Call function/method
    {
        ::QSGGeometry::DataPattern cppArg0{QSGGeometry::AlwaysUploadPattern};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setVertexDataPattern(QSGGeometry::DataPattern)
            cppSelf->setVertexDataPattern(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGGeometryFunc_sizeOfIndex(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGGeometry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sizeOfIndex()const
        int cppResult = const_cast<const ::QSGGeometry *>(cppSelf)->sizeOfIndex();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGGeometryFunc_sizeOfVertex(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGGeometry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sizeOfVertex()const
        int cppResult = const_cast<const ::QSGGeometry *>(cppSelf)->sizeOfVertex();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGGeometryFunc_updateColoredRectGeometry(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "updateColoredRectGeometry", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QSGGeometry::updateColoredRectGeometry(QSGGeometry*,QRectF)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[1])))) {
        overloadId = 0; // updateColoredRectGeometry(QSGGeometry*,QRectF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "updateColoredRectGeometry", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QSGGeometry *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QRectF cppArg1_local;
        ::QRectF *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // updateColoredRectGeometry(QSGGeometry*,QRectF)
            ::QSGGeometry::updateColoredRectGeometry(cppArg0, *cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGGeometryFunc_updateRectGeometry(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "updateRectGeometry", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QSGGeometry::updateRectGeometry(QSGGeometry*,QRectF)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[1])))) {
        overloadId = 0; // updateRectGeometry(QSGGeometry*,QRectF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "updateRectGeometry", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QSGGeometry *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QRectF cppArg1_local;
        ::QRectF *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // updateRectGeometry(QSGGeometry*,QRectF)
            ::QSGGeometry::updateRectGeometry(cppArg0, *cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGGeometryFunc_updateTexturedRectGeometry(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "updateTexturedRectGeometry", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QSGGeometry::updateTexturedRectGeometry(QSGGeometry*,QRectF,QRectF)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[2])))) {
        overloadId = 0; // updateTexturedRectGeometry(QSGGeometry*,QRectF,QRectF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "updateTexturedRectGeometry", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QSGGeometry *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QRectF cppArg1_local;
        ::QRectF *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QRectF cppArg2_local;
        ::QRectF *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2].isValue())
            pythonToCpp[2](pyArgs[2], &cppArg2_local);
        else
            pythonToCpp[2](pyArgs[2], &cppArg2);


        if (Shiboken::Errors::occurred() == nullptr) {
            // updateTexturedRectGeometry(QSGGeometry*,QRectF,QRectF)
            ::QSGGeometry::updateTexturedRectGeometry(cppArg0, *cppArg1, *cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGGeometryFunc_vertexCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGGeometry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // vertexCount()const
        int cppResult = const_cast<const ::QSGGeometry *>(cppSelf)->vertexCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGGeometryFunc_vertexData(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGGeometry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // vertexData()
        void * cppResult = cppSelf->vertexData();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGGeometryFunc_vertexDataAsColoredPoint2D(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGGeometry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // vertexDataAsColoredPoint2D()
        QSGGeometry::ColoredPoint2D * cppResult = cppSelf->vertexDataAsColoredPoint2D();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_ColoredPoint2D_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGGeometryFunc_vertexDataAsPoint2D(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGGeometry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // vertexDataAsPoint2D()
        // Begin code injection
        // ========================================================================
        // START of custom code block [file: ../glue/qtquick.cpp (qsgeometry-vertexdataaspoint2d)]
        auto *points = cppSelf->vertexDataAsPoint2D();
        const Py_ssize_t vertexCount = cppSelf->vertexCount();
        pyResult = PyList_New(vertexCount);
        for (Py_ssize_t i = 0; i < vertexCount; ++i) {
            QSGGeometry::Point2D p = points[i];
            PyList_SET_ITEM(pyResult, i, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Point2D_IDX]), &p));
        }
        // END of custom code block [file: ../glue/qtquick.cpp (qsgeometry-vertexdataaspoint2d)]
        // ========================================================================
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGGeometryFunc_vertexDataAsTexturedPoint2D(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGGeometry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // vertexDataAsTexturedPoint2D()
        QSGGeometry::TexturedPoint2D * cppResult = cppSelf->vertexDataAsTexturedPoint2D();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_TexturedPoint2D_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGGeometryFunc_vertexDataPattern(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGGeometry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // vertexDataPattern()const
        QSGGeometry::DataPattern cppResult = const_cast<const ::QSGGeometry *>(cppSelf)->vertexDataPattern();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_DataPattern_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QSGGeometry_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QSGGeometry_EnumFlagInfo[] = {
    "AttributeType:Enum",
    "DataPattern:Enum",
    "DrawingMode:IntEnum",
    "Type:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSGGeometry_methods[] = {
    {"allocate", reinterpret_cast<PyCFunction>(Sbk_QSGGeometryFunc_allocate), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"attributeCount", reinterpret_cast<PyCFunction>(Sbk_QSGGeometryFunc_attributeCount), METH_NOARGS, nullptr},
    {"attributes", reinterpret_cast<PyCFunction>(Sbk_QSGGeometryFunc_attributes), METH_NOARGS, nullptr},
    {"defaultAttributes_ColoredPoint2D", reinterpret_cast<PyCFunction>(Sbk_QSGGeometryFunc_defaultAttributes_ColoredPoint2D), METH_NOARGS|METH_STATIC, nullptr},
    {"defaultAttributes_Point2D", reinterpret_cast<PyCFunction>(Sbk_QSGGeometryFunc_defaultAttributes_Point2D), METH_NOARGS|METH_STATIC, nullptr},
    {"defaultAttributes_TexturedPoint2D", reinterpret_cast<PyCFunction>(Sbk_QSGGeometryFunc_defaultAttributes_TexturedPoint2D), METH_NOARGS|METH_STATIC, nullptr},
    {"drawingMode", reinterpret_cast<PyCFunction>(Sbk_QSGGeometryFunc_drawingMode), METH_NOARGS, nullptr},
    {"indexCount", reinterpret_cast<PyCFunction>(Sbk_QSGGeometryFunc_indexCount), METH_NOARGS, nullptr},
    {"indexData", reinterpret_cast<PyCFunction>(Sbk_QSGGeometryFunc_indexData), METH_NOARGS, nullptr},
    {"indexDataAsUInt", reinterpret_cast<PyCFunction>(Sbk_QSGGeometryFunc_indexDataAsUInt), METH_NOARGS, nullptr},
    {"indexDataAsUShort", reinterpret_cast<PyCFunction>(Sbk_QSGGeometryFunc_indexDataAsUShort), METH_NOARGS, nullptr},
    {"indexDataPattern", reinterpret_cast<PyCFunction>(Sbk_QSGGeometryFunc_indexDataPattern), METH_NOARGS, nullptr},
    {"indexType", reinterpret_cast<PyCFunction>(Sbk_QSGGeometryFunc_indexType), METH_NOARGS, nullptr},
    {"lineWidth", reinterpret_cast<PyCFunction>(Sbk_QSGGeometryFunc_lineWidth), METH_NOARGS, nullptr},
    {"markIndexDataDirty", reinterpret_cast<PyCFunction>(Sbk_QSGGeometryFunc_markIndexDataDirty), METH_NOARGS, nullptr},
    {"markVertexDataDirty", reinterpret_cast<PyCFunction>(Sbk_QSGGeometryFunc_markVertexDataDirty), METH_NOARGS, nullptr},
    {"setDrawingMode", reinterpret_cast<PyCFunction>(Sbk_QSGGeometryFunc_setDrawingMode), METH_O, nullptr},
    {"setIndexDataPattern", reinterpret_cast<PyCFunction>(Sbk_QSGGeometryFunc_setIndexDataPattern), METH_O, nullptr},
    {"setLineWidth", reinterpret_cast<PyCFunction>(Sbk_QSGGeometryFunc_setLineWidth), METH_O, nullptr},
    {"setVertexDataAsPoint2D", reinterpret_cast<PyCFunction>(Sbk_QSGGeometryFunc_setVertexDataAsPoint2D), METH_O, nullptr},
    {"setVertexDataPattern", reinterpret_cast<PyCFunction>(Sbk_QSGGeometryFunc_setVertexDataPattern), METH_O, nullptr},
    {"sizeOfIndex", reinterpret_cast<PyCFunction>(Sbk_QSGGeometryFunc_sizeOfIndex), METH_NOARGS, nullptr},
    {"sizeOfVertex", reinterpret_cast<PyCFunction>(Sbk_QSGGeometryFunc_sizeOfVertex), METH_NOARGS, nullptr},
    {"updateColoredRectGeometry", reinterpret_cast<PyCFunction>(Sbk_QSGGeometryFunc_updateColoredRectGeometry), METH_VARARGS|METH_STATIC, nullptr},
    {"updateRectGeometry", reinterpret_cast<PyCFunction>(Sbk_QSGGeometryFunc_updateRectGeometry), METH_VARARGS|METH_STATIC, nullptr},
    {"updateTexturedRectGeometry", reinterpret_cast<PyCFunction>(Sbk_QSGGeometryFunc_updateTexturedRectGeometry), METH_VARARGS|METH_STATIC, nullptr},
    {"vertexCount", reinterpret_cast<PyCFunction>(Sbk_QSGGeometryFunc_vertexCount), METH_NOARGS, nullptr},
    {"vertexData", reinterpret_cast<PyCFunction>(Sbk_QSGGeometryFunc_vertexData), METH_NOARGS, nullptr},
    {"vertexDataAsColoredPoint2D", reinterpret_cast<PyCFunction>(Sbk_QSGGeometryFunc_vertexDataAsColoredPoint2D), METH_NOARGS, nullptr},
    {"vertexDataAsPoint2D", reinterpret_cast<PyCFunction>(Sbk_QSGGeometryFunc_vertexDataAsPoint2D), METH_NOARGS, nullptr},
    {"vertexDataAsTexturedPoint2D", reinterpret_cast<PyCFunction>(Sbk_QSGGeometryFunc_vertexDataAsTexturedPoint2D), METH_NOARGS, nullptr},
    {"vertexDataPattern", reinterpret_cast<PyCFunction>(Sbk_QSGGeometryFunc_vertexDataPattern), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QSGGeometry_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSGGeometry_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSGGeometry_Type = nullptr;
static PyTypeObject *Sbk_QSGGeometry_TypeF(void)
{
    return _Sbk_QSGGeometry_Type;
}

static PyType_Slot Sbk_QSGGeometry_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSGGeometry_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSGGeometry_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSGGeometry_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSGGeometry_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSGGeometry_spec = {
    "2:PySide6.QtQuick.QSGGeometry",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSGGeometry_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QSGGeometry_AttributeType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSGGeometry::AttributeType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSGGeometry::AttributeType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QSGGeometry_AttributeType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_AttributeType_IDX])))
        return Enum_PythonToCpp_QSGGeometry_AttributeType;
    return {};
}

static PyObject *QSGGeometry_AttributeType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QSGGeometry::AttributeType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QSGGeometry::AttributeType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_AttributeType_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QSGGeometry_DataPattern(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSGGeometry::DataPattern>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSGGeometry::DataPattern *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QSGGeometry_DataPattern_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_DataPattern_IDX])))
        return Enum_PythonToCpp_QSGGeometry_DataPattern;
    return {};
}

static PyObject *QSGGeometry_DataPattern_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QSGGeometry::DataPattern>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QSGGeometry::DataPattern *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_DataPattern_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QSGGeometry_DrawingMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSGGeometry::DrawingMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSGGeometry::DrawingMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QSGGeometry_DrawingMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_DrawingMode_IDX])))
        return Enum_PythonToCpp_QSGGeometry_DrawingMode;
    return {};
}

static PyObject *QSGGeometry_DrawingMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QSGGeometry::DrawingMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QSGGeometry::DrawingMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_DrawingMode_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QSGGeometry_Type(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSGGeometry::Type>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSGGeometry::Type *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QSGGeometry_Type_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Type_IDX])))
        return Enum_PythonToCpp_QSGGeometry_Type;
    return {};
}

static PyObject *QSGGeometry_Type_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QSGGeometry::Type>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QSGGeometry::Type *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Type_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSGGeometry_PythonToCpp_QSGGeometry_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSGGeometry_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSGGeometry_PythonToCpp_QSGGeometry_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSGGeometry_TypeF()))
        return QSGGeometry_PythonToCpp_QSGGeometry_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSGGeometry_PTR_CppToPython_QSGGeometry(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QSGGeometry *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QSGGeometry_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSGGeometry_SignatureStrings[] = {
    "PySide6.QtQuick.QSGGeometry(self,attribs:PySide6.QtQuick.QSGGeometry.AttributeSet,vertexCount:int,indexCount:int=0,indexType:int=QSGGeometry.Type.UnsignedShortType)",
    "PySide6.QtQuick.QSGGeometry.allocate(self,vertexCount:int,indexCount:int=0)",
    "PySide6.QtQuick.QSGGeometry.attributeCount(self)->int",
    "PySide6.QtQuick.QSGGeometry.attributes(self)->PySide6.QtQuick.QSGGeometry.Attribute",
    "PySide6.QtQuick.QSGGeometry.defaultAttributes_ColoredPoint2D()->PySide6.QtQuick.QSGGeometry.AttributeSet",
    "PySide6.QtQuick.QSGGeometry.defaultAttributes_Point2D()->PySide6.QtQuick.QSGGeometry.AttributeSet",
    "PySide6.QtQuick.QSGGeometry.defaultAttributes_TexturedPoint2D()->PySide6.QtQuick.QSGGeometry.AttributeSet",
    "PySide6.QtQuick.QSGGeometry.drawingMode(self)->unsigned int",
    "PySide6.QtQuick.QSGGeometry.indexCount(self)->int",
    "PySide6.QtQuick.QSGGeometry.indexData(self)->void",
    "PySide6.QtQuick.QSGGeometry.indexDataAsUInt(self)->uint*",
    "PySide6.QtQuick.QSGGeometry.indexDataAsUShort(self)->quint16*",
    "PySide6.QtQuick.QSGGeometry.indexDataPattern(self)->PySide6.QtQuick.QSGGeometry.DataPattern",
    "PySide6.QtQuick.QSGGeometry.indexType(self)->int",
    "PySide6.QtQuick.QSGGeometry.lineWidth(self)->float",
    "PySide6.QtQuick.QSGGeometry.markIndexDataDirty(self)",
    "PySide6.QtQuick.QSGGeometry.markVertexDataDirty(self)",
    "PySide6.QtQuick.QSGGeometry.setDrawingMode(self,mode:unsigned int)",
    "PySide6.QtQuick.QSGGeometry.setIndexDataPattern(self,p:PySide6.QtQuick.QSGGeometry.DataPattern)",
    "PySide6.QtQuick.QSGGeometry.setLineWidth(self,w:float)",
    "PySide6.QtQuick.QSGGeometry.setVertexDataAsPoint2D(self,points:QList[PySide6.QtQuick.QSGGeometry.Point2D])",
    "PySide6.QtQuick.QSGGeometry.setVertexDataPattern(self,p:PySide6.QtQuick.QSGGeometry.DataPattern)",
    "PySide6.QtQuick.QSGGeometry.sizeOfIndex(self)->int",
    "PySide6.QtQuick.QSGGeometry.sizeOfVertex(self)->int",
    "PySide6.QtQuick.QSGGeometry.updateColoredRectGeometry(g:PySide6.QtQuick.QSGGeometry,rect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect])",
    "PySide6.QtQuick.QSGGeometry.updateRectGeometry(g:PySide6.QtQuick.QSGGeometry,rect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect])",
    "PySide6.QtQuick.QSGGeometry.updateTexturedRectGeometry(g:PySide6.QtQuick.QSGGeometry,rect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect],sourceRect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect])",
    "PySide6.QtQuick.QSGGeometry.vertexCount(self)->int",
    "PySide6.QtQuick.QSGGeometry.vertexData(self)->void",
    "PySide6.QtQuick.QSGGeometry.vertexDataAsColoredPoint2D(self)->PySide6.QtQuick.QSGGeometry.ColoredPoint2D",
    "PySide6.QtQuick.QSGGeometry.vertexDataAsPoint2D(self)->PyObject*",
    "PySide6.QtQuick.QSGGeometry.vertexDataAsTexturedPoint2D(self)->PySide6.QtQuick.QSGGeometry.TexturedPoint2D",
    "PySide6.QtQuick.QSGGeometry.vertexDataPattern(self)->PySide6.QtQuick.QSGGeometry.DataPattern",
    nullptr}; // Sentinel
#else
static constexpr size_t QSGGeometry_SignatureByteSize = 489;
static constexpr uint8_t QSGGeometry_SignatureBytes[489] = {
    0x78, 0xda, 0xcd, 0x56, 0xc1, 0x4e, 0x1b, 0x31, 0x10, 0xbd, 0xf7, 0x2b, 0x38, 0x12, 0xe4, 0xae,
    0x68, 0x0f, 0x1c, 0x56, 0x6a, 0xa5, 0x28, 0x11, 0x28, 0x12, 0x15, 0xd9, 0x06, 0xca, 0x01, 0x21,
    0x64, 0xe2, 0x49, 0x70, 0xd9, 0xd8, 0xa9, 0x3d, 0x0e, 0x84, 0xaf, 0xc7, 0xeb, 0xc5, 0xc9, 0x12,
    0x60, 0x3d, 0xa9, 0x94, 0xaa, 0xb7, 0xb5, 0x35, 0xef, 0xbd, 0x99, 0xe7, 0xb1, 0x67, 0x87, 0xcb,
    0x91, 0x14, 0x70, 0x94, 0x15, 0x58, 0x38, 0x39, 0xbe, 0xcf, 0x8a, 0xd1, 0xc9, 0x09, 0xe8, 0x19,
    0xa0, 0x59, 0xee, 0x5b, 0x28, 0x27, 0x8c, 0x23, 0x1a, 0x79, 0x6b, 0xf3, 0xe1, 0xc7, 0x81, 0x59,
    0x37, 0xc4, 0x38, 0x84, 0x11, 0x20, 0x5b, 0x80, 0x41, 0x78, 0xec, 0x69, 0xa7, 0x30, 0x97, 0x0a,
    0x99, 0x54, 0xa2, 0xb1, 0xfc, 0x76, 0x58, 0x6f, 0x9c, 0x2f, 0xe7, 0x10, 0xd6, 0x4d, 0x9e, 0x6a,
    0x33, 0xbb, 0x50, 0x56, 0x4e, 0x15, 0x88, 0xd1, 0x9d, 0x36, 0x58, 0xed, 0x74, 0x3e, 0xb5, 0x69,
    0xf3, 0xb2, 0xd4, 0x63, 0x8e, 0x50, 0x67, 0x9b, 0x12, 0x4f, 0x70, 0xc5, 0x3a, 0x02, 0x22, 0x30,
    0x76, 0x3e, 0x7f, 0xf7, 0x40, 0x1a, 0xca, 0x46, 0x04, 0xc9, 0xab, 0x56, 0x4e, 0x01, 0x13, 0xee,
    0x4a, 0x5c, 0x05, 0xdb, 0x9b, 0x9e, 0x2e, 0xb5, 0x01, 0x31, 0xd4, 0x3e, 0x9d, 0xaf, 0xfd, 0x7d,
    0xaa, 0x8a, 0x3f, 0x91, 0x2d, 0x85, 0x76, 0xaf, 0x70, 0x0e, 0x8f, 0xe8, 0x76, 0x51, 0x8b, 0xe1,
    0x0f, 0x52, 0x4d, 0x7f, 0x68, 0x01, 0xf1, 0x24, 0xdc, 0x4b, 0x33, 0xed, 0xa5, 0x0e, 0x71, 0xdd,
    0x28, 0xd4, 0x63, 0x0f, 0x88, 0x3e, 0x47, 0x1e, 0x01, 0x0b, 0x2d, 0x05, 0x0d, 0xd1, 0xb5, 0x17,
    0x83, 0xb5, 0x90, 0xf3, 0x4a, 0x07, 0x64, 0x60, 0xb8, 0x16, 0x11, 0xfa, 0xa7, 0xc2, 0x7e, 0x39,
    0x22, 0xa2, 0x87, 0xbe, 0x53, 0xc1, 0x28, 0x4a, 0x97, 0x36, 0xc2, 0xd3, 0xdc, 0xd5, 0x25, 0xa5,
    0xba, 0x56, 0x4a, 0x05, 0x97, 0x52, 0xe0, 0x5d, 0x04, 0x4c, 0x4a, 0xcd, 0xdb, 0x21, 0x33, 0x6e,
    0xee, 0x07, 0xb1, 0x86, 0xbe, 0x34, 0x58, 0xbf, 0x4c, 0x9d, 0x24, 0xe8, 0x57, 0x78, 0x0c, 0xb6,
    0x41, 0x59, 0xc0, 0xfe, 0x46, 0x13, 0xb1, 0x99, 0xff, 0xca, 0x9b, 0x7d, 0x94, 0xa4, 0x18, 0xbc,
    0x67, 0x38, 0x9b, 0xe7, 0x44, 0xc3, 0x93, 0xfc, 0xa7, 0xaf, 0x3c, 0x64, 0x0f, 0x79, 0xf0, 0x30,
    0x09, 0x5b, 0xdb, 0xd1, 0xb5, 0xf1, 0xea, 0xd5, 0x99, 0x55, 0x0b, 0x9b, 0x17, 0xa7, 0xd2, 0xe2,
    0x55, 0x1b, 0xc9, 0x0b, 0xea, 0x7a, 0x0b, 0xa9, 0x9d, 0x58, 0x20, 0x9f, 0xe0, 0x6c, 0x12, 0x5c,
    0xa6, 0xb6, 0x5d, 0x0d, 0xa9, 0xd3, 0xa2, 0x62, 0xdc, 0x5c, 0xf0, 0x6a, 0x14, 0x84, 0x77, 0xf7,
    0x27, 0x8c, 0x71, 0x35, 0x18, 0xa7, 0x6d, 0x75, 0x30, 0xe3, 0x43, 0x73, 0x5c, 0xce, 0x7d, 0x17,
    0xf9, 0x61, 0x26, 0xb5, 0x6a, 0x78, 0xda, 0xf3, 0x5c, 0x59, 0x51, 0x91, 0x1d, 0xb3, 0xbd, 0xf7,
    0xb6, 0x13, 0xde, 0xd6, 0x39, 0xfd, 0x57, 0xc9, 0xc4, 0xd7, 0xfc, 0x9f, 0x25, 0xc5, 0xac, 0x76,
    0x66, 0x1c, 0x4c, 0xd8, 0x55, 0x65, 0x8d, 0xdf, 0x08, 0x6a, 0xb7, 0x2c, 0x56, 0x2d, 0x4f, 0x9e,
    0x07, 0x8b, 0xc6, 0x85, 0xdc, 0x18, 0xef, 0x84, 0x27, 0xfa, 0x35, 0x82, 0x2c, 0xf4, 0x46, 0xe1,
    0xec, 0xf6, 0xb7, 0x37, 0xe4, 0x80, 0x4c, 0xb0, 0x39, 0xbd, 0x09, 0xa9, 0x6e, 0x40, 0x88, 0x52,
    0x7f, 0x39, 0xae, 0x9e, 0x01, 0x30, 0x22, 0xea, 0xbd
};
#endif

PyTypeObject *init_QSGGeometry(PyObject *module)
{
    if (SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX].type != nullptr)
        return SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX].type;

    Shiboken::AutoDecRef Sbk_QSGGeometry_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QSGGeometry_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSGGeometry",
        "QSGGeometry*",
        &Sbk_QSGGeometry_spec,
        &Shiboken::callCppDestructor< QSGGeometry >,
        Sbk_QSGGeometry_Type_bases.object(),
        0);
    auto *pyType = Sbk_QSGGeometry_TypeF(); // references _Sbk_QSGGeometry_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSGGeometry_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSGGeometry_SignatureBytes, QSGGeometry_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSGGeometry_PropertyStrings);
    SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSGGeometry_PythonToCpp_QSGGeometry_PTR,
        is_QSGGeometry_PythonToCpp_QSGGeometry_PTR_Convertible,
        QSGGeometry_PTR_CppToPython_QSGGeometry);

    Shiboken::Conversions::registerConverterName(converter, "QSGGeometry");
    Shiboken::Conversions::registerConverterName(converter, "QSGGeometry*");
    Shiboken::Conversions::registerConverterName(converter, "QSGGeometry&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSGGeometry).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QSGGeometryWrapper).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QSGGeometry_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'AttributeType'.
    const char *AttributeType_Initializer[] = {
        "UnknownAttribute",
        "PositionAttribute",
        "ColorAttribute",
        "TexCoordAttribute",
        "TexCoord1Attribute",
        "TexCoord2Attribute",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t AttributeType_InitializerValues[] = {
        uint8_t(QSGGeometry::AttributeType::UnknownAttribute),   //  0x00  0
        uint8_t(QSGGeometry::AttributeType::PositionAttribute),  //  0x01  1
        uint8_t(QSGGeometry::AttributeType::ColorAttribute),     //  0x02  2
        uint8_t(QSGGeometry::AttributeType::TexCoordAttribute),  //  0x03  3
        uint8_t(QSGGeometry::AttributeType::TexCoord1Attribute), //  0x04  4
        uint8_t(QSGGeometry::AttributeType::TexCoord2Attribute)  //  0x05  5
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSGGeometry_TypeF(),
        "2:PySide6.QtQuick.QSGGeometry.AttributeType",
        AttributeType_Initializer, AttributeType_InitializerValues);
    SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_AttributeType_IDX].type = EType;
    // Register converter for enum 'QSGGeometry::AttributeType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSGGeometry_AttributeType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QSGGeometry_AttributeType,
            is_Enum_PythonToCpp_QSGGeometry_AttributeType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QSGGeometry::AttributeType");
        Shiboken::Conversions::registerConverterAlias(converter, "AttributeType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'AttributeType' enum.

    // Initialization of enum 'DataPattern'.
    const char *DataPattern_Initializer[] = {
        "AlwaysUploadPattern",
        "StreamPattern",
        "DynamicPattern",
        "StaticPattern",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t DataPattern_InitializerValues[] = {
        uint8_t(QSGGeometry::DataPattern::AlwaysUploadPattern), //  0x00  0
        uint8_t(QSGGeometry::DataPattern::StreamPattern),       //  0x01  1
        uint8_t(QSGGeometry::DataPattern::DynamicPattern),      //  0x02  2
        uint8_t(QSGGeometry::DataPattern::StaticPattern)        //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSGGeometry_TypeF(),
        "2:PySide6.QtQuick.QSGGeometry.DataPattern",
        DataPattern_Initializer, DataPattern_InitializerValues);
    SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_DataPattern_IDX].type = EType;
    // Register converter for enum 'QSGGeometry::DataPattern'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSGGeometry_DataPattern_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QSGGeometry_DataPattern,
            is_Enum_PythonToCpp_QSGGeometry_DataPattern_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QSGGeometry::DataPattern");
        Shiboken::Conversions::registerConverterAlias(converter, "DataPattern");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'DataPattern' enum.

    // Initialization of enum 'DrawingMode'.
    const char *DrawingMode_Initializer[] = {
        "DrawPoints",
        "DrawLines",
        "DrawLineLoop",
        "DrawLineStrip",
        "DrawTriangles",
        "DrawTriangleStrip",
        "DrawTriangleFan",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t DrawingMode_InitializerValues[] = {
        uint8_t(QSGGeometry::DrawingMode::DrawPoints),        //  0x00  0
        uint8_t(QSGGeometry::DrawingMode::DrawLines),         //  0x01  1
        uint8_t(QSGGeometry::DrawingMode::DrawLineLoop),      //  0x02  2
        uint8_t(QSGGeometry::DrawingMode::DrawLineStrip),     //  0x03  3
        uint8_t(QSGGeometry::DrawingMode::DrawTriangles),     //  0x04  4
        uint8_t(QSGGeometry::DrawingMode::DrawTriangleStrip), //  0x05  5
        uint8_t(QSGGeometry::DrawingMode::DrawTriangleFan)    //  0x06  6
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSGGeometry_TypeF(),
        "2:PySide6.QtQuick.QSGGeometry.DrawingMode",
        DrawingMode_Initializer, DrawingMode_InitializerValues);
    SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_DrawingMode_IDX].type = EType;
    // Register converter for enum 'QSGGeometry::DrawingMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSGGeometry_DrawingMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QSGGeometry_DrawingMode,
            is_Enum_PythonToCpp_QSGGeometry_DrawingMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QSGGeometry::DrawingMode");
        Shiboken::Conversions::registerConverterAlias(converter, "DrawingMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'DrawingMode' enum.

    // Initialization of enum 'Type'.
    const char *Type_Initializer[] = {
        "ByteType",
        "UnsignedByteType",
        "ShortType",
        "UnsignedShortType",
        "IntType",
        "UnsignedIntType",
        "FloatType",
        "Bytes2Type",
        "Bytes3Type",
        "Bytes4Type",
        "DoubleType",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t Type_InitializerValues[] = {
        uint16_t(QSGGeometry::Type::ByteType),          //  0x1400  5120
        uint16_t(QSGGeometry::Type::UnsignedByteType),  //  0x1401  5121
        uint16_t(QSGGeometry::Type::ShortType),         //  0x1402  5122
        uint16_t(QSGGeometry::Type::UnsignedShortType), //  0x1403  5123
        uint16_t(QSGGeometry::Type::IntType),           //  0x1404  5124
        uint16_t(QSGGeometry::Type::UnsignedIntType),   //  0x1405  5125
        uint16_t(QSGGeometry::Type::FloatType),         //  0x1406  5126
        uint16_t(QSGGeometry::Type::Bytes2Type),        //  0x1407  5127
        uint16_t(QSGGeometry::Type::Bytes3Type),        //  0x1408  5128
        uint16_t(QSGGeometry::Type::Bytes4Type),        //  0x1409  5129
        uint16_t(QSGGeometry::Type::DoubleType)         //  0x140a  5130
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSGGeometry_TypeF(),
        "2:PySide6.QtQuick.QSGGeometry.Type",
        Type_Initializer, Type_InitializerValues);
    SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_Type_IDX].type = EType;
    // Register converter for enum 'QSGGeometry::Type'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSGGeometry_Type_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QSGGeometry_Type,
            is_Enum_PythonToCpp_QSGGeometry_Type_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QSGGeometry::Type");
        Shiboken::Conversions::registerConverterAlias(converter, "Type");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Type' enum.

    qRegisterMetaType< ::QSGGeometry *>();
    qRegisterMetaType< ::QSGGeometry::AttributeType >("QSGGeometry::AttributeType");
    qRegisterMetaType< ::QSGGeometry::DataPattern >("QSGGeometry::DataPattern");
    qRegisterMetaType< ::QSGGeometry::DrawingMode >("QSGGeometry::DrawingMode");
    qRegisterMetaType< ::QSGGeometry::Type >("QSGGeometry::Type");

    return pyType;
}
