// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtquick_python.h"

// main header
#include "qsggeometrynode_wrapper.h"

// Argument includes
#include <QtGui/qmatrix4x4.h>
#include <QtQuick/qsggeometry.h>
#include <QtQuick/qsgmaterial.h>
#include <QtQuick/qsgnode.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QSGGeometryNodeWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QSGGeometryNodeWrapper::QSGGeometryNodeWrapper()
{
}

bool QSGGeometryNodeWrapper::isSubtreeBlocked() const
{
    if (m_PyMethodCache[0])
        return this->::QSGNode::isSubtreeBlocked();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "isSubtreeBlocked";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QSGNode::isSubtreeBlocked();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSGGeometryNode", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSGGeometryNode", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QSGGeometryNodeWrapper::preprocess()
{
    if (m_PyMethodCache[1]) {
        return this->::QSGNode::preprocess();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "preprocess";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QSGNode::preprocess();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSGGeometryNode", funcName);
        return;
    }
}

QSGGeometryNodeWrapper::~QSGGeometryNodeWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSGGeometryNode_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSGGeometryNode >()))
        return -1;

    QSGGeometryNodeWrapper *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometryNode_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QSGGeometryNode()
        cptr = new QSGGeometryNodeWrapper();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QSGGeometryNode >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSGGeometryNodeFunc_activeMaterial(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGGeometryNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometryNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // activeMaterial()const
        QSGMaterial * cppResult = const_cast<const ::QSGGeometryNode *>(cppSelf)->activeMaterial();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGGeometryNodeFunc_inheritedOpacity(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGGeometryNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometryNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // inheritedOpacity()const
        qreal cppResult = const_cast<const ::QSGGeometryNode *>(cppSelf)->inheritedOpacity();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGGeometryNodeFunc_material(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGGeometryNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometryNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // material()const
        QSGMaterial * cppResult = const_cast<const ::QSGGeometryNode *>(cppSelf)->material();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGGeometryNodeFunc_opaqueMaterial(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGGeometryNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometryNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // opaqueMaterial()const
        QSGMaterial * cppResult = const_cast<const ::QSGGeometryNode *>(cppSelf)->opaqueMaterial();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGGeometryNodeFunc_renderOrder(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGGeometryNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometryNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // renderOrder()const
        int cppResult = const_cast<const ::QSGGeometryNode *>(cppSelf)->renderOrder();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGGeometryNodeFunc_setInheritedOpacity(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGGeometryNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometryNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGGeometryNode::setInheritedOpacity(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setInheritedOpacity(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setInheritedOpacity", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometryNode_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setInheritedOpacity(qreal)
            cppSelf->setInheritedOpacity(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGGeometryNodeFunc_setMaterial(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGGeometryNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometryNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGGeometryNode::setMaterial(QSGMaterial*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]), (pyArg)))) {
        overloadId = 0; // setMaterial(QSGMaterial*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMaterial", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometryNode_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSGMaterial *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMaterial(QSGMaterial*)
            cppSelf->setMaterial(cppArg0);

            // Ownership transferences.
            Shiboken::Object::releaseOwnership(pyArg);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGGeometryNodeFunc_setOpaqueMaterial(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGGeometryNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometryNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGGeometryNode::setOpaqueMaterial(QSGMaterial*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]), (pyArg)))) {
        overloadId = 0; // setOpaqueMaterial(QSGMaterial*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOpaqueMaterial", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometryNode_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSGMaterial *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOpaqueMaterial(QSGMaterial*)
            cppSelf->setOpaqueMaterial(cppArg0);

            // Ownership transferences.
            Shiboken::Object::releaseOwnership(pyArg);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGGeometryNodeFunc_setRenderOrder(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGGeometryNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometryNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGGeometryNode::setRenderOrder(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setRenderOrder(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRenderOrder", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometryNode_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRenderOrder(int)
            cppSelf->setRenderOrder(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QSGGeometryNode_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSGGeometryNode_methods[] = {
    {"activeMaterial", reinterpret_cast<PyCFunction>(Sbk_QSGGeometryNodeFunc_activeMaterial), METH_NOARGS, nullptr},
    {"inheritedOpacity", reinterpret_cast<PyCFunction>(Sbk_QSGGeometryNodeFunc_inheritedOpacity), METH_NOARGS, nullptr},
    {"material", reinterpret_cast<PyCFunction>(Sbk_QSGGeometryNodeFunc_material), METH_NOARGS, nullptr},
    {"opaqueMaterial", reinterpret_cast<PyCFunction>(Sbk_QSGGeometryNodeFunc_opaqueMaterial), METH_NOARGS, nullptr},
    {"renderOrder", reinterpret_cast<PyCFunction>(Sbk_QSGGeometryNodeFunc_renderOrder), METH_NOARGS, nullptr},
    {"setInheritedOpacity", reinterpret_cast<PyCFunction>(Sbk_QSGGeometryNodeFunc_setInheritedOpacity), METH_O, nullptr},
    {"setMaterial", reinterpret_cast<PyCFunction>(Sbk_QSGGeometryNodeFunc_setMaterial), METH_O, nullptr},
    {"setOpaqueMaterial", reinterpret_cast<PyCFunction>(Sbk_QSGGeometryNodeFunc_setOpaqueMaterial), METH_O, nullptr},
    {"setRenderOrder", reinterpret_cast<PyCFunction>(Sbk_QSGGeometryNodeFunc_setRenderOrder), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QSGGeometryNode_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QSGGeometryNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometryNode_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QSGGeometryNodeWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QSGGeometryNode_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSGGeometryNode_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QSGGeometryNode__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGGeometryNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometryNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSGGeometryNode_Type = nullptr;
static PyTypeObject *Sbk_QSGGeometryNode_TypeF(void)
{
    return _Sbk_QSGGeometryNode_Type;
}

static PyType_Slot Sbk_QSGGeometryNode_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QSGGeometryNode__repr__)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QSGGeometryNode_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSGGeometryNode_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSGGeometryNode_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSGGeometryNode_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSGGeometryNode_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSGGeometryNode_spec = {
    "2:PySide6.QtQuick.QSGGeometryNode",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSGGeometryNode_slots
};

} //extern "C"

static void *Sbk_QSGGeometryNode_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QSGNode >())
        return dynamic_cast< ::QSGGeometryNode *>(reinterpret_cast< ::QSGNode *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSGGeometryNode_PythonToCpp_QSGGeometryNode_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSGGeometryNode_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSGGeometryNode_PythonToCpp_QSGGeometryNode_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSGGeometryNode_TypeF()))
        return QSGGeometryNode_PythonToCpp_QSGGeometryNode_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSGGeometryNode_PTR_CppToPython_QSGGeometryNode(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QSGGeometryNode *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QSGGeometryNode_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSGGeometryNode_SignatureStrings[] = {
    "PySide6.QtQuick.QSGGeometryNode(self)",
    "PySide6.QtQuick.QSGGeometryNode.activeMaterial(self)->PySide6.QtQuick.QSGMaterial",
    "PySide6.QtQuick.QSGGeometryNode.inheritedOpacity(self)->qreal",
    "PySide6.QtQuick.QSGGeometryNode.material(self)->PySide6.QtQuick.QSGMaterial",
    "PySide6.QtQuick.QSGGeometryNode.opaqueMaterial(self)->PySide6.QtQuick.QSGMaterial",
    "PySide6.QtQuick.QSGGeometryNode.renderOrder(self)->int",
    "PySide6.QtQuick.QSGGeometryNode.setInheritedOpacity(self,opacity:qreal)",
    "PySide6.QtQuick.QSGGeometryNode.setMaterial(self,material:PySide6.QtQuick.QSGMaterial)",
    "PySide6.QtQuick.QSGGeometryNode.setOpaqueMaterial(self,material:PySide6.QtQuick.QSGMaterial)",
    "PySide6.QtQuick.QSGGeometryNode.setRenderOrder(self,order:int)",
    nullptr}; // Sentinel
#else
static constexpr size_t QSGGeometryNode_SignatureByteSize = 171;
static constexpr uint8_t QSGGeometryNode_SignatureBytes[171] = {
    0x78, 0xda, 0xad, 0x90, 0xb1, 0x0e, 0x82, 0x30, 0x14, 0x45, 0x77, 0xbe, 0x44, 0x92, 0xca, 0xe8,
    0xd0, 0xc1, 0x95, 0x38, 0x28, 0x54, 0xbe, 0xa0, 0x69, 0x9f, 0xf1, 0x45, 0xa0, 0x50, 0x1e, 0x26,
    0xfd, 0x7b, 0xab, 0xa4, 0x83, 0x4a, 0x80, 0xa1, 0x4b, 0xd3, 0x26, 0xf7, 0x9e, 0xf4, 0x9e, 0xd2,
    0x55, 0xa8, 0xe1, 0x90, 0x09, 0x12, 0x23, 0xaa, 0x47, 0x26, 0xaa, 0x3c, 0x07, 0xd3, 0x00, 0x59,
    0x77, 0x31, 0x1a, 0x76, 0x03, 0xd4, 0xb7, 0x34, 0x29, 0x97, 0x53, 0x99, 0x54, 0x84, 0x4f, 0x38,
    0x4b, 0x02, 0x8b, 0xb2, 0x9e, 0x4a, 0xfb, 0xe3, 0x4c, 0x2b, 0x44, 0x56, 0x89, 0xd8, 0xde, 0x7d,
    0x90, 0x40, 0x17, 0x9d, 0x54, 0x48, 0x2e, 0x30, 0x7b, 0x0b, 0x1b, 0xda, 0x4d, 0xc4, 0x9f, 0x98,
    0x4e, 0xf6, 0x63, 0xd4, 0x6d, 0x16, 0x5a, 0x0d, 0xb6, 0xb0, 0xfe, 0x08, 0x38, 0x6c, 0x69, 0xb5,
    0x36, 0x00, 0x9d, 0xe6, 0xac, 0x30, 0x33, 0x3d, 0xf8, 0xc7, 0x4d, 0xba, 0x85, 0xf3, 0xb5, 0x86,
    0x05, 0x5b, 0x7c, 0x61, 0xd4, 0x26, 0x6c, 0xf1, 0xaf, 0x2a, 0x1e, 0xfc, 0xfa, 0x63, 0x8d, 0x99,
    0xf7, 0x95, 0x7b, 0x73, 0x69, 0xf2, 0x02, 0x8c, 0xc6, 0x00, 0xf3
};
#endif

PyTypeObject *init_QSGGeometryNode(PyObject *module)
{
    if (SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometryNode_IDX].type != nullptr)
        return SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometryNode_IDX].type;

    Shiboken::AutoDecRef Sbk_QSGGeometryNode_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGBasicGeometryNode_IDX]))));

    _Sbk_QSGGeometryNode_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSGGeometryNode",
        "QSGGeometryNode*",
        &Sbk_QSGGeometryNode_spec,
        &Shiboken::callCppDestructor< QSGGeometryNode >,
        Sbk_QSGGeometryNode_Type_bases.object(),
        0);
    auto *pyType = Sbk_QSGGeometryNode_TypeF(); // references _Sbk_QSGGeometryNode_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSGGeometryNode_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSGGeometryNode_SignatureBytes, QSGGeometryNode_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSGGeometryNode_PropertyStrings);
    SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometryNode_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSGGeometryNode_PythonToCpp_QSGGeometryNode_PTR,
        is_QSGGeometryNode_PythonToCpp_QSGGeometryNode_PTR_Convertible,
        QSGGeometryNode_PTR_CppToPython_QSGGeometryNode);

    Shiboken::Conversions::registerConverterName(converter, "QSGGeometryNode");
    Shiboken::Conversions::registerConverterName(converter, "QSGGeometryNode*");
    Shiboken::Conversions::registerConverterName(converter, "QSGGeometryNode&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSGGeometryNode).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QSGGeometryNodeWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QSGGeometryNode_TypeF(), &Sbk_QSGGeometryNode_typeDiscovery);

    qRegisterMetaType< ::QSGGeometryNode *>();

    return pyType;
}
