// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtquick_python.h"

// main header
#include "qsgmaterial_wrapper.h"

// Argument includes
#include <QtQuick/qsgmaterial.h>
#include <QtQuick/qsgmaterialshader.h>
#include <QtQuick/qsgmaterialtype.h>
#include <QtQuick/qsgrendererinterface.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QSGMaterialWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QSGMaterialWrapper::QSGMaterialWrapper()
{
}

int QSGMaterialWrapper::compare(const ::QSGMaterial * other) const
{
    if (m_PyMethodCache[0])
        return this->::QSGMaterial::compare(other);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return 0;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "compare";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QSGMaterial::compare(other);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]), other)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]), other)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSGMaterial", funcName);
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSGMaterial", funcName, "int", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    int cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QSGMaterialShader * QSGMaterialWrapper::createShader(::QSGRendererInterface::RenderMode renderMode) const
{
    if (m_PyMethodCache[1]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QSGMaterial.createShader");
        return nullptr;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "createShader";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        Shiboken::Errors::setPureVirtualMethodError("QSGMaterial.createShader");
        return nullptr;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_RenderMode_IDX])))->converter, &renderMode)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_RenderMode_IDX])))->converter, &renderMode)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSGMaterial", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSGMaterial", funcName, Shiboken::SbkType< QSGMaterialShader >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QSGMaterialShader *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QSGMaterialType * QSGMaterialWrapper::type() const
{
    if (m_PyMethodCache[2]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QSGMaterial.type");
        return nullptr;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "type";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        Shiboken::Errors::setPureVirtualMethodError("QSGMaterial.type");
        return nullptr;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSGMaterial", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialType_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSGMaterial", funcName, Shiboken::SbkType< QSGMaterialType >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QSGMaterialType *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QSGMaterialWrapper::~QSGMaterialWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSGMaterial_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QSGMaterial");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSGMaterial >()))
        return -1;

    QSGMaterialWrapper *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QSGMaterial()
        cptr = new QSGMaterialWrapper();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QSGMaterial >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSGMaterialFunc_compare(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGMaterial::compare(const QSGMaterial*)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]), (pyArg)))) {
        overloadId = 0; // compare(const QSGMaterial*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "compare", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSGMaterial *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // compare(const QSGMaterial*)const
            int cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QSGMaterial *>(cppSelf)->::QSGMaterial::compare(cppArg0)
                : const_cast<const ::QSGMaterial *>(cppSelf)->compare(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGMaterialFunc_createShader(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGMaterial::createShader(QSGRendererInterface::RenderMode)const->QSGMaterialShader*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_RenderMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // createShader(QSGRendererInterface::RenderMode)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "createShader", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]);

    // Call function/method
    {
        ::QSGRendererInterface::RenderMode cppArg0{QSGRendererInterface::RenderMode2D};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createShader(QSGRendererInterface::RenderMode)const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QSGMaterial.createShader");
                return {};
            }
            QSGMaterialShader * cppResult = const_cast<const ::QSGMaterial *>(cppSelf)->createShader(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGMaterialFunc_flags(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // flags()const
        QFlags<QSGMaterial::Flag> cppResult = const_cast<const ::QSGMaterial *>(cppSelf)->flags();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QSGMaterial_Flag_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGMaterialFunc_setFlag(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setFlag", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setFlag", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSGMaterial::setFlag(QFlags<QSGMaterial::Flag>,bool=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QSGMaterial_Flag_IDX])))->flagsConverter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setFlag(QFlags<QSGMaterial::Flag>,bool)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 0; // setFlag(QFlags<QSGMaterial::Flag>,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setFlag", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_on = Shiboken::String::createStaticString("on");
            if (PyDict_Contains(kwds, key_on) != 0) {
                value = PyDict_GetItem(kwds, key_on);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_on);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setFlag", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "setFlag", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_on);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setFlag", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]);
            }
        }
        ::QFlags<QSGMaterial::Flag> cppArg0 = QFlags<QSGMaterial::Flag>(0);
        pythonToCpp[0](pyArgs[0], &cppArg0);
        bool cppArg1 = true;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFlag(QFlags<QSGMaterial::Flag>,bool)
            cppSelf->setFlag(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGMaterialFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QSGMaterial.type");
            return {};
        }
        QSGMaterialType * cppResult = const_cast<const ::QSGMaterial *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialType_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGMaterialFunc_viewCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // viewCount()const
        int cppResult = const_cast<const ::QSGMaterial *>(cppSelf)->viewCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QSGMaterial_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QSGMaterial_EnumFlagInfo[] = {
    "Flag:Flag:Flags",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSGMaterial_methods[] = {
    {"compare", reinterpret_cast<PyCFunction>(Sbk_QSGMaterialFunc_compare), METH_O, nullptr},
    {"createShader", reinterpret_cast<PyCFunction>(Sbk_QSGMaterialFunc_createShader), METH_O, nullptr},
    {"flags", reinterpret_cast<PyCFunction>(Sbk_QSGMaterialFunc_flags), METH_NOARGS, nullptr},
    {"setFlag", reinterpret_cast<PyCFunction>(Sbk_QSGMaterialFunc_setFlag), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QSGMaterialFunc_type), METH_NOARGS, nullptr},
    {"viewCount", reinterpret_cast<PyCFunction>(Sbk_QSGMaterialFunc_viewCount), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QSGMaterial_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QSGMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QSGMaterialWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QSGMaterial_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSGMaterial_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSGMaterial_Type = nullptr;
static PyTypeObject *Sbk_QSGMaterial_TypeF(void)
{
    return _Sbk_QSGMaterial_Type;
}

static PyType_Slot Sbk_QSGMaterial_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QSGMaterial_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSGMaterial_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSGMaterial_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSGMaterial_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSGMaterial_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSGMaterial_spec = {
    "2:PySide6.QtQuick.QSGMaterial",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSGMaterial_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QSGMaterial_Flag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSGMaterial::Flag>(Shiboken::Enum::getValue(pyIn));
    switch (value) {
    case QSGMaterial::Flag::CustomCompileStep:
        Shiboken::Warnings::warnDeprecatedEnumValue("QSGMaterial::Flag", "CustomCompileStep");
        break;
    default:
        break;
    }
    *reinterpret_cast<::QSGMaterial::Flag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QSGMaterial_Flag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_Flag_IDX])))
        return Enum_PythonToCpp_QSGMaterial_Flag;
    return {};
}

static PyObject *QSGMaterial_Flag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QSGMaterial::Flag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QSGMaterial::Flag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_Flag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QSGMaterial_Flag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QSGMaterial::Flag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QSGMaterial::Flag> *>(cppOut) = value;

}

static PyObject *QSGMaterial_Flag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QSGMaterial::Flag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_Flag_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSGMaterial_PythonToCpp_QSGMaterial_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSGMaterial_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSGMaterial_PythonToCpp_QSGMaterial_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSGMaterial_TypeF()))
        return QSGMaterial_PythonToCpp_QSGMaterial_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSGMaterial_PTR_CppToPython_QSGMaterial(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QSGMaterial *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QSGMaterial_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSGMaterial_SignatureStrings[] = {
    "PySide6.QtQuick.QSGMaterial(self)",
    "PySide6.QtQuick.QSGMaterial.compare(self,other:PySide6.QtQuick.QSGMaterial)->int",
    "PySide6.QtQuick.QSGMaterial.createShader(self,renderMode:PySide6.QtQuick.QSGRendererInterface.RenderMode)->PySide6.QtQuick.QSGMaterialShader",
    "PySide6.QtQuick.QSGMaterial.flags(self)->PySide6.QtQuick.QSGMaterial.Flag",
    "PySide6.QtQuick.QSGMaterial.setFlag(self,flags:PySide6.QtQuick.QSGMaterial.Flag,on:bool=true)",
    "PySide6.QtQuick.QSGMaterial.type(self)->PySide6.QtQuick.QSGMaterialType",
    "PySide6.QtQuick.QSGMaterial.viewCount(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t QSGMaterial_SignatureByteSize = 181;
static constexpr uint8_t QSGMaterial_SignatureBytes[181] = {
    0x78, 0xda, 0x8d, 0x91, 0xcb, 0x0a, 0xc2, 0x40, 0x0c, 0x45, 0xf7, 0x7e, 0x89, 0x85, 0x3a, 0x4b,
    0x17, 0x05, 0xdd, 0x08, 0x8a, 0x8b, 0x42, 0x1f, 0xfe, 0xc0, 0xd8, 0xa6, 0x76, 0x70, 0x9c, 0x94,
    0x34, 0x55, 0xfa, 0xf7, 0x4e, 0x3b, 0xe8, 0x4a, 0xa3, 0xbb, 0x40, 0x0e, 0xe7, 0xe6, 0x91, 0x8d,
    0xa5, 0xa9, 0x61, 0xad, 0x72, 0xce, 0x07, 0x53, 0x5d, 0x55, 0x5e, 0x1e, 0x52, 0xcd, 0x40, 0x46,
    0xdb, 0x65, 0x0f, 0xb6, 0x89, 0x16, 0xd9, 0x77, 0x42, 0x55, 0x78, 0xeb, 0x34, 0xc1, 0x4c, 0xc6,
    0xc8, 0x2d, 0x50, 0x22, 0xe0, 0xd1, 0x6a, 0x6b, 0x1c, 0xcb, 0x42, 0x02, 0x5f, 0x96, 0xad, 0xae,
    0x81, 0x82, 0x95, 0xc0, 0xf9, 0x3a, 0xc5, 0x1a, 0x3e, 0xa9, 0x8b, 0xb9, 0x0b, 0x74, 0x74, 0x5e,
    0xd0, 0xe8, 0x0a, 0x54, 0xf1, 0xe6, 0x7d, 0x9c, 0x10, 0x15, 0x32, 0xc4, 0x61, 0x1a, 0xab, 0x2f,
    0x7d, 0xb8, 0x82, 0xa8, 0x52, 0x7b, 0x0f, 0x8a, 0xa6, 0x1e, 0x78, 0x62, 0xc2, 0x46, 0xb3, 0x36,
    0xf9, 0xe5, 0x8b, 0xd1, 0x25, 0x67, 0x44, 0xbb, 0x61, 0x1a, 0x40, 0xfe, 0x02, 0x8f, 0x1d, 0xfc,
    0x31, 0xe6, 0xc9, 0x63, 0xa2, 0xe7, 0x6e, 0xe0, 0xb1, 0xc3, 0xc1, 0xf1, 0x4b, 0x36, 0x7d, 0xeb,
    0x09, 0x11, 0x10, 0xc1, 0xc3
};
#endif

PyTypeObject *init_QSGMaterial(PyObject *module)
{
    if (SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX].type != nullptr)
        return SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX].type;

    Shiboken::AutoDecRef Sbk_QSGMaterial_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QSGMaterial_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSGMaterial",
        "QSGMaterial*",
        &Sbk_QSGMaterial_spec,
        &Shiboken::callCppDestructor< QSGMaterial >,
        Sbk_QSGMaterial_Type_bases.object(),
        0);
    auto *pyType = Sbk_QSGMaterial_TypeF(); // references _Sbk_QSGMaterial_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSGMaterial_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSGMaterial_SignatureBytes, QSGMaterial_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSGMaterial_PropertyStrings);
    SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSGMaterial_PythonToCpp_QSGMaterial_PTR,
        is_QSGMaterial_PythonToCpp_QSGMaterial_PTR_Convertible,
        QSGMaterial_PTR_CppToPython_QSGMaterial);

    Shiboken::Conversions::registerConverterName(converter, "QSGMaterial");
    Shiboken::Conversions::registerConverterName(converter, "QSGMaterial*");
    Shiboken::Conversions::registerConverterName(converter, "QSGMaterial&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSGMaterial).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QSGMaterialWrapper).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QSGMaterial_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Flag'.
    const char *Flag_Initializer[] = {
        "Blending",
        "RequiresDeterminant",
        "RequiresFullMatrixExceptTranslate",
        "RequiresFullMatrix",
        "NoBatching",
        "MultiView2",
        "MultiView3",
        "MultiView4",
        "CustomCompileStep",
        nullptr};
    // "uint32_t" used instead of "unsigned int"
    constexpr uint32_t Flag_InitializerValues[] = {
        uint32_t(QSGMaterial::Flag::Blending),                          //  0x00000001  1
        uint32_t(QSGMaterial::Flag::RequiresDeterminant),               //  0x00000002  2
        uint32_t(QSGMaterial::Flag::RequiresFullMatrixExceptTranslate), //  0x00000006  6
        uint32_t(QSGMaterial::Flag::RequiresFullMatrix),                //  0x0000000e  14
        uint32_t(QSGMaterial::Flag::NoBatching),                        //  0x00000010  16
        uint32_t(QSGMaterial::Flag::MultiView2),                        //  0x00010000  65536
        uint32_t(QSGMaterial::Flag::MultiView3),                        //  0x00020000  131072
        uint32_t(QSGMaterial::Flag::MultiView4),                        //  0x00040000  262144
        uint32_t(QSGMaterial::Flag::CustomCompileStep)                  //  0x00000010  16
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSGMaterial_TypeF(),
        "2:PySide6.QtQuick.QSGMaterial.Flag",
        Flag_Initializer, Flag_InitializerValues);
    SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_Flag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QSGMaterial_Flag_IDX].type =
        EType;
    // Register converter for enum 'QSGMaterial::Flag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSGMaterial_Flag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QSGMaterial_Flag,
            is_Enum_PythonToCpp_QSGMaterial_Flag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QSGMaterial::Flag");
        Shiboken::Conversions::registerConverterAlias(converter, "Flag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QSGMaterial_Flag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QSGMaterial_Flag,
            is_Enum_PythonToCpp_QSGMaterial_Flag_Convertible);
        // Register converter for flag 'QFlags<QSGMaterial::Flag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QSGMaterial::Flag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QSGMaterial::Flags");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'Flag' enum/flags.

    qRegisterMetaType< ::QSGMaterial *>();
    qRegisterMetaType< ::QSGMaterial::Flag >("QSGMaterial::Flag");

    return pyType;
}
