// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtquick_python.h"

// main header
#include "qsgmaterialshader_wrapper.h"

// inner classes
#include "qsgmaterialshader_graphicspipelinestate_wrapper.h"
#include "qsgmaterialshader_renderstate_wrapper.h"

// Argument includes
#include <QString>
#include <QtQuick/qsgmaterial.h>
#include <QtQuick/qsgmaterialshader.h>
#include <QtQuick/qsgtexture.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QSGMaterialShaderWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QSGMaterialShaderWrapper::QSGMaterialShaderWrapper()
{
}

bool QSGMaterialShaderWrapper::updateGraphicsPipelineState(::QSGMaterialShader::RenderState & state, ::QSGMaterialShader::GraphicsPipelineState * ps, ::QSGMaterial * newMaterial, ::QSGMaterial * oldMaterial)
{
    if (m_PyMethodCache[0])
        return this->::QSGMaterialShader::updateGraphicsPipelineState(state, ps, newMaterial, oldMaterial);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "updateGraphicsPipelineState";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QSGMaterialShader::updateGraphicsPipelineState(state, ps, newMaterial, oldMaterial);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[4] = {
        Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_RenderState_IDX]), &state),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_GraphicsPipelineState_IDX]), ps),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]), newMaterial),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]), oldMaterial)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNNN)",
        Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_RenderState_IDX]), &state),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_GraphicsPipelineState_IDX]), ps),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]), newMaterial),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]), oldMaterial)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 4, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
    Py_DECREF(pyArgArray[3]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSGMaterialShader", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSGMaterialShader", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QSGMaterialShaderWrapper::updateUniformData(::QSGMaterialShader::RenderState & state, ::QSGMaterial * newMaterial, ::QSGMaterial * oldMaterial)
{
    if (m_PyMethodCache[1])
        return this->::QSGMaterialShader::updateUniformData(state, newMaterial, oldMaterial);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "updateUniformData";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QSGMaterialShader::updateUniformData(state, newMaterial, oldMaterial);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[3] = {
        Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_RenderState_IDX]), &state),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]), newMaterial),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]), oldMaterial)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNN)",
        Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_RenderState_IDX]), &state),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]), newMaterial),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]), oldMaterial)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 3, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSGMaterialShader", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSGMaterialShader", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QSGMaterialShaderWrapper::~QSGMaterialShaderWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSGMaterialShader_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSGMaterialShader >()))
        return -1;

    QSGMaterialShaderWrapper *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QSGMaterialShader()
        cptr = new QSGMaterialShaderWrapper();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QSGMaterialShader >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSGMaterialShaderFunc_combinedImageSamplerCount(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGMaterialShader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGMaterialShader::combinedImageSamplerCount(int)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // combinedImageSamplerCount(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "combinedImageSamplerCount", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // combinedImageSamplerCount(int)const
            int cppResult = const_cast<const ::QSGMaterialShader *>(cppSelf)->combinedImageSamplerCount(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGMaterialShaderFunc_flags(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGMaterialShader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // flags()const
        QFlags<QSGMaterialShader::Flag> cppResult = const_cast<const ::QSGMaterialShader *>(cppSelf)->flags();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QSGMaterialShader_Flag_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGMaterialShaderFunc_setFlag(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGMaterialShader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setFlag", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setFlag", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSGMaterialShader::setFlag(QFlags<QSGMaterialShader::Flag>,bool=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QSGMaterialShader_Flag_IDX])))->flagsConverter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setFlag(QFlags<QSGMaterialShader::Flag>,bool)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 0; // setFlag(QFlags<QSGMaterialShader::Flag>,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setFlag", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_on = Shiboken::String::createStaticString("on");
            if (PyDict_Contains(kwds, key_on) != 0) {
                value = PyDict_GetItem(kwds, key_on);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_on);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setFlag", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "setFlag", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_on);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setFlag", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_IDX]);
            }
        }
        ::QFlags<QSGMaterialShader::Flag> cppArg0 = QFlags<QSGMaterialShader::Flag>(0);
        pythonToCpp[0](pyArgs[0], &cppArg0);
        bool cppArg1 = true;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFlag(QFlags<QSGMaterialShader::Flag>,bool)
            cppSelf->setFlag(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGMaterialShaderFunc_setFlags(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGMaterialShader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGMaterialShader::setFlags(QFlags<QSGMaterialShader::Flag>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QSGMaterialShader_Flag_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setFlags(QFlags<QSGMaterialShader::Flag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFlags", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_IDX]);

    // Call function/method
    {
        ::QFlags<QSGMaterialShader::Flag> cppArg0 = QFlags<QSGMaterialShader::Flag>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFlags(QFlags<QSGMaterialShader::Flag>)
            cppSelf->setFlags(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGMaterialShaderFunc_setShaderFileName(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGMaterialShader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setShaderFileName", 2, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSGMaterialShader::setShaderFileName(QSGMaterialShader::Stage,QString)
    // 1: QSGMaterialShader::setShaderFileName(QSGMaterialShader::Stage,QString,int)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_Stage_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // setShaderFileName(QSGMaterialShader::Stage,QString)
        } else if (numArgs == 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
            overloadId = 1; // setShaderFileName(QSGMaterialShader::Stage,QString,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setShaderFileName", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setShaderFileName(QSGMaterialShader::Stage stage, const QString &filename)
        {
            ::QSGMaterialShader::Stage cppArg0{QSGMaterialShader::VertexStage};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setShaderFileName(QSGMaterialShader::Stage,QString)
                cppSelf->setShaderFileName(cppArg0, cppArg1);
            }
            break;
        }
        case 1: // setShaderFileName(QSGMaterialShader::Stage stage, const QString &filename, int viewCount)
        {
            ::QSGMaterialShader::Stage cppArg0{QSGMaterialShader::VertexStage};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setShaderFileName(QSGMaterialShader::Stage,QString,int)
                cppSelf->setShaderFileName(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGMaterialShaderFunc_updateGraphicsPipelineState(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGMaterialShader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "updateGraphicsPipelineState", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSGMaterialShader::updateGraphicsPipelineState(QSGMaterialShader::RenderState&,QSGMaterialShader::GraphicsPipelineState*,QSGMaterial*,QSGMaterial*)->bool
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_RenderState_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_GraphicsPipelineState_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]), (pyArgs[3])))) {
        overloadId = 0; // updateGraphicsPipelineState(QSGMaterialShader::RenderState&,QSGMaterialShader::GraphicsPipelineState*,QSGMaterial*,QSGMaterial*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "updateGraphicsPipelineState", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QSGMaterialShader::RenderState cppArg0_local;
        ::QSGMaterialShader::RenderState *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QSGMaterialShader::GraphicsPipelineState *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QSGMaterial *cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        if (!Shiboken::Object::isValid(pyArgs[3]))
            return {};
        ::QSGMaterial *cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // updateGraphicsPipelineState(QSGMaterialShader::RenderState&,QSGMaterialShader::GraphicsPipelineState*,QSGMaterial*,QSGMaterial*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSGMaterialShader::updateGraphicsPipelineState(*cppArg0, cppArg1, cppArg2, cppArg3)
                : cppSelf->updateGraphicsPipelineState(*cppArg0, cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGMaterialShaderFunc_updateUniformData(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGMaterialShader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "updateUniformData", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSGMaterialShader::updateUniformData(QSGMaterialShader::RenderState&,QSGMaterial*,QSGMaterial*)->bool
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_RenderState_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]), (pyArgs[2])))) {
        overloadId = 0; // updateUniformData(QSGMaterialShader::RenderState&,QSGMaterial*,QSGMaterial*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "updateUniformData", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QSGMaterialShader::RenderState cppArg0_local;
        ::QSGMaterialShader::RenderState *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QSGMaterial *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QSGMaterial *cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // updateUniformData(QSGMaterialShader::RenderState&,QSGMaterial*,QSGMaterial*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSGMaterialShader::updateUniformData(*cppArg0, cppArg1, cppArg2)
                : cppSelf->updateUniformData(*cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QSGMaterialShader_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QSGMaterialShader_EnumFlagInfo[] = {
    "Flag:Flag:Flags",
    "Stage:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSGMaterialShader_methods[] = {
    {"combinedImageSamplerCount", reinterpret_cast<PyCFunction>(Sbk_QSGMaterialShaderFunc_combinedImageSamplerCount), METH_O, nullptr},
    {"flags", reinterpret_cast<PyCFunction>(Sbk_QSGMaterialShaderFunc_flags), METH_NOARGS, nullptr},
    {"setFlag", reinterpret_cast<PyCFunction>(Sbk_QSGMaterialShaderFunc_setFlag), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setFlags", reinterpret_cast<PyCFunction>(Sbk_QSGMaterialShaderFunc_setFlags), METH_O, nullptr},
    {"setShaderFileName", reinterpret_cast<PyCFunction>(Sbk_QSGMaterialShaderFunc_setShaderFileName), METH_VARARGS, nullptr},
    {"updateGraphicsPipelineState", reinterpret_cast<PyCFunction>(Sbk_QSGMaterialShaderFunc_updateGraphicsPipelineState), METH_VARARGS, nullptr},
    {"updateUniformData", reinterpret_cast<PyCFunction>(Sbk_QSGMaterialShaderFunc_updateUniformData), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QSGMaterialShader_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QSGMaterialShader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QSGMaterialShaderWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QSGMaterialShader_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSGMaterialShader_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSGMaterialShader_Type = nullptr;
static PyTypeObject *Sbk_QSGMaterialShader_TypeF(void)
{
    return _Sbk_QSGMaterialShader_Type;
}

static PyType_Slot Sbk_QSGMaterialShader_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QSGMaterialShader_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSGMaterialShader_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSGMaterialShader_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSGMaterialShader_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSGMaterialShader_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSGMaterialShader_spec = {
    "2:PySide6.QtQuick.QSGMaterialShader",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSGMaterialShader_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QSGMaterialShader_Flag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSGMaterialShader::Flag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSGMaterialShader::Flag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QSGMaterialShader_Flag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_Flag_IDX])))
        return Enum_PythonToCpp_QSGMaterialShader_Flag;
    return {};
}

static PyObject *QSGMaterialShader_Flag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QSGMaterialShader::Flag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QSGMaterialShader::Flag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_Flag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QSGMaterialShader_Flag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QSGMaterialShader::Flag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QSGMaterialShader::Flag> *>(cppOut) = value;

}

static PyObject *QSGMaterialShader_Flag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QSGMaterialShader::Flag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_Flag_IDX]), flags.toInt());

}

static void Enum_PythonToCpp_QSGMaterialShader_Stage(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSGMaterialShader::Stage>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSGMaterialShader::Stage *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QSGMaterialShader_Stage_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_Stage_IDX])))
        return Enum_PythonToCpp_QSGMaterialShader_Stage;
    return {};
}

static PyObject *QSGMaterialShader_Stage_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QSGMaterialShader::Stage>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QSGMaterialShader::Stage *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_Stage_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSGMaterialShader_PythonToCpp_QSGMaterialShader_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSGMaterialShader_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSGMaterialShader_PythonToCpp_QSGMaterialShader_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSGMaterialShader_TypeF()))
        return QSGMaterialShader_PythonToCpp_QSGMaterialShader_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSGMaterialShader_PTR_CppToPython_QSGMaterialShader(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QSGMaterialShader *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QSGMaterialShader_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSGMaterialShader_SignatureStrings[] = {
    "PySide6.QtQuick.QSGMaterialShader(self)",
    "PySide6.QtQuick.QSGMaterialShader.combinedImageSamplerCount(self,binding:int)->int",
    "PySide6.QtQuick.QSGMaterialShader.flags(self)->PySide6.QtQuick.QSGMaterialShader.Flag",
    "PySide6.QtQuick.QSGMaterialShader.setFlag(self,flags:PySide6.QtQuick.QSGMaterialShader.Flag,on:bool=true)",
    "PySide6.QtQuick.QSGMaterialShader.setFlags(self,flags:PySide6.QtQuick.QSGMaterialShader.Flag)",
    "1:PySide6.QtQuick.QSGMaterialShader.setShaderFileName(self,stage:PySide6.QtQuick.QSGMaterialShader.Stage,filename:QString)",
    "0:PySide6.QtQuick.QSGMaterialShader.setShaderFileName(self,stage:PySide6.QtQuick.QSGMaterialShader.Stage,filename:QString,viewCount:int)",
    "PySide6.QtQuick.QSGMaterialShader.updateGraphicsPipelineState(self,state:PySide6.QtQuick.QSGMaterialShader.RenderState,ps:PySide6.QtQuick.QSGMaterialShader.GraphicsPipelineState,newMaterial:PySide6.QtQuick.QSGMaterial,oldMaterial:PySide6.QtQuick.QSGMaterial)->bool",
    "PySide6.QtQuick.QSGMaterialShader.updateUniformData(self,state:PySide6.QtQuick.QSGMaterialShader.RenderState,newMaterial:PySide6.QtQuick.QSGMaterial,oldMaterial:PySide6.QtQuick.QSGMaterial)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QSGMaterialShader_SignatureByteSize = 266;
static constexpr uint8_t QSGMaterialShader_SignatureBytes[266] = {
    0x78, 0xda, 0xc5, 0x52, 0xc1, 0x4a, 0xc4, 0x30, 0x10, 0xbd, 0xf7, 0x4b, 0x2c, 0x64, 0x8b, 0x5e,
    0x3c, 0x14, 0xdc, 0x8b, 0xb2, 0x8b, 0x07, 0xa5, 0x35, 0xf8, 0x01, 0xd9, 0x66, 0xda, 0x1d, 0x4c,
    0x93, 0x90, 0x4c, 0x5d, 0xfc, 0x7b, 0xa7, 0x2d, 0xe2, 0x45, 0xdc, 0x51, 0x10, 0x2f, 0x49, 0x48,
    0xde, 0xbc, 0xf7, 0x26, 0xf3, 0x9a, 0x37, 0x8d, 0x16, 0xae, 0xab, 0x96, 0xda, 0x09, 0xbb, 0x97,
    0xaa, 0xd5, 0xfb, 0x07, 0x43, 0x90, 0xd0, 0x38, 0x7d, 0x34, 0x16, 0xd2, 0x45, 0x06, 0xd7, 0x97,
    0x45, 0x73, 0x0e, 0x57, 0x75, 0x61, 0x3c, 0xa0, 0x07, 0x7b, 0x3f, 0x9a, 0x01, 0xb4, 0x19, 0xa3,
    0x83, 0x74, 0x1b, 0x26, 0x4f, 0x0b, 0x83, 0xe2, 0x37, 0x8b, 0x7e, 0xa8, 0xd1, 0x53, 0xb9, 0xd9,
    0xf2, 0x2a, 0xa0, 0xec, 0x9d, 0x19, 0xf2, 0x6a, 0x60, 0xb3, 0x3d, 0x0f, 0xdf, 0x31, 0x5c, 0xc0,
    0x9a, 0x81, 0x66, 0xe4, 0x6a, 0x6b, 0x91, 0xa8, 0x65, 0xdc, 0x2a, 0xf8, 0xfa, 0x10, 0x82, 0xbb,
    0xa1, 0x34, 0x41, 0x29, 0x57, 0xca, 0x3f, 0x97, 0x2a, 0x8b, 0xab, 0x5a, 0xc4, 0xbf, 0x9e, 0x76,
    0xe8, 0xe0, 0xd1, 0x8c, 0xb0, 0x0a, 0x65, 0xe2, 0x09, 0x08, 0xca, 0xf5, 0x8c, 0x53, 0x3d, 0xd7,
    0x7a, 0xae, 0xad, 0x5b, 0x4d, 0x89, 0x27, 0x54, 0x16, 0x97, 0xff, 0x25, 0xad, 0x5e, 0x11, 0x4e,
    0x4b, 0x66, 0x96, 0x98, 0x08, 0x7e, 0x78, 0x8a, 0x96, 0x2f, 0xf6, 0xc9, 0xc4, 0x23, 0x76, 0xb9,
    0xc1, 0x08, 0x8e, 0x33, 0xc8, 0xec, 0xf4, 0x69, 0x88, 0x24, 0x86, 0x9e, 0xc0, 0xf3, 0xb6, 0x14,
    0xaa, 0x28, 0x99, 0xd2, 0x97, 0x9a, 0xca, 0xc3, 0xe9, 0x03, 0xf7, 0x1d, 0x87, 0x0a, 0xce, 0x4a,
    0x70, 0x1c, 0xfb, 0x39, 0x70, 0xe2, 0x8f, 0x78, 0xf6, 0xd8, 0x87, 0x34, 0xde, 0x19, 0x32, 0xbf,
    0x6f, 0xff, 0x8f, 0x7a, 0x78, 0x07, 0x74, 0x47, 0x9a, 0x73
};
#endif

PyTypeObject *init_QSGMaterialShader(PyObject *module)
{
    if (SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_IDX].type != nullptr)
        return SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_IDX].type;

    Shiboken::AutoDecRef Sbk_QSGMaterialShader_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QSGMaterialShader_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSGMaterialShader",
        "QSGMaterialShader*",
        &Sbk_QSGMaterialShader_spec,
        &Shiboken::callCppDestructor< QSGMaterialShader >,
        Sbk_QSGMaterialShader_Type_bases.object(),
        0);
    auto *pyType = Sbk_QSGMaterialShader_TypeF(); // references _Sbk_QSGMaterialShader_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSGMaterialShader_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSGMaterialShader_SignatureBytes, QSGMaterialShader_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSGMaterialShader_PropertyStrings);
    SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSGMaterialShader_PythonToCpp_QSGMaterialShader_PTR,
        is_QSGMaterialShader_PythonToCpp_QSGMaterialShader_PTR_Convertible,
        QSGMaterialShader_PTR_CppToPython_QSGMaterialShader);

    Shiboken::Conversions::registerConverterName(converter, "QSGMaterialShader");
    Shiboken::Conversions::registerConverterName(converter, "QSGMaterialShader*");
    Shiboken::Conversions::registerConverterName(converter, "QSGMaterialShader&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSGMaterialShader).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QSGMaterialShaderWrapper).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QSGMaterialShader_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Flag'.
    const char *Flag_Initializer[] = {
        "UpdatesGraphicsPipelineState",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Flag_InitializerValues[] = {
        uint8_t(QSGMaterialShader::Flag::UpdatesGraphicsPipelineState) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSGMaterialShader_TypeF(),
        "2:PySide6.QtQuick.QSGMaterialShader.Flag",
        Flag_Initializer, Flag_InitializerValues);
    SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_Flag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QSGMaterialShader_Flag_IDX].type =
        EType;
    // Register converter for enum 'QSGMaterialShader::Flag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSGMaterialShader_Flag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QSGMaterialShader_Flag,
            is_Enum_PythonToCpp_QSGMaterialShader_Flag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QSGMaterialShader::Flag");
        Shiboken::Conversions::registerConverterAlias(converter, "Flag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QSGMaterialShader_Flag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QSGMaterialShader_Flag,
            is_Enum_PythonToCpp_QSGMaterialShader_Flag_Convertible);
        // Register converter for flag 'QFlags<QSGMaterialShader::Flag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QSGMaterialShader::Flag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QSGMaterialShader::Flags");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'Flag' enum/flags.

    // Initialization of enum 'Stage'.
    const char *Stage_Initializer[] = {
        "VertexStage",
        "FragmentStage",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Stage_InitializerValues[] = {
        uint8_t(QSGMaterialShader::Stage::VertexStage),  //  0x00  0
        uint8_t(QSGMaterialShader::Stage::FragmentStage) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSGMaterialShader_TypeF(),
        "2:PySide6.QtQuick.QSGMaterialShader.Stage",
        Stage_Initializer, Stage_InitializerValues);
    SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_Stage_IDX].type = EType;
    // Register converter for enum 'QSGMaterialShader::Stage'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSGMaterialShader_Stage_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QSGMaterialShader_Stage,
            is_Enum_PythonToCpp_QSGMaterialShader_Stage_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QSGMaterialShader::Stage");
        Shiboken::Conversions::registerConverterAlias(converter, "Stage");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Stage' enum.

    qRegisterMetaType< ::QSGMaterialShader *>();
    qRegisterMetaType< ::QSGMaterialShader::Flag >("QSGMaterialShader::Flag");
    qRegisterMetaType< ::QSGMaterialShader::Stage >("QSGMaterialShader::Stage");

    return pyType;
}
