// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtquick_python.h"

// main header
#include "qsgninepatchnode_wrapper.h"

// Argument includes
#include <QtGui/qvectornd.h>
#include <QtQuick/qsggeometry.h>
#include <QtQuick/qsgmaterial.h>
#include <QtQuick/qsgtexture.h>
#include <qrect.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QSGNinePatchNodeWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QSGNinePatchNodeWrapper::QSGNinePatchNodeWrapper()
{
}

bool QSGNinePatchNodeWrapper::isSubtreeBlocked() const
{
    if (m_PyMethodCache[0])
        return this->::QSGNode::isSubtreeBlocked();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "isSubtreeBlocked";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QSGNode::isSubtreeBlocked();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSGNinePatchNode", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSGNinePatchNode", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QSGNinePatchNodeWrapper::preprocess()
{
    if (m_PyMethodCache[1]) {
        return this->::QSGNode::preprocess();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "preprocess";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QSGNode::preprocess();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSGNinePatchNode", funcName);
        return;
    }
}

void QSGNinePatchNodeWrapper::setBounds(const ::QRectF & bounds)
{
    if (m_PyMethodCache[2]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QSGNinePatchNode.setBounds");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setBounds";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        Shiboken::Errors::setPureVirtualMethodError("QSGNinePatchNode.setBounds");
        return;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &bounds)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &bounds)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSGNinePatchNode", funcName);
        return;
    }
}

void QSGNinePatchNodeWrapper::setDevicePixelRatio(qreal ratio)
{
    if (m_PyMethodCache[3]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QSGNinePatchNode.setDevicePixelRatio");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setDevicePixelRatio";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        Shiboken::Errors::setPureVirtualMethodError("QSGNinePatchNode.setDevicePixelRatio");
        return;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &ratio)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(d)",
        ratio
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSGNinePatchNode", funcName);
        return;
    }
}

void QSGNinePatchNodeWrapper::setPadding(qreal left, qreal top, qreal right, qreal bottom)
{
    if (m_PyMethodCache[4]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QSGNinePatchNode.setPadding");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setPadding";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        Shiboken::Errors::setPureVirtualMethodError("QSGNinePatchNode.setPadding");
        return;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[4] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &left),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &top),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &right),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &bottom)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(dddd)",
        left,
        top,
        right,
        bottom
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 4, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
    Py_DECREF(pyArgArray[3]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSGNinePatchNode", funcName);
        return;
    }
}

void QSGNinePatchNodeWrapper::setTexture(::QSGTexture * texture)
{
    if (m_PyMethodCache[5]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QSGNinePatchNode.setTexture");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setTexture";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        Shiboken::Errors::setPureVirtualMethodError("QSGNinePatchNode.setTexture");
        return;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTexture_IDX]), texture)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTexture_IDX]), texture)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSGNinePatchNode", funcName);
        return;
    }
}

void QSGNinePatchNodeWrapper::update()
{
    if (m_PyMethodCache[6]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QSGNinePatchNode.update");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "update";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        Shiboken::Errors::setPureVirtualMethodError("QSGNinePatchNode.update");
        return;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSGNinePatchNode", funcName);
        return;
    }
}

QSGNinePatchNodeWrapper::~QSGNinePatchNodeWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSGNinePatchNode_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNinePatchNode_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QSGNinePatchNode");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSGNinePatchNode >()))
        return -1;

    QSGNinePatchNodeWrapper *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtQuickTypeStructs[SBK_QSGNinePatchNode_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QSGNinePatchNode()
        cptr = new QSGNinePatchNodeWrapper();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QSGNinePatchNode >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSGNinePatchNodeFunc_rebuildGeometry(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "rebuildGeometry", 5, 5, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QSGNinePatchNode::rebuildGeometry(QSGTexture*,QSGGeometry*,QVector4D,QRectF,qreal)
    if (numArgs == 5
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTexture_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[4])))) {
        overloadId = 0; // rebuildGeometry(QSGTexture*,QSGGeometry*,QVector4D,QRectF,qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "rebuildGeometry", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGNinePatchNode_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QSGTexture *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QSGGeometry *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QVector4D cppArg2_local;
        ::QVector4D *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2].isValue())
            pythonToCpp[2](pyArgs[2], &cppArg2_local);
        else
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (!Shiboken::Object::isValid(pyArgs[3]))
            return {};
        ::QRectF cppArg3_local;
        ::QRectF *cppArg3 = &cppArg3_local;
        if (pythonToCpp[3].isValue())
            pythonToCpp[3](pyArgs[3], &cppArg3_local);
        else
            pythonToCpp[3](pyArgs[3], &cppArg3);

        qreal cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);

        if (Shiboken::Errors::occurred() == nullptr) {
            // rebuildGeometry(QSGTexture*,QSGGeometry*,QVector4D,QRectF,qreal)
            ::QSGNinePatchNode::rebuildGeometry(cppArg0, cppArg1, *cppArg2, *cppArg3, cppArg4);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGNinePatchNodeFunc_setBounds(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGNinePatchNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNinePatchNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGNinePatchNode::setBounds(QRectF)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArg)))) {
        overloadId = 0; // setBounds(QRectF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBounds", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGNinePatchNode_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRectF cppArg0_local;
        ::QRectF *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setBounds(QRectF)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QSGNinePatchNode.setBounds");
                return {};
            }
            cppSelf->setBounds(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGNinePatchNodeFunc_setDevicePixelRatio(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGNinePatchNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNinePatchNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGNinePatchNode::setDevicePixelRatio(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setDevicePixelRatio(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDevicePixelRatio", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGNinePatchNode_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDevicePixelRatio(qreal)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QSGNinePatchNode.setDevicePixelRatio");
                return {};
            }
            cppSelf->setDevicePixelRatio(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGNinePatchNodeFunc_setPadding(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGNinePatchNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNinePatchNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setPadding", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSGNinePatchNode::setPadding(qreal,qreal,qreal,qreal)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[3])))) {
        overloadId = 0; // setPadding(qreal,qreal,qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setPadding", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGNinePatchNode_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qreal cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        qreal cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        qreal cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPadding(qreal,qreal,qreal,qreal)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QSGNinePatchNode.setPadding");
                return {};
            }
            cppSelf->setPadding(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGNinePatchNodeFunc_setTexture(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGNinePatchNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNinePatchNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGNinePatchNode::setTexture(QSGTexture*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTexture_IDX]), (pyArg)))) {
        overloadId = 0; // setTexture(QSGTexture*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTexture", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGNinePatchNode_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSGTexture *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTexture(QSGTexture*)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QSGNinePatchNode.setTexture");
                return {};
            }
            cppSelf->setTexture(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGNinePatchNodeFunc_update(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGNinePatchNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNinePatchNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // update()
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QSGNinePatchNode.update");
            return {};
        }
        cppSelf->update();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QSGNinePatchNode_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSGNinePatchNode_methods[] = {
    {"rebuildGeometry", reinterpret_cast<PyCFunction>(Sbk_QSGNinePatchNodeFunc_rebuildGeometry), METH_VARARGS|METH_STATIC, nullptr},
    {"setBounds", reinterpret_cast<PyCFunction>(Sbk_QSGNinePatchNodeFunc_setBounds), METH_O, nullptr},
    {"setDevicePixelRatio", reinterpret_cast<PyCFunction>(Sbk_QSGNinePatchNodeFunc_setDevicePixelRatio), METH_O, nullptr},
    {"setPadding", reinterpret_cast<PyCFunction>(Sbk_QSGNinePatchNodeFunc_setPadding), METH_VARARGS, nullptr},
    {"setTexture", reinterpret_cast<PyCFunction>(Sbk_QSGNinePatchNodeFunc_setTexture), METH_O, nullptr},
    {"update", reinterpret_cast<PyCFunction>(Sbk_QSGNinePatchNodeFunc_update), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QSGNinePatchNode_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QSGNinePatchNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNinePatchNode_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QSGNinePatchNodeWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QSGNinePatchNode_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSGNinePatchNode_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSGNinePatchNode_Type = nullptr;
static PyTypeObject *Sbk_QSGNinePatchNode_TypeF(void)
{
    return _Sbk_QSGNinePatchNode_Type;
}

static PyType_Slot Sbk_QSGNinePatchNode_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QSGNinePatchNode_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSGNinePatchNode_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSGNinePatchNode_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSGNinePatchNode_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSGNinePatchNode_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSGNinePatchNode_spec = {
    "2:PySide6.QtQuick.QSGNinePatchNode",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSGNinePatchNode_slots
};

} //extern "C"

static void *Sbk_QSGNinePatchNode_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QSGNode >())
        return dynamic_cast< ::QSGNinePatchNode *>(reinterpret_cast< ::QSGNode *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSGNinePatchNode_PythonToCpp_QSGNinePatchNode_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSGNinePatchNode_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSGNinePatchNode_PythonToCpp_QSGNinePatchNode_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSGNinePatchNode_TypeF()))
        return QSGNinePatchNode_PythonToCpp_QSGNinePatchNode_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSGNinePatchNode_PTR_CppToPython_QSGNinePatchNode(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QSGNinePatchNode *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QSGNinePatchNode_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSGNinePatchNode_SignatureStrings[] = {
    "PySide6.QtQuick.QSGNinePatchNode(self)",
    "PySide6.QtQuick.QSGNinePatchNode.rebuildGeometry(texture:PySide6.QtQuick.QSGTexture,geometry:PySide6.QtQuick.QSGGeometry,padding:PySide6.QtGui.QVector4D,bounds:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect],dpr:qreal)",
    "PySide6.QtQuick.QSGNinePatchNode.setBounds(self,bounds:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect])",
    "PySide6.QtQuick.QSGNinePatchNode.setDevicePixelRatio(self,ratio:qreal)",
    "PySide6.QtQuick.QSGNinePatchNode.setPadding(self,left:qreal,top:qreal,right:qreal,bottom:qreal)",
    "PySide6.QtQuick.QSGNinePatchNode.setTexture(self,texture:PySide6.QtQuick.QSGTexture)",
    "PySide6.QtQuick.QSGNinePatchNode.update(self)",
    nullptr}; // Sentinel
#else
static constexpr size_t QSGNinePatchNode_SignatureByteSize = 230;
static constexpr uint8_t QSGNinePatchNode_SignatureBytes[230] = {
    0x78, 0xda, 0xa5, 0x92, 0x31, 0x6f, 0xc2, 0x30, 0x10, 0x85, 0xf7, 0xfe, 0x0a, 0x46, 0x2a, 0x59,
    0x9e, 0xaa, 0x0e, 0x19, 0x0b, 0x6a, 0x36, 0x64, 0x43, 0xdb, 0x05, 0x75, 0x70, 0xe2, 0x23, 0x9c,
    0x30, 0x3e, 0xd7, 0x39, 0x57, 0xe4, 0xdf, 0x43, 0x71, 0xa2, 0x76, 0x88, 0x44, 0x50, 0xb7, 0xd3,
    0xf9, 0x7b, 0xef, 0xd9, 0x77, 0x56, 0xdd, 0x06, 0x2d, 0x3c, 0x4b, 0xcd, 0x3a, 0x61, 0x7d, 0x90,
    0x7a, 0x53, 0xae, 0xd0, 0x83, 0x32, 0x5c, 0xef, 0x57, 0x64, 0x61, 0xde, 0x82, 0xdb, 0x3d, 0x3e,
    0xa8, 0x1b, 0x98, 0x8c, 0x50, 0x25, 0x74, 0xb6, 0x04, 0x3a, 0x02, 0xc7, 0x6e, 0xce, 0x70, 0xe2,
    0x14, 0xa1, 0x18, 0x11, 0xbe, 0xe5, 0x23, 0xd1, 0xf4, 0xec, 0x18, 0x33, 0xf8, 0x88, 0x60, 0xac,
    0x45, 0xdf, 0xfc, 0x61, 0xca, 0x84, 0x52, 0x7f, 0x40, 0xcd, 0x14, 0x9f, 0x96, 0xa2, 0xa2, 0xe4,
    0x6d, 0x5b, 0x70, 0x17, 0x2e, 0x94, 0x7c, 0xf7, 0x48, 0x7e, 0xfb, 0xcb, 0x2e, 0x28, 0x82, 0xd4,
    0xeb, 0x0b, 0xfc, 0x2a, 0x66, 0x63, 0xed, 0x4f, 0x61, 0x43, 0x2c, 0xbe, 0x22, 0x18, 0x37, 0xe1,
    0x91, 0x2d, 0xf0, 0xcb, 0x35, 0xef, 0x3a, 0x95, 0x7f, 0x67, 0x4f, 0x4b, 0x5c, 0xc2, 0x37, 0xd6,
    0xa0, 0xf0, 0x04, 0x6e, 0x6d, 0x18, 0x29, 0x67, 0xc7, 0x9f, 0xf2, 0x9e, 0x8b, 0xab, 0x3c, 0xc8,
    0xac, 0x76, 0xb0, 0xe3, 0x2c, 0x16, 0x4c, 0xa1, 0xaf, 0x22, 0x36, 0xfb, 0xa1, 0x5b, 0x11, 0x33,
    0x1d, 0xef, 0xf1, 0xef, 0xb7, 0x9a, 0xfd, 0x6f, 0x6f, 0x7f, 0x82, 0x69, 0x0a, 0xd6, 0xf0, 0xf0,
    0x01, 0xcf, 0xbf, 0x7a, 0xf5, 0xa5
};
#endif

PyTypeObject *init_QSGNinePatchNode(PyObject *module)
{
    if (SbkPySide6_QtQuickTypeStructs[SBK_QSGNinePatchNode_IDX].type != nullptr)
        return SbkPySide6_QtQuickTypeStructs[SBK_QSGNinePatchNode_IDX].type;

    Shiboken::AutoDecRef Sbk_QSGNinePatchNode_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometryNode_IDX]))));

    _Sbk_QSGNinePatchNode_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSGNinePatchNode",
        "QSGNinePatchNode*",
        &Sbk_QSGNinePatchNode_spec,
        &Shiboken::callCppDestructor< QSGNinePatchNode >,
        Sbk_QSGNinePatchNode_Type_bases.object(),
        0);
    auto *pyType = Sbk_QSGNinePatchNode_TypeF(); // references _Sbk_QSGNinePatchNode_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSGNinePatchNode_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSGNinePatchNode_SignatureBytes, QSGNinePatchNode_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSGNinePatchNode_PropertyStrings);
    SbkPySide6_QtQuickTypeStructs[SBK_QSGNinePatchNode_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSGNinePatchNode_PythonToCpp_QSGNinePatchNode_PTR,
        is_QSGNinePatchNode_PythonToCpp_QSGNinePatchNode_PTR_Convertible,
        QSGNinePatchNode_PTR_CppToPython_QSGNinePatchNode);

    Shiboken::Conversions::registerConverterName(converter, "QSGNinePatchNode");
    Shiboken::Conversions::registerConverterName(converter, "QSGNinePatchNode*");
    Shiboken::Conversions::registerConverterName(converter, "QSGNinePatchNode&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSGNinePatchNode).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QSGNinePatchNodeWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QSGNinePatchNode_TypeF(), &Sbk_QSGNinePatchNode_typeDiscovery);

    qRegisterMetaType< ::QSGNinePatchNode *>();

    return pyType;
}
