// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtquick_python.h"

// main header
#include "qsgnodevisitor_wrapper.h"

// Argument includes
#include <QtQuick/qsgnode.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QSGNodeVisitorWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QSGNodeVisitorWrapper::QSGNodeVisitorWrapper()
{
}

void QSGNodeVisitorWrapper::enterClipNode(::QSGClipNode * arg__1)
{
    if (m_PyMethodCache[0]) {
        return this->::QSGNodeVisitor::enterClipNode(arg__1);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "enterClipNode";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QSGNodeVisitor::enterClipNode(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGClipNode_IDX]), arg__1)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGClipNode_IDX]), arg__1)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSGNodeVisitor", funcName);
        return;
    }
}

void QSGNodeVisitorWrapper::enterGeometryNode(::QSGGeometryNode * arg__1)
{
    if (m_PyMethodCache[1]) {
        return this->::QSGNodeVisitor::enterGeometryNode(arg__1);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "enterGeometryNode";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QSGNodeVisitor::enterGeometryNode(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometryNode_IDX]), arg__1)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometryNode_IDX]), arg__1)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSGNodeVisitor", funcName);
        return;
    }
}

void QSGNodeVisitorWrapper::enterOpacityNode(::QSGOpacityNode * arg__1)
{
    if (m_PyMethodCache[2]) {
        return this->::QSGNodeVisitor::enterOpacityNode(arg__1);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "enterOpacityNode";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QSGNodeVisitor::enterOpacityNode(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGOpacityNode_IDX]), arg__1)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGOpacityNode_IDX]), arg__1)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSGNodeVisitor", funcName);
        return;
    }
}

void QSGNodeVisitorWrapper::enterTransformNode(::QSGTransformNode * arg__1)
{
    if (m_PyMethodCache[3]) {
        return this->::QSGNodeVisitor::enterTransformNode(arg__1);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "enterTransformNode";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QSGNodeVisitor::enterTransformNode(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTransformNode_IDX]), arg__1)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTransformNode_IDX]), arg__1)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSGNodeVisitor", funcName);
        return;
    }
}

void QSGNodeVisitorWrapper::leaveClipNode(::QSGClipNode * arg__1)
{
    if (m_PyMethodCache[4]) {
        return this->::QSGNodeVisitor::leaveClipNode(arg__1);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "leaveClipNode";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QSGNodeVisitor::leaveClipNode(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGClipNode_IDX]), arg__1)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGClipNode_IDX]), arg__1)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSGNodeVisitor", funcName);
        return;
    }
}

void QSGNodeVisitorWrapper::leaveGeometryNode(::QSGGeometryNode * arg__1)
{
    if (m_PyMethodCache[5]) {
        return this->::QSGNodeVisitor::leaveGeometryNode(arg__1);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "leaveGeometryNode";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QSGNodeVisitor::leaveGeometryNode(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometryNode_IDX]), arg__1)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometryNode_IDX]), arg__1)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSGNodeVisitor", funcName);
        return;
    }
}

void QSGNodeVisitorWrapper::leaveOpacityNode(::QSGOpacityNode * arg__1)
{
    if (m_PyMethodCache[6]) {
        return this->::QSGNodeVisitor::leaveOpacityNode(arg__1);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "leaveOpacityNode";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QSGNodeVisitor::leaveOpacityNode(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGOpacityNode_IDX]), arg__1)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGOpacityNode_IDX]), arg__1)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSGNodeVisitor", funcName);
        return;
    }
}

void QSGNodeVisitorWrapper::leaveTransformNode(::QSGTransformNode * arg__1)
{
    if (m_PyMethodCache[7]) {
        return this->::QSGNodeVisitor::leaveTransformNode(arg__1);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "leaveTransformNode";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[7] = true;
        gil.release();
        return this->::QSGNodeVisitor::leaveTransformNode(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTransformNode_IDX]), arg__1)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTransformNode_IDX]), arg__1)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSGNodeVisitor", funcName);
        return;
    }
}

void QSGNodeVisitorWrapper::visitChildren(::QSGNode * n)
{
    if (m_PyMethodCache[8]) {
        return this->::QSGNodeVisitor::visitChildren(n);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "visitChildren";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[8] = true;
        gil.release();
        return this->::QSGNodeVisitor::visitChildren(n);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), n)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), n)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSGNodeVisitor", funcName);
        return;
    }
}

void QSGNodeVisitorWrapper::visitNode(::QSGNode * n)
{
    if (m_PyMethodCache[9]) {
        return this->::QSGNodeVisitor::visitNode(n);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "visitNode";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[9] = true;
        gil.release();
        return this->::QSGNodeVisitor::visitNode(n);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), n)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), n)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSGNodeVisitor", funcName);
        return;
    }
}

QSGNodeVisitorWrapper::~QSGNodeVisitorWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSGNodeVisitor_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSGNodeVisitor >()))
        return -1;

    QSGNodeVisitorWrapper *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtQuickTypeStructs[SBK_QSGNodeVisitor_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QSGNodeVisitor()
        cptr = new QSGNodeVisitorWrapper();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QSGNodeVisitor >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSGNodeVisitorFunc_enterClipNode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGNodeVisitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNodeVisitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGNodeVisitor::enterClipNode(QSGClipNode*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGClipNode_IDX]), (pyArg)))) {
        overloadId = 0; // enterClipNode(QSGClipNode*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "enterClipNode", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGNodeVisitor_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSGClipNode *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // enterClipNode(QSGClipNode*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSGNodeVisitor::enterClipNode(cppArg0)
                : cppSelf->enterClipNode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGNodeVisitorFunc_enterGeometryNode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGNodeVisitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNodeVisitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGNodeVisitor::enterGeometryNode(QSGGeometryNode*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometryNode_IDX]), (pyArg)))) {
        overloadId = 0; // enterGeometryNode(QSGGeometryNode*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "enterGeometryNode", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGNodeVisitor_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSGGeometryNode *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // enterGeometryNode(QSGGeometryNode*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSGNodeVisitor::enterGeometryNode(cppArg0)
                : cppSelf->enterGeometryNode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGNodeVisitorFunc_enterOpacityNode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGNodeVisitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNodeVisitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGNodeVisitor::enterOpacityNode(QSGOpacityNode*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGOpacityNode_IDX]), (pyArg)))) {
        overloadId = 0; // enterOpacityNode(QSGOpacityNode*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "enterOpacityNode", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGNodeVisitor_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSGOpacityNode *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // enterOpacityNode(QSGOpacityNode*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSGNodeVisitor::enterOpacityNode(cppArg0)
                : cppSelf->enterOpacityNode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGNodeVisitorFunc_enterTransformNode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGNodeVisitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNodeVisitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGNodeVisitor::enterTransformNode(QSGTransformNode*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTransformNode_IDX]), (pyArg)))) {
        overloadId = 0; // enterTransformNode(QSGTransformNode*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "enterTransformNode", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGNodeVisitor_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSGTransformNode *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // enterTransformNode(QSGTransformNode*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSGNodeVisitor::enterTransformNode(cppArg0)
                : cppSelf->enterTransformNode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGNodeVisitorFunc_leaveClipNode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGNodeVisitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNodeVisitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGNodeVisitor::leaveClipNode(QSGClipNode*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGClipNode_IDX]), (pyArg)))) {
        overloadId = 0; // leaveClipNode(QSGClipNode*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "leaveClipNode", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGNodeVisitor_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSGClipNode *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // leaveClipNode(QSGClipNode*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSGNodeVisitor::leaveClipNode(cppArg0)
                : cppSelf->leaveClipNode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGNodeVisitorFunc_leaveGeometryNode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGNodeVisitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNodeVisitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGNodeVisitor::leaveGeometryNode(QSGGeometryNode*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometryNode_IDX]), (pyArg)))) {
        overloadId = 0; // leaveGeometryNode(QSGGeometryNode*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "leaveGeometryNode", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGNodeVisitor_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSGGeometryNode *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // leaveGeometryNode(QSGGeometryNode*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSGNodeVisitor::leaveGeometryNode(cppArg0)
                : cppSelf->leaveGeometryNode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGNodeVisitorFunc_leaveOpacityNode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGNodeVisitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNodeVisitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGNodeVisitor::leaveOpacityNode(QSGOpacityNode*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGOpacityNode_IDX]), (pyArg)))) {
        overloadId = 0; // leaveOpacityNode(QSGOpacityNode*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "leaveOpacityNode", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGNodeVisitor_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSGOpacityNode *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // leaveOpacityNode(QSGOpacityNode*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSGNodeVisitor::leaveOpacityNode(cppArg0)
                : cppSelf->leaveOpacityNode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGNodeVisitorFunc_leaveTransformNode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGNodeVisitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNodeVisitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGNodeVisitor::leaveTransformNode(QSGTransformNode*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTransformNode_IDX]), (pyArg)))) {
        overloadId = 0; // leaveTransformNode(QSGTransformNode*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "leaveTransformNode", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGNodeVisitor_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSGTransformNode *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // leaveTransformNode(QSGTransformNode*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSGNodeVisitor::leaveTransformNode(cppArg0)
                : cppSelf->leaveTransformNode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGNodeVisitorFunc_visitChildren(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGNodeVisitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNodeVisitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGNodeVisitor::visitChildren(QSGNode*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), (pyArg)))) {
        overloadId = 0; // visitChildren(QSGNode*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "visitChildren", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGNodeVisitor_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSGNode *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // visitChildren(QSGNode*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSGNodeVisitor::visitChildren(cppArg0)
                : cppSelf->visitChildren(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGNodeVisitorFunc_visitNode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGNodeVisitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNodeVisitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGNodeVisitor::visitNode(QSGNode*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), (pyArg)))) {
        overloadId = 0; // visitNode(QSGNode*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "visitNode", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGNodeVisitor_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSGNode *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // visitNode(QSGNode*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSGNodeVisitor::visitNode(cppArg0)
                : cppSelf->visitNode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QSGNodeVisitor_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSGNodeVisitor_methods[] = {
    {"enterClipNode", reinterpret_cast<PyCFunction>(Sbk_QSGNodeVisitorFunc_enterClipNode), METH_O, nullptr},
    {"enterGeometryNode", reinterpret_cast<PyCFunction>(Sbk_QSGNodeVisitorFunc_enterGeometryNode), METH_O, nullptr},
    {"enterOpacityNode", reinterpret_cast<PyCFunction>(Sbk_QSGNodeVisitorFunc_enterOpacityNode), METH_O, nullptr},
    {"enterTransformNode", reinterpret_cast<PyCFunction>(Sbk_QSGNodeVisitorFunc_enterTransformNode), METH_O, nullptr},
    {"leaveClipNode", reinterpret_cast<PyCFunction>(Sbk_QSGNodeVisitorFunc_leaveClipNode), METH_O, nullptr},
    {"leaveGeometryNode", reinterpret_cast<PyCFunction>(Sbk_QSGNodeVisitorFunc_leaveGeometryNode), METH_O, nullptr},
    {"leaveOpacityNode", reinterpret_cast<PyCFunction>(Sbk_QSGNodeVisitorFunc_leaveOpacityNode), METH_O, nullptr},
    {"leaveTransformNode", reinterpret_cast<PyCFunction>(Sbk_QSGNodeVisitorFunc_leaveTransformNode), METH_O, nullptr},
    {"visitChildren", reinterpret_cast<PyCFunction>(Sbk_QSGNodeVisitorFunc_visitChildren), METH_O, nullptr},
    {"visitNode", reinterpret_cast<PyCFunction>(Sbk_QSGNodeVisitorFunc_visitNode), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QSGNodeVisitor_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QSGNodeVisitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNodeVisitor_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QSGNodeVisitorWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QSGNodeVisitor_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSGNodeVisitor_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSGNodeVisitor_Type = nullptr;
static PyTypeObject *Sbk_QSGNodeVisitor_TypeF(void)
{
    return _Sbk_QSGNodeVisitor_Type;
}

static PyType_Slot Sbk_QSGNodeVisitor_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QSGNodeVisitor_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSGNodeVisitor_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSGNodeVisitor_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSGNodeVisitor_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSGNodeVisitor_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSGNodeVisitor_spec = {
    "2:PySide6.QtQuick.QSGNodeVisitor",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSGNodeVisitor_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSGNodeVisitor_PythonToCpp_QSGNodeVisitor_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSGNodeVisitor_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSGNodeVisitor_PythonToCpp_QSGNodeVisitor_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSGNodeVisitor_TypeF()))
        return QSGNodeVisitor_PythonToCpp_QSGNodeVisitor_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSGNodeVisitor_PTR_CppToPython_QSGNodeVisitor(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QSGNodeVisitor *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QSGNodeVisitor_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSGNodeVisitor_SignatureStrings[] = {
    "PySide6.QtQuick.QSGNodeVisitor(self)",
    "PySide6.QtQuick.QSGNodeVisitor.enterClipNode(self,arg__1:PySide6.QtQuick.QSGClipNode)",
    "PySide6.QtQuick.QSGNodeVisitor.enterGeometryNode(self,arg__1:PySide6.QtQuick.QSGGeometryNode)",
    "PySide6.QtQuick.QSGNodeVisitor.enterOpacityNode(self,arg__1:PySide6.QtQuick.QSGOpacityNode)",
    "PySide6.QtQuick.QSGNodeVisitor.enterTransformNode(self,arg__1:PySide6.QtQuick.QSGTransformNode)",
    "PySide6.QtQuick.QSGNodeVisitor.leaveClipNode(self,arg__1:PySide6.QtQuick.QSGClipNode)",
    "PySide6.QtQuick.QSGNodeVisitor.leaveGeometryNode(self,arg__1:PySide6.QtQuick.QSGGeometryNode)",
    "PySide6.QtQuick.QSGNodeVisitor.leaveOpacityNode(self,arg__1:PySide6.QtQuick.QSGOpacityNode)",
    "PySide6.QtQuick.QSGNodeVisitor.leaveTransformNode(self,arg__1:PySide6.QtQuick.QSGTransformNode)",
    "PySide6.QtQuick.QSGNodeVisitor.visitChildren(self,n:PySide6.QtQuick.QSGNode)",
    "PySide6.QtQuick.QSGNodeVisitor.visitNode(self,n:PySide6.QtQuick.QSGNode)",
    nullptr}; // Sentinel
#else
static constexpr size_t QSGNodeVisitor_SignatureByteSize = 167;
static constexpr uint8_t QSGNodeVisitor_SignatureBytes[167] = {
    0x78, 0xda, 0xb5, 0xd0, 0x31, 0x0b, 0xc2, 0x30, 0x10, 0x05, 0xe0, 0xdd, 0x5f, 0xa2, 0x20, 0x01,
    0x17, 0x87, 0xae, 0x1d, 0xba, 0x69, 0x43, 0x8b, 0x6b, 0x09, 0xcd, 0x55, 0x0f, 0xd3, 0xa4, 0x5c,
    0x62, 0xa1, 0xff, 0x5e, 0x1a, 0x11, 0x2b, 0x68, 0xbd, 0xc1, 0x4e, 0x81, 0xe3, 0xbd, 0x8f, 0xf0,
    0xf2, 0xa1, 0x40, 0x0d, 0x7b, 0x21, 0x83, 0xbc, 0x61, 0x7d, 0x15, 0xb2, 0xc8, 0x0e, 0x4e, 0xc3,
    0x09, 0x3d, 0x06, 0x47, 0x6b, 0x0f, 0xa6, 0xd9, 0xac, 0xf2, 0xd9, 0x90, 0x00, 0x1b, 0x80, 0x52,
    0x83, 0xdd, 0x78, 0x8c, 0x95, 0xad, 0xa2, 0x73, 0x55, 0xed, 0x92, 0x0f, 0xc5, 0x67, 0x8e, 0xa7,
    0x66, 0xe0, 0x5a, 0x08, 0x34, 0x70, 0xe4, 0x69, 0x96, 0xa7, 0x1f, 0x3b, 0x55, 0x63, 0x60, 0xe1,
    0x93, 0x28, 0xcf, 0x2e, 0x49, 0x59, 0xdf, 0x38, 0x6a, 0x39, 0xfa, 0x5b, 0xf8, 0xa7, 0x6f, 0x40,
    0xf5, 0xf0, 0xf7, 0xbd, 0xa3, 0xba, 0xd8, 0xde, 0x51, 0x5f, 0x68, 0xef, 0x68, 0x2f, 0xb8, 0x77,
    0x3f, 0xbe, 0xe9, 0x05, 0x8d, 0x26, 0xb0, 0x0f, 0xda, 0x26, 0x5f, 0x3a, 0x3c, 0xec, 0xf5, 0xc7,
    0x19, 0xe8, 0x0e, 0x7b, 0xbf, 0x4b, 0x9f
};
#endif

PyTypeObject *init_QSGNodeVisitor(PyObject *module)
{
    if (SbkPySide6_QtQuickTypeStructs[SBK_QSGNodeVisitor_IDX].type != nullptr)
        return SbkPySide6_QtQuickTypeStructs[SBK_QSGNodeVisitor_IDX].type;

    Shiboken::AutoDecRef Sbk_QSGNodeVisitor_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QSGNodeVisitor_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSGNodeVisitor",
        "QSGNodeVisitor*",
        &Sbk_QSGNodeVisitor_spec,
        &Shiboken::callCppDestructor< QSGNodeVisitor >,
        Sbk_QSGNodeVisitor_Type_bases.object(),
        0);
    auto *pyType = Sbk_QSGNodeVisitor_TypeF(); // references _Sbk_QSGNodeVisitor_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSGNodeVisitor_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSGNodeVisitor_SignatureBytes, QSGNodeVisitor_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSGNodeVisitor_PropertyStrings);
    SbkPySide6_QtQuickTypeStructs[SBK_QSGNodeVisitor_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSGNodeVisitor_PythonToCpp_QSGNodeVisitor_PTR,
        is_QSGNodeVisitor_PythonToCpp_QSGNodeVisitor_PTR_Convertible,
        QSGNodeVisitor_PTR_CppToPython_QSGNodeVisitor);

    Shiboken::Conversions::registerConverterName(converter, "QSGNodeVisitor");
    Shiboken::Conversions::registerConverterName(converter, "QSGNodeVisitor*");
    Shiboken::Conversions::registerConverterName(converter, "QSGNodeVisitor&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSGNodeVisitor).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QSGNodeVisitorWrapper).name());

    qRegisterMetaType< ::QSGNodeVisitor *>();

    return pyType;
}
