// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtquick_python.h"

// main header
#include "qsgrendernode_wrapper.h"

// inner classes
#include "qsgrendernode_renderstate_wrapper.h"

// Argument includes
#include <QtGui/qmatrix4x4.h>
#include <QtQuick/qsgnode.h>
#include <QtQuick/qsgrendernode.h>
#include <qrect.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QSGRenderNodeWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QSGRenderNodeWrapper::QSGRenderNodeWrapper()
{
}

::QFlags<QSGRenderNode::StateFlag> QSGRenderNodeWrapper::changedStates() const
{
    if (m_PyMethodCache[0])
        return this->::QSGRenderNode::changedStates();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return QFlags<QSGRenderNode::StateFlag>(0);
    static PyObject *nameCache[2] = {};
    static const char *funcName = "changedStates";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QSGRenderNode::changedStates();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSGRenderNode", funcName);
        return QFlags<QSGRenderNode::StateFlag>(0);
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QSGRenderNode_StateFlag_IDX])))->flagsConverter, pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSGRenderNode", funcName, Shiboken::SbkType< QFlags<QSGRenderNode::StateFlag> >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return QFlags<QSGRenderNode::StateFlag>(0);
    }
    ::QFlags<QSGRenderNode::StateFlag> cppResult = QFlags<QSGRenderNode::StateFlag>(0);
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QFlags<QSGRenderNode::RenderingFlag> QSGRenderNodeWrapper::flags() const
{
    if (m_PyMethodCache[1])
        return this->::QSGRenderNode::flags();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return QFlags<QSGRenderNode::RenderingFlag>(0);
    static PyObject *nameCache[2] = {};
    static const char *funcName = "flags";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QSGRenderNode::flags();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSGRenderNode", funcName);
        return QFlags<QSGRenderNode::RenderingFlag>(0);
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QSGRenderNode_RenderingFlag_IDX])))->flagsConverter, pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSGRenderNode", funcName, Shiboken::SbkType< QFlags<QSGRenderNode::RenderingFlag> >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return QFlags<QSGRenderNode::RenderingFlag>(0);
    }
    ::QFlags<QSGRenderNode::RenderingFlag> cppResult = QFlags<QSGRenderNode::RenderingFlag>(0);
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QSGRenderNodeWrapper::isSubtreeBlocked() const
{
    if (m_PyMethodCache[2])
        return this->::QSGNode::isSubtreeBlocked();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "isSubtreeBlocked";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QSGNode::isSubtreeBlocked();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSGRenderNode", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSGRenderNode", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QSGRenderNodeWrapper::prepare()
{
    if (m_PyMethodCache[3]) {
        return this->::QSGRenderNode::prepare();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "prepare";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QSGRenderNode::prepare();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSGRenderNode", funcName);
        return;
    }
}

void QSGRenderNodeWrapper::preprocess()
{
    if (m_PyMethodCache[4]) {
        return this->::QSGNode::preprocess();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "preprocess";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QSGNode::preprocess();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSGRenderNode", funcName);
        return;
    }
}

::QRectF QSGRenderNodeWrapper::rect() const
{
    if (m_PyMethodCache[5])
        return this->::QSGRenderNode::rect();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return {};
    static PyObject *nameCache[2] = {};
    static const char *funcName = "rect";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QSGRenderNode::rect();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSGRenderNode", funcName);
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSGRenderNode", funcName, Shiboken::SbkType< QRectF >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QRectF cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QSGRenderNodeWrapper::releaseResources()
{
    if (m_PyMethodCache[6]) {
        return this->::QSGRenderNode::releaseResources();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "releaseResources";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QSGRenderNode::releaseResources();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSGRenderNode", funcName);
        return;
    }
}

void QSGRenderNodeWrapper::render(const ::QSGRenderNode::RenderState * state)
{
    if (m_PyMethodCache[7]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QSGRenderNode.render");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "render";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[7] = true;
        Shiboken::Errors::setPureVirtualMethodError("QSGRenderNode.render");
        return;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_RenderState_IDX]), state)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_RenderState_IDX]), state)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSGRenderNode", funcName);
        return;
    }
}

QSGRenderNodeWrapper::~QSGRenderNodeWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSGRenderNode_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QSGRenderNode");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSGRenderNode >()))
        return -1;

    QSGRenderNodeWrapper *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QSGRenderNode()
        cptr = new QSGRenderNodeWrapper();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QSGRenderNode >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSGRenderNodeFunc_changedStates(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGRenderNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // changedStates()const
        QFlags<QSGRenderNode::StateFlag> cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QSGRenderNode *>(cppSelf)->::QSGRenderNode::changedStates()
            : const_cast<const ::QSGRenderNode *>(cppSelf)->changedStates();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QSGRenderNode_StateFlag_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGRenderNodeFunc_clipList(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGRenderNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clipList()const
        const QSGClipNode * cppResult = const_cast<const ::QSGRenderNode *>(cppSelf)->clipList();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGClipNode_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGRenderNodeFunc_commandBuffer(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGRenderNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // commandBuffer()const
        QRhiCommandBuffer * cppResult = const_cast<const ::QSGRenderNode *>(cppSelf)->commandBuffer();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGRenderNodeFunc_flags(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGRenderNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // flags()const
        QFlags<QSGRenderNode::RenderingFlag> cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QSGRenderNode *>(cppSelf)->::QSGRenderNode::flags()
            : const_cast<const ::QSGRenderNode *>(cppSelf)->flags();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QSGRenderNode_RenderingFlag_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGRenderNodeFunc_inheritedOpacity(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGRenderNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // inheritedOpacity()const
        qreal cppResult = const_cast<const ::QSGRenderNode *>(cppSelf)->inheritedOpacity();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGRenderNodeFunc_matrix(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGRenderNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // matrix()const
        const QMatrix4x4 * cppResult = const_cast<const ::QSGRenderNode *>(cppSelf)->matrix();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGRenderNodeFunc_prepare(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGRenderNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // prepare()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QSGRenderNode::prepare()
            : cppSelf->prepare();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGRenderNodeFunc_projectionMatrix(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGRenderNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "projectionMatrix", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSGRenderNode::projectionMatrix()const->const QMatrix4x4*
    // 1: QSGRenderNode::projectionMatrix(qsizetype)const->const QMatrix4x4*
    if (numArgs == 0) {
        overloadId = 0; // projectionMatrix()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))) {
        overloadId = 1; // projectionMatrix(qsizetype)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "projectionMatrix", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // projectionMatrix() const
        {

            // projectionMatrix()const
            const QMatrix4x4 * cppResult = const_cast<const ::QSGRenderNode *>(cppSelf)->projectionMatrix();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), cppResult);
            break;
        }
        case 1: // projectionMatrix(qsizetype index) const
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // projectionMatrix(qsizetype)const
                const QMatrix4x4 * cppResult = const_cast<const ::QSGRenderNode *>(cppSelf)->projectionMatrix(cppArg0);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGRenderNodeFunc_rect(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGRenderNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rect()const
        QRectF cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QSGRenderNode *>(cppSelf)->::QSGRenderNode::rect()
            : const_cast<const ::QSGRenderNode *>(cppSelf)->rect();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGRenderNodeFunc_releaseResources(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGRenderNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // releaseResources()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QSGRenderNode::releaseResources()
            : cppSelf->releaseResources();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGRenderNodeFunc_render(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGRenderNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGRenderNode::render(const QSGRenderNode::RenderState*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_RenderState_IDX]), (pyArg)))) {
        overloadId = 0; // render(const QSGRenderNode::RenderState*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "render", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSGRenderNode::RenderState *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // render(const QSGRenderNode::RenderState*)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QSGRenderNode.render");
                return {};
            }
            cppSelf->render(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGRenderNodeFunc_renderTarget(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGRenderNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // renderTarget()const
        QRhiRenderTarget * cppResult = const_cast<const ::QSGRenderNode *>(cppSelf)->renderTarget();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderTarget_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QSGRenderNode_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QSGRenderNode_EnumFlagInfo[] = {
    "RenderingFlag:Flag:RenderingFlags",
    "StateFlag:Flag:StateFlags",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSGRenderNode_methods[] = {
    {"changedStates", reinterpret_cast<PyCFunction>(Sbk_QSGRenderNodeFunc_changedStates), METH_NOARGS, nullptr},
    {"clipList", reinterpret_cast<PyCFunction>(Sbk_QSGRenderNodeFunc_clipList), METH_NOARGS, nullptr},
    {"commandBuffer", reinterpret_cast<PyCFunction>(Sbk_QSGRenderNodeFunc_commandBuffer), METH_NOARGS, nullptr},
    {"flags", reinterpret_cast<PyCFunction>(Sbk_QSGRenderNodeFunc_flags), METH_NOARGS, nullptr},
    {"inheritedOpacity", reinterpret_cast<PyCFunction>(Sbk_QSGRenderNodeFunc_inheritedOpacity), METH_NOARGS, nullptr},
    {"matrix", reinterpret_cast<PyCFunction>(Sbk_QSGRenderNodeFunc_matrix), METH_NOARGS, nullptr},
    {"prepare", reinterpret_cast<PyCFunction>(Sbk_QSGRenderNodeFunc_prepare), METH_NOARGS, nullptr},
    {"projectionMatrix", reinterpret_cast<PyCFunction>(Sbk_QSGRenderNodeFunc_projectionMatrix), METH_VARARGS, nullptr},
    {"rect", reinterpret_cast<PyCFunction>(Sbk_QSGRenderNodeFunc_rect), METH_NOARGS, nullptr},
    {"releaseResources", reinterpret_cast<PyCFunction>(Sbk_QSGRenderNodeFunc_releaseResources), METH_NOARGS, nullptr},
    {"render", reinterpret_cast<PyCFunction>(Sbk_QSGRenderNodeFunc_render), METH_O, nullptr},
    {"renderTarget", reinterpret_cast<PyCFunction>(Sbk_QSGRenderNodeFunc_renderTarget), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QSGRenderNode_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QSGRenderNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QSGRenderNodeWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QSGRenderNode_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSGRenderNode_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSGRenderNode_Type = nullptr;
static PyTypeObject *Sbk_QSGRenderNode_TypeF(void)
{
    return _Sbk_QSGRenderNode_Type;
}

static PyType_Slot Sbk_QSGRenderNode_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QSGRenderNode_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSGRenderNode_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSGRenderNode_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSGRenderNode_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSGRenderNode_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSGRenderNode_spec = {
    "2:PySide6.QtQuick.QSGRenderNode",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSGRenderNode_slots
};

} //extern "C"

static void *Sbk_QSGRenderNode_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QSGNode >())
        return dynamic_cast< ::QSGRenderNode *>(reinterpret_cast< ::QSGNode *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QSGRenderNode_StateFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSGRenderNode::StateFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSGRenderNode::StateFlag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QSGRenderNode_StateFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_StateFlag_IDX])))
        return Enum_PythonToCpp_QSGRenderNode_StateFlag;
    return {};
}

static PyObject *QSGRenderNode_StateFlag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QSGRenderNode::StateFlag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QSGRenderNode::StateFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_StateFlag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QSGRenderNode_StateFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QSGRenderNode::StateFlag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QSGRenderNode::StateFlag> *>(cppOut) = value;

}

static PyObject *QSGRenderNode_StateFlag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QSGRenderNode::StateFlag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_StateFlag_IDX]), flags.toInt());

}

static void Enum_PythonToCpp_QSGRenderNode_RenderingFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSGRenderNode::RenderingFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSGRenderNode::RenderingFlag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QSGRenderNode_RenderingFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_RenderingFlag_IDX])))
        return Enum_PythonToCpp_QSGRenderNode_RenderingFlag;
    return {};
}

static PyObject *QSGRenderNode_RenderingFlag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QSGRenderNode::RenderingFlag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QSGRenderNode::RenderingFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_RenderingFlag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QSGRenderNode_RenderingFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QSGRenderNode::RenderingFlag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QSGRenderNode::RenderingFlag> *>(cppOut) = value;

}

static PyObject *QSGRenderNode_RenderingFlag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QSGRenderNode::RenderingFlag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_RenderingFlag_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSGRenderNode_PythonToCpp_QSGRenderNode_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSGRenderNode_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSGRenderNode_PythonToCpp_QSGRenderNode_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSGRenderNode_TypeF()))
        return QSGRenderNode_PythonToCpp_QSGRenderNode_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSGRenderNode_PTR_CppToPython_QSGRenderNode(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QSGRenderNode *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QSGRenderNode_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSGRenderNode_SignatureStrings[] = {
    "PySide6.QtQuick.QSGRenderNode(self)",
    "PySide6.QtQuick.QSGRenderNode.changedStates(self)->PySide6.QtQuick.QSGRenderNode.StateFlag",
    "PySide6.QtQuick.QSGRenderNode.clipList(self)->PySide6.QtQuick.QSGClipNode",
    "PySide6.QtQuick.QSGRenderNode.commandBuffer(self)->PySide6.QtGui.QRhiCommandBuffer",
    "PySide6.QtQuick.QSGRenderNode.flags(self)->PySide6.QtQuick.QSGRenderNode.RenderingFlag",
    "PySide6.QtQuick.QSGRenderNode.inheritedOpacity(self)->qreal",
    "PySide6.QtQuick.QSGRenderNode.matrix(self)->PySide6.QtGui.QMatrix4x4",
    "PySide6.QtQuick.QSGRenderNode.prepare(self)",
    "1:PySide6.QtQuick.QSGRenderNode.projectionMatrix(self)->PySide6.QtGui.QMatrix4x4",
    "0:PySide6.QtQuick.QSGRenderNode.projectionMatrix(self,index:qsizetype)->PySide6.QtGui.QMatrix4x4",
    "PySide6.QtQuick.QSGRenderNode.rect(self)->PySide6.QtCore.QRectF",
    "PySide6.QtQuick.QSGRenderNode.releaseResources(self)",
    "PySide6.QtQuick.QSGRenderNode.render(self,state:PySide6.QtQuick.QSGRenderNode.RenderState)",
    "PySide6.QtQuick.QSGRenderNode.renderTarget(self)->PySide6.QtGui.QRhiRenderTarget",
    nullptr}; // Sentinel
#else
static constexpr size_t QSGRenderNode_SignatureByteSize = 261;
static constexpr uint8_t QSGRenderNode_SignatureBytes[261] = {
    0x78, 0xda, 0x9d, 0x93, 0xc1, 0x6a, 0xc3, 0x30, 0x10, 0x44, 0xef, 0xf9, 0x92, 0x16, 0x5a, 0xd3,
    0x42, 0xe8, 0xc1, 0x87, 0x1e, 0x6a, 0x48, 0x2e, 0x4d, 0x1b, 0xdb, 0xfd, 0x01, 0x21, 0xad, 0xed,
    0x4d, 0x65, 0x49, 0x91, 0xd6, 0x60, 0xf7, 0xeb, 0x2b, 0xdb, 0x18, 0x02, 0x21, 0x96, 0xc8, 0x6d,
    0x61, 0x67, 0x9e, 0x34, 0x68, 0x74, 0x1c, 0x4a, 0x14, 0xf0, 0x96, 0xe4, 0x94, 0x77, 0xc8, 0x7f,
    0x93, 0xbc, 0xdc, 0x17, 0xa0, 0x04, 0xd8, 0x2f, 0x2d, 0xe0, 0xc1, 0x81, 0xac, 0x1e, 0x37, 0xc7,
    0x35, 0x4d, 0xc2, 0x1b, 0xa6, 0x6a, 0x10, 0x25, 0x31, 0x02, 0x37, 0x3b, 0x9e, 0xdf, 0xd7, 0x2d,
    0x93, 0x76, 0x27, 0x59, 0x1d, 0x42, 0x4b, 0x34, 0x9f, 0xe8, 0x68, 0x85, 0x9a, 0x79, 0xc9, 0xa8,
    0x0d, 0x91, 0x74, 0xdb, 0x32, 0x25, 0x3e, 0xba, 0xaa, 0x02, 0x7b, 0x8d, 0xdb, 0x77, 0x98, 0xe4,
    0x45, 0x83, 0xd9, 0xa5, 0x2c, 0x80, 0xac, 0xfc, 0xfd, 0x23, 0xf3, 0xce, 0x23, 0xaa, 0x3a, 0x22,
    0x33, 0xaa, 0xc6, 0x4b, 0x09, 0xc4, 0xb7, 0x61, 0x1c, 0x69, 0x58, 0x4e, 0x38, 0x5b, 0x60, 0x32,
    0xe0, 0x6d, 0x19, 0x59, 0xec, 0x6f, 0xc4, 0x3b, 0x4c, 0xcb, 0x6d, 0xbf, 0x0d, 0x40, 0x8c, 0x05,
    0xc3, 0xec, 0xf2, 0xf6, 0xaf, 0x69, 0x48, 0xad, 0x4f, 0xc0, 0x09, 0xb5, 0x3a, 0xc4, 0x1d, 0xfe,
    0x72, 0x0f, 0xf0, 0x09, 0xfd, 0xbe, 0x4f, 0xcf, 0x0e, 0xff, 0x80, 0x06, 0x03, 0xf7, 0xa7, 0xb3,
    0x9e, 0x7d, 0x7d, 0xc7, 0x4c, 0x5b, 0xf0, 0x05, 0xf0, 0xbb, 0x5d, 0xd0, 0x2f, 0x81, 0x39, 0x28,
    0xc0, 0xe9, 0xce, 0xf2, 0xa5, 0xf0, 0x41, 0xd3, 0x38, 0xce, 0x49, 0xdc, 0xd8, 0xfd, 0x34, 0xa6,
    0x2f, 0xd3, 0x2f, 0x89, 0x43, 0xff, 0x30, 0x5b, 0x03, 0xdd, 0xee, 0x75, 0x71, 0xa1, 0xda, 0xfc,
    0x03, 0xfc, 0x89, 0x67, 0x68
};
#endif

PyTypeObject *init_QSGRenderNode(PyObject *module)
{
    if (SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_IDX].type != nullptr)
        return SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_IDX].type;

    Shiboken::AutoDecRef Sbk_QSGRenderNode_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]))));

    _Sbk_QSGRenderNode_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSGRenderNode",
        "QSGRenderNode*",
        &Sbk_QSGRenderNode_spec,
        &Shiboken::callCppDestructor< QSGRenderNode >,
        Sbk_QSGRenderNode_Type_bases.object(),
        0);
    auto *pyType = Sbk_QSGRenderNode_TypeF(); // references _Sbk_QSGRenderNode_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSGRenderNode_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSGRenderNode_SignatureBytes, QSGRenderNode_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSGRenderNode_PropertyStrings);
    SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSGRenderNode_PythonToCpp_QSGRenderNode_PTR,
        is_QSGRenderNode_PythonToCpp_QSGRenderNode_PTR_Convertible,
        QSGRenderNode_PTR_CppToPython_QSGRenderNode);

    Shiboken::Conversions::registerConverterName(converter, "QSGRenderNode");
    Shiboken::Conversions::registerConverterName(converter, "QSGRenderNode*");
    Shiboken::Conversions::registerConverterName(converter, "QSGRenderNode&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSGRenderNode).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QSGRenderNodeWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QSGRenderNode_TypeF(), &Sbk_QSGRenderNode_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QSGRenderNode_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'StateFlag'.
    const char *StateFlag_Initializer[] = {
        "DepthState",
        "StencilState",
        "ScissorState",
        "ColorState",
        "BlendState",
        "CullState",
        "ViewportState",
        "RenderTargetState",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t StateFlag_InitializerValues[] = {
        uint8_t(QSGRenderNode::StateFlag::DepthState),       //  0x01  1
        uint8_t(QSGRenderNode::StateFlag::StencilState),     //  0x02  2
        uint8_t(QSGRenderNode::StateFlag::ScissorState),     //  0x04  4
        uint8_t(QSGRenderNode::StateFlag::ColorState),       //  0x08  8
        uint8_t(QSGRenderNode::StateFlag::BlendState),       //  0x10  16
        uint8_t(QSGRenderNode::StateFlag::CullState),        //  0x20  32
        uint8_t(QSGRenderNode::StateFlag::ViewportState),    //  0x40  64
        uint8_t(QSGRenderNode::StateFlag::RenderTargetState) //  0x80  128
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSGRenderNode_TypeF(),
        "2:PySide6.QtQuick.QSGRenderNode.StateFlag",
        StateFlag_Initializer, StateFlag_InitializerValues);
    SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_StateFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QSGRenderNode_StateFlag_IDX].type =
        EType;
    // Register converter for enum 'QSGRenderNode::StateFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSGRenderNode_StateFlag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QSGRenderNode_StateFlag,
            is_Enum_PythonToCpp_QSGRenderNode_StateFlag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QSGRenderNode::StateFlag");
        Shiboken::Conversions::registerConverterAlias(converter, "StateFlag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QSGRenderNode_StateFlag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QSGRenderNode_StateFlag,
            is_Enum_PythonToCpp_QSGRenderNode_StateFlag_Convertible);
        // Register converter for flag 'QFlags<QSGRenderNode::StateFlag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QSGRenderNode::StateFlag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QSGRenderNode::StateFlags");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'StateFlag' enum/flags.

    // Initialization of enum 'RenderingFlag'.
    const char *RenderingFlag_Initializer[] = {
        "BoundedRectRendering",
        "DepthAwareRendering",
        "OpaqueRendering",
        "NoExternalRendering",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t RenderingFlag_InitializerValues[] = {
        uint8_t(QSGRenderNode::RenderingFlag::BoundedRectRendering), //  0x01  1
        uint8_t(QSGRenderNode::RenderingFlag::DepthAwareRendering),  //  0x02  2
        uint8_t(QSGRenderNode::RenderingFlag::OpaqueRendering),      //  0x04  4
        uint8_t(QSGRenderNode::RenderingFlag::NoExternalRendering)   //  0x08  8
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSGRenderNode_TypeF(),
        "2:PySide6.QtQuick.QSGRenderNode.RenderingFlag",
        RenderingFlag_Initializer, RenderingFlag_InitializerValues);
    SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_RenderingFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QSGRenderNode_RenderingFlag_IDX].type =
        EType;
    // Register converter for enum 'QSGRenderNode::RenderingFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSGRenderNode_RenderingFlag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QSGRenderNode_RenderingFlag,
            is_Enum_PythonToCpp_QSGRenderNode_RenderingFlag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QSGRenderNode::RenderingFlag");
        Shiboken::Conversions::registerConverterAlias(converter, "RenderingFlag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QSGRenderNode_RenderingFlag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QSGRenderNode_RenderingFlag,
            is_Enum_PythonToCpp_QSGRenderNode_RenderingFlag_Convertible);
        // Register converter for flag 'QFlags<QSGRenderNode::RenderingFlag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QSGRenderNode::RenderingFlag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QSGRenderNode::RenderingFlags");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'RenderingFlag' enum/flags.

    qRegisterMetaType< ::QSGRenderNode *>();
    qRegisterMetaType< ::QSGRenderNode::StateFlag >("QSGRenderNode::StateFlag");
    qRegisterMetaType< ::QSGRenderNode::RenderingFlag >("QSGRenderNode::RenderingFlag");

    return pyType;
}
