// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtquick_python.h"

// main header
#include "qsgsimpletexturenode_wrapper.h"

// Argument includes
#include <QtQuick/qsgmaterial.h>
#include <QtQuick/qsgtexture.h>
#include <qrect.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QSGSimpleTextureNodeWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QSGSimpleTextureNodeWrapper::QSGSimpleTextureNodeWrapper()
{
}

bool QSGSimpleTextureNodeWrapper::isSubtreeBlocked() const
{
    if (m_PyMethodCache[0])
        return this->::QSGNode::isSubtreeBlocked();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "isSubtreeBlocked";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QSGNode::isSubtreeBlocked();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSGSimpleTextureNode", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSGSimpleTextureNode", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QSGSimpleTextureNodeWrapper::preprocess()
{
    if (m_PyMethodCache[1]) {
        return this->::QSGNode::preprocess();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "preprocess";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QSGNode::preprocess();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSGSimpleTextureNode", funcName);
        return;
    }
}

QSGSimpleTextureNodeWrapper::~QSGSimpleTextureNodeWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSGSimpleTextureNode_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSGSimpleTextureNode >()))
        return -1;

    QSGSimpleTextureNodeWrapper *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtQuickTypeStructs[SBK_QSGSimpleTextureNode_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QSGSimpleTextureNode()
        cptr = new QSGSimpleTextureNodeWrapper();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QSGSimpleTextureNode >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSGSimpleTextureNodeFunc_filtering(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGSimpleTextureNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGSimpleTextureNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // filtering()const
        QSGTexture::Filtering cppResult = const_cast<const ::QSGSimpleTextureNode *>(cppSelf)->filtering();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTexture_Filtering_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGSimpleTextureNodeFunc_ownsTexture(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGSimpleTextureNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGSimpleTextureNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ownsTexture()const
        bool cppResult = const_cast<const ::QSGSimpleTextureNode *>(cppSelf)->ownsTexture();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGSimpleTextureNodeFunc_rect(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGSimpleTextureNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGSimpleTextureNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rect()const
        QRectF cppResult = const_cast<const ::QSGSimpleTextureNode *>(cppSelf)->rect();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGSimpleTextureNodeFunc_setFiltering(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGSimpleTextureNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGSimpleTextureNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGSimpleTextureNode::setFiltering(QSGTexture::Filtering)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTexture_Filtering_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setFiltering(QSGTexture::Filtering)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFiltering", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGSimpleTextureNode_IDX]);

    // Call function/method
    {
        ::QSGTexture::Filtering cppArg0{QSGTexture::None};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFiltering(QSGTexture::Filtering)
            cppSelf->setFiltering(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGSimpleTextureNodeFunc_setOwnsTexture(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGSimpleTextureNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGSimpleTextureNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGSimpleTextureNode::setOwnsTexture(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setOwnsTexture(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOwnsTexture", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGSimpleTextureNode_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOwnsTexture(bool)
            cppSelf->setOwnsTexture(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGSimpleTextureNodeFunc_setRect(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGSimpleTextureNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGSimpleTextureNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        return Shiboken::returnWrongArguments(args, "setRect", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGSimpleTextureNode_IDX]);

    if (PyArg_UnpackTuple(args, "setRect", 1, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSGSimpleTextureNode::setRect(QRectF)
    // 1: QSGSimpleTextureNode::setRect(qreal,qreal,qreal,qreal)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[3])))) {
        overloadId = 1; // setRect(qreal,qreal,qreal,qreal)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[0])))) {
        overloadId = 0; // setRect(QRectF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setRect", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGSimpleTextureNode_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setRect(const QRectF &rect)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRectF cppArg0_local;
            ::QRectF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setRect(QRectF)
                cppSelf->setRect(*cppArg0);
            }
            break;
        }
        case 1: // setRect(qreal x, qreal y, qreal w, qreal h)
        {
            qreal cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            qreal cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            qreal cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setRect(qreal,qreal,qreal,qreal)
                cppSelf->setRect(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGSimpleTextureNodeFunc_setSourceRect(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGSimpleTextureNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGSimpleTextureNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        return Shiboken::returnWrongArguments(args, "setSourceRect", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGSimpleTextureNode_IDX]);

    if (PyArg_UnpackTuple(args, "setSourceRect", 1, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSGSimpleTextureNode::setSourceRect(QRectF)
    // 1: QSGSimpleTextureNode::setSourceRect(qreal,qreal,qreal,qreal)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[3])))) {
        overloadId = 1; // setSourceRect(qreal,qreal,qreal,qreal)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[0])))) {
        overloadId = 0; // setSourceRect(QRectF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setSourceRect", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGSimpleTextureNode_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setSourceRect(const QRectF &r)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRectF cppArg0_local;
            ::QRectF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setSourceRect(QRectF)
                cppSelf->setSourceRect(*cppArg0);
            }
            break;
        }
        case 1: // setSourceRect(qreal x, qreal y, qreal w, qreal h)
        {
            qreal cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            qreal cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            qreal cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setSourceRect(qreal,qreal,qreal,qreal)
                cppSelf->setSourceRect(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGSimpleTextureNodeFunc_setTexture(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGSimpleTextureNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGSimpleTextureNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGSimpleTextureNode::setTexture(QSGTexture*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTexture_IDX]), (pyArg)))) {
        overloadId = 0; // setTexture(QSGTexture*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTexture", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGSimpleTextureNode_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSGTexture *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTexture(QSGTexture*)
            cppSelf->setTexture(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGSimpleTextureNodeFunc_setTextureCoordinatesTransform(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGSimpleTextureNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGSimpleTextureNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGSimpleTextureNode::setTextureCoordinatesTransform(QFlags<QSGSimpleTextureNode::TextureCoordinatesTransformFlag>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QSGSimpleTextureNode_TextureCoordinatesTransformFlag_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setTextureCoordinatesTransform(QFlags<QSGSimpleTextureNode::TextureCoordinatesTransformFlag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTextureCoordinatesTransform", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGSimpleTextureNode_IDX]);

    // Call function/method
    {
        ::QFlags<QSGSimpleTextureNode::TextureCoordinatesTransformFlag> cppArg0 = QFlags<QSGSimpleTextureNode::TextureCoordinatesTransformFlag>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTextureCoordinatesTransform(QFlags<QSGSimpleTextureNode::TextureCoordinatesTransformFlag>)
            cppSelf->setTextureCoordinatesTransform(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGSimpleTextureNodeFunc_sourceRect(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGSimpleTextureNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGSimpleTextureNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sourceRect()const
        QRectF cppResult = const_cast<const ::QSGSimpleTextureNode *>(cppSelf)->sourceRect();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGSimpleTextureNodeFunc_texture(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGSimpleTextureNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGSimpleTextureNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // texture()const
        QSGTexture * cppResult = const_cast<const ::QSGSimpleTextureNode *>(cppSelf)->texture();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTexture_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGSimpleTextureNodeFunc_textureCoordinatesTransform(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGSimpleTextureNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGSimpleTextureNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // textureCoordinatesTransform()const
        QFlags<QSGSimpleTextureNode::TextureCoordinatesTransformFlag> cppResult = const_cast<const ::QSGSimpleTextureNode *>(cppSelf)->textureCoordinatesTransform();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QSGSimpleTextureNode_TextureCoordinatesTransformFlag_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QSGSimpleTextureNode_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QSGSimpleTextureNode_EnumFlagInfo[] = {
    "TextureCoordinatesTransformFlag:Flag:TextureCoordinatesTransformMode",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSGSimpleTextureNode_methods[] = {
    {"filtering", reinterpret_cast<PyCFunction>(Sbk_QSGSimpleTextureNodeFunc_filtering), METH_NOARGS, nullptr},
    {"ownsTexture", reinterpret_cast<PyCFunction>(Sbk_QSGSimpleTextureNodeFunc_ownsTexture), METH_NOARGS, nullptr},
    {"rect", reinterpret_cast<PyCFunction>(Sbk_QSGSimpleTextureNodeFunc_rect), METH_NOARGS, nullptr},
    {"setFiltering", reinterpret_cast<PyCFunction>(Sbk_QSGSimpleTextureNodeFunc_setFiltering), METH_O, nullptr},
    {"setOwnsTexture", reinterpret_cast<PyCFunction>(Sbk_QSGSimpleTextureNodeFunc_setOwnsTexture), METH_O, nullptr},
    {"setRect", reinterpret_cast<PyCFunction>(Sbk_QSGSimpleTextureNodeFunc_setRect), METH_VARARGS, nullptr},
    {"setSourceRect", reinterpret_cast<PyCFunction>(Sbk_QSGSimpleTextureNodeFunc_setSourceRect), METH_VARARGS, nullptr},
    {"setTexture", reinterpret_cast<PyCFunction>(Sbk_QSGSimpleTextureNodeFunc_setTexture), METH_O, nullptr},
    {"setTextureCoordinatesTransform", reinterpret_cast<PyCFunction>(Sbk_QSGSimpleTextureNodeFunc_setTextureCoordinatesTransform), METH_O, nullptr},
    {"sourceRect", reinterpret_cast<PyCFunction>(Sbk_QSGSimpleTextureNodeFunc_sourceRect), METH_NOARGS, nullptr},
    {"texture", reinterpret_cast<PyCFunction>(Sbk_QSGSimpleTextureNodeFunc_texture), METH_NOARGS, nullptr},
    {"textureCoordinatesTransform", reinterpret_cast<PyCFunction>(Sbk_QSGSimpleTextureNodeFunc_textureCoordinatesTransform), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QSGSimpleTextureNode_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QSGSimpleTextureNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGSimpleTextureNode_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QSGSimpleTextureNodeWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QSGSimpleTextureNode_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSGSimpleTextureNode_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSGSimpleTextureNode_Type = nullptr;
static PyTypeObject *Sbk_QSGSimpleTextureNode_TypeF(void)
{
    return _Sbk_QSGSimpleTextureNode_Type;
}

static PyType_Slot Sbk_QSGSimpleTextureNode_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QSGSimpleTextureNode_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSGSimpleTextureNode_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSGSimpleTextureNode_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSGSimpleTextureNode_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSGSimpleTextureNode_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSGSimpleTextureNode_spec = {
    "2:PySide6.QtQuick.QSGSimpleTextureNode",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSGSimpleTextureNode_slots
};

} //extern "C"

static void *Sbk_QSGSimpleTextureNode_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QSGNode >())
        return dynamic_cast< ::QSGSimpleTextureNode *>(reinterpret_cast< ::QSGNode *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QSGSimpleTextureNode_TextureCoordinatesTransformFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSGSimpleTextureNode::TextureCoordinatesTransformFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSGSimpleTextureNode::TextureCoordinatesTransformFlag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QSGSimpleTextureNode_TextureCoordinatesTransformFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGSimpleTextureNode_TextureCoordinatesTransformFlag_IDX])))
        return Enum_PythonToCpp_QSGSimpleTextureNode_TextureCoordinatesTransformFlag;
    return {};
}

static PyObject *QSGSimpleTextureNode_TextureCoordinatesTransformFlag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QSGSimpleTextureNode::TextureCoordinatesTransformFlag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QSGSimpleTextureNode::TextureCoordinatesTransformFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGSimpleTextureNode_TextureCoordinatesTransformFlag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QSGSimpleTextureNode_TextureCoordinatesTransformFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QSGSimpleTextureNode::TextureCoordinatesTransformFlag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QSGSimpleTextureNode::TextureCoordinatesTransformFlag> *>(cppOut) = value;

}

static PyObject *QSGSimpleTextureNode_TextureCoordinatesTransformFlag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QSGSimpleTextureNode::TextureCoordinatesTransformFlag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGSimpleTextureNode_TextureCoordinatesTransformFlag_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSGSimpleTextureNode_PythonToCpp_QSGSimpleTextureNode_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSGSimpleTextureNode_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSGSimpleTextureNode_PythonToCpp_QSGSimpleTextureNode_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSGSimpleTextureNode_TypeF()))
        return QSGSimpleTextureNode_PythonToCpp_QSGSimpleTextureNode_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSGSimpleTextureNode_PTR_CppToPython_QSGSimpleTextureNode(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QSGSimpleTextureNode *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QSGSimpleTextureNode_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSGSimpleTextureNode_SignatureStrings[] = {
    "PySide6.QtQuick.QSGSimpleTextureNode(self)",
    "PySide6.QtQuick.QSGSimpleTextureNode.filtering(self)->PySide6.QtQuick.QSGTexture.Filtering",
    "PySide6.QtQuick.QSGSimpleTextureNode.ownsTexture(self)->bool",
    "PySide6.QtQuick.QSGSimpleTextureNode.rect(self)->PySide6.QtCore.QRectF",
    "PySide6.QtQuick.QSGSimpleTextureNode.setFiltering(self,filtering:PySide6.QtQuick.QSGTexture.Filtering)",
    "PySide6.QtQuick.QSGSimpleTextureNode.setOwnsTexture(self,owns:bool)",
    "1:PySide6.QtQuick.QSGSimpleTextureNode.setRect(self,rect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect])",
    "0:PySide6.QtQuick.QSGSimpleTextureNode.setRect(self,x:qreal,y:qreal,w:qreal,h:qreal)",
    "1:PySide6.QtQuick.QSGSimpleTextureNode.setSourceRect(self,r:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect])",
    "0:PySide6.QtQuick.QSGSimpleTextureNode.setSourceRect(self,x:qreal,y:qreal,w:qreal,h:qreal)",
    "PySide6.QtQuick.QSGSimpleTextureNode.setTexture(self,texture:PySide6.QtQuick.QSGTexture)",
    "PySide6.QtQuick.QSGSimpleTextureNode.setTextureCoordinatesTransform(self,mode:PySide6.QtQuick.QSGSimpleTextureNode.TextureCoordinatesTransformFlag)",
    "PySide6.QtQuick.QSGSimpleTextureNode.sourceRect(self)->PySide6.QtCore.QRectF",
    "PySide6.QtQuick.QSGSimpleTextureNode.texture(self)->PySide6.QtQuick.QSGTexture",
    "PySide6.QtQuick.QSGSimpleTextureNode.textureCoordinatesTransform(self)->PySide6.QtQuick.QSGSimpleTextureNode.TextureCoordinatesTransformFlag",
    nullptr}; // Sentinel
#else
static constexpr size_t QSGSimpleTextureNode_SignatureByteSize = 274;
static constexpr uint8_t QSGSimpleTextureNode_SignatureBytes[274] = {
    0x78, 0xda, 0xbd, 0x93, 0xb1, 0x4e, 0xc3, 0x30, 0x10, 0x86, 0xf7, 0x3c, 0x05, 0x23, 0x91, 0x8c,
    0xd5, 0x2e, 0x0c, 0x1e, 0x58, 0x2a, 0x85, 0x0d, 0x9a, 0xa6, 0x4c, 0x88, 0x21, 0x24, 0x17, 0xb0,
    0x70, 0x7c, 0xc5, 0xbe, 0xa8, 0xcd, 0xdb, 0x93, 0x28, 0x09, 0x22, 0x25, 0x2d, 0x17, 0x90, 0x98,
    0x4e, 0xb6, 0xef, 0xfe, 0xbb, 0xef, 0xb7, 0xbd, 0xae, 0x13, 0x9d, 0xc3, 0xb5, 0x8c, 0x29, 0xae,
    0x74, 0xf6, 0x26, 0xe3, 0xe4, 0x36, 0xd1, 0xe5, 0xce, 0xc0, 0x16, 0x0e, 0x54, 0x39, 0xb8, 0xc3,
    0x1c, 0x2e, 0x3d, 0x98, 0x22, 0x0c, 0xd6, 0x8c, 0x54, 0x59, 0x68, 0x43, 0xe0, 0xb4, 0x7d, 0xe9,
    0x8a, 0xae, 0x6e, 0x26, 0xaa, 0xfa, 0x7c, 0x19, 0x0d, 0xb9, 0x3c, 0x69, 0xdc, 0x5b, 0xdf, 0xaf,
    0x07, 0xf1, 0x67, 0x44, 0xc3, 0x2b, 0x76, 0x90, 0xd1, 0xf7, 0x91, 0x56, 0xd8, 0x8c, 0x11, 0x6f,
    0x9a, 0xb3, 0x88, 0x27, 0xe3, 0x81, 0xa2, 0x11, 0xa1, 0xf8, 0x04, 0x56, 0x1c, 0xd2, 0x90, 0xdd,
    0xe6, 0xfe, 0x88, 0x56, 0xb4, 0xf8, 0xaa, 0x05, 0x0e, 0x83, 0xa5, 0xe2, 0xaa, 0x6c, 0x06, 0x6c,
    0xd1, 0x1a, 0xa0, 0xa8, 0xde, 0x35, 0x43, 0xc8, 0x07, 0xab, 0xd1, 0x3e, 0x4e, 0xda, 0x20, 0x2e,
    0xa6, 0xb6, 0x9f, 0xc2, 0x60, 0xf1, 0x8b, 0x9e, 0x07, 0xf5, 0xee, 0x20, 0x35, 0xa2, 0xee, 0xe3,
    0xbe, 0x8f, 0xaf, 0x5d, 0x9c, 0x03, 0x92, 0x60, 0xe5, 0x32, 0xf8, 0x82, 0xf3, 0x3f, 0x2c, 0xc7,
    0x6d, 0x7f, 0x24, 0xe2, 0x0a, 0x8f, 0xae, 0x96, 0xba, 0xc5, 0x99, 0x17, 0x34, 0x5b, 0x78, 0x85,
    0xe8, 0x72, 0x6d, 0x53, 0x02, 0xbf, 0x75, 0xa9, 0xf5, 0x05, 0xba, 0xb2, 0x6b, 0x56, 0x36, 0x89,
    0x3c, 0xfe, 0x33, 0x52, 0x91, 0x49, 0xd9, 0x6f, 0x79, 0x6c, 0xe1, 0xdf, 0xfe, 0x1f, 0x8d, 0xff,
    0xff, 0x69, 0xc3, 0x66, 0xc9, 0x9d, 0x34, 0x6b, 0xba, 0xc5, 0x6c, 0xa7, 0x82, 0x0f, 0x39, 0x69,
    0xf9, 0xad
};
#endif

PyTypeObject *init_QSGSimpleTextureNode(PyObject *module)
{
    if (SbkPySide6_QtQuickTypeStructs[SBK_QSGSimpleTextureNode_IDX].type != nullptr)
        return SbkPySide6_QtQuickTypeStructs[SBK_QSGSimpleTextureNode_IDX].type;

    Shiboken::AutoDecRef Sbk_QSGSimpleTextureNode_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometryNode_IDX]))));

    _Sbk_QSGSimpleTextureNode_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSGSimpleTextureNode",
        "QSGSimpleTextureNode*",
        &Sbk_QSGSimpleTextureNode_spec,
        &Shiboken::callCppDestructor< QSGSimpleTextureNode >,
        Sbk_QSGSimpleTextureNode_Type_bases.object(),
        0);
    auto *pyType = Sbk_QSGSimpleTextureNode_TypeF(); // references _Sbk_QSGSimpleTextureNode_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSGSimpleTextureNode_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSGSimpleTextureNode_SignatureBytes, QSGSimpleTextureNode_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSGSimpleTextureNode_PropertyStrings);
    SbkPySide6_QtQuickTypeStructs[SBK_QSGSimpleTextureNode_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSGSimpleTextureNode_PythonToCpp_QSGSimpleTextureNode_PTR,
        is_QSGSimpleTextureNode_PythonToCpp_QSGSimpleTextureNode_PTR_Convertible,
        QSGSimpleTextureNode_PTR_CppToPython_QSGSimpleTextureNode);

    Shiboken::Conversions::registerConverterName(converter, "QSGSimpleTextureNode");
    Shiboken::Conversions::registerConverterName(converter, "QSGSimpleTextureNode*");
    Shiboken::Conversions::registerConverterName(converter, "QSGSimpleTextureNode&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSGSimpleTextureNode).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QSGSimpleTextureNodeWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QSGSimpleTextureNode_TypeF(), &Sbk_QSGSimpleTextureNode_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QSGSimpleTextureNode_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'TextureCoordinatesTransformFlag'.
    const char *TextureCoordinatesTransformFlag_Initializer[] = {
        "NoTransform",
        "MirrorHorizontally",
        "MirrorVertically",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t TextureCoordinatesTransformFlag_InitializerValues[] = {
        uint8_t(QSGSimpleTextureNode::TextureCoordinatesTransformFlag::NoTransform),        //  0x00  0
        uint8_t(QSGSimpleTextureNode::TextureCoordinatesTransformFlag::MirrorHorizontally), //  0x01  1
        uint8_t(QSGSimpleTextureNode::TextureCoordinatesTransformFlag::MirrorVertically)    //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSGSimpleTextureNode_TypeF(),
        "2:PySide6.QtQuick.QSGSimpleTextureNode.TextureCoordinatesTransformFlag",
        TextureCoordinatesTransformFlag_Initializer, TextureCoordinatesTransformFlag_InitializerValues);
    SbkPySide6_QtQuickTypeStructs[SBK_QSGSimpleTextureNode_TextureCoordinatesTransformFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QSGSimpleTextureNode_TextureCoordinatesTransformFlag_IDX].type =
        EType;
    // Register converter for enum 'QSGSimpleTextureNode::TextureCoordinatesTransformFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSGSimpleTextureNode_TextureCoordinatesTransformFlag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QSGSimpleTextureNode_TextureCoordinatesTransformFlag,
            is_Enum_PythonToCpp_QSGSimpleTextureNode_TextureCoordinatesTransformFlag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QSGSimpleTextureNode::TextureCoordinatesTransformFlag");
        Shiboken::Conversions::registerConverterAlias(converter, "TextureCoordinatesTransformFlag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QSGSimpleTextureNode_TextureCoordinatesTransformFlag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QSGSimpleTextureNode_TextureCoordinatesTransformFlag,
            is_Enum_PythonToCpp_QSGSimpleTextureNode_TextureCoordinatesTransformFlag_Convertible);
        // Register converter for flag 'QFlags<QSGSimpleTextureNode::TextureCoordinatesTransformFlag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QSGSimpleTextureNode::TextureCoordinatesTransformFlag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QSGSimpleTextureNode::TextureCoordinatesTransformMode");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'TextureCoordinatesTransformFlag' enum/flags.

    qRegisterMetaType< ::QSGSimpleTextureNode *>();
    qRegisterMetaType< ::QSGSimpleTextureNode::TextureCoordinatesTransformFlag >("QSGSimpleTextureNode::TextureCoordinatesTransformFlag");

    return pyType;
}
