// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtquick_python.h"

// main header
#include "qsgtexturematerial_wrapper.h"

// Argument includes
#include <QtQuick/qsgmaterial.h>
#include <QtQuick/qsgmaterialshader.h>
#include <QtQuick/qsgmaterialtype.h>
#include <QtQuick/qsgrendererinterface.h>
#include <QtQuick/qsgtexture.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QSGTextureMaterialWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QSGTextureMaterialWrapper::QSGTextureMaterialWrapper()
{
}

int QSGTextureMaterialWrapper::compare(const ::QSGMaterial * other) const
{
    if (m_PyMethodCache[0])
        return this->::QSGOpaqueTextureMaterial::compare(other);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return 0;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "compare";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QSGOpaqueTextureMaterial::compare(other);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]), other)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]), other)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSGTextureMaterial", funcName);
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSGTextureMaterial", funcName, "int", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    int cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QSGMaterialShader * QSGTextureMaterialWrapper::createShader(::QSGRendererInterface::RenderMode renderMode) const
{
    if (m_PyMethodCache[1])
        return this->::QSGTextureMaterial::createShader(renderMode);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "createShader";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QSGTextureMaterial::createShader(renderMode);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_RenderMode_IDX])))->converter, &renderMode)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_RenderMode_IDX])))->converter, &renderMode)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSGTextureMaterial", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSGTextureMaterial", funcName, Shiboken::SbkType< QSGMaterialShader >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QSGMaterialShader *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QSGMaterialType * QSGTextureMaterialWrapper::type() const
{
    if (m_PyMethodCache[2])
        return this->::QSGTextureMaterial::type();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "type";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QSGTextureMaterial::type();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSGTextureMaterial", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialType_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSGTextureMaterial", funcName, Shiboken::SbkType< QSGMaterialType >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QSGMaterialType *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QSGTextureMaterialWrapper::~QSGTextureMaterialWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSGTextureMaterial_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSGTextureMaterial >()))
        return -1;

    QSGTextureMaterialWrapper *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtQuickTypeStructs[SBK_QSGTextureMaterial_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QSGTextureMaterial()
        cptr = new QSGTextureMaterialWrapper();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QSGTextureMaterial >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSGTextureMaterialFunc_createShader(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGTextureMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTextureMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGMaterial::createShader(QSGRendererInterface::RenderMode)const->QSGMaterialShader*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_RenderMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // createShader(QSGRendererInterface::RenderMode)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "createShader", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGTextureMaterial_IDX]);

    // Call function/method
    {
        ::QSGRendererInterface::RenderMode cppArg0{QSGRendererInterface::RenderMode2D};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createShader(QSGRendererInterface::RenderMode)const
            QSGMaterialShader * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QSGTextureMaterial *>(cppSelf)->::QSGTextureMaterial::createShader(cppArg0)
                : const_cast<const ::QSGTextureMaterial *>(cppSelf)->createShader(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGTextureMaterialFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGTextureMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTextureMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        QSGMaterialType * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QSGTextureMaterial *>(cppSelf)->::QSGTextureMaterial::type()
            : const_cast<const ::QSGTextureMaterial *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialType_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QSGTextureMaterial_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSGTextureMaterial_methods[] = {
    {"createShader", reinterpret_cast<PyCFunction>(Sbk_QSGTextureMaterialFunc_createShader), METH_O, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QSGTextureMaterialFunc_type), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QSGTextureMaterial_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QSGTextureMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTextureMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QSGTextureMaterialWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QSGTextureMaterial_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSGTextureMaterial_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSGTextureMaterial_Type = nullptr;
static PyTypeObject *Sbk_QSGTextureMaterial_TypeF(void)
{
    return _Sbk_QSGTextureMaterial_Type;
}

static PyType_Slot Sbk_QSGTextureMaterial_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QSGTextureMaterial_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSGTextureMaterial_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSGTextureMaterial_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSGTextureMaterial_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSGTextureMaterial_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSGTextureMaterial_spec = {
    "2:PySide6.QtQuick.QSGTextureMaterial",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSGTextureMaterial_slots
};

} //extern "C"

static void *Sbk_QSGTextureMaterial_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QSGMaterial >())
        return dynamic_cast< ::QSGTextureMaterial *>(reinterpret_cast< ::QSGMaterial *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSGTextureMaterial_PythonToCpp_QSGTextureMaterial_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSGTextureMaterial_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSGTextureMaterial_PythonToCpp_QSGTextureMaterial_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSGTextureMaterial_TypeF()))
        return QSGTextureMaterial_PythonToCpp_QSGTextureMaterial_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSGTextureMaterial_PTR_CppToPython_QSGTextureMaterial(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QSGTextureMaterial *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QSGTextureMaterial_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSGTextureMaterial_SignatureStrings[] = {
    "PySide6.QtQuick.QSGTextureMaterial(self)",
    "PySide6.QtQuick.QSGTextureMaterial.createShader(self,renderMode:PySide6.QtQuick.QSGRendererInterface.RenderMode)->PySide6.QtQuick.QSGMaterialShader",
    "PySide6.QtQuick.QSGTextureMaterial.type(self)->PySide6.QtQuick.QSGMaterialType",
    nullptr}; // Sentinel
#else
static constexpr size_t QSGTextureMaterial_SignatureByteSize = 120;
static constexpr uint8_t QSGTextureMaterial_SignatureBytes[120] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x09, 0x2c, 0xcd, 0x4c,
    0xce, 0xd6, 0x0b, 0x0c, 0x76, 0x0f, 0x49, 0xad, 0x28, 0x29, 0x2d, 0x4a, 0xf5, 0x4d, 0x2c, 0x49,
    0x2d, 0xca, 0x4c, 0xcc, 0xd1, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0xe4, 0x0a, 0x20, 0xa8, 0x50, 0x2f,
    0xb9, 0x28, 0x15, 0xc8, 0x0c, 0xce, 0x48, 0x4c, 0x49, 0x2d, 0x02, 0xeb, 0xd2, 0x29, 0x4a, 0xcd,
    0x03, 0xb2, 0x7d, 0xf3, 0x53, 0x52, 0xad, 0xb0, 0xe8, 0x0f, 0x02, 0xcb, 0xa6, 0x16, 0x79, 0xe6,
    0x01, 0x0d, 0x48, 0x4b, 0x4c, 0x4e, 0xd5, 0x0b, 0x82, 0xab, 0xd7, 0xd4, 0xb5, 0xc3, 0xa2, 0x03,
    0x66, 0x15, 0xc4, 0x0e, 0x62, 0xdc, 0x54, 0x52, 0x59, 0x90, 0x0a, 0xf1, 0x01, 0x5e, 0x03, 0x43,
    0x80, 0xca, 0xb8, 0x00, 0x41, 0x2e, 0x61, 0x1a
};
#endif

PyTypeObject *init_QSGTextureMaterial(PyObject *module)
{
    if (SbkPySide6_QtQuickTypeStructs[SBK_QSGTextureMaterial_IDX].type != nullptr)
        return SbkPySide6_QtQuickTypeStructs[SBK_QSGTextureMaterial_IDX].type;

    Shiboken::AutoDecRef Sbk_QSGTextureMaterial_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGOpaqueTextureMaterial_IDX]))));

    _Sbk_QSGTextureMaterial_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSGTextureMaterial",
        "QSGTextureMaterial*",
        &Sbk_QSGTextureMaterial_spec,
        &Shiboken::callCppDestructor< QSGTextureMaterial >,
        Sbk_QSGTextureMaterial_Type_bases.object(),
        0);
    auto *pyType = Sbk_QSGTextureMaterial_TypeF(); // references _Sbk_QSGTextureMaterial_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSGTextureMaterial_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSGTextureMaterial_SignatureBytes, QSGTextureMaterial_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSGTextureMaterial_PropertyStrings);
    SbkPySide6_QtQuickTypeStructs[SBK_QSGTextureMaterial_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSGTextureMaterial_PythonToCpp_QSGTextureMaterial_PTR,
        is_QSGTextureMaterial_PythonToCpp_QSGTextureMaterial_PTR_Convertible,
        QSGTextureMaterial_PTR_CppToPython_QSGTextureMaterial);

    Shiboken::Conversions::registerConverterName(converter, "QSGTextureMaterial");
    Shiboken::Conversions::registerConverterName(converter, "QSGTextureMaterial*");
    Shiboken::Conversions::registerConverterName(converter, "QSGTextureMaterial&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSGTextureMaterial).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QSGTextureMaterialWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QSGTextureMaterial_TypeF(), &Sbk_QSGTextureMaterial_typeDiscovery);

    qRegisterMetaType< ::QSGTextureMaterial *>();

    return pyType;
}
