// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtquick3d_python.h"

// main header
#include "qquick3dgeometry_attribute_wrapper.h"

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QQuick3DGeometry_Attribute_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QQuick3DGeometry::Attribute >()))
        return -1;

    ::QQuick3DGeometry::Attribute *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "Attribute", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: Attribute::Attribute()
    // 1: Attribute::Attribute(QQuick3DGeometry::Attribute)
    if (numArgs == 0) {
        overloadId = 0; // Attribute()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DGeometry_Attribute_IDX]), (pyArgs[0])))) {
        overloadId = 1; // Attribute(QQuick3DGeometry::Attribute)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DGeometry_Attribute_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DGeometry_Attribute_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // Attribute()
        {

            // Attribute()
            cptr = new ::QQuick3DGeometry::Attribute();
            break;
        }
        case 1: // Attribute(const QQuick3DGeometry::Attribute &Attribute)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QQuick3DGeometry::Attribute cppArg0_local;
            ::QQuick3DGeometry::Attribute *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // Attribute(QQuick3DGeometry::Attribute)
                cptr = new ::QQuick3DGeometry::Attribute(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QQuick3DGeometry::Attribute >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DGeometry_Attribute_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QQuick3DGeometry_Attribute__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QQuick3DGeometry::Attribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DGeometry_Attribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DGeometry_Attribute_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QQuick3DGeometry_Attribute_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QQuick3DGeometry_Attribute_EnumFlagInfo[] = {
    "ComponentType:Enum",
    "Semantic:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QQuick3DGeometry_Attribute_methods[] = {
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QQuick3DGeometry_Attribute__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QQuick3DGeometry_Attribute_get_semantic(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuick3DGeometry::Attribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DGeometry_Attribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::QQuick3DGeometry::Attribute::Semantic cppOut_local = cppSelf->semantic;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DGeometry_Attribute_Semantic_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QQuick3DGeometry_Attribute_set_semantic(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QQuick3DGeometry::Attribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DGeometry_Attribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("semantic");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DGeometry_Attribute_Semantic_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("semantic", "Semantic");
        return -1;
    }

    auto cppOut_local = cppSelf->semantic;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->semantic = cppOut_local;

    return 0;
}

static PyObject *Sbk_QQuick3DGeometry_Attribute_get_offset(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuick3DGeometry::Attribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DGeometry_Attribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int cppOut_local = cppSelf->offset;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QQuick3DGeometry_Attribute_set_offset(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QQuick3DGeometry::Attribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DGeometry_Attribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("offset");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("offset", "int");
        return -1;
    }

    auto cppOut_local = cppSelf->offset;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->offset = cppOut_local;

    return 0;
}

static PyObject *Sbk_QQuick3DGeometry_Attribute_get_componentType(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuick3DGeometry::Attribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DGeometry_Attribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::QQuick3DGeometry::Attribute::ComponentType cppOut_local = cppSelf->componentType;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DGeometry_Attribute_ComponentType_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QQuick3DGeometry_Attribute_set_componentType(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QQuick3DGeometry::Attribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DGeometry_Attribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("componentType");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DGeometry_Attribute_ComponentType_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("componentType", "ComponentType");
        return -1;
    }

    auto cppOut_local = cppSelf->componentType;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->componentType = cppOut_local;

    return 0;
}

// Getters and Setters for Attribute
static PyGetSetDef Sbk_QQuick3DGeometry_Attribute_getsetlist[] = {
    {const_cast<char *>("semantic"), Sbk_QQuick3DGeometry_Attribute_get_semantic, Sbk_QQuick3DGeometry_Attribute_set_semantic, nullptr, nullptr},
    {const_cast<char *>("offset"), Sbk_QQuick3DGeometry_Attribute_get_offset, Sbk_QQuick3DGeometry_Attribute_set_offset, nullptr, nullptr},
    {const_cast<char *>("componentType"), Sbk_QQuick3DGeometry_Attribute_get_componentType, Sbk_QQuick3DGeometry_Attribute_set_componentType, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QQuick3DGeometry_Attribute_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QQuick3DGeometry_Attribute_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QQuick3DGeometry_Attribute_Type = nullptr;
static PyTypeObject *Sbk_QQuick3DGeometry_Attribute_TypeF(void)
{
    return _Sbk_QQuick3DGeometry_Attribute_Type;
}

static PyType_Slot Sbk_QQuick3DGeometry_Attribute_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QQuick3DGeometry_Attribute_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QQuick3DGeometry_Attribute_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QQuick3DGeometry_Attribute_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QQuick3DGeometry_Attribute_getsetlist)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QQuick3DGeometry_Attribute_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QQuick3DGeometry_Attribute_spec = {
    "2:PySide6.QtQuick3D.QQuick3DGeometry.Attribute",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QQuick3DGeometry_Attribute_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QQuick3DGeometry_Attribute_Semantic(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QQuick3DGeometry::Attribute::Semantic>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QQuick3DGeometry::Attribute::Semantic *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QQuick3DGeometry_Attribute_Semantic_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DGeometry_Attribute_Semantic_IDX])))
        return Enum_PythonToCpp_QQuick3DGeometry_Attribute_Semantic;
    return {};
}

static PyObject *QQuick3DGeometry_Attribute_Semantic_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QQuick3DGeometry::Attribute::Semantic>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QQuick3DGeometry::Attribute::Semantic *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DGeometry_Attribute_Semantic_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QQuick3DGeometry_Attribute_ComponentType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QQuick3DGeometry::Attribute::ComponentType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QQuick3DGeometry::Attribute::ComponentType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QQuick3DGeometry_Attribute_ComponentType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DGeometry_Attribute_ComponentType_IDX])))
        return Enum_PythonToCpp_QQuick3DGeometry_Attribute_ComponentType;
    return {};
}

static PyObject *QQuick3DGeometry_Attribute_ComponentType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QQuick3DGeometry::Attribute::ComponentType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QQuick3DGeometry::Attribute::ComponentType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DGeometry_Attribute_ComponentType_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void Attribute_PythonToCpp_Attribute_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QQuick3DGeometry_Attribute_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_Attribute_PythonToCpp_Attribute_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QQuick3DGeometry_Attribute_TypeF()))
        return Attribute_PythonToCpp_Attribute_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *Attribute_PTR_CppToPython_Attribute(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QQuick3DGeometry_Attribute_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *Attribute_COPY_CppToPython_Attribute(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QQuick3DGeometry::Attribute *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QQuick3DGeometry_Attribute_TypeF(), new ::QQuick3DGeometry::Attribute(*source), true, true);
}

// Python to C++ copy conversion.
static void Attribute_PythonToCpp_Attribute_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QQuick3DGeometry::Attribute *>(cppOut) = *reinterpret_cast< ::QQuick3DGeometry::Attribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DGeometry_Attribute_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_Attribute_PythonToCpp_Attribute_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QQuick3DGeometry_Attribute_TypeF()))
        return Attribute_PythonToCpp_Attribute_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QQuick3DGeometry_Attribute_SignatureStrings[] = {
    "1:PySide6.QtQuick3D.QQuick3DGeometry.Attribute(self)",
    "0:PySide6.QtQuick3D.QQuick3DGeometry.Attribute(self,Attribute:PySide6.QtQuick3D.QQuick3DGeometry.Attribute)",
    "PySide6.QtQuick3D.QQuick3DGeometry.Attribute.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QQuick3DGeometry_Attribute_SignatureByteSize = 92;
static constexpr uint8_t QQuick3DGeometry_Attribute_SignatureBytes[92] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x09, 0x2c,
    0xcd, 0x4c, 0xce, 0x36, 0x76, 0xd1, 0x0b, 0x84, 0x32, 0xdc, 0x53, 0xf3, 0x73, 0x53, 0x4b, 0x8a,
    0x2a, 0xf5, 0x1c, 0x4b, 0x4a, 0x8a, 0x32, 0x93, 0x4a, 0x4b, 0x52, 0x35, 0x8a, 0x53, 0x73, 0xd2,
    0x34, 0xb9, 0x0c, 0x48, 0xd7, 0xa4, 0x03, 0xe7, 0x92, 0xa4, 0x57, 0x93, 0x8b, 0x14, 0xd5, 0x7a,
    0xf1, 0xf1, 0xc9, 0xf9, 0x05, 0x95, 0xf1, 0xf1, 0x10, 0x77, 0xea, 0xda, 0x95, 0x54, 0x16, 0x64,
    0xe6, 0xa5, 0xeb, 0x05, 0x03, 0x79, 0x5c, 0x00, 0xf8, 0x6d, 0x53, 0x52
};
#endif

PyTypeObject *init_QQuick3DGeometry_Attribute(PyObject *enclosingClass)
{
    if (SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DGeometry_Attribute_IDX].type != nullptr)
        return SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DGeometry_Attribute_IDX].type;

    Shiboken::AutoDecRef Sbk_QQuick3DGeometry_Attribute_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QQuick3DGeometry_Attribute_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "Attribute",
        "QQuick3DGeometry::Attribute",
        &Sbk_QQuick3DGeometry_Attribute_spec,
        &Shiboken::callCppDestructor< ::QQuick3DGeometry::Attribute >,
        Sbk_QQuick3DGeometry_Attribute_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass | Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QQuick3DGeometry_Attribute_TypeF(); // references _Sbk_QQuick3DGeometry_Attribute_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QQuick3DGeometry_Attribute_SignatureStrings);
#else
    InitSignatureBytes(pyType, QQuick3DGeometry_Attribute_SignatureBytes, QQuick3DGeometry_Attribute_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QQuick3DGeometry_Attribute_PropertyStrings);
    SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DGeometry_Attribute_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        Attribute_PythonToCpp_Attribute_PTR,
        is_Attribute_PythonToCpp_Attribute_PTR_Convertible,
        Attribute_PTR_CppToPython_Attribute,
        Attribute_COPY_CppToPython_Attribute);

    Shiboken::Conversions::registerConverterName(converter, "QQuick3DGeometry::Attribute");
    Shiboken::Conversions::registerConverterName(converter, "QQuick3DGeometry::Attribute*");
    Shiboken::Conversions::registerConverterName(converter, "QQuick3DGeometry::Attribute&");
    Shiboken::Conversions::registerConverterAlias(converter, "Attribute");
    Shiboken::Conversions::registerConverterAlias(converter, "Attribute*");
    Shiboken::Conversions::registerConverterAlias(converter, "Attribute&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QQuick3DGeometry::Attribute).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        Attribute_PythonToCpp_Attribute_COPY,
        is_Attribute_PythonToCpp_Attribute_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QQuick3DGeometry_Attribute_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Semantic'.
    const char *Semantic_Initializer[] = {
        "IndexSemantic",
        "PositionSemantic",
        "NormalSemantic",
        "TexCoordSemantic",
        "TangentSemantic",
        "BinormalSemantic",
        "JointSemantic",
        "WeightSemantic",
        "ColorSemantic",
        "TargetPositionSemantic",
        "TargetNormalSemantic",
        "TargetTangentSemantic",
        "TargetBinormalSemantic",
        "TexCoord1Semantic",
        "TexCoord0Semantic",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Semantic_InitializerValues[] = {
        uint8_t(QQuick3DGeometry::Attribute::Semantic::IndexSemantic),          //  0x00  0
        uint8_t(QQuick3DGeometry::Attribute::Semantic::PositionSemantic),       //  0x01  1
        uint8_t(QQuick3DGeometry::Attribute::Semantic::NormalSemantic),         //  0x02  2
        uint8_t(QQuick3DGeometry::Attribute::Semantic::TexCoordSemantic),       //  0x03  3
        uint8_t(QQuick3DGeometry::Attribute::Semantic::TangentSemantic),        //  0x04  4
        uint8_t(QQuick3DGeometry::Attribute::Semantic::BinormalSemantic),       //  0x05  5
        uint8_t(QQuick3DGeometry::Attribute::Semantic::JointSemantic),          //  0x06  6
        uint8_t(QQuick3DGeometry::Attribute::Semantic::WeightSemantic),         //  0x07  7
        uint8_t(QQuick3DGeometry::Attribute::Semantic::ColorSemantic),          //  0x08  8
        uint8_t(QQuick3DGeometry::Attribute::Semantic::TargetPositionSemantic), //  0x09  9
        uint8_t(QQuick3DGeometry::Attribute::Semantic::TargetNormalSemantic),   //  0x0a  10
        uint8_t(QQuick3DGeometry::Attribute::Semantic::TargetTangentSemantic),  //  0x0b  11
        uint8_t(QQuick3DGeometry::Attribute::Semantic::TargetBinormalSemantic), //  0x0c  12
        uint8_t(QQuick3DGeometry::Attribute::Semantic::TexCoord1Semantic),      //  0x0d  13
        uint8_t(QQuick3DGeometry::Attribute::Semantic::TexCoord0Semantic)       //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QQuick3DGeometry_Attribute_TypeF(),
        "2:PySide6.QtQuick3D.QQuick3DGeometry.Attribute.Semantic",
        Semantic_Initializer, Semantic_InitializerValues);
    SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DGeometry_Attribute_Semantic_IDX].type = EType;
    // Register converter for enum 'QQuick3DGeometry::Attribute::Semantic'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QQuick3DGeometry_Attribute_Semantic_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QQuick3DGeometry_Attribute_Semantic,
            is_Enum_PythonToCpp_QQuick3DGeometry_Attribute_Semantic_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QQuick3DGeometry::Attribute::Semantic");
        Shiboken::Conversions::registerConverterAlias(converter, "Attribute::Semantic");
        Shiboken::Conversions::registerConverterAlias(converter, "Semantic");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Semantic' enum.

    // Initialization of enum 'ComponentType'.
    const char *ComponentType_Initializer[] = {
        "U16Type",
        "U32Type",
        "I32Type",
        "F32Type",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ComponentType_InitializerValues[] = {
        uint8_t(QQuick3DGeometry::Attribute::ComponentType::U16Type), //  0x00  0
        uint8_t(QQuick3DGeometry::Attribute::ComponentType::U32Type), //  0x01  1
        uint8_t(QQuick3DGeometry::Attribute::ComponentType::I32Type), //  0x02  2
        uint8_t(QQuick3DGeometry::Attribute::ComponentType::F32Type)  //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QQuick3DGeometry_Attribute_TypeF(),
        "2:PySide6.QtQuick3D.QQuick3DGeometry.Attribute.ComponentType",
        ComponentType_Initializer, ComponentType_InitializerValues);
    SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DGeometry_Attribute_ComponentType_IDX].type = EType;
    // Register converter for enum 'QQuick3DGeometry::Attribute::ComponentType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QQuick3DGeometry_Attribute_ComponentType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QQuick3DGeometry_Attribute_ComponentType,
            is_Enum_PythonToCpp_QQuick3DGeometry_Attribute_ComponentType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QQuick3DGeometry::Attribute::ComponentType");
        Shiboken::Conversions::registerConverterAlias(converter, "Attribute::ComponentType");
        Shiboken::Conversions::registerConverterAlias(converter, "ComponentType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ComponentType' enum.

    qRegisterMetaType< ::QQuick3DGeometry::Attribute >("Attribute");
    qRegisterMetaType< ::QQuick3DGeometry::Attribute >("QQuick3DGeometry::Attribute");
    qRegisterMetaType< ::QQuick3DGeometry::Attribute::Semantic >("Attribute::Semantic");
    qRegisterMetaType< ::QQuick3DGeometry::Attribute::Semantic >("QQuick3DGeometry::Attribute::Semantic");
    qRegisterMetaType< ::QQuick3DGeometry::Attribute::ComponentType >("Attribute::ComponentType");
    qRegisterMetaType< ::QQuick3DGeometry::Attribute::ComponentType >("QQuick3DGeometry::Attribute::ComponentType");

    return pyType;
}
