// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtquick3d_python.h"

// main header
#include "qquick3dinstancing_wrapper.h"

// inner classes
#include "qquick3dinstancing_instancetableentry_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtGui/qcolor.h>
#include <QtGui/qquaternion.h>
#include <QtGui/qvectornd.h>
#include <QtQuick3D/qquick3dinstancing.h>
#include <QtQuick3D/qquick3dobject.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QQuick3DInstancingWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QQuick3DInstancingWrapper::QQuick3DInstancingWrapper(::QQuick3DObject * parent) : QQuick3DInstancing(parent)
{
}

void QQuick3DInstancingWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuick3DInstancing", funcName);
        return;
    }
}

void QQuick3DInstancingWrapper::classBegin()
{
    if (m_PyMethodCache[1]) {
        return this->::QQuick3DObject::classBegin();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "classBegin";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QQuick3DObject::classBegin();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuick3DInstancing", funcName);
        return;
    }
}

void QQuick3DInstancingWrapper::componentComplete()
{
    if (m_PyMethodCache[2]) {
        return this->::QQuick3DObject::componentComplete();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "componentComplete";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QQuick3DObject::componentComplete();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuick3DInstancing", funcName);
        return;
    }
}

void QQuick3DInstancingWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuick3DInstancing", funcName);
        return;
    }
}

void QQuick3DInstancingWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[4]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuick3DInstancing", funcName);
        return;
    }
}

void QQuick3DInstancingWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[5]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuick3DInstancing", funcName);
        return;
    }
}

bool QQuick3DInstancingWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[6])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuick3DInstancing", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QQuick3DInstancing", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QQuick3DInstancingWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[7])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[7] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuick3DInstancing", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QQuick3DInstancing", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QByteArray QQuick3DInstancingWrapper::getInstanceBuffer(int * instanceCount)
{
    if (m_PyMethodCache[8]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QQuick3DInstancing.getInstanceBuffer");
        return {};
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return {};
    static PyObject *nameCache[2] = {};
    static const char *funcName = "getInstanceBuffer";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[8] = true;
        Shiboken::Errors::setPureVirtualMethodError("QQuick3DInstancing.getInstanceBuffer");
        return {};
    }

    // Begin code injection
    // ========================================================================
    // START of custom code block [file: ../glue/qtquick3d.cpp (qquick3dinstancing-getinstancebuffer-virtual-redirect)]
    std::pair<QByteArray, int> resultPair = getInstanceBufferOverride(gil, pyOverride.object());
    if (instanceCount != nullptr)
        *instanceCount = resultPair.second;
    return resultPair.first;
    // END of custom code block [file: ../glue/qtquick3d.cpp (qquick3dinstancing-getinstancebuffer-virtual-redirect)]
    // ========================================================================
    // End of code injection

    SBK_UNUSED(instanceCount)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuick3DInstancing", funcName);
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QQuick3DInstancing", funcName, Shiboken::SbkType< QByteArray >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QByteArray cppResult;
    pythonToCpp(pyResult, &cppResult);

    return cppResult;
}

void QQuick3DInstancingWrapper::markAllDirty()
{
    if (m_PyMethodCache[9]) {
        return this->::QQuick3DObject::markAllDirty();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "markAllDirty";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[9] = true;
        gil.release();
        return this->::QQuick3DObject::markAllDirty();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuick3DInstancing", funcName);
        return;
    }
}

void QQuick3DInstancingWrapper::preSync()
{
    if (m_PyMethodCache[10]) {
        return this->::QQuick3DObject::preSync();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "preSync";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[10] = true;
        gil.release();
        return this->::QQuick3DObject::preSync();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuick3DInstancing", funcName);
        return;
    }
}

void QQuick3DInstancingWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[11]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[11] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuick3DInstancing", funcName);
        return;
    }
}

const QMetaObject *QQuick3DInstancingWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QQuick3DInstancing::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QQuick3DInstancingWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QQuick3DInstancing::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QQuick3DInstancingWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QQuick3DInstancingWrapper *>(this));
    return QQuick3DInstancing::qt_metacast(_clname);
}

QQuick3DInstancingWrapper::~QQuick3DInstancingWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

::std::pair<QByteArray,int> QQuick3DInstancingWrapper::getInstanceBufferOverride(Shiboken::GilState &gil, PyObject *pyOverride)
{
    SBK_UNUSED(gil)
    static const char *funcName = "getInstanceBufferOverride";
#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuick3DInstancing", funcName);
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtQuick3DTypeConverters[SBK_QtQuick3D_std_pair_QByteArray_int_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QQuick3DInstancing", funcName, "tuple", Py_TYPE(pyResult)->tp_name);
        return {};
    }
    std::pair<QByteArray,int> cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QQuick3DInstancing_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DInstancing_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QQuick3DInstancing");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QQuick3DInstancing >()))
        return -1;

    QQuick3DInstancingWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QQuick3DInstancing", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QQuick3DInstancing::QQuick3DInstancing(QQuick3DObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QQuick3DInstancing(QQuick3DObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QQuick3DInstancing(QQuick3DObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DInstancing_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DInstancing_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DInstancing_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DObject_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DInstancing_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                // fall through to handle extra keyword signals and properties
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QQuick3DObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QQuick3DInstancing(QQuick3DObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QQuick3DInstancingWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QQuick3DInstancingWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QQuick3DInstancing >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DInstancing_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DInstancing_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QQuick3DInstancingFunc_calculateTableEntry(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 4, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "calculateTableEntry", errInfo, SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DInstancing_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOO:calculateTableEntry", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QQuick3DInstancing::calculateTableEntry(QVector3D,QVector3D,QVector3D,QColor,const QVector4D&=)->QQuick3DInstancing::InstanceTableEntry
    if (numArgs >= 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArgs[3])))) {
        if (numArgs == 4) {
            overloadId = 0; // calculateTableEntry(QVector3D,QVector3D,QVector3D,QColor,QVector4D)
        } else if (numArgs >= 5
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), (pyArgs[4])))) {
            overloadId = 0; // calculateTableEntry(QVector3D,QVector3D,QVector3D,QColor,QVector4D)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "calculateTableEntry", errInfo, SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DInstancing_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_customData = Shiboken::String::createStaticString("customData");
            if (PyDict_Contains(kwds, key_customData) != 0) {
                value = PyDict_GetItem(kwds, key_customData);
                if (value != nullptr && pyArgs[4] != nullptr ) {
                    errInfo.reset(key_customData);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "calculateTableEntry", errInfo, SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DInstancing_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[4] = value;
                    if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), (pyArgs[4]))))
                        return Shiboken::returnWrongArguments(args, "calculateTableEntry", errInfo, SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DInstancing_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_customData);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "calculateTableEntry", errInfo, SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DInstancing_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QVector3D cppArg0_local;
        ::QVector3D *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QVector3D cppArg1_local;
        ::QVector3D *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QVector3D cppArg2_local;
        ::QVector3D *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2].isValue())
            pythonToCpp[2](pyArgs[2], &cppArg2_local);
        else
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (!Shiboken::Object::isValid(pyArgs[3]))
            return {};
        ::QColor cppArg3_local;
        ::QColor *cppArg3 = &cppArg3_local;
        if (pythonToCpp[3].isValue())
            pythonToCpp[3](pyArgs[3], &cppArg3_local);
        else
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (!Shiboken::Object::isValid(pyArgs[4]))
            return {};
        ::QVector4D cppArg4_local{};
        ::QVector4D *cppArg4 = &cppArg4_local;
        if (pythonToCpp[4]) {
            if (pythonToCpp[4].isValue())
                pythonToCpp[4](pyArgs[4], &cppArg4_local);
            else
                pythonToCpp[4](pyArgs[4], &cppArg4);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // calculateTableEntry(QVector3D,QVector3D,QVector3D,QColor,QVector4D)
            QQuick3DInstancing::InstanceTableEntry cppResult = ::QQuick3DInstancing::calculateTableEntry(*cppArg0, *cppArg1, *cppArg2, *cppArg3, *cppArg4);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DInstancing_InstanceTableEntry_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuick3DInstancingFunc_calculateTableEntryFromQuaternion(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 4, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "calculateTableEntryFromQuaternion", errInfo, SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DInstancing_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOO:calculateTableEntryFromQuaternion", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QQuick3DInstancing::calculateTableEntryFromQuaternion(QVector3D,QVector3D,QQuaternion,QColor,const QVector4D&=)->QQuick3DInstancing::InstanceTableEntry
    if (numArgs >= 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArgs[3])))) {
        if (numArgs == 4) {
            overloadId = 0; // calculateTableEntryFromQuaternion(QVector3D,QVector3D,QQuaternion,QColor,QVector4D)
        } else if (numArgs >= 5
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), (pyArgs[4])))) {
            overloadId = 0; // calculateTableEntryFromQuaternion(QVector3D,QVector3D,QQuaternion,QColor,QVector4D)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "calculateTableEntryFromQuaternion", errInfo, SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DInstancing_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_customData = Shiboken::String::createStaticString("customData");
            if (PyDict_Contains(kwds, key_customData) != 0) {
                value = PyDict_GetItem(kwds, key_customData);
                if (value != nullptr && pyArgs[4] != nullptr ) {
                    errInfo.reset(key_customData);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "calculateTableEntryFromQuaternion", errInfo, SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DInstancing_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[4] = value;
                    if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), (pyArgs[4]))))
                        return Shiboken::returnWrongArguments(args, "calculateTableEntryFromQuaternion", errInfo, SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DInstancing_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_customData);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "calculateTableEntryFromQuaternion", errInfo, SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DInstancing_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QVector3D cppArg0_local;
        ::QVector3D *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QVector3D cppArg1_local;
        ::QVector3D *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QQuaternion cppArg2_local;
        ::QQuaternion *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2].isValue())
            pythonToCpp[2](pyArgs[2], &cppArg2_local);
        else
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (!Shiboken::Object::isValid(pyArgs[3]))
            return {};
        ::QColor cppArg3_local;
        ::QColor *cppArg3 = &cppArg3_local;
        if (pythonToCpp[3].isValue())
            pythonToCpp[3](pyArgs[3], &cppArg3_local);
        else
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (!Shiboken::Object::isValid(pyArgs[4]))
            return {};
        ::QVector4D cppArg4_local{};
        ::QVector4D *cppArg4 = &cppArg4_local;
        if (pythonToCpp[4]) {
            if (pythonToCpp[4].isValue())
                pythonToCpp[4](pyArgs[4], &cppArg4_local);
            else
                pythonToCpp[4](pyArgs[4], &cppArg4);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // calculateTableEntryFromQuaternion(QVector3D,QVector3D,QQuaternion,QColor,QVector4D)
            QQuick3DInstancing::InstanceTableEntry cppResult = ::QQuick3DInstancing::calculateTableEntryFromQuaternion(*cppArg0, *cppArg1, *cppArg2, *cppArg3, *cppArg4);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DInstancing_InstanceTableEntry_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuick3DInstancingFunc_depthSortingEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuick3DInstancing *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DInstancing_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // depthSortingEnabled()const
        bool cppResult = const_cast<const ::QQuick3DInstancing *>(cppSelf)->depthSortingEnabled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuick3DInstancingFunc_getInstanceBuffer(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuick3DInstancing *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DInstancing_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // getInstanceBuffer(int*)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QQuick3DInstancing.getInstanceBuffer");
                return {};
            }
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtquick3d.cpp (qquick3dinstancing-getinstancebuffer-return)]
            int count{};
            ::QByteArray retval_ = cppSelf->getInstanceBuffer(&count);
            pyResult = PyTuple_New(2);
            PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &retval_));
            PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &count));
            // END of custom code block [file: ../glue/qtquick3d.cpp (qquick3dinstancing-getinstancebuffer-return)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuick3DInstancingFunc_hasTransparency(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuick3DInstancing *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DInstancing_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hasTransparency()const
        bool cppResult = const_cast<const ::QQuick3DInstancing *>(cppSelf)->hasTransparency();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuick3DInstancingFunc_instanceBuffer(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuick3DInstancing *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DInstancing_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuick3DInstancing::instanceBuffer(int*)->QByteArray
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // instanceBuffer(int*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "instanceBuffer", errInfo, SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DInstancing_IDX]);

    // Call function/method
    {
        int *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // instanceBuffer(int*)
            QByteArray cppResult = cppSelf->instanceBuffer(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuick3DInstancingFunc_instanceColor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuick3DInstancing *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DInstancing_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuick3DInstancing::instanceColor(int)->QColor
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // instanceColor(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "instanceColor", errInfo, SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DInstancing_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // instanceColor(int)
            QColor cppResult = cppSelf->instanceColor(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuick3DInstancingFunc_instanceCountOverride(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuick3DInstancing *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DInstancing_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // instanceCountOverride()const
        int cppResult = const_cast<const ::QQuick3DInstancing *>(cppSelf)->instanceCountOverride();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuick3DInstancingFunc_instanceCustomData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuick3DInstancing *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DInstancing_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuick3DInstancing::instanceCustomData(int)->QVector4D
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // instanceCustomData(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "instanceCustomData", errInfo, SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DInstancing_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // instanceCustomData(int)
            QVector4D cppResult = cppSelf->instanceCustomData(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuick3DInstancingFunc_instancePosition(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuick3DInstancing *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DInstancing_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuick3DInstancing::instancePosition(int)->QVector3D
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // instancePosition(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "instancePosition", errInfo, SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DInstancing_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // instancePosition(int)
            QVector3D cppResult = cppSelf->instancePosition(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuick3DInstancingFunc_instanceRotation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuick3DInstancing *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DInstancing_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuick3DInstancing::instanceRotation(int)->QQuaternion
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // instanceRotation(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "instanceRotation", errInfo, SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DInstancing_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // instanceRotation(int)
            QQuaternion cppResult = cppSelf->instanceRotation(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuick3DInstancingFunc_instanceScale(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuick3DInstancing *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DInstancing_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuick3DInstancing::instanceScale(int)->QVector3D
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // instanceScale(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "instanceScale", errInfo, SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DInstancing_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // instanceScale(int)
            QVector3D cppResult = cppSelf->instanceScale(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuick3DInstancingFunc_markDirty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuick3DInstancing *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DInstancing_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // markDirty()
        cppSelf->markDirty();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuick3DInstancingFunc_setDepthSortingEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuick3DInstancing *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DInstancing_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuick3DInstancing::setDepthSortingEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setDepthSortingEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDepthSortingEnabled", errInfo, SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DInstancing_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDepthSortingEnabled(bool)
            cppSelf->setDepthSortingEnabled(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuick3DInstancingFunc_setHasTransparency(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuick3DInstancing *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DInstancing_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuick3DInstancing::setHasTransparency(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setHasTransparency(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHasTransparency", errInfo, SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DInstancing_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHasTransparency(bool)
            cppSelf->setHasTransparency(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuick3DInstancingFunc_setInstanceCountOverride(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuick3DInstancing *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DInstancing_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuick3DInstancing::setInstanceCountOverride(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setInstanceCountOverride(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setInstanceCountOverride", errInfo, SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DInstancing_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setInstanceCountOverride(int)
            cppSelf->setInstanceCountOverride(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QQuick3DInstancing_PropertyStrings[] = {
    "depthSortingEnabled::",
    "hasTransparency::",
    "instanceCountOverride::",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QQuick3DInstancing_methods[] = {
    {"calculateTableEntry", reinterpret_cast<PyCFunction>(Sbk_QQuick3DInstancingFunc_calculateTableEntry), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"calculateTableEntryFromQuaternion", reinterpret_cast<PyCFunction>(Sbk_QQuick3DInstancingFunc_calculateTableEntryFromQuaternion), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"depthSortingEnabled", reinterpret_cast<PyCFunction>(Sbk_QQuick3DInstancingFunc_depthSortingEnabled), METH_NOARGS, nullptr},
    {"getInstanceBuffer", reinterpret_cast<PyCFunction>(Sbk_QQuick3DInstancingFunc_getInstanceBuffer), METH_NOARGS, nullptr},
    {"hasTransparency", reinterpret_cast<PyCFunction>(Sbk_QQuick3DInstancingFunc_hasTransparency), METH_NOARGS, nullptr},
    {"instanceBuffer", reinterpret_cast<PyCFunction>(Sbk_QQuick3DInstancingFunc_instanceBuffer), METH_O, nullptr},
    {"instanceColor", reinterpret_cast<PyCFunction>(Sbk_QQuick3DInstancingFunc_instanceColor), METH_O, nullptr},
    {"instanceCountOverride", reinterpret_cast<PyCFunction>(Sbk_QQuick3DInstancingFunc_instanceCountOverride), METH_NOARGS, nullptr},
    {"instanceCustomData", reinterpret_cast<PyCFunction>(Sbk_QQuick3DInstancingFunc_instanceCustomData), METH_O, nullptr},
    {"instancePosition", reinterpret_cast<PyCFunction>(Sbk_QQuick3DInstancingFunc_instancePosition), METH_O, nullptr},
    {"instanceRotation", reinterpret_cast<PyCFunction>(Sbk_QQuick3DInstancingFunc_instanceRotation), METH_O, nullptr},
    {"instanceScale", reinterpret_cast<PyCFunction>(Sbk_QQuick3DInstancingFunc_instanceScale), METH_O, nullptr},
    {"markDirty", reinterpret_cast<PyCFunction>(Sbk_QQuick3DInstancingFunc_markDirty), METH_NOARGS, nullptr},
    {"setDepthSortingEnabled", reinterpret_cast<PyCFunction>(Sbk_QQuick3DInstancingFunc_setDepthSortingEnabled), METH_O, nullptr},
    {"setHasTransparency", reinterpret_cast<PyCFunction>(Sbk_QQuick3DInstancingFunc_setHasTransparency), METH_O, nullptr},
    {"setInstanceCountOverride", reinterpret_cast<PyCFunction>(Sbk_QQuick3DInstancingFunc_setInstanceCountOverride), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QQuick3DInstancing_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QQuick3DInstancing *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DInstancing_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QQuick3DInstancingWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QQuick3DInstancing_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QQuick3DInstancing_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
static void * Sbk_QQuick3DInstancingSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QQuick3DInstancing *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DObject_IDX]))
        return static_cast< ::QQuick3DObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlParserStatus_IDX]))
        return static_cast< ::QQmlParserStatus *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QQuick3DInstancing_Type = nullptr;
static PyTypeObject *Sbk_QQuick3DInstancing_TypeF(void)
{
    return _Sbk_QQuick3DInstancing_Type;
}

static PyType_Slot Sbk_QQuick3DInstancing_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QQuick3DInstancing_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QQuick3DInstancing_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QQuick3DInstancing_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QQuick3DInstancing_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QQuick3DInstancing_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QQuick3DInstancing_spec = {
    "2:PySide6.QtQuick3D.QQuick3DInstancing",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QQuick3DInstancing_slots
};

} //extern "C"

static void *Sbk_QQuick3DInstancing_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QQuick3DInstancing *>(reinterpret_cast< ::QObject *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QQmlParserStatus >())
        return dynamic_cast< ::QQuick3DInstancing *>(reinterpret_cast< ::QQmlParserStatus *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QQuick3DInstancing_PythonToCpp_QQuick3DInstancing_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QQuick3DInstancing_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QQuick3DInstancing_PythonToCpp_QQuick3DInstancing_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QQuick3DInstancing_TypeF()))
        return QQuick3DInstancing_PythonToCpp_QQuick3DInstancing_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QQuick3DInstancing_PTR_CppToPython_QQuick3DInstancing(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QQuick3DInstancing *>(const_cast<void *>(cppIn)), Sbk_QQuick3DInstancing_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QQuick3DInstancing_SignatureStrings[] = {
    "PySide6.QtQuick3D.QQuick3DInstancing(self,parent:PySide6.QtQuick3D.QQuick3DObject=nullptr,*:KeywordOnly=None,instanceCountOverride:int=None,hasTransparency:bool=None,depthSortingEnabled:bool=None)",
    "PySide6.QtQuick3D.QQuick3DInstancing.calculateTableEntry(position:PySide6.QtGui.QVector3D,scale:PySide6.QtGui.QVector3D,eulerRotation:PySide6.QtGui.QVector3D,color:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int],customData:PySide6.QtGui.QVector4D={})->PySide6.QtQuick3D.QQuick3DInstancing.InstanceTableEntry",
    "PySide6.QtQuick3D.QQuick3DInstancing.calculateTableEntryFromQuaternion(position:PySide6.QtGui.QVector3D,scale:PySide6.QtGui.QVector3D,rotation:PySide6.QtGui.QQuaternion,color:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int],customData:PySide6.QtGui.QVector4D={})->PySide6.QtQuick3D.QQuick3DInstancing.InstanceTableEntry",
    "PySide6.QtQuick3D.QQuick3DInstancing.depthSortingEnabled(self)->bool",
    "PySide6.QtQuick3D.QQuick3DInstancing.getInstanceBuffer(self)->Tuple[bool, str]",
    "PySide6.QtQuick3D.QQuick3DInstancing.hasTransparency(self)->bool",
    "PySide6.QtQuick3D.QQuick3DInstancing.instanceBuffer(self,instanceCount:int*)->PySide6.QtCore.QByteArray",
    "PySide6.QtQuick3D.QQuick3DInstancing.instanceColor(self,index:int)->PySide6.QtGui.QColor",
    "PySide6.QtQuick3D.QQuick3DInstancing.instanceCountOverride(self)->int",
    "PySide6.QtQuick3D.QQuick3DInstancing.instanceCustomData(self,index:int)->PySide6.QtGui.QVector4D",
    "PySide6.QtQuick3D.QQuick3DInstancing.instancePosition(self,index:int)->PySide6.QtGui.QVector3D",
    "PySide6.QtQuick3D.QQuick3DInstancing.instanceRotation(self,index:int)->PySide6.QtGui.QQuaternion",
    "PySide6.QtQuick3D.QQuick3DInstancing.instanceScale(self,index:int)->PySide6.QtGui.QVector3D",
    "PySide6.QtQuick3D.QQuick3DInstancing.markDirty(self)",
    "PySide6.QtQuick3D.QQuick3DInstancing.setDepthSortingEnabled(self,enabled:bool)",
    "PySide6.QtQuick3D.QQuick3DInstancing.setHasTransparency(self,hasTransparency:bool)",
    "PySide6.QtQuick3D.QQuick3DInstancing.setInstanceCountOverride(self,instanceCountOverride:int)",
    nullptr}; // Sentinel
#else
static constexpr size_t QQuick3DInstancing_SignatureByteSize = 483;
static constexpr uint8_t QQuick3DInstancing_SignatureBytes[483] = {
    0x78, 0xda, 0xed, 0x95, 0xcd, 0x6e, 0xd3, 0x40, 0x10, 0x80, 0xef, 0x7d, 0x8a, 0x1c, 0x9b, 0x6a,
    0xb1, 0x84, 0x52, 0xf5, 0x60, 0x29, 0x48, 0x34, 0x2e, 0xa5, 0x02, 0x91, 0xb8, 0x09, 0xbd, 0x54,
    0x3d, 0xac, 0xed, 0x49, 0xba, 0x74, 0x33, 0x6b, 0xcd, 0xce, 0x02, 0x16, 0xe2, 0xdd, 0x59, 0x27,
    0x31, 0x71, 0x82, 0x4d, 0x6d, 0xe0, 0xc8, 0xc9, 0x2b, 0xcf, 0xcc, 0x37, 0xb3, 0xf3, 0xb7, 0xb3,
    0x62, 0xae, 0x32, 0xb8, 0x08, 0x62, 0x8e, 0x9d, 0x4a, 0x9f, 0x46, 0x51, 0x10, 0xef, 0x0e, 0x37,
    0x68, 0x59, 0x62, 0xaa, 0x70, 0x75, 0x6a, 0x41, 0x2f, 0x45, 0x2e, 0x09, 0x90, 0xc3, 0x59, 0xab,
    0xc1, 0x34, 0xf9, 0x04, 0x29, 0x8f, 0xd1, 0x69, 0x9d, 0x33, 0x89, 0xb3, 0xf0, 0x1d, 0x14, 0x5f,
    0x0c, 0x65, 0x53, 0xd4, 0xc5, 0xf8, 0x83, 0x41, 0x10, 0x6a, 0x8b, 0x84, 0x89, 0x71, 0xc8, 0xd3,
    0xcf, 0x40, 0xe4, 0x51, 0xa1, 0x42, 0xde, 0x8a, 0x1f, 0xa5, 0x5d, 0x90, 0x44, 0xbb, 0xf1, 0x94,
    0x16, 0x61, 0x62, 0x8c, 0xde, 0x4a, 0x32, 0xc8, 0xf9, 0x71, 0x6e, 0x88, 0x7d, 0x34, 0x57, 0x28,
    0x13, 0x0d, 0xd9, 0x5e, 0x3a, 0x3c, 0x99, 0x75, 0xb8, 0x44, 0x90, 0x4a, 0x9d, 0x3a, 0x2d, 0x19,
    0x16, 0xa5, 0xfd, 0x15, 0x32, 0x15, 0xa7, 0xb9, 0xb1, 0x8a, 0x95, 0xc1, 0xda, 0xad, 0xae, 0x9d,
    0x0a, 0xe2, 0x3b, 0x7f, 0x11, 0x43, 0xa3, 0x48, 0x58, 0x6f, 0x05, 0xad, 0x52, 0x70, 0x1a, 0xe8,
    0xd6, 0xb0, 0xfc, 0x2d, 0x23, 0x35, 0xda, 0x50, 0xc8, 0x45, 0x5e, 0x46, 0xf1, 0x11, 0xbd, 0xea,
    0xfd, 0x91, 0xea, 0xa4, 0xd4, 0x10, 0x83, 0xf8, 0xbd, 0x07, 0xe1, 0xcb, 0x39, 0x93, 0xd7, 0x14,
    0x83, 0x23, 0xa5, 0xdb, 0x55, 0x22, 0x2f, 0xce, 0xbd, 0xd6, 0x9d, 0x24, 0x25, 0x91, 0xeb, 0x0a,
    0x13, 0x43, 0xe0, 0x3f, 0xc1, 0xb5, 0x36, 0x89, 0xd4, 0x15, 0xae, 0x02, 0x39, 0xb4, 0x6a, 0x85,
    0x90, 0x0d, 0x7c, 0xa6, 0x1f, 0x44, 0xea, 0x2c, 0x9b, 0x75, 0x24, 0x59, 0x36, 0x47, 0x7c, 0x1e,
    0x8d, 0xbf, 0x7d, 0x1f, 0xbe, 0x78, 0xd5, 0x29, 0xa9, 0xbb, 0x63, 0x2d, 0xa7, 0x7f, 0x5c, 0x8c,
    0x37, 0x64, 0xd6, 0xb1, 0xf3, 0xbf, 0xa8, 0x4c, 0xd1, 0xdf, 0x96, 0x86, 0x5a, 0xaa, 0xb2, 0xf7,
    0xf0, 0xbf, 0x2e, 0x0d, 0x76, 0x0d, 0x83, 0xb6, 0x99, 0x7e, 0xef, 0xb7, 0x9c, 0xb7, 0x6e, 0x90,
    0x15, 0x70, 0xe5, 0xff, 0xd2, 0x2d, 0x97, 0x40, 0x15, 0x62, 0xe1, 0x72, 0x0d, 0xf7, 0x25, 0x48,
    0x0c, 0x2c, 0xd3, 0x43, 0x37, 0xdc, 0xd1, 0x5a, 0xe8, 0x1f, 0x8f, 0xfa, 0x35, 0x98, 0xc3, 0x55,
    0x54, 0xae, 0xa0, 0xb3, 0x83, 0xd4, 0x6e, 0x0b, 0x77, 0x59, 0x30, 0xbc, 0x26, 0x92, 0x45, 0x3f,
    0x3f, 0x9b, 0x3a, 0x57, 0x6e, 0x32, 0xf8, 0x5a, 0xe2, 0x0f, 0xe8, 0xfb, 0xe6, 0xea, 0x0b, 0xae,
    0xed, 0xcd, 0x2a, 0x0f, 0x1e, 0xde, 0x93, 0xf2, 0xb3, 0xd1, 0x9e, 0x8d, 0xb1, 0xea, 0xbc, 0x7e,
    0x0e, 0x66, 0xbb, 0xd1, 0xed, 0x88, 0x1f, 0xf5, 0xc4, 0x57, 0x0b, 0xf7, 0x59, 0xfc, 0x7e, 0xd6,
    0xfb, 0x39, 0x98, 0x97, 0x9b, 0xe5, 0x1f, 0x07, 0xbf, 0x96, 0xf4, 0x14, 0x29, 0xe2, 0x5d, 0xfb,
    0x76, 0x33, 0xb2, 0xc0, 0x51, 0xcb, 0x40, 0x0a, 0xa8, 0x3d, 0x83, 0xdd, 0x71, 0x6f, 0x1b, 0x66,
    0xa9, 0xf1, 0xdd, 0xed, 0x8e, 0xbc, 0x69, 0x6d, 0xce, 0xf6, 0xf7, 0x7e, 0x78, 0xf2, 0x03, 0xd7,
    0x0e, 0x0e, 0xc9
};
#endif

PyTypeObject *init_QQuick3DInstancing(PyObject *module)
{
    if (SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DInstancing_IDX].type != nullptr)
        return SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DInstancing_IDX].type;

    Shiboken::AutoDecRef Sbk_QQuick3DInstancing_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DObject_IDX]))));

    _Sbk_QQuick3DInstancing_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QQuick3DInstancing",
        "QQuick3DInstancing*",
        &Sbk_QQuick3DInstancing_spec,
        &Shiboken::callCppDestructor< QQuick3DInstancing >,
        Sbk_QQuick3DInstancing_Type_bases.object(),
        0);
    auto *pyType = Sbk_QQuick3DInstancing_TypeF(); // references _Sbk_QQuick3DInstancing_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QQuick3DInstancing_SignatureStrings);
#else
    InitSignatureBytes(pyType, QQuick3DInstancing_SignatureBytes, QQuick3DInstancing_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QQuick3DInstancing_PropertyStrings);
    SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DInstancing_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QQuick3DInstancing_PythonToCpp_QQuick3DInstancing_PTR,
        is_QQuick3DInstancing_PythonToCpp_QQuick3DInstancing_PTR_Convertible,
        QQuick3DInstancing_PTR_CppToPython_QQuick3DInstancing);

    Shiboken::Conversions::registerConverterName(converter, "QQuick3DInstancing");
    Shiboken::Conversions::registerConverterName(converter, "QQuick3DInstancing*");
    Shiboken::Conversions::registerConverterName(converter, "QQuick3DInstancing&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QQuick3DInstancing).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QQuick3DInstancingWrapper).name());

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleInheritanceFunction(Shiboken::Module::get(SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3DObject_IDX]));
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QQuick3DInstancing_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QQuick3DInstancing_TypeF(), &Sbk_QQuick3DInstancingSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QQuick3DInstancing_TypeF(), &Sbk_QQuick3DInstancing_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::QQuick3DInstancing::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QQuick3DInstancing::staticMetaObject, sizeof(QQuick3DInstancingWrapper));

    return pyType;
}
