// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtquickcontrols2_python.h"

// main header
#include "qquickattachedpropertypropagator_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QtQuickControls2/qquickattachedpropertypropagator.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QQuickAttachedPropertyPropagatorWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QQuickAttachedPropertyPropagatorWrapper::QQuickAttachedPropertyPropagatorWrapper(::QObject * parent) : QQuickAttachedPropertyPropagator(parent)
{
}

void QQuickAttachedPropertyPropagatorWrapper::attachedParentChange(::QQuickAttachedPropertyPropagator * newParent, ::QQuickAttachedPropertyPropagator * oldParent)
{
    if (m_PyMethodCache[0]) {
        return this->::QQuickAttachedPropertyPropagator::attachedParentChange(newParent, oldParent);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "attachedParentChange";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QQuickAttachedPropertyPropagator::attachedParentChange(newParent, oldParent);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickControls2TypeStructs[SBK_QQuickAttachedPropertyPropagator_IDX]), newParent),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickControls2TypeStructs[SBK_QQuickAttachedPropertyPropagator_IDX]), oldParent)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickControls2TypeStructs[SBK_QQuickAttachedPropertyPropagator_IDX]), newParent),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickControls2TypeStructs[SBK_QQuickAttachedPropertyPropagator_IDX]), oldParent)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickAttachedPropertyPropagator", funcName);
        return;
    }
}

void QQuickAttachedPropertyPropagatorWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickAttachedPropertyPropagator", funcName);
        return;
    }
}

void QQuickAttachedPropertyPropagatorWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickAttachedPropertyPropagator", funcName);
        return;
    }
}

void QQuickAttachedPropertyPropagatorWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickAttachedPropertyPropagator", funcName);
        return;
    }
}

void QQuickAttachedPropertyPropagatorWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[4]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickAttachedPropertyPropagator", funcName);
        return;
    }
}

bool QQuickAttachedPropertyPropagatorWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickAttachedPropertyPropagator", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QQuickAttachedPropertyPropagator", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QQuickAttachedPropertyPropagatorWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[6])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickAttachedPropertyPropagator", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QQuickAttachedPropertyPropagator", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QQuickAttachedPropertyPropagatorWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[7]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[7] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickAttachedPropertyPropagator", funcName);
        return;
    }
}

const QMetaObject *QQuickAttachedPropertyPropagatorWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QQuickAttachedPropertyPropagator::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QQuickAttachedPropertyPropagatorWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QQuickAttachedPropertyPropagator::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QQuickAttachedPropertyPropagatorWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QQuickAttachedPropertyPropagatorWrapper *>(this));
    return QQuickAttachedPropertyPropagator::qt_metacast(_clname);
}

QQuickAttachedPropertyPropagatorWrapper::~QQuickAttachedPropertyPropagatorWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QQuickAttachedPropertyPropagator_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QQuickAttachedPropertyPropagator >()))
        return -1;

    QQuickAttachedPropertyPropagatorWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QQuickAttachedPropertyPropagator", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QQuickAttachedPropertyPropagator::QQuickAttachedPropertyPropagator(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QQuickAttachedPropertyPropagator(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QQuickAttachedPropertyPropagator(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQuickControls2TypeStructs[SBK_QQuickAttachedPropertyPropagator_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtQuickControls2TypeStructs[SBK_QQuickAttachedPropertyPropagator_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQuickControls2TypeStructs[SBK_QQuickAttachedPropertyPropagator_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQuickControls2TypeStructs[SBK_QQuickAttachedPropertyPropagator_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                // fall through to handle extra keyword signals and properties
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QQuickAttachedPropertyPropagator(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QQuickAttachedPropertyPropagatorWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QQuickAttachedPropertyPropagatorWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QQuickAttachedPropertyPropagator >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQuickControls2TypeStructs[SBK_QQuickAttachedPropertyPropagator_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQuickControls2TypeStructs[SBK_QQuickAttachedPropertyPropagator_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QQuickAttachedPropertyPropagatorFunc_attachedChildren(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickAttachedPropertyPropagator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickControls2TypeStructs[SBK_QQuickAttachedPropertyPropagator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // attachedChildren()const
        QList<QQuickAttachedPropertyPropagator*> cppResult = const_cast<const ::QQuickAttachedPropertyPropagator *>(cppSelf)->attachedChildren();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtQuickControls2TypeConverters[SBK_QtQuickControls2_QList_QQuickAttachedPropertyPropagatorPTR_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickAttachedPropertyPropagatorFunc_attachedParent(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickAttachedPropertyPropagator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickControls2TypeStructs[SBK_QQuickAttachedPropertyPropagator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // attachedParent()const
        QQuickAttachedPropertyPropagator * cppResult = const_cast<const ::QQuickAttachedPropertyPropagator *>(cppSelf)->attachedParent();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickControls2TypeStructs[SBK_QQuickAttachedPropertyPropagator_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickAttachedPropertyPropagatorFunc_attachedParentChange(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickAttachedPropertyPropagator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickControls2TypeStructs[SBK_QQuickAttachedPropertyPropagator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "attachedParentChange", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QQuickAttachedPropertyPropagator::attachedParentChange(QQuickAttachedPropertyPropagator*,QQuickAttachedPropertyPropagator*)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickControls2TypeStructs[SBK_QQuickAttachedPropertyPropagator_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickControls2TypeStructs[SBK_QQuickAttachedPropertyPropagator_IDX]), (pyArgs[1])))) {
        overloadId = 0; // attachedParentChange(QQuickAttachedPropertyPropagator*,QQuickAttachedPropertyPropagator*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "attachedParentChange", errInfo, SbkPySide6_QtQuickControls2TypeStructs[SBK_QQuickAttachedPropertyPropagator_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QQuickAttachedPropertyPropagator *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QQuickAttachedPropertyPropagator *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // attachedParentChange(QQuickAttachedPropertyPropagator*,QQuickAttachedPropertyPropagator*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QQuickAttachedPropertyPropagator::attachedParentChange(cppArg0, cppArg1)
                : cppSelf->attachedParentChange(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickAttachedPropertyPropagatorFunc_initialize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickAttachedPropertyPropagator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickControls2TypeStructs[SBK_QQuickAttachedPropertyPropagator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // initialize()
        cppSelf->initialize();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QQuickAttachedPropertyPropagator_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QQuickAttachedPropertyPropagator_methods[] = {
    {"attachedChildren", reinterpret_cast<PyCFunction>(Sbk_QQuickAttachedPropertyPropagatorFunc_attachedChildren), METH_NOARGS, nullptr},
    {"attachedParent", reinterpret_cast<PyCFunction>(Sbk_QQuickAttachedPropertyPropagatorFunc_attachedParent), METH_NOARGS, nullptr},
    {"attachedParentChange", reinterpret_cast<PyCFunction>(Sbk_QQuickAttachedPropertyPropagatorFunc_attachedParentChange), METH_VARARGS, nullptr},
    {"initialize", reinterpret_cast<PyCFunction>(Sbk_QQuickAttachedPropertyPropagatorFunc_initialize), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QQuickAttachedPropertyPropagator_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QQuickAttachedPropertyPropagator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickControls2TypeStructs[SBK_QQuickAttachedPropertyPropagator_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QQuickAttachedPropertyPropagatorWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QQuickAttachedPropertyPropagator_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QQuickAttachedPropertyPropagator_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QQuickAttachedPropertyPropagator_Type = nullptr;
static PyTypeObject *Sbk_QQuickAttachedPropertyPropagator_TypeF(void)
{
    return _Sbk_QQuickAttachedPropertyPropagator_Type;
}

static PyType_Slot Sbk_QQuickAttachedPropertyPropagator_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QQuickAttachedPropertyPropagator_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QQuickAttachedPropertyPropagator_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QQuickAttachedPropertyPropagator_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QQuickAttachedPropertyPropagator_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QQuickAttachedPropertyPropagator_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QQuickAttachedPropertyPropagator_spec = {
    "2:PySide6.QtQuickControls2.QQuickAttachedPropertyPropagator",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QQuickAttachedPropertyPropagator_slots
};

} //extern "C"

static void *Sbk_QQuickAttachedPropertyPropagator_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QQuickAttachedPropertyPropagator *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QQuickAttachedPropertyPropagator_PythonToCpp_QQuickAttachedPropertyPropagator_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QQuickAttachedPropertyPropagator_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QQuickAttachedPropertyPropagator_PythonToCpp_QQuickAttachedPropertyPropagator_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QQuickAttachedPropertyPropagator_TypeF()))
        return QQuickAttachedPropertyPropagator_PythonToCpp_QQuickAttachedPropertyPropagator_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QQuickAttachedPropertyPropagator_PTR_CppToPython_QQuickAttachedPropertyPropagator(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QQuickAttachedPropertyPropagator *>(const_cast<void *>(cppIn)), Sbk_QQuickAttachedPropertyPropagator_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QQuickAttachedPropertyPropagator_SignatureStrings[] = {
    "PySide6.QtQuickControls2.QQuickAttachedPropertyPropagator(self,parent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtQuickControls2.QQuickAttachedPropertyPropagator.attachedChildren(self)->QList[PySide6.QtQuickControls2.QQuickAttachedPropertyPropagator]",
    "PySide6.QtQuickControls2.QQuickAttachedPropertyPropagator.attachedParent(self)->PySide6.QtQuickControls2.QQuickAttachedPropertyPropagator",
    "PySide6.QtQuickControls2.QQuickAttachedPropertyPropagator.attachedParentChange(self,newParent:PySide6.QtQuickControls2.QQuickAttachedPropertyPropagator,oldParent:PySide6.QtQuickControls2.QQuickAttachedPropertyPropagator)",
    "PySide6.QtQuickControls2.QQuickAttachedPropertyPropagator.initialize(self)",
    nullptr}; // Sentinel
#else
static constexpr size_t QQuickAttachedPropertyPropagator_SignatureByteSize = 174;
static constexpr uint8_t QQuickAttachedPropertyPropagator_SignatureBytes[174] = {
    0x78, 0xda, 0xad, 0x91, 0xb1, 0x0a, 0xc2, 0x40, 0x10, 0x44, 0xfb, 0x7c, 0x89, 0x81, 0x78, 0x85,
    0x85, 0x85, 0xa0, 0x20, 0xd7, 0x0a, 0xde, 0x61, 0x29, 0x16, 0x6b, 0x6e, 0x4d, 0x56, 0x97, 0xbb,
    0x70, 0xd9, 0x20, 0xf1, 0xeb, 0xd5, 0x44, 0x2d, 0xec, 0x8c, 0xa9, 0x96, 0x61, 0xe1, 0xcd, 0x0c,
    0x63, 0xda, 0x1d, 0x39, 0x9c, 0x2b, 0x2b, 0xb6, 0xa1, 0xfc, 0xa2, 0x83, 0x97, 0x18, 0xb8, 0x9e,
    0x29, 0xdb, 0xe9, 0xb5, 0x08, 0xe4, 0x25, 0x3a, 0x13, 0x43, 0x85, 0x51, 0xda, 0xe7, 0x85, 0x02,
    0x24, 0xc4, 0x49, 0x8d, 0x7c, 0xca, 0x2a, 0x88, 0xe8, 0x65, 0x61, 0x3e, 0x14, 0x1d, 0x22, 0x2a,
    0xbb, 0x3d, 0x9e, 0x31, 0x97, 0xa5, 0x6f, 0x98, 0x2b, 0x89, 0x69, 0x62, 0x86, 0xba, 0x28, 0x78,
    0xbd, 0x74, 0x49, 0xec, 0x1e, 0x5e, 0x9d, 0x6d, 0x3a, 0x5d, 0xd9, 0x0d, 0xd5, 0xb2, 0x1f, 0xcc,
    0x3d, 0x8c, 0x10, 0xc9, 0x74, 0xdd, 0xdf, 0x81, 0x06, 0xf3, 0x46, 0x4b, 0xa2, 0x4b, 0xf0, 0x05,
    0xf6, 0xbb, 0x78, 0xbc, 0x9a, 0xef, 0x69, 0x7e, 0xa4, 0x67, 0x81, 0xdd, 0xbf, 0x8c, 0x7f, 0x96,
    0x27, 0x4f, 0x42, 0xc0, 0x74, 0xeb, 0x2b, 0xa5, 0xc9, 0x1d, 0xd5, 0xab, 0x03, 0xa0
};
#endif

PyTypeObject *init_QQuickAttachedPropertyPropagator(PyObject *module)
{
    if (SbkPySide6_QtQuickControls2TypeStructs[SBK_QQuickAttachedPropertyPropagator_IDX].type != nullptr)
        return SbkPySide6_QtQuickControls2TypeStructs[SBK_QQuickAttachedPropertyPropagator_IDX].type;

    Shiboken::AutoDecRef Sbk_QQuickAttachedPropertyPropagator_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QQuickAttachedPropertyPropagator_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QQuickAttachedPropertyPropagator",
        "QQuickAttachedPropertyPropagator*",
        &Sbk_QQuickAttachedPropertyPropagator_spec,
        &Shiboken::callCppDestructor< QQuickAttachedPropertyPropagator >,
        Sbk_QQuickAttachedPropertyPropagator_Type_bases.object(),
        0);
    auto *pyType = Sbk_QQuickAttachedPropertyPropagator_TypeF(); // references _Sbk_QQuickAttachedPropertyPropagator_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QQuickAttachedPropertyPropagator_SignatureStrings);
#else
    InitSignatureBytes(pyType, QQuickAttachedPropertyPropagator_SignatureBytes, QQuickAttachedPropertyPropagator_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QQuickAttachedPropertyPropagator_PropertyStrings);
    SbkPySide6_QtQuickControls2TypeStructs[SBK_QQuickAttachedPropertyPropagator_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QQuickAttachedPropertyPropagator_PythonToCpp_QQuickAttachedPropertyPropagator_PTR,
        is_QQuickAttachedPropertyPropagator_PythonToCpp_QQuickAttachedPropertyPropagator_PTR_Convertible,
        QQuickAttachedPropertyPropagator_PTR_CppToPython_QQuickAttachedPropertyPropagator);

    Shiboken::Conversions::registerConverterName(converter, "QQuickAttachedPropertyPropagator");
    Shiboken::Conversions::registerConverterName(converter, "QQuickAttachedPropertyPropagator*");
    Shiboken::Conversions::registerConverterName(converter, "QQuickAttachedPropertyPropagator&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QQuickAttachedPropertyPropagator).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QQuickAttachedPropertyPropagatorWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QQuickAttachedPropertyPropagator_TypeF(), &Sbk_QQuickAttachedPropertyPropagator_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QQuickAttachedPropertyPropagator::staticMetaObject, sizeof(QQuickAttachedPropertyPropagatorWrapper));

    return pyType;
}
