// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtquickcontrols2_python.h"

// main header
#include "qquickstyle_wrapper.h"

// Argument includes
#include <QString>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QQuickStyle_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QQuickStyle >()))
        return -1;

    ::QQuickStyle *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtQuickControls2TypeStructs[SBK_QQuickStyle_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QQuickStyle()
        cptr = new ::QQuickStyle();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QQuickStyle >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QQuickStyleFunc_name(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // name()
        QString cppResult = ::QQuickStyle::name();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickStyleFunc_setFallbackStyle(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QQuickStyle::setFallbackStyle(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setFallbackStyle(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFallbackStyle", errInfo, SbkPySide6_QtQuickControls2TypeStructs[SBK_QQuickStyle_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFallbackStyle(QString)
            ::QQuickStyle::setFallbackStyle(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickStyleFunc_setStyle(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QQuickStyle::setStyle(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setStyle(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStyle", errInfo, SbkPySide6_QtQuickControls2TypeStructs[SBK_QQuickStyle_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStyle(QString)
            ::QQuickStyle::setStyle(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QQuickStyle_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QQuickStyle_methods[] = {
    {"name", reinterpret_cast<PyCFunction>(Sbk_QQuickStyleFunc_name), METH_NOARGS|METH_STATIC, nullptr},
    {"setFallbackStyle", reinterpret_cast<PyCFunction>(Sbk_QQuickStyleFunc_setFallbackStyle), METH_O|METH_STATIC, nullptr},
    {"setStyle", reinterpret_cast<PyCFunction>(Sbk_QQuickStyleFunc_setStyle), METH_O|METH_STATIC, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QQuickStyle_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QQuickStyle_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QQuickStyle_Type = nullptr;
static PyTypeObject *Sbk_QQuickStyle_TypeF(void)
{
    return _Sbk_QQuickStyle_Type;
}

static PyType_Slot Sbk_QQuickStyle_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QQuickStyle_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QQuickStyle_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QQuickStyle_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QQuickStyle_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QQuickStyle_spec = {
    "2:PySide6.QtQuickControls2.QQuickStyle",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QQuickStyle_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QQuickStyle_PythonToCpp_QQuickStyle_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QQuickStyle_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QQuickStyle_PythonToCpp_QQuickStyle_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QQuickStyle_TypeF()))
        return QQuickStyle_PythonToCpp_QQuickStyle_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QQuickStyle_PTR_CppToPython_QQuickStyle(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QQuickStyle_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QQuickStyle_SignatureStrings[] = {
    "PySide6.QtQuickControls2.QQuickStyle(self)",
    "PySide6.QtQuickControls2.QQuickStyle.name()->QString",
    "PySide6.QtQuickControls2.QQuickStyle.setFallbackStyle(style:QString)",
    "PySide6.QtQuickControls2.QQuickStyle.setStyle(style:QString)",
    nullptr}; // Sentinel
#else
static constexpr size_t QQuickStyle_SignatureByteSize = 91;
static constexpr uint8_t QQuickStyle_SignatureBytes[91] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x09, 0x2c, 0xcd, 0x4c,
    0xce, 0x76, 0xce, 0xcf, 0x2b, 0x29, 0xca, 0xcf, 0x29, 0x36, 0xd2, 0x0b, 0x04, 0xf3, 0x83, 0x4b,
    0x2a, 0x73, 0x52, 0x35, 0x8a, 0x53, 0x73, 0xd2, 0x34, 0xb9, 0x02, 0x88, 0x50, 0xaa, 0x97, 0x97,
    0x98, 0x9b, 0xaa, 0xa1, 0xa9, 0x6b, 0x17, 0x18, 0x5c, 0x52, 0x94, 0x99, 0x97, 0x4e, 0x9c, 0xa6,
    0xe2, 0xd4, 0x12, 0xb7, 0xc4, 0x9c, 0x9c, 0xa4, 0x44, 0xb8, 0x85, 0x20, 0xd2, 0x0a, 0x6a, 0x86,
    0x26, 0xd1, 0x86, 0x60, 0xd5, 0x0c, 0x00, 0x89, 0x14, 0x52, 0xc1
};
#endif

PyTypeObject *init_QQuickStyle(PyObject *module)
{
    if (SbkPySide6_QtQuickControls2TypeStructs[SBK_QQuickStyle_IDX].type != nullptr)
        return SbkPySide6_QtQuickControls2TypeStructs[SBK_QQuickStyle_IDX].type;

    Shiboken::AutoDecRef Sbk_QQuickStyle_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QQuickStyle_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QQuickStyle",
        "QQuickStyle*",
        &Sbk_QQuickStyle_spec,
        &Shiboken::callCppDestructor< ::QQuickStyle >,
        Sbk_QQuickStyle_Type_bases.object(),
        0);
    auto *pyType = Sbk_QQuickStyle_TypeF(); // references _Sbk_QQuickStyle_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QQuickStyle_SignatureStrings);
#else
    InitSignatureBytes(pyType, QQuickStyle_SignatureBytes, QQuickStyle_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QQuickStyle_PropertyStrings);
    SbkPySide6_QtQuickControls2TypeStructs[SBK_QQuickStyle_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QQuickStyle_PythonToCpp_QQuickStyle_PTR,
        is_QQuickStyle_PythonToCpp_QQuickStyle_PTR_Convertible,
        QQuickStyle_PTR_CppToPython_QQuickStyle);

    Shiboken::Conversions::registerConverterName(converter, "QQuickStyle");
    Shiboken::Conversions::registerConverterName(converter, "QQuickStyle*");
    Shiboken::Conversions::registerConverterName(converter, "QQuickStyle&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QQuickStyle).name());

    qRegisterMetaType< ::QQuickStyle *>();

    return pyType;
}
