// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtremoteobjects_python.h"

// main header
#include "qremoteobjectnode_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QStringList>
#include <QStringView>
#include <QtRemoteObjects/qremoteobjectabstractitemmodelreplica.h>
#include <QtRemoteObjects/qremoteobjectdynamicreplica.h>
#include <QtRemoteObjects/qremoteobjectnode.h>
#include <QtRemoteObjects/qremoteobjectregistry.h>
#include <QtRemoteObjects/qremoteobjectreplica.h>
#include <QtRemoteObjects/qtremoteobjectglobal.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qiodevice.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qurl.h>
#include <qvariant.h>
#include <utility>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QRemoteObjectNodeWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QRemoteObjectNodeWrapper::QRemoteObjectNodeWrapper(::QObject * parent) : QRemoteObjectNode(parent)
{
}

QRemoteObjectNodeWrapper::QRemoteObjectNodeWrapper(const ::QUrl & registryAddress, ::QObject * parent) : QRemoteObjectNode(registryAddress, parent)
{
}

void QRemoteObjectNodeWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRemoteObjectNode", funcName);
        return;
    }
}

void QRemoteObjectNodeWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRemoteObjectNode", funcName);
        return;
    }
}

void QRemoteObjectNodeWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRemoteObjectNode", funcName);
        return;
    }
}

void QRemoteObjectNodeWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRemoteObjectNode", funcName);
        return;
    }
}

bool QRemoteObjectNodeWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRemoteObjectNode", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QRemoteObjectNode", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QRemoteObjectNodeWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRemoteObjectNode", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QRemoteObjectNode", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QRemoteObjectNodeWrapper::setName(const ::QString & name)
{
    if (m_PyMethodCache[6]) {
        return this->::QRemoteObjectNode::setName(name);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setName";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QRemoteObjectNode::setName(name);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &name)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &name)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRemoteObjectNode", funcName);
        return;
    }
}

bool QRemoteObjectNodeWrapper::setRegistryUrl(const ::QUrl & registryAddress)
{
    if (m_PyMethodCache[7])
        return this->::QRemoteObjectNode::setRegistryUrl(registryAddress);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setRegistryUrl";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[7] = true;
        gil.release();
        return this->::QRemoteObjectNode::setRegistryUrl(registryAddress);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &registryAddress)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &registryAddress)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRemoteObjectNode", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QRemoteObjectNode", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QRemoteObjectNodeWrapper::timerEvent(::QTimerEvent * arg__1)
{
    if (m_PyMethodCache[8]) {
        return this->::QRemoteObjectNode::timerEvent(arg__1);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[8] = true;
        gil.release();
        return this->::QRemoteObjectNode::timerEvent(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), arg__1)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), arg__1)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRemoteObjectNode", funcName);
        return;
    }
}

const QMetaObject *QRemoteObjectNodeWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QRemoteObjectNode::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QRemoteObjectNodeWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QRemoteObjectNode::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QRemoteObjectNodeWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QRemoteObjectNodeWrapper *>(this));
    return QRemoteObjectNode::qt_metacast(_clname);
}

QRemoteObjectNodeWrapper::~QRemoteObjectNodeWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QRemoteObjectNode_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QRemoteObjectNode >()))
        return -1;

    QRemoteObjectNodeWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:QRemoteObjectNode", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QRemoteObjectNode::QRemoteObjectNode(QObject*=)
    // 1: QRemoteObjectNode::QRemoteObjectNode(QUrl,QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QRemoteObjectNode(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QRemoteObjectNode(QUrl,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 1; // QRemoteObjectNode(QUrl,QObject*)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QRemoteObjectNode(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QRemoteObjectNode(QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0 = nullptr;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QRemoteObjectNode(QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QRemoteObjectNodeWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QRemoteObjectNodeWrapper(cppArg0);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
        case 1: // QRemoteObjectNode(const QUrl &registryAddress, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QUrl cppArg0_local;
            ::QUrl *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QObject *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QRemoteObjectNode(QUrl,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QRemoteObjectNodeWrapper(*cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QRemoteObjectNodeWrapper(*cppArg0, cppArg1);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QRemoteObjectNode >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QRemoteObjectNodeFunc_acquireDynamic(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRemoteObjectNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRemoteObjectNode::acquireDynamic(QString)->QRemoteObjectDynamicReplica*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // acquireDynamic(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "acquireDynamic", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // acquireDynamic(QString)
            QRemoteObjectDynamicReplica * cppResult = cppSelf->acquireDynamic(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectDynamicReplica_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRemoteObjectNodeFunc_acquireModel(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRemoteObjectNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "acquireModel", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:acquireModel", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRemoteObjectNode::acquireModel(QString,QtRemoteObjects::InitialAction=,const QList<int>&=)->QAbstractItemModelReplica*
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // acquireModel(QString,QtRemoteObjects::InitialAction,QList<int>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtRemoteObjects_InitialAction_IDX])))->converter, (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // acquireModel(QString,QtRemoteObjects::InitialAction,QList<int>)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(SbkPySide6_QtRemoteObjectsTypeConverters[SBK_QtRemoteObjects_QList_int_IDX], (pyArgs[2])))) {
                overloadId = 0; // acquireModel(QString,QtRemoteObjects::InitialAction,QList<int>)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "acquireModel", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_action = Shiboken::String::createStaticString("action");
            if (PyDict_Contains(kwds, key_action) != 0) {
                value = PyDict_GetItem(kwds, key_action);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_action);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "acquireModel", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtRemoteObjects_InitialAction_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "acquireModel", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_action);
            }
            static PyObject *const key_rolesHint = Shiboken::String::createStaticString("rolesHint");
            if (PyDict_Contains(kwds, key_rolesHint) != 0) {
                value = PyDict_GetItem(kwds, key_rolesHint);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_rolesHint);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "acquireModel", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(SbkPySide6_QtRemoteObjectsTypeConverters[SBK_QtRemoteObjects_QList_int_IDX], (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "acquireModel", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_rolesHint);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "acquireModel", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QtRemoteObjects::InitialAction cppArg1(QtRemoteObjects::FetchRootSize);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QList<int> cppArg2_local{};
        ::QList<int> *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2]) {
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // acquireModel(QString,QtRemoteObjects::InitialAction,QList<int>)
            QAbstractItemModelReplica * cppResult = cppSelf->acquireModel(cppArg0, cppArg1, *cppArg2);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QAbstractItemModelReplica_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRemoteObjectNodeFunc_addClientSideConnection(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRemoteObjectNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRemoteObjectNode::addClientSideConnection(QIODevice*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), (pyArg)))) {
        overloadId = 0; // addClientSideConnection(QIODevice*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addClientSideConnection", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QIODevice *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addClientSideConnection(QIODevice*)
            cppSelf->addClientSideConnection(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRemoteObjectNodeFunc_connectToNode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRemoteObjectNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRemoteObjectNode::connectToNode(QUrl)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // connectToNode(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "connectToNode", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // connectToNode(QUrl)
            bool cppResult = cppSelf->connectToNode(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRemoteObjectNodeFunc_heartbeatInterval(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRemoteObjectNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // heartbeatInterval()const
        int cppResult = const_cast<const ::QRemoteObjectNode *>(cppSelf)->heartbeatInterval();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRemoteObjectNodeFunc_instances(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRemoteObjectNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRemoteObjectNode::instances(QStringView)const->QStringList
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // instances(QStringView)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "instances", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // instances(QStringView)const
            QStringList cppResult = const_cast<const ::QRemoteObjectNode *>(cppSelf)->instances(QStringView(cppArg0));
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRemoteObjectNodeFunc_lastError(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRemoteObjectNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lastError()const
        QRemoteObjectNode::ErrorCode cppResult = const_cast<const ::QRemoteObjectNode *>(cppSelf)->lastError();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_ErrorCode_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRemoteObjectNodeFunc_persistedStore(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRemoteObjectNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // persistedStore()const
        QRemoteObjectAbstractPersistedStore * cppResult = const_cast<const ::QRemoteObjectNode *>(cppSelf)->persistedStore();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectAbstractPersistedStore_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRemoteObjectNodeFunc_registry(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRemoteObjectNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // registry()const
        const QRemoteObjectRegistry * cppResult = const_cast<const ::QRemoteObjectNode *>(cppSelf)->registry();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectRegistry_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRemoteObjectNodeFunc_registryUrl(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRemoteObjectNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // registryUrl()const
        QUrl cppResult = const_cast<const ::QRemoteObjectNode *>(cppSelf)->registryUrl();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRemoteObjectNodeFunc_setHeartbeatInterval(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRemoteObjectNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRemoteObjectNode::setHeartbeatInterval(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setHeartbeatInterval(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHeartbeatInterval", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHeartbeatInterval(int)
            cppSelf->setHeartbeatInterval(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRemoteObjectNodeFunc_setName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRemoteObjectNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRemoteObjectNode::setName(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setName", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setName(QString)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QRemoteObjectNode::setName(cppArg0)
                : cppSelf->setName(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRemoteObjectNodeFunc_setPersistedStore(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRemoteObjectNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRemoteObjectNode::setPersistedStore(QRemoteObjectAbstractPersistedStore*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectAbstractPersistedStore_IDX]), (pyArg)))) {
        overloadId = 0; // setPersistedStore(QRemoteObjectAbstractPersistedStore*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPersistedStore", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRemoteObjectAbstractPersistedStore *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPersistedStore(QRemoteObjectAbstractPersistedStore*)
            cppSelf->setPersistedStore(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRemoteObjectNodeFunc_setRegistryUrl(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRemoteObjectNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRemoteObjectNode::setRegistryUrl(QUrl)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // setRegistryUrl(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRegistryUrl", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setRegistryUrl(QUrl)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QRemoteObjectNode::setRegistryUrl(*cppArg0)
                : cppSelf->setRegistryUrl(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRemoteObjectNodeFunc_timerEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRemoteObjectNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::timerEvent(QTimerEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), (pyArg)))) {
        overloadId = 0; // timerEvent(QTimerEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "timerEvent", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTimerEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // timerEvent(QTimerEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QRemoteObjectNode::timerEvent(cppArg0)
                : cppSelf->timerEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRemoteObjectNodeFunc_waitForRegistry(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRemoteObjectNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "waitForRegistry", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]);

    if (PyArg_ParseTuple(args, "|O:waitForRegistry", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRemoteObjectNode::waitForRegistry(int=)->bool
    if (numArgs == 0) {
        overloadId = 0; // waitForRegistry(int)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // waitForRegistry(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "waitForRegistry", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_timeout = Shiboken::String::createStaticString("timeout");
            if (PyDict_Contains(kwds, key_timeout) != 0) {
                value = PyDict_GetItem(kwds, key_timeout);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_timeout);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "waitForRegistry", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "waitForRegistry", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_timeout);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "waitForRegistry", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]);
            }
        }
        int cppArg0 = 30000;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // waitForRegistry(int)
            bool cppResult = cppSelf->waitForRegistry(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QRemoteObjectNode_PropertyStrings[] = {
    "heartbeatInterval::",
    "persistedStore::",
    "registryUrl::",
    nullptr // Sentinel
};

static const char *Sbk_QRemoteObjectNode_EnumFlagInfo[] = {
    "ErrorCode:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QRemoteObjectNode_methods[] = {
    {"acquireDynamic", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectNodeFunc_acquireDynamic), METH_O, nullptr},
    {"acquireModel", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectNodeFunc_acquireModel), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"addClientSideConnection", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectNodeFunc_addClientSideConnection), METH_O, nullptr},
    {"connectToNode", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectNodeFunc_connectToNode), METH_O, nullptr},
    {"heartbeatInterval", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectNodeFunc_heartbeatInterval), METH_NOARGS, nullptr},
    {"instances", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectNodeFunc_instances), METH_O, nullptr},
    {"lastError", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectNodeFunc_lastError), METH_NOARGS, nullptr},
    {"persistedStore", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectNodeFunc_persistedStore), METH_NOARGS, nullptr},
    {"registry", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectNodeFunc_registry), METH_NOARGS, nullptr},
    {"registryUrl", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectNodeFunc_registryUrl), METH_NOARGS, nullptr},
    {"setHeartbeatInterval", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectNodeFunc_setHeartbeatInterval), METH_O, nullptr},
    {"setName", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectNodeFunc_setName), METH_O, nullptr},
    {"setPersistedStore", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectNodeFunc_setPersistedStore), METH_O, nullptr},
    {"setRegistryUrl", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectNodeFunc_setRegistryUrl), METH_O, nullptr},
    {"timerEvent", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectNodeFunc_timerEvent), METH_O, nullptr},
    {"waitForRegistry", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectNodeFunc_waitForRegistry), METH_VARARGS|METH_KEYWORDS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QRemoteObjectNode_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QRemoteObjectNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QRemoteObjectNodeWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QRemoteObjectNode_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QRemoteObjectNode_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QRemoteObjectNode_Type = nullptr;
static PyTypeObject *Sbk_QRemoteObjectNode_TypeF(void)
{
    return _Sbk_QRemoteObjectNode_Type;
}

static PyType_Slot Sbk_QRemoteObjectNode_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QRemoteObjectNode_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QRemoteObjectNode_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QRemoteObjectNode_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QRemoteObjectNode_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QRemoteObjectNode_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QRemoteObjectNode_spec = {
    "2:PySide6.QtRemoteObjects.QRemoteObjectNode",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QRemoteObjectNode_slots
};

} //extern "C"

static void *Sbk_QRemoteObjectNode_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QRemoteObjectNode *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QRemoteObjectNode_ErrorCode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRemoteObjectNode::ErrorCode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRemoteObjectNode::ErrorCode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QRemoteObjectNode_ErrorCode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_ErrorCode_IDX])))
        return Enum_PythonToCpp_QRemoteObjectNode_ErrorCode;
    return {};
}

static PyObject *QRemoteObjectNode_ErrorCode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QRemoteObjectNode::ErrorCode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QRemoteObjectNode::ErrorCode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_ErrorCode_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QRemoteObjectNode_PythonToCpp_QRemoteObjectNode_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QRemoteObjectNode_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QRemoteObjectNode_PythonToCpp_QRemoteObjectNode_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QRemoteObjectNode_TypeF()))
        return QRemoteObjectNode_PythonToCpp_QRemoteObjectNode_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QRemoteObjectNode_PTR_CppToPython_QRemoteObjectNode(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QRemoteObjectNode *>(const_cast<void *>(cppIn)), Sbk_QRemoteObjectNode_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QRemoteObjectNode_SignatureStrings[] = {
    "1:PySide6.QtRemoteObjects.QRemoteObjectNode(self,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,registryUrl:QUrl=None,persistedStore:QRemoteObjectAbstractPersistedStore=None,heartbeatInterval:int=None)",
    "0:PySide6.QtRemoteObjects.QRemoteObjectNode(self,registryAddress:typing.Union[PySide6.QtCore.QUrl, QString],parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,registryUrl:QUrl=None,persistedStore:QRemoteObjectAbstractPersistedStore=None,heartbeatInterval:int=None)",
    "PySide6.QtRemoteObjects.QRemoteObjectNode.acquireDynamic(self,name:QString)->PySide6.QtRemoteObjects.QRemoteObjectDynamicReplica",
    "PySide6.QtRemoteObjects.QRemoteObjectNode.acquireModel(self,name:QString,action:PySide6.QtRemoteObjects.QtRemoteObjects.InitialAction=QtRemoteObjects.FetchRootSize,rolesHint:QList[int]={})->PySide6.QtRemoteObjects.QAbstractItemModelReplica",
    "PySide6.QtRemoteObjects.QRemoteObjectNode.addClientSideConnection(self,ioDevice:PySide6.QtCore.QIODevice)",
    "PySide6.QtRemoteObjects.QRemoteObjectNode.connectToNode(self,address:typing.Union[PySide6.QtCore.QUrl, QString])->bool",
    "PySide6.QtRemoteObjects.QRemoteObjectNode.heartbeatInterval(self)->int",
    "PySide6.QtRemoteObjects.QRemoteObjectNode.instances(self,typeName:QString)->QStringList",
    "PySide6.QtRemoteObjects.QRemoteObjectNode.lastError(self)->PySide6.QtRemoteObjects.QRemoteObjectNode.ErrorCode",
    "PySide6.QtRemoteObjects.QRemoteObjectNode.persistedStore(self)->PySide6.QtRemoteObjects.QRemoteObjectAbstractPersistedStore",
    "PySide6.QtRemoteObjects.QRemoteObjectNode.registry(self)->PySide6.QtRemoteObjects.QRemoteObjectRegistry",
    "PySide6.QtRemoteObjects.QRemoteObjectNode.registryUrl(self)->PySide6.QtCore.QUrl",
    "PySide6.QtRemoteObjects.QRemoteObjectNode.setHeartbeatInterval(self,interval:int)",
    "PySide6.QtRemoteObjects.QRemoteObjectNode.setName(self,name:QString)",
    "PySide6.QtRemoteObjects.QRemoteObjectNode.setPersistedStore(self,persistedStore:PySide6.QtRemoteObjects.QRemoteObjectAbstractPersistedStore)",
    "PySide6.QtRemoteObjects.QRemoteObjectNode.setRegistryUrl(self,registryAddress:typing.Union[PySide6.QtCore.QUrl, QString])->bool",
    "PySide6.QtRemoteObjects.QRemoteObjectNode.timerEvent(self,arg__1:PySide6.QtCore.QTimerEvent)",
    "PySide6.QtRemoteObjects.QRemoteObjectNode.waitForRegistry(self,timeout:int=30000)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QRemoteObjectNode_SignatureByteSize = 503;
static constexpr uint8_t QRemoteObjectNode_SignatureBytes[503] = {
    0x78, 0xda, 0xd5, 0x55, 0x51, 0x6f, 0xda, 0x40, 0x0c, 0x7e, 0xdf, 0xaf, 0xd8, 0xe3, 0x98, 0xb2,
    0xa8, 0xd5, 0xa4, 0x3d, 0x44, 0x62, 0x12, 0xa2, 0xad, 0x8a, 0xb6, 0x01, 0x09, 0xed, 0x53, 0x55,
    0x55, 0xc7, 0xc5, 0xa5, 0xae, 0x8e, 0xbb, 0xcc, 0x67, 0xa8, 0xb2, 0x69, 0xff, 0x7d, 0x26, 0x21,
    0x1d, 0x24, 0x6c, 0xe2, 0xda, 0xa7, 0xf1, 0x80, 0x9c, 0x9c, 0xed, 0xef, 0xb3, 0xfd, 0x9d, 0x73,
    0x9a, 0x4c, 0xcb, 0x19, 0xe6, 0xf0, 0x29, 0x4e, 0x39, 0x83, 0xa5, 0x63, 0x98, 0xcc, 0x1f, 0x41,
    0xb3, 0x8f, 0xd3, 0xdd, 0xc7, 0xb1, 0xcb, 0xe1, 0x9d, 0x07, 0x73, 0x1f, 0x15, 0x8a, 0xc0, 0xf2,
    0x4e, 0xd4, 0xd0, 0x11, 0xc4, 0x69, 0xed, 0xd6, 0xb7, 0x2b, 0x63, 0x0a, 0xa6, 0xe8, 0x7d, 0xf2,
    0x05, 0xca, 0x27, 0x47, 0xf9, 0xc4, 0x9a, 0xb2, 0x3f, 0x76, 0x16, 0x22, 0x82, 0x05, 0x7a, 0xa6,
    0xf2, 0x9a, 0x4c, 0x92, 0xca, 0x5f, 0xfd, 0xb6, 0x00, 0xf2, 0xf2, 0x1a, 0xf2, 0x19, 0x4b, 0x9e,
    0x64, 0x0f, 0x74, 0x30, 0x17, 0x7f, 0xa5, 0x79, 0xba, 0xe7, 0x53, 0xc7, 0x3d, 0x80, 0x22, 0x9e,
    0x83, 0xe2, 0x91, 0x65, 0xa0, 0xb5, 0x32, 0x09, 0x5a, 0xae, 0x8e, 0x7a, 0x6f, 0x4e, 0x42, 0x6b,
    0x6a, 0xa8, 0x0d, 0xf2, 0x9c, 0xc0, 0xfb, 0x84, 0xcb, 0x02, 0xed, 0x22, 0xbe, 0xb6, 0xe8, 0xec,
    0x4d, 0xbb, 0x52, 0xa1, 0x1e, 0xbd, 0x4d, 0x67, 0x4c, 0xe2, 0x72, 0xfb, 0x3f, 0xb4, 0xe3, 0xe8,
    0x66, 0xc4, 0x4a, 0x7f, 0x5f, 0x21, 0xc1, 0x59, 0x69, 0xd5, 0x12, 0x75, 0xdd, 0x1b, 0x31, 0x85,
    0x47, 0x5d, 0x6e, 0xef, 0xc3, 0xe7, 0xa3, 0x92, 0x6d, 0x13, 0x64, 0x50, 0x18, 0xd4, 0x2a, 0x9c,
    0xc0, 0x37, 0xb1, 0x4d, 0x17, 0x3e, 0x92, 0xe2, 0x65, 0x22, 0x7f, 0x9f, 0x6e, 0xeb, 0x79, 0x64,
    0x91, 0x51, 0x99, 0x41, 0x15, 0xd5, 0x6f, 0x9f, 0x5e, 0x00, 0xeb, 0x87, 0xcc, 0x39, 0x9e, 0xe1,
    0x0f, 0x19, 0x87, 0x33, 0xe0, 0x2f, 0xa5, 0x69, 0x49, 0xfa, 0x55, 0x9a, 0x7b, 0x23, 0xd6, 0x6d,
    0xff, 0xe7, 0xaf, 0x7f, 0x55, 0xdc, 0xcc, 0x63, 0xc4, 0xb0, 0xac, 0x18, 0xbf, 0xa0, 0xde, 0x3c,
    0x1f, 0x1a, 0x14, 0x01, 0x6d, 0x02, 0x86, 0xce, 0x5a, 0xa8, 0xb8, 0xd6, 0xa5, 0xa3, 0x3b, 0x83,
    0x35, 0x6a, 0xe8, 0x88, 0x6b, 0x34, 0xa9, 0x0f, 0x42, 0x46, 0xab, 0xeb, 0xe4, 0x57, 0xee, 0x8f,
    0xea, 0x55, 0xb0, 0xda, 0xa5, 0x1b, 0x73, 0xe7, 0x4c, 0x00, 0x6c, 0x47, 0x97, 0x15, 0xb4, 0xe4,
    0x91, 0xfe, 0x06, 0xa4, 0x41, 0xeb, 0x59, 0x59, 0x0d, 0xbe, 0x66, 0x2e, 0x8c, 0x61, 0xbc, 0xaf,
    0xcb, 0xad, 0xb5, 0x99, 0x5d, 0x40, 0x5e, 0xa3, 0x3c, 0x9f, 0x13, 0x39, 0x6a, 0x68, 0x1d, 0x1f,
    0x5a, 0x85, 0x0d, 0xc5, 0x0a, 0x80, 0xdb, 0xbf, 0xdd, 0x41, 0x98, 0x87, 0x2f, 0x7f, 0x00, 0x76,
    0xb3, 0x6f, 0x82, 0x50, 0xb3, 0x6d, 0xd0, 0x0b, 0x70, 0x44, 0x38, 0x5d, 0xa8, 0x67, 0x4d, 0x05,
    0x24, 0xf4, 0xc0, 0x97, 0x07, 0x55, 0x14, 0xe1, 0xce, 0xae, 0xeb, 0x85, 0x65, 0xdc, 0xa8, 0xe7,
    0xc0, 0x7e, 0x0b, 0x4b, 0x32, 0xed, 0x8e, 0xb3, 0xbd, 0xc0, 0x5f, 0x31, 0xdb, 0x40, 0x32, 0x59,
    0xab, 0xef, 0xaf, 0xf8, 0xa8, 0x85, 0x5f, 0x73, 0xc6, 0x25, 0xd0, 0xf9, 0x5a, 0x16, 0xd9, 0x76,
    0xb5, 0xd0, 0xe2, 0xee, 0xee, 0xb4, 0xb3, 0xb8, 0xae, 0x9e, 0xdd, 0x42, 0x8a, 0x7b, 0x52, 0xc8,
    0x17, 0x8e, 0xb2, 0x5d, 0x01, 0x47, 0x1b, 0x44, 0xb7, 0xe2, 0xea, 0x33, 0xf7, 0xf1, 0x44, 0x7e,
    0x0d, 0xe9, 0xdf, 0x8c, 0xa3, 0x48, 0xa5
};
#endif

PyTypeObject *init_QRemoteObjectNode(PyObject *module)
{
    if (SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX].type != nullptr)
        return SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX].type;

    Shiboken::AutoDecRef Sbk_QRemoteObjectNode_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QRemoteObjectNode_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QRemoteObjectNode",
        "QRemoteObjectNode*",
        &Sbk_QRemoteObjectNode_spec,
        &Shiboken::callCppDestructor< QRemoteObjectNode >,
        Sbk_QRemoteObjectNode_Type_bases.object(),
        0);
    auto *pyType = Sbk_QRemoteObjectNode_TypeF(); // references _Sbk_QRemoteObjectNode_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QRemoteObjectNode_SignatureStrings);
#else
    InitSignatureBytes(pyType, QRemoteObjectNode_SignatureBytes, QRemoteObjectNode_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QRemoteObjectNode_PropertyStrings);
    SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QRemoteObjectNode_PythonToCpp_QRemoteObjectNode_PTR,
        is_QRemoteObjectNode_PythonToCpp_QRemoteObjectNode_PTR_Convertible,
        QRemoteObjectNode_PTR_CppToPython_QRemoteObjectNode);

    Shiboken::Conversions::registerConverterName(converter, "QRemoteObjectNode");
    Shiboken::Conversions::registerConverterName(converter, "QRemoteObjectNode*");
    Shiboken::Conversions::registerConverterName(converter, "QRemoteObjectNode&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QRemoteObjectNode).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QRemoteObjectNodeWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QRemoteObjectNode_TypeF(), &Sbk_QRemoteObjectNode_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QRemoteObjectNode_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'ErrorCode'.
    const char *ErrorCode_Initializer[] = {
        "NoError",
        "RegistryNotAcquired",
        "RegistryAlreadyHosted",
        "NodeIsNoServer",
        "ServerAlreadyCreated",
        "UnintendedRegistryHosting",
        "OperationNotValidOnClientNode",
        "SourceNotRegistered",
        "MissingObjectName",
        "HostUrlInvalid",
        "ProtocolMismatch",
        "ListenFailed",
        "SocketAccessError",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ErrorCode_InitializerValues[] = {
        uint8_t(QRemoteObjectNode::ErrorCode::NoError),                       //  0x00  0
        uint8_t(QRemoteObjectNode::ErrorCode::RegistryNotAcquired),           //  0x01  1
        uint8_t(QRemoteObjectNode::ErrorCode::RegistryAlreadyHosted),         //  0x02  2
        uint8_t(QRemoteObjectNode::ErrorCode::NodeIsNoServer),                //  0x03  3
        uint8_t(QRemoteObjectNode::ErrorCode::ServerAlreadyCreated),          //  0x04  4
        uint8_t(QRemoteObjectNode::ErrorCode::UnintendedRegistryHosting),     //  0x05  5
        uint8_t(QRemoteObjectNode::ErrorCode::OperationNotValidOnClientNode), //  0x06  6
        uint8_t(QRemoteObjectNode::ErrorCode::SourceNotRegistered),           //  0x07  7
        uint8_t(QRemoteObjectNode::ErrorCode::MissingObjectName),             //  0x08  8
        uint8_t(QRemoteObjectNode::ErrorCode::HostUrlInvalid),                //  0x09  9
        uint8_t(QRemoteObjectNode::ErrorCode::ProtocolMismatch),              //  0x0a  10
        uint8_t(QRemoteObjectNode::ErrorCode::ListenFailed),                  //  0x0b  11
        uint8_t(QRemoteObjectNode::ErrorCode::SocketAccessError)              //  0x0c  12
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRemoteObjectNode_TypeF(),
        "2:PySide6.QtRemoteObjects.QRemoteObjectNode.ErrorCode",
        ErrorCode_Initializer, ErrorCode_InitializerValues);
    SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_ErrorCode_IDX].type = EType;
    // Register converter for enum 'QRemoteObjectNode::ErrorCode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRemoteObjectNode_ErrorCode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QRemoteObjectNode_ErrorCode,
            is_Enum_PythonToCpp_QRemoteObjectNode_ErrorCode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QRemoteObjectNode::ErrorCode");
        Shiboken::Conversions::registerConverterAlias(converter, "ErrorCode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ErrorCode' enum.

    PySide::Signal::registerSignals(pyType, &::QRemoteObjectNode::staticMetaObject);
    qRegisterMetaType< ::QRemoteObjectNode::ErrorCode >("QRemoteObjectNode::ErrorCode");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QRemoteObjectNode::staticMetaObject, sizeof(QRemoteObjectNodeWrapper));

    return pyType;
}
