// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtremoteobjects_python.h"

// main header
#include "qremoteobjectpendingcall_wrapper.h"

// Argument includes
#include <QtRemoteObjects/qremoteobjectpendingcall.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QRemoteObjectPendingCall_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QRemoteObjectPendingCall >()))
        return -1;

    ::QRemoteObjectPendingCall *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QRemoteObjectPendingCall", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QRemoteObjectPendingCall::QRemoteObjectPendingCall()
    // 1: QRemoteObjectPendingCall::QRemoteObjectPendingCall(QRemoteObjectPendingCall)
    if (numArgs == 0) {
        overloadId = 0; // QRemoteObjectPendingCall()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectPendingCall_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QRemoteObjectPendingCall(QRemoteObjectPendingCall)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectPendingCall_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectPendingCall_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QRemoteObjectPendingCall()
        {

            // QRemoteObjectPendingCall()
            cptr = new ::QRemoteObjectPendingCall();
            break;
        }
        case 1: // QRemoteObjectPendingCall(const QRemoteObjectPendingCall &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QRemoteObjectPendingCall *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QRemoteObjectPendingCall(QRemoteObjectPendingCall)
                cptr = new ::QRemoteObjectPendingCall(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QRemoteObjectPendingCall >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectPendingCall_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QRemoteObjectPendingCallFunc_error(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRemoteObjectPendingCall *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectPendingCall_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // error()const
        QRemoteObjectPendingCall::Error cppResult = const_cast<const ::QRemoteObjectPendingCall *>(cppSelf)->error();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectPendingCall_Error_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRemoteObjectPendingCallFunc_fromCompletedCall(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QRemoteObjectPendingCall::fromCompletedCall(QVariant)->QRemoteObjectPendingCall
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // fromCompletedCall(QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fromCompletedCall", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectPendingCall_IDX]);

    // Call function/method
    {
        ::QVariant cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromCompletedCall(QVariant)
            QRemoteObjectPendingCall* cppResult = new QRemoteObjectPendingCall(::QRemoteObjectPendingCall::fromCompletedCall(cppArg0));
            pyResult = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectPendingCall_IDX]), cppResult, true, true);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRemoteObjectPendingCallFunc_isFinished(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRemoteObjectPendingCall *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectPendingCall_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isFinished()const
        bool cppResult = const_cast<const ::QRemoteObjectPendingCall *>(cppSelf)->isFinished();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRemoteObjectPendingCallFunc_returnValue(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRemoteObjectPendingCall *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectPendingCall_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // returnValue()const
        QVariant cppResult = const_cast<const ::QRemoteObjectPendingCall *>(cppSelf)->returnValue();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRemoteObjectPendingCallFunc_waitForFinished(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRemoteObjectPendingCall *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectPendingCall_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "waitForFinished", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectPendingCall_IDX]);

    if (PyArg_ParseTuple(args, "|O:waitForFinished", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRemoteObjectPendingCall::waitForFinished(int=)->bool
    if (numArgs == 0) {
        overloadId = 0; // waitForFinished(int)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // waitForFinished(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "waitForFinished", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectPendingCall_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_timeout = Shiboken::String::createStaticString("timeout");
            if (PyDict_Contains(kwds, key_timeout) != 0) {
                value = PyDict_GetItem(kwds, key_timeout);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_timeout);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "waitForFinished", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectPendingCall_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "waitForFinished", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectPendingCall_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_timeout);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "waitForFinished", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectPendingCall_IDX]);
            }
        }
        int cppArg0 = 30000;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // waitForFinished(int)
            bool cppResult = cppSelf->waitForFinished(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QRemoteObjectPendingCall_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QRemoteObjectPendingCall_EnumFlagInfo[] = {
    "Error:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QRemoteObjectPendingCall_methods[] = {
    {"error", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectPendingCallFunc_error), METH_NOARGS, nullptr},
    {"fromCompletedCall", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectPendingCallFunc_fromCompletedCall), METH_O|METH_STATIC, nullptr},
    {"isFinished", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectPendingCallFunc_isFinished), METH_NOARGS, nullptr},
    {"returnValue", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectPendingCallFunc_returnValue), METH_NOARGS, nullptr},
    {"waitForFinished", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectPendingCallFunc_waitForFinished), METH_VARARGS|METH_KEYWORDS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QRemoteObjectPendingCall_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QRemoteObjectPendingCall_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QRemoteObjectPendingCall_Type = nullptr;
static PyTypeObject *Sbk_QRemoteObjectPendingCall_TypeF(void)
{
    return _Sbk_QRemoteObjectPendingCall_Type;
}

static PyType_Slot Sbk_QRemoteObjectPendingCall_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QRemoteObjectPendingCall_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QRemoteObjectPendingCall_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QRemoteObjectPendingCall_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QRemoteObjectPendingCall_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QRemoteObjectPendingCall_spec = {
    "2:PySide6.QtRemoteObjects.QRemoteObjectPendingCall",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QRemoteObjectPendingCall_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QRemoteObjectPendingCall_Error(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRemoteObjectPendingCall::Error>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRemoteObjectPendingCall::Error *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QRemoteObjectPendingCall_Error_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectPendingCall_Error_IDX])))
        return Enum_PythonToCpp_QRemoteObjectPendingCall_Error;
    return {};
}

static PyObject *QRemoteObjectPendingCall_Error_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QRemoteObjectPendingCall::Error>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QRemoteObjectPendingCall::Error *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectPendingCall_Error_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QRemoteObjectPendingCall_PythonToCpp_QRemoteObjectPendingCall_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QRemoteObjectPendingCall_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QRemoteObjectPendingCall_PythonToCpp_QRemoteObjectPendingCall_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QRemoteObjectPendingCall_TypeF()))
        return QRemoteObjectPendingCall_PythonToCpp_QRemoteObjectPendingCall_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QRemoteObjectPendingCall_PTR_CppToPython_QRemoteObjectPendingCall(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QRemoteObjectPendingCall_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QRemoteObjectPendingCall_SignatureStrings[] = {
    "1:PySide6.QtRemoteObjects.QRemoteObjectPendingCall(self)",
    "0:PySide6.QtRemoteObjects.QRemoteObjectPendingCall(self,other:PySide6.QtRemoteObjects.QRemoteObjectPendingCall)",
    "PySide6.QtRemoteObjects.QRemoteObjectPendingCall.error(self)->PySide6.QtRemoteObjects.QRemoteObjectPendingCall.Error",
    "PySide6.QtRemoteObjects.QRemoteObjectPendingCall.fromCompletedCall(returnValue:QVariant)->PySide6.QtRemoteObjects.QRemoteObjectPendingCall",
    "PySide6.QtRemoteObjects.QRemoteObjectPendingCall.isFinished(self)->bool",
    "PySide6.QtRemoteObjects.QRemoteObjectPendingCall.returnValue(self)->QVariant",
    "PySide6.QtRemoteObjects.QRemoteObjectPendingCall.waitForFinished(self,timeout:int=30000)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QRemoteObjectPendingCall_SignatureByteSize = 173;
static constexpr uint8_t QRemoteObjectPendingCall_SignatureBytes[173] = {
    0x78, 0xda, 0x9d, 0x90, 0x3d, 0x0b, 0xc2, 0x40, 0x0c, 0x86, 0x77, 0x7f, 0x89, 0x85, 0x5a, 0x2a,
    0x82, 0x43, 0x41, 0x97, 0x62, 0x57, 0x5b, 0x85, 0xee, 0x57, 0x2f, 0xb5, 0x91, 0xbb, 0x8b, 0xe4,
    0x52, 0xc4, 0x7f, 0xef, 0x17, 0x07, 0x75, 0xbc, 0x66, 0xcb, 0xf0, 0xbc, 0x79, 0xde, 0xac, 0x8b,
    0xfa, 0x79, 0x46, 0x0d, 0xdb, 0xac, 0x91, 0x13, 0x58, 0x12, 0x38, 0x76, 0x37, 0xb8, 0x88, 0xcf,
    0x9a, 0xe9, 0x5a, 0x83, 0xd3, 0xe8, 0xae, 0xa5, 0x32, 0x66, 0xe9, 0xc1, 0xf4, 0xc9, 0x22, 0x9f,
    0x07, 0xa6, 0x24, 0x03, 0x70, 0x34, 0x9b, 0x2c, 0x62, 0x89, 0x0c, 0x98, 0x89, 0x7f, 0xb2, 0xab,
    0x7d, 0x34, 0x7d, 0xf8, 0xd0, 0xf1, 0x47, 0x7b, 0x26, 0x5b, 0x92, 0xbd, 0x1b, 0x10, 0xd0, 0xdf,
    0xd2, 0x0c, 0x32, 0xb2, 0x6b, 0x95, 0x19, 0xa1, 0x68, 0x5a, 0xc5, 0xa8, 0x9c, 0xcc, 0x10, 0x8a,
    0x57, 0x41, 0x5f, 0xa1, 0x43, 0x3f, 0x80, 0x0e, 0x4f, 0xe8, 0x88, 0x66, 0xe4, 0x4c, 0x0a, 0x84,
    0xa0, 0xd0, 0x23, 0x3e, 0xec, 0xa1, 0x50, 0x2a, 0xe2, 0x3f, 0xb3, 0x54, 0xd0, 0x02, 0x8d, 0x52,
    0xa0, 0x93, 0xdd, 0x26, 0x7f, 0x4f, 0x70, 0x7d, 0x01, 0xc9, 0xcc, 0xf6, 0xef
};
#endif

PyTypeObject *init_QRemoteObjectPendingCall(PyObject *module)
{
    if (SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectPendingCall_IDX].type != nullptr)
        return SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectPendingCall_IDX].type;

    Shiboken::AutoDecRef Sbk_QRemoteObjectPendingCall_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QRemoteObjectPendingCall_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QRemoteObjectPendingCall",
        "QRemoteObjectPendingCall*",
        &Sbk_QRemoteObjectPendingCall_spec,
        &Shiboken::callCppDestructor< ::QRemoteObjectPendingCall >,
        Sbk_QRemoteObjectPendingCall_Type_bases.object(),
        0);
    auto *pyType = Sbk_QRemoteObjectPendingCall_TypeF(); // references _Sbk_QRemoteObjectPendingCall_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QRemoteObjectPendingCall_SignatureStrings);
#else
    InitSignatureBytes(pyType, QRemoteObjectPendingCall_SignatureBytes, QRemoteObjectPendingCall_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QRemoteObjectPendingCall_PropertyStrings);
    SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectPendingCall_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QRemoteObjectPendingCall_PythonToCpp_QRemoteObjectPendingCall_PTR,
        is_QRemoteObjectPendingCall_PythonToCpp_QRemoteObjectPendingCall_PTR_Convertible,
        QRemoteObjectPendingCall_PTR_CppToPython_QRemoteObjectPendingCall);

    Shiboken::Conversions::registerConverterName(converter, "QRemoteObjectPendingCall");
    Shiboken::Conversions::registerConverterName(converter, "QRemoteObjectPendingCall*");
    Shiboken::Conversions::registerConverterName(converter, "QRemoteObjectPendingCall&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QRemoteObjectPendingCall).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QRemoteObjectPendingCall_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Error'.
    const char *Error_Initializer[] = {
        "NoError",
        "InvalidMessage",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Error_InitializerValues[] = {
        uint8_t(QRemoteObjectPendingCall::Error::NoError),       //  0x00  0
        uint8_t(QRemoteObjectPendingCall::Error::InvalidMessage) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRemoteObjectPendingCall_TypeF(),
        "2:PySide6.QtRemoteObjects.QRemoteObjectPendingCall.Error",
        Error_Initializer, Error_InitializerValues);
    SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectPendingCall_Error_IDX].type = EType;
    // Register converter for enum 'QRemoteObjectPendingCall::Error'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRemoteObjectPendingCall_Error_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QRemoteObjectPendingCall_Error,
            is_Enum_PythonToCpp_QRemoteObjectPendingCall_Error_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QRemoteObjectPendingCall::Error");
        Shiboken::Conversions::registerConverterAlias(converter, "Error");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Error' enum.

    qRegisterMetaType< ::QRemoteObjectPendingCall *>();
    qRegisterMetaType< ::QRemoteObjectPendingCall::Error >("QRemoteObjectPendingCall::Error");

    return pyType;
}
