// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtremoteobjects_python.h"

// main header
#include "qtremoteobjects_wrapper.h"

// Argument includes
#include <qdatastream.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QtRemoteObjectsFunc_copyStoredProperties(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "copyStoredProperties", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QtRemoteObjects::copyStoredProperties(const QMetaObject*,QDataStream&,void*)
    // 1: static QtRemoteObjects::copyStoredProperties(const QMetaObject*,const void*,QDataStream&)
    // 2: static QtRemoteObjects::copyStoredProperties(const QMetaObject*,const void*,void*)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_IDX]), (pyArgs[0])))) {
        if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[1])))) {
            if (numArgs == 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[2])))) {
                overloadId = 2; // copyStoredProperties(const QMetaObject*,const void*,void*)
            } else if (numArgs == 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArgs[2])))) {
                overloadId = 1; // copyStoredProperties(const QMetaObject*,const void*,QDataStream&)
            }
        } else if (numArgs == 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[2])))) {
            overloadId = 0; // copyStoredProperties(const QMetaObject*,QDataStream&,void*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "copyStoredProperties", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtRemoteObjectsQtRemoteObjects_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // copyStoredProperties(const QMetaObject *mo, QDataStream &src, void *dst)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QMetaObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QDataStream *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            void* cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // copyStoredProperties(const QMetaObject*,QDataStream&,void*)
                ::QtRemoteObjects::copyStoredProperties(cppArg0, *cppArg1, cppArg2);
            }
            break;
        }
        case 1: // copyStoredProperties(const QMetaObject *mo, const void *src, QDataStream &dst)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QMetaObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            void* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QDataStream *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // copyStoredProperties(const QMetaObject*,const void*,QDataStream&)
                ::QtRemoteObjects::copyStoredProperties(cppArg0, cppArg1, *cppArg2);
            }
            break;
        }
        case 2: // copyStoredProperties(const QMetaObject *mo, const void *src, void *dst)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QMetaObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            void* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            void* cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // copyStoredProperties(const QMetaObject*,const void*,void*)
                ::QtRemoteObjects::copyStoredProperties(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QtRemoteObjects_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QtRemoteObjects_EnumFlagInfo[] = {
    "InitialAction:Enum",
    "QRemoteObjectPacketTypeEnum:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QtRemoteObjects_methods[] = {
    {"copyStoredProperties", reinterpret_cast<PyCFunction>(Sbk_QtRemoteObjectsFunc_copyStoredProperties), METH_VARARGS|METH_STATIC, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QtRemoteObjects_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QtRemoteObjects_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QtRemoteObjects_Type = nullptr;
static PyTypeObject *Sbk_QtRemoteObjects_TypeF(void)
{
    return _Sbk_QtRemoteObjects_Type;
}

static PyType_Slot Sbk_QtRemoteObjects_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(Sbk_object_dealloc /* PYSIDE-832: Prevent replacement of "0" with subtype_dealloc. */)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QtRemoteObjects_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QtRemoteObjects_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QtRemoteObjects_methods)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QtRemoteObjects_spec = {
    "2:PySide6.QtRemoteObjects.QtRemoteObjects",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QtRemoteObjects_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QtRemoteObjects_QRemoteObjectPacketTypeEnum(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QtRemoteObjects::QRemoteObjectPacketTypeEnum>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QtRemoteObjects::QRemoteObjectPacketTypeEnum *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QtRemoteObjects_QRemoteObjectPacketTypeEnum_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtRemoteObjects_QRemoteObjectPacketTypeEnum_IDX])))
        return Enum_PythonToCpp_QtRemoteObjects_QRemoteObjectPacketTypeEnum;
    return {};
}

static PyObject *QtRemoteObjects_QRemoteObjectPacketTypeEnum_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QtRemoteObjects::QRemoteObjectPacketTypeEnum>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QtRemoteObjects::QRemoteObjectPacketTypeEnum *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtRemoteObjects_QRemoteObjectPacketTypeEnum_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QtRemoteObjects_InitialAction(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QtRemoteObjects::InitialAction>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QtRemoteObjects::InitialAction *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QtRemoteObjects_InitialAction_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtRemoteObjects_InitialAction_IDX])))
        return Enum_PythonToCpp_QtRemoteObjects_InitialAction;
    return {};
}

static PyObject *QtRemoteObjects_InitialAction_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QtRemoteObjects::InitialAction>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QtRemoteObjects::InitialAction *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtRemoteObjects_InitialAction_IDX]), castCppIn);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QtRemoteObjectsQtRemoteObjects_SignatureStrings[] = {
    "2:PySide6.QtRemoteObjects.QtRemoteObjects.copyStoredProperties(mo:PySide6.QtCore.QMetaObject,src:PySide6.QtCore.QDataStream,dst:void)",
    "1:PySide6.QtRemoteObjects.QtRemoteObjects.copyStoredProperties(mo:PySide6.QtCore.QMetaObject,src:void,dst:PySide6.QtCore.QDataStream)",
    "0:PySide6.QtRemoteObjects.QtRemoteObjects.copyStoredProperties(mo:PySide6.QtCore.QMetaObject,src:void,dst:void)",
    nullptr}; // Sentinel
#else
static constexpr size_t QtRemoteObjectsQtRemoteObjects_SignatureByteSize = 116;
static constexpr uint8_t QtRemoteObjectsQtRemoteObjects_SignatureBytes[116] = {
    0x78, 0xda, 0x33, 0xb2, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x09, 0x4a,
    0xcd, 0xcd, 0x2f, 0x49, 0xf5, 0x4f, 0xca, 0x4a, 0x4d, 0x2e, 0x29, 0xc6, 0xe0, 0x27, 0xe7, 0x17,
    0x54, 0x06, 0x97, 0xe4, 0x17, 0xa5, 0xa6, 0x04, 0x14, 0xe5, 0x17, 0xa4, 0x16, 0x95, 0x64, 0xa6,
    0x16, 0x6b, 0xe4, 0xe6, 0x23, 0xe9, 0x77, 0x06, 0x4a, 0xea, 0x05, 0xfa, 0xa6, 0x96, 0x24, 0x42,
    0xf4, 0xe8, 0x14, 0x17, 0x25, 0x63, 0x48, 0xbb, 0x24, 0x96, 0x24, 0x06, 0x97, 0x14, 0xa5, 0x26,
    0xe6, 0xea, 0xa4, 0x14, 0x97, 0x58, 0x95, 0xe5, 0x67, 0xa6, 0x68, 0x72, 0x19, 0xd2, 0xda, 0x15,
    0x20, 0x6b, 0xc0, 0xf6, 0xe1, 0x76, 0x8e, 0x26, 0x97, 0x01, 0xdd, 0x5c, 0x01, 0xf1, 0x35, 0x00,
    0x03, 0xc7, 0x8b, 0x72
};
#endif

PyTypeObject *init_QtRemoteObjectsQtRemoteObjects(PyObject *module)
{
    if (SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtRemoteObjectsQtRemoteObjects_IDX].type != nullptr)
        return SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtRemoteObjectsQtRemoteObjects_IDX].type;

    Shiboken::AutoDecRef Sbk_QtRemoteObjects_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QtRemoteObjects_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QtRemoteObjects",
        "QtRemoteObjects",
        &Sbk_QtRemoteObjects_spec,
        nullptr,
        Sbk_QtRemoteObjects_Type_bases.object(),
        0);
    auto *pyType = Sbk_QtRemoteObjects_TypeF(); // references _Sbk_QtRemoteObjects_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QtRemoteObjectsQtRemoteObjects_SignatureStrings);
#else
    InitSignatureBytes(pyType, QtRemoteObjectsQtRemoteObjects_SignatureBytes, QtRemoteObjectsQtRemoteObjects_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QtRemoteObjects_PropertyStrings);
    SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtRemoteObjectsQtRemoteObjects_IDX].type = pyType;


    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QtRemoteObjects_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'QRemoteObjectPacketTypeEnum'.
    const char *QRemoteObjectPacketTypeEnum_Initializer[] = {
        "Invalid",
        "Handshake",
        "InitPacket",
        "InitDynamicPacket",
        "AddObject",
        "RemoveObject",
        "InvokePacket",
        "InvokeReplyPacket",
        "PropertyChangePacket",
        "ObjectList",
        "Ping",
        "Pong",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t QRemoteObjectPacketTypeEnum_InitializerValues[] = {
        uint8_t(QtRemoteObjects::QRemoteObjectPacketTypeEnum::Invalid),              //  0x00  0
        uint8_t(QtRemoteObjects::QRemoteObjectPacketTypeEnum::Handshake),            //  0x01  1
        uint8_t(QtRemoteObjects::QRemoteObjectPacketTypeEnum::InitPacket),           //  0x02  2
        uint8_t(QtRemoteObjects::QRemoteObjectPacketTypeEnum::InitDynamicPacket),    //  0x03  3
        uint8_t(QtRemoteObjects::QRemoteObjectPacketTypeEnum::AddObject),            //  0x04  4
        uint8_t(QtRemoteObjects::QRemoteObjectPacketTypeEnum::RemoveObject),         //  0x05  5
        uint8_t(QtRemoteObjects::QRemoteObjectPacketTypeEnum::InvokePacket),         //  0x06  6
        uint8_t(QtRemoteObjects::QRemoteObjectPacketTypeEnum::InvokeReplyPacket),    //  0x07  7
        uint8_t(QtRemoteObjects::QRemoteObjectPacketTypeEnum::PropertyChangePacket), //  0x08  8
        uint8_t(QtRemoteObjects::QRemoteObjectPacketTypeEnum::ObjectList),           //  0x09  9
        uint8_t(QtRemoteObjects::QRemoteObjectPacketTypeEnum::Ping),                 //  0x0a  10
        uint8_t(QtRemoteObjects::QRemoteObjectPacketTypeEnum::Pong)                  //  0x0b  11
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QtRemoteObjects_TypeF(),
        "2:PySide6.QtRemoteObjects.QtRemoteObjects.QRemoteObjectPacketTypeEnum",
        QRemoteObjectPacketTypeEnum_Initializer, QRemoteObjectPacketTypeEnum_InitializerValues);
    SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtRemoteObjects_QRemoteObjectPacketTypeEnum_IDX].type = EType;
    // Register converter for enum 'QtRemoteObjects::QRemoteObjectPacketTypeEnum'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QtRemoteObjects_QRemoteObjectPacketTypeEnum_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QtRemoteObjects_QRemoteObjectPacketTypeEnum,
            is_Enum_PythonToCpp_QtRemoteObjects_QRemoteObjectPacketTypeEnum_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QtRemoteObjects::QRemoteObjectPacketTypeEnum");
        Shiboken::Conversions::registerConverterAlias(converter, "QRemoteObjectPacketTypeEnum");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'QRemoteObjectPacketTypeEnum' enum.

    // Initialization of enum 'InitialAction'.
    const char *InitialAction_Initializer[] = {
        "FetchRootSize",
        "PrefetchData",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t InitialAction_InitializerValues[] = {
        uint8_t(QtRemoteObjects::InitialAction::FetchRootSize), //  0x00  0
        uint8_t(QtRemoteObjects::InitialAction::PrefetchData)   //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QtRemoteObjects_TypeF(),
        "2:PySide6.QtRemoteObjects.QtRemoteObjects.InitialAction",
        InitialAction_Initializer, InitialAction_InitializerValues);
    SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtRemoteObjects_InitialAction_IDX].type = EType;
    // Register converter for enum 'QtRemoteObjects::InitialAction'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QtRemoteObjects_InitialAction_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QtRemoteObjects_InitialAction,
            is_Enum_PythonToCpp_QtRemoteObjects_InitialAction_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QtRemoteObjects::InitialAction");
        Shiboken::Conversions::registerConverterAlias(converter, "InitialAction");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'InitialAction' enum.

    qRegisterMetaType< ::QtRemoteObjects::QRemoteObjectPacketTypeEnum >("QtRemoteObjects::QRemoteObjectPacketTypeEnum");
    qRegisterMetaType< ::QtRemoteObjects::InitialAction >("QtRemoteObjects::InitialAction");

    return pyType;
}
