// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtremoteobjects_python.h"

// main header
#include "qtroclientfactory_wrapper.h"

// Argument includes
#include <QtRemoteObjects/qconnectionfactories.h>
#include <qobject.h>
#include <qurl.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QtROClientFactoryFunc_create(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QtROClientFactory *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROClientFactory_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "create", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROClientFactory_IDX]);

    if (PyArg_ParseTuple(args, "|OO:create", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QtROClientFactory::create(QUrl,QObject*=)->QtROClientIoDevice*
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // create(QUrl,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 0; // create(QUrl,QObject*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "create", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROClientFactory_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "create", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROClientFactory_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "create", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROClientFactory_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "create", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROClientFactory_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QObject *cppArg1 = nullptr;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // create(QUrl,QObject*)
            QtROClientIoDevice * cppResult = cppSelf->create(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROClientIoDevice_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QtROClientFactoryFunc_instance(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // instance()
        QtROClientFactory * cppResult = ::QtROClientFactory::instance();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROClientFactory_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QtROClientFactoryFunc_isValid(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QtROClientFactory *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROClientFactory_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QtROClientFactory::isValid(QUrl)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // isValid(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isValid", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROClientFactory_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // isValid(QUrl)
            bool cppResult = cppSelf->isValid(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QtROClientFactory_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QtROClientFactory_methods[] = {
    {"create", reinterpret_cast<PyCFunction>(Sbk_QtROClientFactoryFunc_create), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"instance", reinterpret_cast<PyCFunction>(Sbk_QtROClientFactoryFunc_instance), METH_NOARGS|METH_STATIC, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QtROClientFactoryFunc_isValid), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QtROClientFactory_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QtROClientFactory_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QtROClientFactory_Type = nullptr;
static PyTypeObject *Sbk_QtROClientFactory_TypeF(void)
{
    return _Sbk_QtROClientFactory_Type;
}

static PyType_Slot Sbk_QtROClientFactory_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QtROClientFactory_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QtROClientFactory_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QtROClientFactory_methods)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QtROClientFactory_spec = {
    "2:PySide6.QtRemoteObjects.QtROClientFactory",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QtROClientFactory_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QtROClientFactory_PythonToCpp_QtROClientFactory_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QtROClientFactory_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QtROClientFactory_PythonToCpp_QtROClientFactory_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QtROClientFactory_TypeF()))
        return QtROClientFactory_PythonToCpp_QtROClientFactory_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QtROClientFactory_PTR_CppToPython_QtROClientFactory(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QtROClientFactory_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QtROClientFactory_SignatureStrings[] = {
    "PySide6.QtRemoteObjects.QtROClientFactory.create(self,url:typing.Union[PySide6.QtCore.QUrl, QString],parent:PySide6.QtCore.QObject=nullptr)->PySide6.QtRemoteObjects.QtROClientIoDevice",
    "PySide6.QtRemoteObjects.QtROClientFactory.instance()->PySide6.QtRemoteObjects.QtROClientFactory",
    "PySide6.QtRemoteObjects.QtROClientFactory.isValid(self,url:typing.Union[PySide6.QtCore.QUrl, QString])->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QtROClientFactory_SignatureByteSize = 164;
static constexpr uint8_t QtROClientFactory_SignatureBytes[164] = {
    0x78, 0xda, 0x9d, 0x90, 0xb1, 0x0a, 0xc2, 0x40, 0x10, 0x44, 0xfb, 0x7c, 0x85, 0x65, 0x84, 0x78,
    0xa5, 0x45, 0x40, 0x9b, 0x88, 0x60, 0x95, 0x8b, 0x21, 0x36, 0x62, 0x71, 0xb9, 0xac, 0xb2, 0x61,
    0xbd, 0x0b, 0x7b, 0x1b, 0x21, 0x7f, 0x6f, 0x44, 0xb1, 0xb0, 0x31, 0x5a, 0x2e, 0xcc, 0xbc, 0x79,
    0xac, 0x1e, 0x4a, 0x6c, 0x60, 0xa9, 0x0a, 0xd9, 0xc3, 0xd5, 0x0b, 0xe4, 0x75, 0x0b, 0x56, 0xc2,
    0xe3, 0xce, 0x33, 0x42, 0x70, 0xb2, 0x35, 0x56, 0x3c, 0x0f, 0xca, 0x32, 0x18, 0x81, 0x38, 0x00,
    0x9d, 0x93, 0x9e, 0x29, 0x95, 0xa1, 0x43, 0x77, 0x51, 0x95, 0x43, 0xef, 0x8e, 0xfa, 0x8d, 0xc9,
    0x3c, 0x83, 0x2a, 0x2a, 0xa6, 0x64, 0x56, 0x94, 0xc2, 0x63, 0xe4, 0x94, 0x74, 0x86, 0x47, 0x50,
    0xfa, 0x19, 0x7a, 0x6e, 0xad, 0x5c, 0x4f, 0xd4, 0x09, 0xcf, 0x17, 0x6b, 0xfd, 0x55, 0x66, 0xe7,
    0x37, 0x70, 0x43, 0x0b, 0x91, 0x9e, 0xec, 0x8d, 0x2e, 0x88, 0x71, 0x16, 0xe2, 0x49, 0x03, 0xaf,
    0xd6, 0x2f, 0xfc, 0x70, 0x30, 0x84, 0xcd, 0x3f, 0x8f, 0x19, 0x8d, 0x6a, 0xef, 0x29, 0xba, 0x03,
    0xce, 0xf3, 0x8e, 0x20
};
#endif

PyTypeObject *init_QtROClientFactory(PyObject *module)
{
    if (SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROClientFactory_IDX].type != nullptr)
        return SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROClientFactory_IDX].type;

    Shiboken::AutoDecRef Sbk_QtROClientFactory_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QtROClientFactory_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QtROClientFactory",
        "QtROClientFactory*",
        &Sbk_QtROClientFactory_spec,
        &Shiboken::callCppDestructor< ::QtROClientFactory >,
        Sbk_QtROClientFactory_Type_bases.object(),
        0);
    auto *pyType = Sbk_QtROClientFactory_TypeF(); // references _Sbk_QtROClientFactory_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QtROClientFactory_SignatureStrings);
#else
    InitSignatureBytes(pyType, QtROClientFactory_SignatureBytes, QtROClientFactory_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QtROClientFactory_PropertyStrings);
    SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROClientFactory_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QtROClientFactory_PythonToCpp_QtROClientFactory_PTR,
        is_QtROClientFactory_PythonToCpp_QtROClientFactory_PTR_Convertible,
        QtROClientFactory_PTR_CppToPython_QtROClientFactory);

    Shiboken::Conversions::registerConverterName(converter, "QtROClientFactory");
    Shiboken::Conversions::registerConverterName(converter, "QtROClientFactory*");
    Shiboken::Conversions::registerConverterName(converter, "QtROClientFactory&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QtROClientFactory).name());

    qRegisterMetaType< ::QtROClientFactory *>();

    return pyType;
}
