// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtremoteobjects_python.h"

// main header
#include "qtroserverfactory_wrapper.h"

// Argument includes
#include <QtRemoteObjects/qconnectionfactories.h>
#include <qobject.h>
#include <qurl.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QtROServerFactoryFunc_create(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QtROServerFactory *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROServerFactory_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "create", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROServerFactory_IDX]);

    if (PyArg_ParseTuple(args, "|OO:create", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QtROServerFactory::create(QUrl,QObject*=)->QConnectionAbstractServer*
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // create(QUrl,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 0; // create(QUrl,QObject*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "create", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROServerFactory_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "create", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROServerFactory_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "create", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROServerFactory_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "create", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROServerFactory_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QObject *cppArg1 = nullptr;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // create(QUrl,QObject*)
            QConnectionAbstractServer * cppResult = cppSelf->create(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QConnectionAbstractServer_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QtROServerFactoryFunc_instance(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // instance()
        QtROServerFactory * cppResult = ::QtROServerFactory::instance();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROServerFactory_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QtROServerFactoryFunc_isValid(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QtROServerFactory *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROServerFactory_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QtROServerFactory::isValid(QUrl)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // isValid(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isValid", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROServerFactory_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // isValid(QUrl)
            bool cppResult = cppSelf->isValid(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QtROServerFactory_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QtROServerFactory_methods[] = {
    {"create", reinterpret_cast<PyCFunction>(Sbk_QtROServerFactoryFunc_create), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"instance", reinterpret_cast<PyCFunction>(Sbk_QtROServerFactoryFunc_instance), METH_NOARGS|METH_STATIC, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QtROServerFactoryFunc_isValid), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QtROServerFactory_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QtROServerFactory_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QtROServerFactory_Type = nullptr;
static PyTypeObject *Sbk_QtROServerFactory_TypeF(void)
{
    return _Sbk_QtROServerFactory_Type;
}

static PyType_Slot Sbk_QtROServerFactory_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QtROServerFactory_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QtROServerFactory_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QtROServerFactory_methods)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QtROServerFactory_spec = {
    "2:PySide6.QtRemoteObjects.QtROServerFactory",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QtROServerFactory_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QtROServerFactory_PythonToCpp_QtROServerFactory_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QtROServerFactory_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QtROServerFactory_PythonToCpp_QtROServerFactory_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QtROServerFactory_TypeF()))
        return QtROServerFactory_PythonToCpp_QtROServerFactory_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QtROServerFactory_PTR_CppToPython_QtROServerFactory(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QtROServerFactory_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QtROServerFactory_SignatureStrings[] = {
    "PySide6.QtRemoteObjects.QtROServerFactory.create(self,url:typing.Union[PySide6.QtCore.QUrl, QString],parent:PySide6.QtCore.QObject=nullptr)->PySide6.QtRemoteObjects.QConnectionAbstractServer",
    "PySide6.QtRemoteObjects.QtROServerFactory.instance()->PySide6.QtRemoteObjects.QtROServerFactory",
    "PySide6.QtRemoteObjects.QtROServerFactory.isValid(self,url:typing.Union[PySide6.QtCore.QUrl, QString])->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QtROServerFactory_SignatureByteSize = 170;
static constexpr uint8_t QtROServerFactory_SignatureBytes[170] = {
    0x78, 0xda, 0x9d, 0x90, 0xb1, 0x0a, 0xc2, 0x40, 0x0c, 0x86, 0xf7, 0x3e, 0x85, 0x63, 0x85, 0x7a,
    0xa3, 0x43, 0x41, 0x41, 0x0a, 0xae, 0xbd, 0x5a, 0xea, 0x22, 0x0e, 0xd7, 0x33, 0xca, 0x49, 0xcc,
    0x95, 0x5c, 0x2a, 0xf4, 0xed, 0x3d, 0x29, 0x38, 0x14, 0x14, 0x75, 0x4b, 0xe0, 0xcf, 0xff, 0x7d,
    0x44, 0x0f, 0xb5, 0x3b, 0xc1, 0x52, 0x55, 0xb2, 0x83, 0x9b, 0x17, 0x28, 0xdb, 0x2b, 0x58, 0x09,
    0xcf, 0xbd, 0xac, 0x81, 0xef, 0xc0, 0x5b, 0x63, 0xc5, 0xf3, 0xa0, 0x2c, 0x83, 0x11, 0x48, 0x03,
    0xe0, 0x39, 0xeb, 0x19, 0x73, 0x19, 0x3a, 0x47, 0x17, 0xd5, 0x90, 0xf3, 0x74, 0xd0, 0xaf, 0x9a,
    0xc2, 0x33, 0xa8, 0xaa, 0x61, 0xcc, 0x66, 0x55, 0x2d, 0x1c, 0x23, 0xc7, 0xac, 0x33, 0x0c, 0x24,
    0xf9, 0x34, 0x34, 0xb2, 0x56, 0xd4, 0x23, 0x76, 0xc2, 0xf3, 0xc5, 0x5a, 0xbf, 0x93, 0x29, 0x3c,
    0x51, 0x9c, 0x22, 0x69, 0xd3, 0x06, 0xe1, 0x68, 0x34, 0xba, 0x25, 0xfa, 0x6b, 0x7d, 0x47, 0x41,
    0x0c, 0x59, 0x48, 0x3f, 0x71, 0xa6, 0x57, 0xbf, 0xf4, 0x87, 0xbd, 0x41, 0x77, 0xfa, 0xe7, 0x3f,
    0xd1, 0xa8, 0xf5, 0x1e, 0x93, 0x07, 0x99, 0xe5, 0x91, 0xbf
};
#endif

PyTypeObject *init_QtROServerFactory(PyObject *module)
{
    if (SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROServerFactory_IDX].type != nullptr)
        return SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROServerFactory_IDX].type;

    Shiboken::AutoDecRef Sbk_QtROServerFactory_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QtROServerFactory_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QtROServerFactory",
        "QtROServerFactory*",
        &Sbk_QtROServerFactory_spec,
        &Shiboken::callCppDestructor< ::QtROServerFactory >,
        Sbk_QtROServerFactory_Type_bases.object(),
        0);
    auto *pyType = Sbk_QtROServerFactory_TypeF(); // references _Sbk_QtROServerFactory_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QtROServerFactory_SignatureStrings);
#else
    InitSignatureBytes(pyType, QtROServerFactory_SignatureBytes, QtROServerFactory_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QtROServerFactory_PropertyStrings);
    SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROServerFactory_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QtROServerFactory_PythonToCpp_QtROServerFactory_PTR,
        is_QtROServerFactory_PythonToCpp_QtROServerFactory_PTR_Convertible,
        QtROServerFactory_PTR_CppToPython_QtROServerFactory);

    Shiboken::Conversions::registerConverterName(converter, "QtROServerFactory");
    Shiboken::Conversions::registerConverterName(converter, "QtROServerFactory*");
    Shiboken::Conversions::registerConverterName(converter, "QtROServerFactory&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QtROServerFactory).name());

    qRegisterMetaType< ::QtROServerFactory *>();

    return pyType;
}
