// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtscxml_python.h"

// main header
#include "qscxmlcompiler_loader_wrapper.h"

// Argument includes
#include <QString>
#include <QStringList>
#include <qbytearray.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void LoaderWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

LoaderWrapper::LoaderWrapper()
{
}

::QByteArray LoaderWrapper::load(const ::QString & name, const ::QString & baseDir, ::QStringList * errors)
{
    if (m_PyMethodCache[0]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("Loader.load");
        return {};
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return {};
    static PyObject *nameCache[2] = {};
    static const char *funcName = "load";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        Shiboken::Errors::setPureVirtualMethodError("Loader.load");
        return {};
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[3] = {
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &name),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &baseDir),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], errors)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNN)",
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &name),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &baseDir),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], errors)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 3, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("Loader", funcName);
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("Loader", funcName, Shiboken::SbkType< QByteArray >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QByteArray cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

LoaderWrapper::~LoaderWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QScxmlCompiler_Loader_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlCompiler_Loader_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QScxmlCompiler::Loader");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QScxmlCompiler::Loader >()))
        return -1;

    LoaderWrapper *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlCompiler_Loader_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // Loader()
        cptr = new LoaderWrapper();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QScxmlCompiler::Loader >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QScxmlCompiler_LoaderFunc_load(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlCompiler::Loader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlCompiler_Loader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "load", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Loader::load(QString,QString,QStringList*)->QByteArray
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[2])))) {
        overloadId = 0; // load(QString,QString,QStringList*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "load", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlCompiler_Loader_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QStringList *cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // load(QString,QString,QStringList*)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("Loader.load");
                return {};
            }
            QByteArray cppResult = cppSelf->load(cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QScxmlCompiler_Loader_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QScxmlCompiler_Loader_methods[] = {
    {"load", reinterpret_cast<PyCFunction>(Sbk_QScxmlCompiler_LoaderFunc_load), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QScxmlCompiler_Loader_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QScxmlCompiler::Loader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlCompiler_Loader_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<LoaderWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QScxmlCompiler_Loader_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QScxmlCompiler_Loader_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QScxmlCompiler_Loader_Type = nullptr;
static PyTypeObject *Sbk_QScxmlCompiler_Loader_TypeF(void)
{
    return _Sbk_QScxmlCompiler_Loader_Type;
}

static PyType_Slot Sbk_QScxmlCompiler_Loader_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QScxmlCompiler_Loader_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QScxmlCompiler_Loader_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QScxmlCompiler_Loader_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QScxmlCompiler_Loader_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QScxmlCompiler_Loader_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QScxmlCompiler_Loader_spec = {
    "2:PySide6.QtScxml.QScxmlCompiler.Loader",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QScxmlCompiler_Loader_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void Loader_PythonToCpp_Loader_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QScxmlCompiler_Loader_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_Loader_PythonToCpp_Loader_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QScxmlCompiler_Loader_TypeF()))
        return Loader_PythonToCpp_Loader_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *Loader_PTR_CppToPython_Loader(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QScxmlCompiler::Loader *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QScxmlCompiler_Loader_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QScxmlCompiler_Loader_SignatureStrings[] = {
    "PySide6.QtScxml.QScxmlCompiler.Loader(self)",
    "PySide6.QtScxml.QScxmlCompiler.Loader.load(self,name:QString,baseDir:QString,errors:QStringList*)->PySide6.QtCore.QByteArray",
    nullptr}; // Sentinel
#else
static constexpr size_t QScxmlCompiler_Loader_SignatureByteSize = 114;
static constexpr uint8_t QScxmlCompiler_Loader_SignatureBytes[114] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x09, 0x4e, 0xae, 0xc8,
    0xcd, 0xd1, 0x0b, 0x04, 0x53, 0xce, 0xf9, 0xb9, 0x05, 0x99, 0x39, 0xa9, 0x45, 0x7a, 0x3e, 0xf9,
    0x89, 0x29, 0xa9, 0x45, 0x1a, 0xc5, 0xa9, 0x39, 0x69, 0x9a, 0x5c, 0x01, 0xc4, 0xa8, 0xd5, 0xcb,
    0x01, 0x52, 0x60, 0x0d, 0x3a, 0x79, 0x89, 0xb9, 0xa9, 0x56, 0x81, 0xc1, 0x25, 0x45, 0x99, 0x79,
    0xe9, 0x3a, 0x49, 0x89, 0xc5, 0xa9, 0x2e, 0x99, 0x45, 0x70, 0x7e, 0x6a, 0x51, 0x51, 0x7e, 0x51,
    0x31, 0x8c, 0xeb, 0x93, 0x59, 0x5c, 0xa2, 0xa5, 0xa9, 0x6b, 0x87, 0xb0, 0xc2, 0x39, 0xbf, 0x28,
    0x55, 0x2f, 0xd0, 0xa9, 0xb2, 0x24, 0xd5, 0xb1, 0xa8, 0x28, 0xb1, 0x92, 0x0b, 0x00, 0x6a, 0x71,
    0x3d, 0x26
};
#endif

PyTypeObject *init_QScxmlCompiler_Loader(PyObject *enclosingClass)
{
    if (SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlCompiler_Loader_IDX].type != nullptr)
        return SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlCompiler_Loader_IDX].type;

    Shiboken::AutoDecRef Sbk_QScxmlCompiler_Loader_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QScxmlCompiler_Loader_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "Loader",
        "QScxmlCompiler::Loader*",
        &Sbk_QScxmlCompiler_Loader_spec,
        &Shiboken::callCppDestructor< QScxmlCompiler::Loader >,
        Sbk_QScxmlCompiler_Loader_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
    auto *pyType = Sbk_QScxmlCompiler_Loader_TypeF(); // references _Sbk_QScxmlCompiler_Loader_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QScxmlCompiler_Loader_SignatureStrings);
#else
    InitSignatureBytes(pyType, QScxmlCompiler_Loader_SignatureBytes, QScxmlCompiler_Loader_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QScxmlCompiler_Loader_PropertyStrings);
    SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlCompiler_Loader_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        Loader_PythonToCpp_Loader_PTR,
        is_Loader_PythonToCpp_Loader_PTR_Convertible,
        Loader_PTR_CppToPython_Loader);

    Shiboken::Conversions::registerConverterName(converter, "QScxmlCompiler::Loader");
    Shiboken::Conversions::registerConverterName(converter, "QScxmlCompiler::Loader*");
    Shiboken::Conversions::registerConverterName(converter, "QScxmlCompiler::Loader&");
    Shiboken::Conversions::registerConverterAlias(converter, "Loader");
    Shiboken::Conversions::registerConverterAlias(converter, "Loader*");
    Shiboken::Conversions::registerConverterAlias(converter, "Loader&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QScxmlCompiler::Loader).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(LoaderWrapper).name());

    qRegisterMetaType< ::QScxmlCompiler::Loader *>();

    return pyType;
}
