// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtscxml_python.h"

// main header
#include "qscxmlcompiler_wrapper.h"

// inner classes
#include "qscxmlcompiler_loader_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtScxml/qscxmlcompiler.h>
#include <QtScxml/qscxmlerror.h>
#include <QtScxml/qscxmlstatemachine.h>
#include <qxmlstream.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QScxmlCompiler_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QScxmlCompiler >()))
        return -1;

    ::QScxmlCompiler *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QScxmlCompiler", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QScxmlCompiler::QScxmlCompiler(QXmlStreamReader*)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QScxmlCompiler(QXmlStreamReader*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlCompiler_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlCompiler_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QXmlStreamReader *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QScxmlCompiler(QXmlStreamReader*)
            cptr = new ::QScxmlCompiler(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QScxmlCompiler >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlCompiler_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QScxmlCompilerFunc_compile(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlCompiler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlCompiler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // compile()
        QScxmlStateMachine * cppResult = cppSelf->compile();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScxmlCompilerFunc_errors(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlCompiler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlCompiler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // errors()const
        QList<QScxmlError> cppResult = const_cast<const ::QScxmlCompiler *>(cppSelf)->errors();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtScxmlTypeConverters[SBK_QtScxml_QList_QScxmlError_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScxmlCompilerFunc_fileName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlCompiler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlCompiler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // fileName()const
        QString cppResult = const_cast<const ::QScxmlCompiler *>(cppSelf)->fileName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScxmlCompilerFunc_loader(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlCompiler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlCompiler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // loader()const
        QScxmlCompiler::Loader * cppResult = const_cast<const ::QScxmlCompiler *>(cppSelf)->loader();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlCompiler_Loader_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScxmlCompilerFunc_setFileName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlCompiler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlCompiler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QScxmlCompiler::setFileName(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setFileName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFileName", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlCompiler_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFileName(QString)
            cppSelf->setFileName(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QScxmlCompilerFunc_setLoader(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlCompiler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlCompiler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QScxmlCompiler::setLoader(QScxmlCompiler::Loader*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlCompiler_Loader_IDX]), (pyArg)))) {
        overloadId = 0; // setLoader(QScxmlCompiler::Loader*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLoader", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlCompiler_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QScxmlCompiler::Loader *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLoader(QScxmlCompiler::Loader*)
            cppSelf->setLoader(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QScxmlCompiler_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QScxmlCompiler_methods[] = {
    {"compile", reinterpret_cast<PyCFunction>(Sbk_QScxmlCompilerFunc_compile), METH_NOARGS, nullptr},
    {"errors", reinterpret_cast<PyCFunction>(Sbk_QScxmlCompilerFunc_errors), METH_NOARGS, nullptr},
    {"fileName", reinterpret_cast<PyCFunction>(Sbk_QScxmlCompilerFunc_fileName), METH_NOARGS, nullptr},
    {"loader", reinterpret_cast<PyCFunction>(Sbk_QScxmlCompilerFunc_loader), METH_NOARGS, nullptr},
    {"setFileName", reinterpret_cast<PyCFunction>(Sbk_QScxmlCompilerFunc_setFileName), METH_O, nullptr},
    {"setLoader", reinterpret_cast<PyCFunction>(Sbk_QScxmlCompilerFunc_setLoader), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QScxmlCompiler_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QScxmlCompiler_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QScxmlCompiler_Type = nullptr;
static PyTypeObject *Sbk_QScxmlCompiler_TypeF(void)
{
    return _Sbk_QScxmlCompiler_Type;
}

static PyType_Slot Sbk_QScxmlCompiler_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QScxmlCompiler_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QScxmlCompiler_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QScxmlCompiler_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QScxmlCompiler_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QScxmlCompiler_spec = {
    "2:PySide6.QtScxml.QScxmlCompiler",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QScxmlCompiler_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QScxmlCompiler_PythonToCpp_QScxmlCompiler_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QScxmlCompiler_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QScxmlCompiler_PythonToCpp_QScxmlCompiler_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QScxmlCompiler_TypeF()))
        return QScxmlCompiler_PythonToCpp_QScxmlCompiler_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QScxmlCompiler_PTR_CppToPython_QScxmlCompiler(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QScxmlCompiler_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QScxmlCompiler_SignatureStrings[] = {
    "PySide6.QtScxml.QScxmlCompiler(self,xmlReader:PySide6.QtCore.QXmlStreamReader)",
    "PySide6.QtScxml.QScxmlCompiler.compile(self)->PySide6.QtScxml.QScxmlStateMachine",
    "PySide6.QtScxml.QScxmlCompiler.errors(self)->QList[PySide6.QtScxml.QScxmlError]",
    "PySide6.QtScxml.QScxmlCompiler.fileName(self)->QString",
    "PySide6.QtScxml.QScxmlCompiler.loader(self)->PySide6.QtScxml.QScxmlCompiler.Loader",
    "PySide6.QtScxml.QScxmlCompiler.setFileName(self,fileName:QString)",
    "PySide6.QtScxml.QScxmlCompiler.setLoader(self,newLoader:PySide6.QtScxml.QScxmlCompiler.Loader)",
    nullptr}; // Sentinel
#else
static constexpr size_t QScxmlCompiler_SignatureByteSize = 180;
static constexpr uint8_t QScxmlCompiler_SignatureBytes[180] = {
    0x78, 0xda, 0x8d, 0x8f, 0xbd, 0x0e, 0x82, 0x30, 0x14, 0x46, 0x77, 0x9e, 0xc4, 0x26, 0xd8, 0xd1,
    0x81, 0xc1, 0x85, 0xe8, 0x84, 0x86, 0xda, 0xc5, 0xc4, 0x38, 0x34, 0xe5, 0xa2, 0x4d, 0x5a, 0x6a,
    0x6e, 0x9b, 0xa8, 0x6f, 0x2f, 0x14, 0x41, 0x07, 0x42, 0x59, 0xfa, 0xfb, 0xdd, 0x93, 0xf3, 0x95,
    0x6f, 0xae, 0x2a, 0xd8, 0x50, 0xe6, 0xb9, 0x7c, 0x19, 0x4d, 0x59, 0xd8, 0x72, 0x6b, 0x1e, 0x4a,
    0x03, 0xae, 0x1c, 0xe8, 0x3a, 0x6d, 0x1f, 0x4e, 0x20, 0x2a, 0xc0, 0xac, 0x1c, 0xd3, 0xb9, 0x45,
    0xa0, 0xec, 0x6c, 0x34, 0xf7, 0x08, 0xc2, 0xf4, 0xff, 0x24, 0x29, 0x67, 0x71, 0x54, 0xf6, 0x87,
    0x80, 0x25, 0xeb, 0xed, 0x74, 0x9a, 0x7b, 0xe1, 0xe1, 0x20, 0xe4, 0x5d, 0x35, 0x10, 0x03, 0x02,
    0xa2, 0x45, 0x37, 0xf0, 0x58, 0xa1, 0x9c, 0xbf, 0x4c, 0x8f, 0xec, 0xba, 0xe4, 0x35, 0xc6, 0xab,
    0xdb, 0xf5, 0x28, 0xcc, 0x68, 0xc8, 0xda, 0x7a, 0xaa, 0xb9, 0xc5, 0xc6, 0xb4, 0xed, 0xea, 0xcf,
    0xd7, 0x1a, 0xc3, 0x45, 0x08, 0xc7, 0x90, 0x0e, 0xfc, 0xfe, 0x5f, 0x26, 0x1d, 0xd4, 0xb2, 0xaf,
    0x13, 0x59, 0x40, 0x28, 0x7e, 0x5e, 0x69, 0x03, 0xcf, 0xfe, 0x9a, 0x2d, 0xf2, 0x23, 0xc9, 0x07,
    0x01, 0xc3, 0xc4, 0x37
};
#endif

PyTypeObject *init_QScxmlCompiler(PyObject *module)
{
    if (SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlCompiler_IDX].type != nullptr)
        return SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlCompiler_IDX].type;

    Shiboken::AutoDecRef Sbk_QScxmlCompiler_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QScxmlCompiler_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QScxmlCompiler",
        "QScxmlCompiler*",
        &Sbk_QScxmlCompiler_spec,
        &Shiboken::callCppDestructor< ::QScxmlCompiler >,
        Sbk_QScxmlCompiler_Type_bases.object(),
        0);
    auto *pyType = Sbk_QScxmlCompiler_TypeF(); // references _Sbk_QScxmlCompiler_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QScxmlCompiler_SignatureStrings);
#else
    InitSignatureBytes(pyType, QScxmlCompiler_SignatureBytes, QScxmlCompiler_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QScxmlCompiler_PropertyStrings);
    SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlCompiler_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QScxmlCompiler_PythonToCpp_QScxmlCompiler_PTR,
        is_QScxmlCompiler_PythonToCpp_QScxmlCompiler_PTR_Convertible,
        QScxmlCompiler_PTR_CppToPython_QScxmlCompiler);

    Shiboken::Conversions::registerConverterName(converter, "QScxmlCompiler");
    Shiboken::Conversions::registerConverterName(converter, "QScxmlCompiler*");
    Shiboken::Conversions::registerConverterName(converter, "QScxmlCompiler&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QScxmlCompiler).name());

    qRegisterMetaType< ::QScxmlCompiler *>();

    return pyType;
}
