// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtscxml_python.h"

// main header
#include "qscxmlerror_wrapper.h"

// Argument includes
#include <QString>
#include <QtScxml/qscxmlerror.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QScxmlError_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QScxmlError >()))
        return -1;

    ::QScxmlError *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlError_IDX]);

    if (PyArg_UnpackTuple(args, "QScxmlError", 0, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QScxmlError::QScxmlError()
    // 1: QScxmlError::QScxmlError(QScxmlError)
    // 2: QScxmlError::QScxmlError(QString,int,int,QString)
    if (numArgs == 0) {
        overloadId = 0; // QScxmlError()
    } else if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3])))) {
        overloadId = 2; // QScxmlError(QString,int,int,QString)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlError_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QScxmlError(QScxmlError)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlError_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlError_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QScxmlError()
        {

            // QScxmlError()
            cptr = new ::QScxmlError();
            break;
        }
        case 1: // QScxmlError(const QScxmlError &arg__1)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QScxmlError cppArg0_local;
            ::QScxmlError *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QScxmlError(QScxmlError)
                cptr = new ::QScxmlError(*cppArg0);
            }
            break;
        }
        case 2: // QScxmlError(const QString &fileName, int line, int column, const QString &description)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QString cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QScxmlError(QString,int,int,QString)
                cptr = new ::QScxmlError(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QScxmlError >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlError_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QScxmlErrorFunc_column(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // column()const
        int cppResult = const_cast<const ::QScxmlError *>(cppSelf)->column();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScxmlErrorFunc_description(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // description()const
        QString cppResult = const_cast<const ::QScxmlError *>(cppSelf)->description();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScxmlErrorFunc_fileName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // fileName()const
        QString cppResult = const_cast<const ::QScxmlError *>(cppSelf)->fileName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScxmlErrorFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QScxmlError *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScxmlErrorFunc_line(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // line()const
        int cppResult = const_cast<const ::QScxmlError *>(cppSelf)->line();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScxmlErrorFunc_toString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toString()const
        QString cppResult = const_cast<const ::QScxmlError *>(cppSelf)->toString();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScxmlError__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QScxmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlError_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QScxmlError_PropertyStrings[] = {
    "column:",
    "description:",
    "fileName:",
    "line:",
    "valid:isValid",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QScxmlError_methods[] = {
    {"column", reinterpret_cast<PyCFunction>(Sbk_QScxmlErrorFunc_column), METH_NOARGS, nullptr},
    {"description", reinterpret_cast<PyCFunction>(Sbk_QScxmlErrorFunc_description), METH_NOARGS, nullptr},
    {"fileName", reinterpret_cast<PyCFunction>(Sbk_QScxmlErrorFunc_fileName), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QScxmlErrorFunc_isValid), METH_NOARGS, nullptr},
    {"line", reinterpret_cast<PyCFunction>(Sbk_QScxmlErrorFunc_line), METH_NOARGS, nullptr},
    {"toString", reinterpret_cast<PyCFunction>(Sbk_QScxmlErrorFunc_toString), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QScxmlError__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QScxmlError_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QScxmlError_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QScxmlError_Type = nullptr;
static PyTypeObject *Sbk_QScxmlError_TypeF(void)
{
    return _Sbk_QScxmlError_Type;
}

static PyType_Slot Sbk_QScxmlError_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QScxmlError_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QScxmlError_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QScxmlError_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QScxmlError_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QScxmlError_spec = {
    "2:PySide6.QtScxml.QScxmlError",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QScxmlError_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QScxmlError_PythonToCpp_QScxmlError_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QScxmlError_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QScxmlError_PythonToCpp_QScxmlError_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QScxmlError_TypeF()))
        return QScxmlError_PythonToCpp_QScxmlError_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QScxmlError_PTR_CppToPython_QScxmlError(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QScxmlError_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QScxmlError_COPY_CppToPython_QScxmlError(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QScxmlError *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QScxmlError_TypeF(), new ::QScxmlError(*source), true, true);
}

// Python to C++ copy conversion.
static void QScxmlError_PythonToCpp_QScxmlError_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QScxmlError *>(cppOut) = *reinterpret_cast< ::QScxmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlError_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QScxmlError_PythonToCpp_QScxmlError_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QScxmlError_TypeF()))
        return QScxmlError_PythonToCpp_QScxmlError_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QScxmlError_SignatureStrings[] = {
    "2:PySide6.QtScxml.QScxmlError(self,*:KeywordOnly=None,valid:bool=None,fileName:QString=None,line:int=None,column:int=None,description:QString=None)",
    "1:PySide6.QtScxml.QScxmlError(self,arg__1:PySide6.QtScxml.QScxmlError,*:KeywordOnly=None,valid:bool=None,fileName:QString=None,line:int=None,column:int=None,description:QString=None)",
    "0:PySide6.QtScxml.QScxmlError(self,fileName:QString,line:int,column:int,description:QString,*:KeywordOnly=None,valid:bool=None,fileName:QString=None,line:int=None,column:int=None,description:QString=None)",
    "PySide6.QtScxml.QScxmlError.column(self)->int",
    "PySide6.QtScxml.QScxmlError.description(self)->QString",
    "PySide6.QtScxml.QScxmlError.fileName(self)->QString",
    "PySide6.QtScxml.QScxmlError.isValid(self)->bool",
    "PySide6.QtScxml.QScxmlError.line(self)->int",
    "PySide6.QtScxml.QScxmlError.toString(self)->QString",
    "PySide6.QtScxml.QScxmlError.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QScxmlError_SignatureByteSize = 213;
static constexpr uint8_t QScxmlError_SignatureBytes[213] = {
    0x78, 0xda, 0xbd, 0x90, 0xcd, 0x0e, 0x82, 0x30, 0x10, 0x84, 0xef, 0x3c, 0x89, 0x1a, 0x24, 0xea,
    0xc1, 0x43, 0x13, 0xbd, 0x79, 0x32, 0x41, 0x09, 0x89, 0xd7, 0x06, 0xa1, 0x90, 0x4d, 0x4a, 0x97,
    0x94, 0xfa, 0xd3, 0xb7, 0x17, 0xa8, 0x28, 0x1a, 0x53, 0xe4, 0xc2, 0xa9, 0x99, 0x66, 0xbf, 0x9d,
    0x99, 0x5d, 0x91, 0xa3, 0x0e, 0x21, 0x61, 0x6b, 0x2f, 0x50, 0x61, 0x7c, 0xcf, 0xb9, 0x17, 0x34,
    0xcf, 0x4e, 0x4a, 0x94, 0x93, 0x92, 0xf1, 0xd4, 0x9d, 0x91, 0x3d, 0xd3, 0x37, 0x94, 0xc9, 0x41,
    0x70, 0xbd, 0xf1, 0x51, 0x30, 0xf7, 0x1a, 0x71, 0x48, 0xc8, 0x19, 0x91, 0x1b, 0x9d, 0x02, 0x67,
    0x7e, 0x94, 0x33, 0x12, 0x84, 0x4a, 0x82, 0xc8, 0xcc, 0x2f, 0x07, 0xc1, 0x08, 0x08, 0x65, 0x54,
    0x8c, 0xfc, 0x92, 0x8b, 0xb7, 0x4e, 0x58, 0x19, 0x4b, 0x28, 0x14, 0xa0, 0xf8, 0xc0, 0xa6, 0xce,
    0xb2, 0x3f, 0x53, 0x24, 0x33, 0x4a, 0xad, 0x73, 0xe3, 0xc7, 0x5e, 0xf4, 0xc7, 0xfe, 0x36, 0x7c,
    0x79, 0x75, 0x6c, 0x7e, 0x39, 0x8c, 0x5f, 0xc6, 0x52, 0xc5, 0x33, 0x5b, 0x9a, 0x46, 0xd3, 0xf9,
    0xb6, 0x5a, 0x66, 0x9d, 0xee, 0x78, 0xb4, 0xc8, 0xd3, 0xca, 0x8a, 0xb5, 0x75, 0x86, 0x30, 0x50,
    0x9e, 0xea, 0xa3, 0xb4, 0x48, 0x7d, 0x1b, 0xeb, 0x7c, 0x7d, 0x9c, 0x7f, 0x6b, 0x28, 0x34, 0x01,
    0x86, 0xe4, 0xa1, 0x34, 0xc6, 0x42, 0x53, 0xda, 0x32, 0x4a, 0x17, 0x15, 0xe2, 0x85, 0x95, 0x72,
    0x1e, 0xa9, 0xf8, 0x44, 0x19
};
#endif

PyTypeObject *init_QScxmlError(PyObject *module)
{
    if (SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlError_IDX].type != nullptr)
        return SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlError_IDX].type;

    Shiboken::AutoDecRef Sbk_QScxmlError_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QScxmlError_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QScxmlError",
        "QScxmlError",
        &Sbk_QScxmlError_spec,
        &Shiboken::callCppDestructor< ::QScxmlError >,
        Sbk_QScxmlError_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QScxmlError_TypeF(); // references _Sbk_QScxmlError_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QScxmlError_SignatureStrings);
#else
    InitSignatureBytes(pyType, QScxmlError_SignatureBytes, QScxmlError_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QScxmlError_PropertyStrings);
    SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlError_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QScxmlError_PythonToCpp_QScxmlError_PTR,
        is_QScxmlError_PythonToCpp_QScxmlError_PTR_Convertible,
        QScxmlError_PTR_CppToPython_QScxmlError,
        QScxmlError_COPY_CppToPython_QScxmlError);

    Shiboken::Conversions::registerConverterName(converter, "QScxmlError");
    Shiboken::Conversions::registerConverterName(converter, "QScxmlError*");
    Shiboken::Conversions::registerConverterName(converter, "QScxmlError&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QScxmlError).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QScxmlError_PythonToCpp_QScxmlError_COPY,
        is_QScxmlError_PythonToCpp_QScxmlError_COPY_Convertible);

    qRegisterMetaType< ::QScxmlError >("QScxmlError");

    return pyType;
}
