// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtscxml_python.h"

// main header
#include "qscxmlstatemachine_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QMap>
#include <QString>
#include <QStringList>
#include <QtScxml/qscxmlcompiler.h>
#include <QtScxml/qscxmldatamodel.h>
#include <QtScxml/qscxmlerror.h>
#include <QtScxml/qscxmlevent.h>
#include <QtScxml/qscxmlinvokableservice.h>
#include <QtScxml/qscxmlstatemachine.h>
#include <QtScxml/qscxmltabledata.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qiodevice.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QScxmlStateMachineWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QScxmlStateMachineWrapper::QScxmlStateMachineWrapper(const ::QMetaObject * metaObject, ::QObject * parent) : QScxmlStateMachine(metaObject, parent)
{
}

void QScxmlStateMachineWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QScxmlStateMachine", funcName);
        return;
    }
}

void QScxmlStateMachineWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QScxmlStateMachine", funcName);
        return;
    }
}

void QScxmlStateMachineWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QScxmlStateMachine", funcName);
        return;
    }
}

void QScxmlStateMachineWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QScxmlStateMachine", funcName);
        return;
    }
}

bool QScxmlStateMachineWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QScxmlStateMachine", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QScxmlStateMachine", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QScxmlStateMachineWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QScxmlStateMachine", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QScxmlStateMachine", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QScxmlStateMachineWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QScxmlStateMachine", funcName);
        return;
    }
}

const QMetaObject *QScxmlStateMachineWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QScxmlStateMachine::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QScxmlStateMachineWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QScxmlStateMachine::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QScxmlStateMachineWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QScxmlStateMachineWrapper *>(this));
    return QScxmlStateMachine::qt_metacast(_clname);
}

QScxmlStateMachineWrapper::~QScxmlStateMachineWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QScxmlStateMachine_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QScxmlStateMachine >()))
        return -1;

    QScxmlStateMachineWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:QScxmlStateMachine", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QScxmlStateMachine::QScxmlStateMachine(const QMetaObject*,QObject*=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // QScxmlStateMachine(const QMetaObject*,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 0; // QScxmlStateMachine(const QMetaObject*,QObject*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                // fall through to handle extra keyword signals and properties
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QMetaObject *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return -1;
        ::QObject *cppArg1 = nullptr;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QScxmlStateMachine(const QMetaObject*,QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QScxmlStateMachineWrapper(cppArg0, cppArg1);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QScxmlStateMachineWrapper(cppArg0, cppArg1);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[1], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QScxmlStateMachine >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QScxmlStateMachineFunc_activeStateNames(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "activeStateNames", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]);

    if (PyArg_ParseTuple(args, "|O:activeStateNames", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QScxmlStateMachine::activeStateNames(bool=)const->QStringList
    if (numArgs == 0) {
        overloadId = 0; // activeStateNames(bool)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))) {
        overloadId = 0; // activeStateNames(bool)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "activeStateNames", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_compress = Shiboken::String::createStaticString("compress");
            if (PyDict_Contains(kwds, key_compress) != 0) {
                value = PyDict_GetItem(kwds, key_compress);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_compress);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "activeStateNames", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "activeStateNames", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_compress);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "activeStateNames", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]);
            }
        }
        bool cppArg0 = true;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // activeStateNames(bool)const
            QStringList cppResult = const_cast<const ::QScxmlStateMachine *>(cppSelf)->activeStateNames(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScxmlStateMachineFunc_cancelDelayedEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QScxmlStateMachine::cancelDelayedEvent(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // cancelDelayedEvent(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "cancelDelayedEvent", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // cancelDelayedEvent(QString)
            cppSelf->cancelDelayedEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QScxmlStateMachineFunc_connectToEvent(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "connectToEvent", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:connectToEvent", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QScxmlStateMachine::connectToEvent(QString,const QObject*,const char*,Qt::ConnectionType=)->QMetaObject::Connection
    if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))
        && Shiboken::String::check(pyArgs[2]) && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // connectToEvent(QString,const QObject*,const char*,Qt::ConnectionType)
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ConnectionType_IDX])))->converter, (pyArgs[3])))) {
            overloadId = 0; // connectToEvent(QString,const QObject*,const char*,Qt::ConnectionType)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "connectToEvent", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_type = Shiboken::String::createStaticString("type");
            if (PyDict_Contains(kwds, key_type) != 0) {
                value = PyDict_GetItem(kwds, key_type);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_type);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "connectToEvent", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ConnectionType_IDX])))->converter, (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, "connectToEvent", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_type);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "connectToEvent", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QObject *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        const char* cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        ::Qt::ConnectionType cppArg3(Qt::AutoConnection);
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // connectToEvent(QString,const QObject*,const char*,Qt::ConnectionType)
            QMetaObject::Connection cppResult = cppSelf->connectToEvent(cppArg0, cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_Connection_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScxmlStateMachineFunc_connectToState(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "connectToState", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:connectToState", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QScxmlStateMachine::connectToState(QString,const QObject*,const char*,Qt::ConnectionType=)->QMetaObject::Connection
    if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))
        && Shiboken::String::check(pyArgs[2]) && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // connectToState(QString,const QObject*,const char*,Qt::ConnectionType)
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ConnectionType_IDX])))->converter, (pyArgs[3])))) {
            overloadId = 0; // connectToState(QString,const QObject*,const char*,Qt::ConnectionType)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "connectToState", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_type = Shiboken::String::createStaticString("type");
            if (PyDict_Contains(kwds, key_type) != 0) {
                value = PyDict_GetItem(kwds, key_type);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_type);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "connectToState", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ConnectionType_IDX])))->converter, (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, "connectToState", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_type);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "connectToState", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QObject *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        const char* cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        ::Qt::ConnectionType cppArg3(Qt::AutoConnection);
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // connectToState(QString,const QObject*,const char*,Qt::ConnectionType)
            QMetaObject::Connection cppResult = cppSelf->connectToState(cppArg0, cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_Connection_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScxmlStateMachineFunc_dataModel(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // dataModel()const
        QScxmlDataModel * cppResult = const_cast<const ::QScxmlStateMachine *>(cppSelf)->dataModel();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlDataModel_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScxmlStateMachineFunc_fromData(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "fromData", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]);

    if (PyArg_ParseTuple(args, "|OO:fromData", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QScxmlStateMachine::fromData(QIODevice*,const QString&=)->QScxmlStateMachine*
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // fromData(QIODevice*,QString)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 0; // fromData(QIODevice*,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fromData", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_fileName = Shiboken::String::createStaticString("fileName");
            if (PyDict_Contains(kwds, key_fileName) != 0) {
                value = PyDict_GetItem(kwds, key_fileName);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_fileName);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "fromData", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "fromData", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_fileName);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "fromData", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QIODevice *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1 = QString();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromData(QIODevice*,QString)
            QScxmlStateMachine * cppResult = ::QScxmlStateMachine::fromData(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScxmlStateMachineFunc_fromFile(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QScxmlStateMachine::fromFile(QString)->QScxmlStateMachine*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // fromFile(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fromFile", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromFile(QString)
            QScxmlStateMachine * cppResult = ::QScxmlStateMachine::fromFile(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScxmlStateMachineFunc_init(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // init()
        bool cppResult = cppSelf->init();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScxmlStateMachineFunc_initialValues(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // initialValues()
        QMap<QString,QVariant> cppResult = cppSelf->initialValues();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtScxmlTypeConverters[SBK_QtScxml_QMap_QString_QVariant_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScxmlStateMachineFunc_invokedServices(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // invokedServices()const
        QList<QScxmlInvokableService*> cppResult = const_cast<const ::QScxmlStateMachine *>(cppSelf)->invokedServices();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtScxmlTypeConverters[SBK_QtScxml_QList_QScxmlInvokableServicePTR_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScxmlStateMachineFunc_isActive(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QScxmlStateMachine::isActive(QString)const->bool
    // 1: QScxmlStateMachine::isActive(int)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 1; // isActive(int)const
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // isActive(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isActive", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // isActive(const QString &scxmlStateName) const
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // isActive(QString)const
                bool cppResult = const_cast<const ::QScxmlStateMachine *>(cppSelf)->isActive(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // isActive(int stateIndex) const
        {
            int cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // isActive(int)const
                bool cppResult = const_cast<const ::QScxmlStateMachine *>(cppSelf)->isActive(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScxmlStateMachineFunc_isDispatchableTarget(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QScxmlStateMachine::isDispatchableTarget(QString)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // isDispatchableTarget(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isDispatchableTarget", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isDispatchableTarget(QString)const
            bool cppResult = const_cast<const ::QScxmlStateMachine *>(cppSelf)->isDispatchableTarget(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScxmlStateMachineFunc_isInitialized(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isInitialized()const
        bool cppResult = const_cast<const ::QScxmlStateMachine *>(cppSelf)->isInitialized();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScxmlStateMachineFunc_isInvoked(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isInvoked()const
        bool cppResult = const_cast<const ::QScxmlStateMachine *>(cppSelf)->isInvoked();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScxmlStateMachineFunc_isRunning(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isRunning()const
        bool cppResult = const_cast<const ::QScxmlStateMachine *>(cppSelf)->isRunning();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScxmlStateMachineFunc_loader(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // loader()const
        QScxmlCompiler::Loader * cppResult = const_cast<const ::QScxmlStateMachine *>(cppSelf)->loader();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlCompiler_Loader_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScxmlStateMachineFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // name()const
        QString cppResult = const_cast<const ::QScxmlStateMachine *>(cppSelf)->name();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScxmlStateMachineFunc_parseErrors(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // parseErrors()const
        QList<QScxmlError> cppResult = const_cast<const ::QScxmlStateMachine *>(cppSelf)->parseErrors();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtScxmlTypeConverters[SBK_QtScxml_QList_QScxmlError_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScxmlStateMachineFunc_sessionId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sessionId()const
        QString cppResult = const_cast<const ::QScxmlStateMachine *>(cppSelf)->sessionId();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScxmlStateMachineFunc_setDataModel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QScxmlStateMachine::setDataModel(QScxmlDataModel*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlDataModel_IDX]), (pyArg)))) {
        overloadId = 0; // setDataModel(QScxmlDataModel*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDataModel", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QScxmlDataModel *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDataModel(QScxmlDataModel*)
            cppSelf->setDataModel(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QScxmlStateMachineFunc_setInitialValues(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QScxmlStateMachine::setInitialValues(QMap<QString,QVariant>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtScxmlTypeConverters[SBK_QtScxml_QMap_QString_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // setInitialValues(QMap<QString,QVariant>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setInitialValues", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]);

    // Call function/method
    {
        ::QMap<QString,QVariant> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setInitialValues(QMap<QString,QVariant>)
            cppSelf->setInitialValues(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QScxmlStateMachineFunc_setLoader(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QScxmlStateMachine::setLoader(QScxmlCompiler::Loader*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlCompiler_Loader_IDX]), (pyArg)))) {
        overloadId = 0; // setLoader(QScxmlCompiler::Loader*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLoader", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QScxmlCompiler::Loader *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLoader(QScxmlCompiler::Loader*)
            cppSelf->setLoader(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QScxmlStateMachineFunc_setRunning(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QScxmlStateMachine::setRunning(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setRunning(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRunning", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRunning(bool)
            cppSelf->setRunning(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QScxmlStateMachineFunc_setTableData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QScxmlStateMachine::setTableData(QScxmlTableData*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlTableData_IDX]), (pyArg)))) {
        overloadId = 0; // setTableData(QScxmlTableData*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTableData", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QScxmlTableData *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTableData(QScxmlTableData*)
            cppSelf->setTableData(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QScxmlStateMachineFunc_start(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // start()
        cppSelf->start();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QScxmlStateMachineFunc_stateNames(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "stateNames", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]);

    if (PyArg_ParseTuple(args, "|O:stateNames", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QScxmlStateMachine::stateNames(bool=)const->QStringList
    if (numArgs == 0) {
        overloadId = 0; // stateNames(bool)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))) {
        overloadId = 0; // stateNames(bool)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "stateNames", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_compress = Shiboken::String::createStaticString("compress");
            if (PyDict_Contains(kwds, key_compress) != 0) {
                value = PyDict_GetItem(kwds, key_compress);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_compress);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "stateNames", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "stateNames", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_compress);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "stateNames", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]);
            }
        }
        bool cppArg0 = true;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // stateNames(bool)const
            QStringList cppResult = const_cast<const ::QScxmlStateMachine *>(cppSelf)->stateNames(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScxmlStateMachineFunc_stop(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // stop()
        cppSelf->stop();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QScxmlStateMachineFunc_submitEvent(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "submitEvent", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QScxmlStateMachine::submitEvent(QScxmlEvent*)
    // 1: QScxmlStateMachine::submitEvent(QString)
    // 2: QScxmlStateMachine::submitEvent(QString,QVariant)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlEvent_IDX]), (pyArgs[0])))) {
        overloadId = 0; // submitEvent(QScxmlEvent*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // submitEvent(QString)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[1])))) {
            overloadId = 2; // submitEvent(QString,QVariant)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "submitEvent", errInfo, SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // submitEvent(QScxmlEvent *event)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QScxmlEvent *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // submitEvent(QScxmlEvent*)
                cppSelf->submitEvent(cppArg0);

                // Ownership transferences.
                Shiboken::Object::invalidate(pyArgs[0]);
            }
            break;
        }
        case 1: // submitEvent(const QString &eventName)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // submitEvent(QString)
                cppSelf->submitEvent(cppArg0);
            }
            break;
        }
        case 2: // submitEvent(const QString &eventName, const QVariant &data)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QVariant cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // submitEvent(QString,QVariant)
                cppSelf->submitEvent(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QScxmlStateMachineFunc_tableData(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // tableData()const
        QScxmlTableData * cppResult = const_cast<const ::QScxmlStateMachine *>(cppSelf)->tableData();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlTableData_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QScxmlStateMachine_PropertyStrings[] = {
    "dataModel::",
    "initialValues::",
    "initialized:isInitialized",
    "invoked:isInvoked",
    "invokedServices:",
    "loader::",
    "name:",
    "parseErrors:",
    "running:isRunning:",
    "sessionId:",
    "tableData::",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QScxmlStateMachine_methods[] = {
    {"activeStateNames", reinterpret_cast<PyCFunction>(Sbk_QScxmlStateMachineFunc_activeStateNames), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"cancelDelayedEvent", reinterpret_cast<PyCFunction>(Sbk_QScxmlStateMachineFunc_cancelDelayedEvent), METH_O, nullptr},
    {"connectToEvent", reinterpret_cast<PyCFunction>(Sbk_QScxmlStateMachineFunc_connectToEvent), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"connectToState", reinterpret_cast<PyCFunction>(Sbk_QScxmlStateMachineFunc_connectToState), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"dataModel", reinterpret_cast<PyCFunction>(Sbk_QScxmlStateMachineFunc_dataModel), METH_NOARGS, nullptr},
    {"fromData", reinterpret_cast<PyCFunction>(Sbk_QScxmlStateMachineFunc_fromData), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"fromFile", reinterpret_cast<PyCFunction>(Sbk_QScxmlStateMachineFunc_fromFile), METH_O|METH_STATIC, nullptr},
    {"init", reinterpret_cast<PyCFunction>(Sbk_QScxmlStateMachineFunc_init), METH_NOARGS, nullptr},
    {"initialValues", reinterpret_cast<PyCFunction>(Sbk_QScxmlStateMachineFunc_initialValues), METH_NOARGS, nullptr},
    {"invokedServices", reinterpret_cast<PyCFunction>(Sbk_QScxmlStateMachineFunc_invokedServices), METH_NOARGS, nullptr},
    {"isActive", reinterpret_cast<PyCFunction>(Sbk_QScxmlStateMachineFunc_isActive), METH_O, nullptr},
    {"isDispatchableTarget", reinterpret_cast<PyCFunction>(Sbk_QScxmlStateMachineFunc_isDispatchableTarget), METH_O, nullptr},
    {"isInitialized", reinterpret_cast<PyCFunction>(Sbk_QScxmlStateMachineFunc_isInitialized), METH_NOARGS, nullptr},
    {"isInvoked", reinterpret_cast<PyCFunction>(Sbk_QScxmlStateMachineFunc_isInvoked), METH_NOARGS, nullptr},
    {"isRunning", reinterpret_cast<PyCFunction>(Sbk_QScxmlStateMachineFunc_isRunning), METH_NOARGS, nullptr},
    {"loader", reinterpret_cast<PyCFunction>(Sbk_QScxmlStateMachineFunc_loader), METH_NOARGS, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_QScxmlStateMachineFunc_name), METH_NOARGS, nullptr},
    {"parseErrors", reinterpret_cast<PyCFunction>(Sbk_QScxmlStateMachineFunc_parseErrors), METH_NOARGS, nullptr},
    {"sessionId", reinterpret_cast<PyCFunction>(Sbk_QScxmlStateMachineFunc_sessionId), METH_NOARGS, nullptr},
    {"setDataModel", reinterpret_cast<PyCFunction>(Sbk_QScxmlStateMachineFunc_setDataModel), METH_O, nullptr},
    {"setInitialValues", reinterpret_cast<PyCFunction>(Sbk_QScxmlStateMachineFunc_setInitialValues), METH_O, nullptr},
    {"setLoader", reinterpret_cast<PyCFunction>(Sbk_QScxmlStateMachineFunc_setLoader), METH_O, nullptr},
    {"setRunning", reinterpret_cast<PyCFunction>(Sbk_QScxmlStateMachineFunc_setRunning), METH_O, nullptr},
    {"setTableData", reinterpret_cast<PyCFunction>(Sbk_QScxmlStateMachineFunc_setTableData), METH_O, nullptr},
    {"start", reinterpret_cast<PyCFunction>(Sbk_QScxmlStateMachineFunc_start), METH_NOARGS, nullptr},
    {"stateNames", reinterpret_cast<PyCFunction>(Sbk_QScxmlStateMachineFunc_stateNames), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"stop", reinterpret_cast<PyCFunction>(Sbk_QScxmlStateMachineFunc_stop), METH_NOARGS, nullptr},
    {"submitEvent", reinterpret_cast<PyCFunction>(Sbk_QScxmlStateMachineFunc_submitEvent), METH_VARARGS, nullptr},
    {"tableData", reinterpret_cast<PyCFunction>(Sbk_QScxmlStateMachineFunc_tableData), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QScxmlStateMachine_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QScxmlStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QScxmlStateMachineWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QScxmlStateMachine_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QScxmlStateMachine_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QScxmlStateMachine_Type = nullptr;
static PyTypeObject *Sbk_QScxmlStateMachine_TypeF(void)
{
    return _Sbk_QScxmlStateMachine_Type;
}

static PyType_Slot Sbk_QScxmlStateMachine_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QScxmlStateMachine_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QScxmlStateMachine_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QScxmlStateMachine_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QScxmlStateMachine_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QScxmlStateMachine_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QScxmlStateMachine_spec = {
    "2:PySide6.QtScxml.QScxmlStateMachine",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QScxmlStateMachine_slots
};

} //extern "C"

static void *Sbk_QScxmlStateMachine_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QScxmlStateMachine *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QScxmlStateMachine_PythonToCpp_QScxmlStateMachine_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QScxmlStateMachine_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QScxmlStateMachine_PythonToCpp_QScxmlStateMachine_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QScxmlStateMachine_TypeF()))
        return QScxmlStateMachine_PythonToCpp_QScxmlStateMachine_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QScxmlStateMachine_PTR_CppToPython_QScxmlStateMachine(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QScxmlStateMachine *>(const_cast<void *>(cppIn)), Sbk_QScxmlStateMachine_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QScxmlStateMachine_SignatureStrings[] = {
    "PySide6.QtScxml.QScxmlStateMachine(self,metaObject:PySide6.QtCore.QMetaObject,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,running:bool=None,initialized:bool=None,dataModel:QScxmlDataModel=None,initialValues:QMap[QString, QVariant]=None,invokedServices:QList[PySide6.QtScxml.QScxmlInvokableService]=None,sessionId:QString=None,name:QString=None,invoked:bool=None,parseErrors:QList[PySide6.QtScxml.QScxmlError]=None,loader:QScxmlCompiler.Loader=None,tableData:QScxmlTableData=None)",
    "PySide6.QtScxml.QScxmlStateMachine.activeStateNames(self,compress:bool=true)->QStringList",
    "PySide6.QtScxml.QScxmlStateMachine.cancelDelayedEvent(self,sendId:QString)",
    "PySide6.QtScxml.QScxmlStateMachine.connectToEvent(self,scxmlEventSpec:QString,receiver:PySide6.QtCore.QObject,method:char*,type:PySide6.QtCore.Qt.ConnectionType=Qt.AutoConnection)->PySide6.QtCore.QMetaObject.Connection",
    "PySide6.QtScxml.QScxmlStateMachine.connectToState(self,scxmlStateName:QString,receiver:PySide6.QtCore.QObject,method:char*,type:PySide6.QtCore.Qt.ConnectionType=Qt.AutoConnection)->PySide6.QtCore.QMetaObject.Connection",
    "PySide6.QtScxml.QScxmlStateMachine.dataModel(self)->PySide6.QtScxml.QScxmlDataModel",
    "PySide6.QtScxml.QScxmlStateMachine.fromData(data:PySide6.QtCore.QIODevice,fileName:QString=QString())->PySide6.QtScxml.QScxmlStateMachine",
    "PySide6.QtScxml.QScxmlStateMachine.fromFile(fileName:QString)->PySide6.QtScxml.QScxmlStateMachine",
    "PySide6.QtScxml.QScxmlStateMachine.init(self)->bool",
    "PySide6.QtScxml.QScxmlStateMachine.initialValues(self)->QMap[QString, QVariant]",
    "PySide6.QtScxml.QScxmlStateMachine.invokedServices(self)->QList[PySide6.QtScxml.QScxmlInvokableService]",
    "1:PySide6.QtScxml.QScxmlStateMachine.isActive(self,scxmlStateName:QString)->bool",
    "0:PySide6.QtScxml.QScxmlStateMachine.isActive(self,stateIndex:int)->bool",
    "PySide6.QtScxml.QScxmlStateMachine.isDispatchableTarget(self,target:QString)->bool",
    "PySide6.QtScxml.QScxmlStateMachine.isInitialized(self)->bool",
    "PySide6.QtScxml.QScxmlStateMachine.isInvoked(self)->bool",
    "PySide6.QtScxml.QScxmlStateMachine.isRunning(self)->bool",
    "PySide6.QtScxml.QScxmlStateMachine.loader(self)->PySide6.QtScxml.QScxmlCompiler.Loader",
    "PySide6.QtScxml.QScxmlStateMachine.name(self)->QString",
    "PySide6.QtScxml.QScxmlStateMachine.parseErrors(self)->QList[PySide6.QtScxml.QScxmlError]",
    "PySide6.QtScxml.QScxmlStateMachine.sessionId(self)->QString",
    "PySide6.QtScxml.QScxmlStateMachine.setDataModel(self,model:PySide6.QtScxml.QScxmlDataModel)",
    "PySide6.QtScxml.QScxmlStateMachine.setInitialValues(self,initialValues:QMap[QString, QVariant])",
    "PySide6.QtScxml.QScxmlStateMachine.setLoader(self,loader:PySide6.QtScxml.QScxmlCompiler.Loader)",
    "PySide6.QtScxml.QScxmlStateMachine.setRunning(self,running:bool)",
    "PySide6.QtScxml.QScxmlStateMachine.setTableData(self,tableData:PySide6.QtScxml.QScxmlTableData)",
    "PySide6.QtScxml.QScxmlStateMachine.start(self)",
    "PySide6.QtScxml.QScxmlStateMachine.stateNames(self,compress:bool=true)->QStringList",
    "PySide6.QtScxml.QScxmlStateMachine.stop(self)",
    "2:PySide6.QtScxml.QScxmlStateMachine.submitEvent(self,event:PySide6.QtScxml.QScxmlEvent)",
    "1:PySide6.QtScxml.QScxmlStateMachine.submitEvent(self,eventName:QString)",
    "0:PySide6.QtScxml.QScxmlStateMachine.submitEvent(self,eventName:QString,data:QVariant)",
    "PySide6.QtScxml.QScxmlStateMachine.tableData(self)->PySide6.QtScxml.QScxmlTableData",
    nullptr}; // Sentinel
#else
static constexpr size_t QScxmlStateMachine_SignatureByteSize = 692;
static constexpr uint8_t QScxmlStateMachine_SignatureBytes[692] = {
    0x78, 0xda, 0xd5, 0x56, 0x3b, 0x6f, 0xdb, 0x30, 0x10, 0xde, 0xf3, 0x2b, 0x3a, 0xda, 0x81, 0x2a,
    0xb4, 0x1d, 0x3a, 0x08, 0x70, 0x81, 0xc0, 0x4e, 0x01, 0xa1, 0x76, 0x6c, 0x55, 0x46, 0x96, 0x20,
    0x03, 0x4d, 0x9e, 0x63, 0xb6, 0x14, 0x29, 0x90, 0x94, 0x1b, 0xf7, 0xd7, 0x97, 0x14, 0x25, 0x59,
    0xf2, 0x93, 0x0a, 0xb2, 0x74, 0xb2, 0x75, 0xbc, 0xfb, 0xee, 0xfd, 0x58, 0xec, 0x52, 0x4a, 0xe0,
    0x6b, 0x98, 0xe8, 0x14, 0xbf, 0x66, 0x2c, 0x4c, 0xca, 0x9f, 0x54, 0x23, 0x0d, 0x33, 0x84, 0x37,
    0x94, 0xc3, 0x40, 0x01, 0x5b, 0x07, 0x19, 0x68, 0x34, 0x5f, 0xfd, 0x02, 0xac, 0xa3, 0x45, 0x23,
    0x32, 0x16, 0x12, 0xc2, 0x64, 0xd6, 0x3c, 0x05, 0x39, 0x92, 0xc0, 0x8f, 0x39, 0xdc, 0xeb, 0x88,
    0x17, 0x8c, 0xe5, 0x5a, 0x06, 0xb7, 0xd1, 0x0f, 0xd8, 0xfd, 0x11, 0x92, 0xcc, 0x39, 0xdb, 0x8d,
    0x1e, 0x04, 0x87, 0x40, 0x16, 0x9c, 0x53, 0xfe, 0x12, 0xad, 0x84, 0x60, 0x8e, 0x42, 0x39, 0xd5,
    0x14, 0x31, 0xfa, 0x17, 0x48, 0x8b, 0x4a, 0x90, 0x46, 0x33, 0x41, 0x80, 0x45, 0xce, 0xd0, 0x49,
    0xfd, 0xdd, 0x11, 0x7a, 0x44, 0xac, 0x00, 0x15, 0x25, 0x33, 0x94, 0x3f, 0x25, 0xa9, 0x96, 0x06,
    0x39, 0xf8, 0x90, 0x3c, 0x22, 0x49, 0x11, 0xd7, 0xcf, 0x35, 0xeb, 0x56, 0xfc, 0x06, 0x92, 0x82,
    0xdc, 0x52, 0x6c, 0x99, 0xa7, 0x54, 0xe9, 0xa7, 0xc5, 0xc9, 0x70, 0xc4, 0x96, 0x17, 0xad, 0x18,
    0x54, 0xdc, 0x15, 0x84, 0x02, 0xa5, 0xa8, 0xe0, 0x31, 0x89, 0x2a, 0x25, 0x8e, 0xcc, 0x51, 0x06,
    0x5d, 0x4a, 0xa5, 0xab, 0xe5, 0x87, 0x09, 0x94, 0x82, 0x7b, 0x29, 0x85, 0xbc, 0xac, 0xb9, 0x64,
    0xa9, 0xd4, 0x31, 0x81, 0x08, 0xc8, 0xca, 0xf1, 0xb1, 0xc8, 0x72, 0xca, 0x40, 0x86, 0xd3, 0x92,
    0xea, 0x38, 0xb4, 0xb5, 0xd1, 0x86, 0xa4, 0x62, 0x5a, 0xd6, 0xdf, 0xe5, 0xf3, 0xf0, 0x66, 0x71,
    0x35, 0xd9, 0x21, 0xc2, 0x9a, 0x6e, 0xa1, 0x24, 0x3d, 0x18, 0x3f, 0x94, 0xcb, 0x3e, 0x36, 0xda,
    0xa4, 0xf1, 0xd6, 0x79, 0xa0, 0x65, 0x01, 0xc3, 0x8f, 0xdf, 0x2a, 0x17, 0xad, 0xf5, 0x3e, 0xc8,
    0x18, 0x71, 0x0c, 0x6c, 0x02, 0x0c, 0xed, 0x80, 0xdc, 0x6f, 0x4d, 0x9d, 0x38, 0x6c, 0x05, 0x9c,
    0xec, 0x43, 0xe8, 0x65, 0x24, 0x16, 0x9c, 0x9b, 0x82, 0x5a, 0x8a, 0x36, 0x4c, 0x19, 0x2e, 0xfb,
    0x9d, 0xe6, 0x80, 0x6b, 0xb8, 0x40, 0x02, 0x06, 0xe3, 0x90, 0x3c, 0x53, 0x93, 0xb6, 0xae, 0x37,
    0x82, 0x44, 0x78, 0x83, 0xe4, 0x6d, 0xa0, 0x77, 0x39, 0x1c, 0x31, 0xea, 0x70, 0xec, 0xd4, 0x99,
    0x54, 0x2f, 0x0d, 0xc3, 0xc8, 0x50, 0xee, 0x0a, 0x2d, 0xf6, 0x54, 0x13, 0x8b, 0xf3, 0x3d, 0xd1,
    0x92, 0xee, 0xe5, 0x5a, 0x49, 0x6d, 0xb9, 0xd6, 0xa4, 0xe4, 0xbf, 0x75, 0xad, 0xe9, 0xdd, 0xd2,
    0xab, 0x0e, 0x72, 0x5b, 0xa6, 0x69, 0x69, 0x1f, 0xcc, 0xb5, 0x14, 0x99, 0x15, 0x18, 0x58, 0xf0,
    0x23, 0xff, 0xe2, 0xf9, 0x04, 0x6c, 0xbf, 0x06, 0x6b, 0xd3, 0x2a, 0xed, 0xd8, 0x8d, 0xaa, 0xdf,
    0xc1, 0xf0, 0xac, 0x19, 0x6d, 0x35, 0xbe, 0x96, 0x7c, 0x37, 0x6a, 0x06, 0x87, 0xba, 0xde, 0x4d,
    0x83, 0x1d, 0x6e, 0x75, 0xe8, 0x6c, 0x1f, 0xfa, 0xca, 0x34, 0x03, 0xb1, 0x16, 0x3e, 0x33, 0x17,
    0xfd, 0xf0, 0x3a, 0x53, 0xb3, 0x41, 0xec, 0x33, 0x3c, 0x6f, 0x3e, 0x47, 0x3e, 0x9a, 0xd4, 0x5d,
    0x39, 0x8a, 0x2e, 0xb5, 0x40, 0x1d, 0x88, 0x4f, 0x6f, 0x00, 0xb4, 0x4f, 0x31, 0x27, 0xf0, 0x1a,
    0x51, 0xae, 0xfb, 0x44, 0x54, 0x4d, 0xa8, 0xca, 0x91, 0x36, 0x6d, 0x65, 0x7c, 0x5a, 0x22, 0xf9,
    0x02, 0xd5, 0x04, 0xd2, 0xe5, 0xff, 0x43, 0xdb, 0xbc, 0x20, 0xe3, 0xfd, 0xb2, 0xeb, 0x9d, 0x61,
    0x15, 0xbb, 0x9c, 0xf4, 0x17, 0xfc, 0xe9, 0x96, 0x6e, 0x5f, 0x41, 0xb7, 0x87, 0x2e, 0x37, 0xf1,
    0xc1, 0x7a, 0xf2, 0x81, 0xb5, 0x6b, 0xb3, 0xa9, 0x27, 0x17, 0x43, 0x1f, 0xb1, 0xd6, 0x26, 0xf5,
    0xa9, 0x46, 0xb7, 0x50, 0x7d, 0x80, 0x9b, 0xed, 0xfe, 0x06, 0xa3, 0x14, 0xe8, 0x49, 0x67, 0xda,
    0x05, 0x59, 0x79, 0xb4, 0x5c, 0x99, 0x78, 0x43, 0x4f, 0xec, 0xf8, 0xa8, 0xab, 0xfd, 0x2e, 0x1f,
    0x5f, 0xfc, 0xe9, 0x3e, 0xc3, 0xf5, 0xd5, 0xe1, 0x95, 0x66, 0x5f, 0xfc, 0x76, 0xe1, 0x75, 0x4e,
    0x3f, 0x5f, 0x80, 0xe6, 0xb0, 0xa9, 0x3b, 0xaf, 0xbe, 0x7b, 0x4e, 0x8b, 0x37, 0xec, 0x7e, 0xf8,
    0xa6, 0x91, 0xab, 0x41, 0xeb, 0xc9, 0xfe, 0xee, 0xb7, 0x92, 0xd2, 0x22, 0xaf, 0x2c, 0xf8, 0xe2,
    0x33, 0xdb, 0x54, 0xb1, 0xca, 0xa8, 0x6e, 0x5d, 0x43, 0xb0, 0xed, 0xde, 0xe1, 0x9d, 0x16, 0xb0,
    0x6f, 0x43, 0xbf, 0x29, 0x7c, 0x1a, 0xb8, 0x33, 0x83, 0xfd, 0xa6, 0xef, 0x75, 0xa0, 0xf2, 0xb6,
    0x8f, 0xea, 0x5a, 0xf5, 0x0a, 0xbd, 0xee, 0x94, 0xc1, 0xd9, 0x61, 0xd4, 0xa4, 0xff, 0xe6, 0x1f,
    0x3c, 0x07, 0xbe, 0x28
};
#endif

PyTypeObject *init_QScxmlStateMachine(PyObject *module)
{
    if (SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX].type != nullptr)
        return SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX].type;

    Shiboken::AutoDecRef Sbk_QScxmlStateMachine_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QScxmlStateMachine_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QScxmlStateMachine",
        "QScxmlStateMachine*",
        &Sbk_QScxmlStateMachine_spec,
        &Shiboken::callCppDestructor< QScxmlStateMachine >,
        Sbk_QScxmlStateMachine_Type_bases.object(),
        0);
    auto *pyType = Sbk_QScxmlStateMachine_TypeF(); // references _Sbk_QScxmlStateMachine_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QScxmlStateMachine_SignatureStrings);
#else
    InitSignatureBytes(pyType, QScxmlStateMachine_SignatureBytes, QScxmlStateMachine_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QScxmlStateMachine_PropertyStrings);
    SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QScxmlStateMachine_PythonToCpp_QScxmlStateMachine_PTR,
        is_QScxmlStateMachine_PythonToCpp_QScxmlStateMachine_PTR_Convertible,
        QScxmlStateMachine_PTR_CppToPython_QScxmlStateMachine);

    Shiboken::Conversions::registerConverterName(converter, "QScxmlStateMachine");
    Shiboken::Conversions::registerConverterName(converter, "QScxmlStateMachine*");
    Shiboken::Conversions::registerConverterName(converter, "QScxmlStateMachine&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QScxmlStateMachine).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QScxmlStateMachineWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QScxmlStateMachine_TypeF(), &Sbk_QScxmlStateMachine_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::QScxmlStateMachine::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QScxmlStateMachine::staticMetaObject, sizeof(QScxmlStateMachineWrapper));

    return pyType;
}
