// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtsensors_python.h"

// main header
#include "qirproximityfilter_wrapper.h"

// Argument includes
#include <QtSensors/qirproximitysensor.h>
#include <QtSensors/qsensor.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QIRProximityFilterWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

bool QIRProximityFilterWrapper::filter(::QIRProximityReading * reading)
{
    if (m_PyMethodCache[0]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QIRProximityFilter.filter");
        return false;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "filter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        Shiboken::Errors::setPureVirtualMethodError("QIRProximityFilter.filter");
        return false;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QIRProximityReading_IDX]), reading)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QIRProximityReading_IDX]), reading)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QIRProximityFilter", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QIRProximityFilter", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QIRProximityFilterWrapper::setSensor(::QSensor * sensor)
{
    if (m_PyMethodCache[1]) {
        return this->::QSensorFilter::setSensor(sensor);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setSensor";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QSensorFilter::setSensor(sensor);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), sensor)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), sensor)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QIRProximityFilter", funcName);
        return;
    }
}

QIRProximityFilterWrapper::~QIRProximityFilterWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QIRProximityFilterFunc_filter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QIRProximityFilter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QIRProximityFilter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSensorFilter::filter(QSensorReading*)->bool
    // 1: QIRProximityFilter::filter(QIRProximityReading*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QIRProximityReading_IDX]), (pyArg)))) {
        overloadId = 1; // filter(QIRProximityReading*)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensorReading_IDX]), (pyArg)))) {
        overloadId = 0; // filter(QSensorReading*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "filter", errInfo, SbkPySide6_QtSensorsTypeStructs[SBK_QIRProximityFilter_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // filter(QSensorReading *reading)
        {
            Shiboken::Errors::setPrivateMethod("filter(QSensorReading *reading)");
            return {};
            break;
        }
        case 1: // filter(QIRProximityReading *reading)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QIRProximityReading *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // filter(QIRProximityReading*)
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                    Shiboken::Errors::setPureVirtualMethodError("QIRProximityFilter.filter");
                    return {};
                }
                bool cppResult = cppSelf->filter(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QIRProximityFilter_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QIRProximityFilter_methods[] = {
    {"filter", reinterpret_cast<PyCFunction>(Sbk_QIRProximityFilterFunc_filter), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QIRProximityFilter_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QIRProximityFilter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QIRProximityFilter_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QIRProximityFilterWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QIRProximityFilter_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QIRProximityFilter_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QIRProximityFilter_Type = nullptr;
static PyTypeObject *Sbk_QIRProximityFilter_TypeF(void)
{
    return _Sbk_QIRProximityFilter_Type;
}

static PyType_Slot Sbk_QIRProximityFilter_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QIRProximityFilter_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QIRProximityFilter_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QIRProximityFilter_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QIRProximityFilter_methods)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QIRProximityFilter_spec = {
    "2:PySide6.QtSensors.QIRProximityFilter",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QIRProximityFilter_slots
};

} //extern "C"

static void *Sbk_QIRProximityFilter_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QSensorFilter >())
        return dynamic_cast< ::QIRProximityFilter *>(reinterpret_cast< ::QSensorFilter *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QIRProximityFilter_PythonToCpp_QIRProximityFilter_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QIRProximityFilter_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QIRProximityFilter_PythonToCpp_QIRProximityFilter_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QIRProximityFilter_TypeF()))
        return QIRProximityFilter_PythonToCpp_QIRProximityFilter_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QIRProximityFilter_PTR_CppToPython_QIRProximityFilter(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QIRProximityFilter *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QIRProximityFilter_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QIRProximityFilter_SignatureStrings[] = {
    "1:PySide6.QtSensors.QIRProximityFilter.filter(self,reading:PySide6.QtSensors.QSensorReading)->bool",
    "0:PySide6.QtSensors.QIRProximityFilter.filter(self,reading:PySide6.QtSensors.QIRProximityReading)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QIRProximityFilter_SignatureByteSize = 85;
static constexpr uint8_t QIRProximityFilter_SignatureBytes[85] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x09, 0x4e,
    0xcd, 0x2b, 0xce, 0x2f, 0x2a, 0xd6, 0x0b, 0xf4, 0x0c, 0x0a, 0x28, 0xca, 0xaf, 0xc8, 0xcc, 0xcd,
    0x2c, 0xa9, 0x74, 0xcb, 0xcc, 0x29, 0x49, 0x2d, 0xd2, 0x4b, 0x03, 0x53, 0x1a, 0xc5, 0xa9, 0x39,
    0x69, 0x3a, 0x45, 0xa9, 0x89, 0x29, 0x99, 0x79, 0xe9, 0xd8, 0x34, 0x42, 0x18, 0x41, 0x10, 0x05,
    0x9a, 0xba, 0x76, 0x49, 0xf9, 0xf9, 0x39, 0x5c, 0x06, 0x54, 0xb5, 0x02, 0x49, 0x23, 0x9a, 0x3d,
    0x00, 0xb7, 0x66, 0x4a, 0x8c
};
#endif

PyTypeObject *init_QIRProximityFilter(PyObject *module)
{
    if (SbkPySide6_QtSensorsTypeStructs[SBK_QIRProximityFilter_IDX].type != nullptr)
        return SbkPySide6_QtSensorsTypeStructs[SBK_QIRProximityFilter_IDX].type;

    Shiboken::AutoDecRef Sbk_QIRProximityFilter_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensorFilter_IDX]))));

    _Sbk_QIRProximityFilter_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QIRProximityFilter",
        "QIRProximityFilter*",
        &Sbk_QIRProximityFilter_spec,
        &Shiboken::callCppDestructor< QIRProximityFilter >,
        Sbk_QIRProximityFilter_Type_bases.object(),
        0);
    auto *pyType = Sbk_QIRProximityFilter_TypeF(); // references _Sbk_QIRProximityFilter_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QIRProximityFilter_SignatureStrings);
#else
    InitSignatureBytes(pyType, QIRProximityFilter_SignatureBytes, QIRProximityFilter_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QIRProximityFilter_PropertyStrings);
    SbkPySide6_QtSensorsTypeStructs[SBK_QIRProximityFilter_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QIRProximityFilter_PythonToCpp_QIRProximityFilter_PTR,
        is_QIRProximityFilter_PythonToCpp_QIRProximityFilter_PTR_Convertible,
        QIRProximityFilter_PTR_CppToPython_QIRProximityFilter);

    Shiboken::Conversions::registerConverterName(converter, "QIRProximityFilter");
    Shiboken::Conversions::registerConverterName(converter, "QIRProximityFilter*");
    Shiboken::Conversions::registerConverterName(converter, "QIRProximityFilter&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QIRProximityFilter).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QIRProximityFilterWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QIRProximityFilter_TypeF(), &Sbk_QIRProximityFilter_typeDiscovery);

    qRegisterMetaType< ::QIRProximityFilter *>();

    return pyType;
}
