// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtsensors_python.h"

// main header
#include "qmagnetometerfilter_wrapper.h"

// Argument includes
#include <QtSensors/qmagnetometer.h>
#include <QtSensors/qsensor.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QMagnetometerFilterWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

bool QMagnetometerFilterWrapper::filter(::QMagnetometerReading * reading)
{
    if (m_PyMethodCache[0]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QMagnetometerFilter.filter");
        return false;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "filter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        Shiboken::Errors::setPureVirtualMethodError("QMagnetometerFilter.filter");
        return false;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QMagnetometerReading_IDX]), reading)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QMagnetometerReading_IDX]), reading)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QMagnetometerFilter", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QMagnetometerFilter", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QMagnetometerFilterWrapper::setSensor(::QSensor * sensor)
{
    if (m_PyMethodCache[1]) {
        return this->::QSensorFilter::setSensor(sensor);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setSensor";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QSensorFilter::setSensor(sensor);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), sensor)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), sensor)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QMagnetometerFilter", funcName);
        return;
    }
}

QMagnetometerFilterWrapper::~QMagnetometerFilterWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QMagnetometerFilterFunc_filter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMagnetometerFilter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QMagnetometerFilter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSensorFilter::filter(QSensorReading*)->bool
    // 1: QMagnetometerFilter::filter(QMagnetometerReading*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QMagnetometerReading_IDX]), (pyArg)))) {
        overloadId = 1; // filter(QMagnetometerReading*)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensorReading_IDX]), (pyArg)))) {
        overloadId = 0; // filter(QSensorReading*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "filter", errInfo, SbkPySide6_QtSensorsTypeStructs[SBK_QMagnetometerFilter_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // filter(QSensorReading *reading)
        {
            Shiboken::Errors::setPrivateMethod("filter(QSensorReading *reading)");
            return {};
            break;
        }
        case 1: // filter(QMagnetometerReading *reading)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QMagnetometerReading *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // filter(QMagnetometerReading*)
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                    Shiboken::Errors::setPureVirtualMethodError("QMagnetometerFilter.filter");
                    return {};
                }
                bool cppResult = cppSelf->filter(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QMagnetometerFilter_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QMagnetometerFilter_methods[] = {
    {"filter", reinterpret_cast<PyCFunction>(Sbk_QMagnetometerFilterFunc_filter), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QMagnetometerFilter_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QMagnetometerFilter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QMagnetometerFilter_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QMagnetometerFilterWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QMagnetometerFilter_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QMagnetometerFilter_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QMagnetometerFilter_Type = nullptr;
static PyTypeObject *Sbk_QMagnetometerFilter_TypeF(void)
{
    return _Sbk_QMagnetometerFilter_Type;
}

static PyType_Slot Sbk_QMagnetometerFilter_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QMagnetometerFilter_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QMagnetometerFilter_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QMagnetometerFilter_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QMagnetometerFilter_methods)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QMagnetometerFilter_spec = {
    "2:PySide6.QtSensors.QMagnetometerFilter",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QMagnetometerFilter_slots
};

} //extern "C"

static void *Sbk_QMagnetometerFilter_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QSensorFilter >())
        return dynamic_cast< ::QMagnetometerFilter *>(reinterpret_cast< ::QSensorFilter *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QMagnetometerFilter_PythonToCpp_QMagnetometerFilter_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QMagnetometerFilter_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QMagnetometerFilter_PythonToCpp_QMagnetometerFilter_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QMagnetometerFilter_TypeF()))
        return QMagnetometerFilter_PythonToCpp_QMagnetometerFilter_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QMagnetometerFilter_PTR_CppToPython_QMagnetometerFilter(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QMagnetometerFilter *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QMagnetometerFilter_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QMagnetometerFilter_SignatureStrings[] = {
    "1:PySide6.QtSensors.QMagnetometerFilter.filter(self,reading:PySide6.QtSensors.QSensorReading)->bool",
    "0:PySide6.QtSensors.QMagnetometerFilter.filter(self,reading:PySide6.QtSensors.QMagnetometerReading)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QMagnetometerFilter_SignatureByteSize = 85;
static constexpr uint8_t QMagnetometerFilter_SignatureBytes[85] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x09, 0x4e,
    0xcd, 0x2b, 0xce, 0x2f, 0x2a, 0xd6, 0x0b, 0xf4, 0x4d, 0x4c, 0xcf, 0x4b, 0x2d, 0xc9, 0xcf, 0x4d,
    0x2d, 0x49, 0x2d, 0x72, 0xcb, 0xcc, 0x01, 0x92, 0x7a, 0x69, 0x60, 0x4a, 0xa3, 0x38, 0x35, 0x27,
    0x4d, 0xa7, 0x28, 0x35, 0x31, 0x25, 0x33, 0x2f, 0x1d, 0x9b, 0x4e, 0x08, 0x23, 0x08, 0xa2, 0x40,
    0x53, 0xd7, 0x2e, 0x29, 0x3f, 0x3f, 0x87, 0xcb, 0x80, 0xba, 0x76, 0x20, 0xeb, 0x44, 0xb3, 0x09,
    0x00, 0xb7, 0xb8, 0x4b, 0xf4
};
#endif

PyTypeObject *init_QMagnetometerFilter(PyObject *module)
{
    if (SbkPySide6_QtSensorsTypeStructs[SBK_QMagnetometerFilter_IDX].type != nullptr)
        return SbkPySide6_QtSensorsTypeStructs[SBK_QMagnetometerFilter_IDX].type;

    Shiboken::AutoDecRef Sbk_QMagnetometerFilter_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensorFilter_IDX]))));

    _Sbk_QMagnetometerFilter_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QMagnetometerFilter",
        "QMagnetometerFilter*",
        &Sbk_QMagnetometerFilter_spec,
        &Shiboken::callCppDestructor< QMagnetometerFilter >,
        Sbk_QMagnetometerFilter_Type_bases.object(),
        0);
    auto *pyType = Sbk_QMagnetometerFilter_TypeF(); // references _Sbk_QMagnetometerFilter_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QMagnetometerFilter_SignatureStrings);
#else
    InitSignatureBytes(pyType, QMagnetometerFilter_SignatureBytes, QMagnetometerFilter_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QMagnetometerFilter_PropertyStrings);
    SbkPySide6_QtSensorsTypeStructs[SBK_QMagnetometerFilter_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QMagnetometerFilter_PythonToCpp_QMagnetometerFilter_PTR,
        is_QMagnetometerFilter_PythonToCpp_QMagnetometerFilter_PTR_Convertible,
        QMagnetometerFilter_PTR_CppToPython_QMagnetometerFilter);

    Shiboken::Conversions::registerConverterName(converter, "QMagnetometerFilter");
    Shiboken::Conversions::registerConverterName(converter, "QMagnetometerFilter*");
    Shiboken::Conversions::registerConverterName(converter, "QMagnetometerFilter&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QMagnetometerFilter).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QMagnetometerFilterWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QMagnetometerFilter_TypeF(), &Sbk_QMagnetometerFilter_typeDiscovery);

    qRegisterMetaType< ::QMagnetometerFilter *>();

    return pyType;
}
