// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtsensors_python.h"

// main header
#include "qsensor_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QtSensors/qsensor.h>
#include <QtSensors/qsensorbackend.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qvariant.h>
#include <utility>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QSensorWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QSensorWrapper::QSensorWrapper(const ::QByteArray & type, ::QObject * parent) : QSensor(type, parent)
{
}

void QSensorWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSensor", funcName);
        return;
    }
}

void QSensorWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSensor", funcName);
        return;
    }
}

void QSensorWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSensor", funcName);
        return;
    }
}

void QSensorWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSensor", funcName);
        return;
    }
}

bool QSensorWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSensor", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSensor", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QSensorWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSensor", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSensor", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QSensorWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSensor", funcName);
        return;
    }
}

const QMetaObject *QSensorWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QSensor::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QSensorWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QSensor::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QSensorWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QSensorWrapper *>(this));
    return QSensor::qt_metacast(_clname);
}

QSensorWrapper::~QSensorWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSensor_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSensor >()))
        return -1;

    QSensorWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:QSensor", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QSensor::QSensor(QByteArray,QObject*=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // QSensor(QByteArray,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 0; // QSensor(QByteArray,QObject*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                // fall through to handle extra keyword signals and properties
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return -1;
        ::QObject *cppArg1 = nullptr;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QSensor(QByteArray,QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QSensorWrapper(*cppArg0, cppArg1);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QSensorWrapper(*cppArg0, cppArg1);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[1], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QSensor >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QSensorFunc_addFilter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSensor::addFilter(QSensorFilter*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensorFilter_IDX]), (pyArg)))) {
        overloadId = 0; // addFilter(QSensorFilter*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addFilter", errInfo, SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSensorFilter *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addFilter(QSensorFilter*)
            cppSelf->addFilter(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSensorFunc_availableDataRates(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // availableDataRates()const
        QList<std::pair<int,int>> cppResult = const_cast<const ::QSensor *>(cppSelf)->availableDataRates();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtSensorsTypeConverters[SBK_QtSensors_QList_std_pair_int_int_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_axesOrientationMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // axesOrientationMode()const
        QSensor::AxesOrientationMode cppResult = const_cast<const ::QSensor *>(cppSelf)->axesOrientationMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_AxesOrientationMode_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_backend(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // backend()const
        QSensorBackend * cppResult = const_cast<const ::QSensor *>(cppSelf)->backend();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensorBackend_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_bufferSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // bufferSize()const
        int cppResult = const_cast<const ::QSensor *>(cppSelf)->bufferSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_connectToBackend(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // connectToBackend()
        bool cppResult = cppSelf->connectToBackend();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_currentOrientation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // currentOrientation()const
        int cppResult = const_cast<const ::QSensor *>(cppSelf)->currentOrientation();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_dataRate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // dataRate()const
        int cppResult = const_cast<const ::QSensor *>(cppSelf)->dataRate();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_defaultSensorForType(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QSensor::defaultSensorForType(QByteArray)->QByteArray
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // defaultSensorForType(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "defaultSensorForType", errInfo, SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // defaultSensorForType(QByteArray)
            QByteArray cppResult = ::QSensor::defaultSensorForType(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_description(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // description()const
        QString cppResult = const_cast<const ::QSensor *>(cppSelf)->description();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_efficientBufferSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // efficientBufferSize()const
        int cppResult = const_cast<const ::QSensor *>(cppSelf)->efficientBufferSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_error(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // error()const
        int cppResult = const_cast<const ::QSensor *>(cppSelf)->error();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_filters(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // filters()const
        QList<QSensorFilter*> cppResult = const_cast<const ::QSensor *>(cppSelf)->filters();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtSensorsTypeConverters[SBK_QtSensors_QList_QSensorFilterPTR_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_identifier(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // identifier()const
        QByteArray cppResult = const_cast<const ::QSensor *>(cppSelf)->identifier();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_isActive(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isActive()const
        bool cppResult = const_cast<const ::QSensor *>(cppSelf)->isActive();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_isAlwaysOn(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isAlwaysOn()const
        bool cppResult = const_cast<const ::QSensor *>(cppSelf)->isAlwaysOn();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_isBusy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isBusy()const
        bool cppResult = const_cast<const ::QSensor *>(cppSelf)->isBusy();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_isConnectedToBackend(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isConnectedToBackend()const
        bool cppResult = const_cast<const ::QSensor *>(cppSelf)->isConnectedToBackend();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_isFeatureSupported(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSensor::isFeatureSupported(QSensor::Feature)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_Feature_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // isFeatureSupported(QSensor::Feature)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isFeatureSupported", errInfo, SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]);

    // Call function/method
    {
        ::QSensor::Feature cppArg0{QSensor::Buffering};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isFeatureSupported(QSensor::Feature)const
            bool cppResult = const_cast<const ::QSensor *>(cppSelf)->isFeatureSupported(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_maxBufferSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maxBufferSize()const
        int cppResult = const_cast<const ::QSensor *>(cppSelf)->maxBufferSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_outputRange(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // outputRange()const
        int cppResult = const_cast<const ::QSensor *>(cppSelf)->outputRange();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_outputRanges(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // outputRanges()const
        QList<qoutputrange> cppResult = const_cast<const ::QSensor *>(cppSelf)->outputRanges();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtSensorsTypeConverters[SBK_QtSensors_QList_qoutputrange_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_reading(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // reading()const
        QSensorReading * cppResult = const_cast<const ::QSensor *>(cppSelf)->reading();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensorReading_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_removeFilter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSensor::removeFilter(QSensorFilter*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensorFilter_IDX]), (pyArg)))) {
        overloadId = 0; // removeFilter(QSensorFilter*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeFilter", errInfo, SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSensorFilter *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeFilter(QSensorFilter*)
            cppSelf->removeFilter(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSensorFunc_sensorTypes(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sensorTypes()
        QList<QByteArray> cppResult = ::QSensor::sensorTypes();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtSensorsTypeConverters[SBK_QtSensors_QList_QByteArray_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_sensorsForType(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QSensor::sensorsForType(QByteArray)->QList<QByteArray>
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // sensorsForType(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "sensorsForType", errInfo, SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // sensorsForType(QByteArray)
            QList<QByteArray> cppResult = ::QSensor::sensorsForType(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtSensorsTypeConverters[SBK_QtSensors_QList_QByteArray_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_setActive(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSensor::setActive(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setActive(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setActive", errInfo, SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setActive(bool)
            cppSelf->setActive(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSensorFunc_setAlwaysOn(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSensor::setAlwaysOn(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAlwaysOn(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAlwaysOn", errInfo, SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAlwaysOn(bool)
            cppSelf->setAlwaysOn(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSensorFunc_setAxesOrientationMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSensor::setAxesOrientationMode(QSensor::AxesOrientationMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_AxesOrientationMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setAxesOrientationMode(QSensor::AxesOrientationMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAxesOrientationMode", errInfo, SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]);

    // Call function/method
    {
        ::QSensor::AxesOrientationMode cppArg0{QSensor::FixedOrientation};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAxesOrientationMode(QSensor::AxesOrientationMode)
            cppSelf->setAxesOrientationMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSensorFunc_setBufferSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSensor::setBufferSize(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setBufferSize(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBufferSize", errInfo, SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setBufferSize(int)
            cppSelf->setBufferSize(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSensorFunc_setCurrentOrientation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSensor::setCurrentOrientation(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setCurrentOrientation(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCurrentOrientation", errInfo, SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCurrentOrientation(int)
            cppSelf->setCurrentOrientation(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSensorFunc_setDataRate(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSensor::setDataRate(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setDataRate(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDataRate", errInfo, SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDataRate(int)
            cppSelf->setDataRate(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSensorFunc_setEfficientBufferSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSensor::setEfficientBufferSize(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setEfficientBufferSize(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setEfficientBufferSize", errInfo, SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setEfficientBufferSize(int)
            cppSelf->setEfficientBufferSize(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSensorFunc_setIdentifier(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSensor::setIdentifier(QByteArray)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // setIdentifier(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setIdentifier", errInfo, SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setIdentifier(QByteArray)
            cppSelf->setIdentifier(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSensorFunc_setMaxBufferSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSensor::setMaxBufferSize(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setMaxBufferSize(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMaxBufferSize", errInfo, SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMaxBufferSize(int)
            cppSelf->setMaxBufferSize(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSensorFunc_setOutputRange(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSensor::setOutputRange(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setOutputRange(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOutputRange", errInfo, SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOutputRange(int)
            cppSelf->setOutputRange(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSensorFunc_setSkipDuplicates(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSensor::setSkipDuplicates(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setSkipDuplicates(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSkipDuplicates", errInfo, SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSkipDuplicates(bool)
            cppSelf->setSkipDuplicates(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSensorFunc_setUserOrientation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSensor::setUserOrientation(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setUserOrientation(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUserOrientation", errInfo, SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setUserOrientation(int)
            cppSelf->setUserOrientation(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSensorFunc_skipDuplicates(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // skipDuplicates()const
        bool cppResult = const_cast<const ::QSensor *>(cppSelf)->skipDuplicates();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_start(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // start()
        bool cppResult = cppSelf->start();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_stop(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // stop()
        cppSelf->stop();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSensorFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        QByteArray cppResult = const_cast<const ::QSensor *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_userOrientation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // userOrientation()const
        int cppResult = const_cast<const ::QSensor *>(cppSelf)->userOrientation();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QSensor_PropertyStrings[] = {
    "active:isActive:",
    "alwaysOn:isAlwaysOn:",
    "availableDataRates:",
    "axesOrientationMode::",
    "bufferSize::",
    "busy:isBusy",
    "connectedToBackend:isConnectedToBackend",
    "currentOrientation:",
    "dataRate::",
    "description:",
    "efficientBufferSize:",
    "error:",
    "identifier::",
    "maxBufferSize:",
    "outputRange::",
    "outputRanges:",
    "reading:",
    "skipDuplicates::",
    "type:",
    "userOrientation::",
    nullptr // Sentinel
};

static const char *Sbk_QSensor_EnumFlagInfo[] = {
    "AxesOrientationMode:Enum",
    "Feature:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSensor_methods[] = {
    {"addFilter", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_addFilter), METH_O, nullptr},
    {"availableDataRates", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_availableDataRates), METH_NOARGS, nullptr},
    {"axesOrientationMode", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_axesOrientationMode), METH_NOARGS, nullptr},
    {"backend", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_backend), METH_NOARGS, nullptr},
    {"bufferSize", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_bufferSize), METH_NOARGS, nullptr},
    {"connectToBackend", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_connectToBackend), METH_NOARGS, nullptr},
    {"currentOrientation", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_currentOrientation), METH_NOARGS, nullptr},
    {"dataRate", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_dataRate), METH_NOARGS, nullptr},
    {"defaultSensorForType", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_defaultSensorForType), METH_O|METH_STATIC, nullptr},
    {"description", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_description), METH_NOARGS, nullptr},
    {"efficientBufferSize", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_efficientBufferSize), METH_NOARGS, nullptr},
    {"error", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_error), METH_NOARGS, nullptr},
    {"filters", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_filters), METH_NOARGS, nullptr},
    {"identifier", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_identifier), METH_NOARGS, nullptr},
    {"isActive", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_isActive), METH_NOARGS, nullptr},
    {"isAlwaysOn", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_isAlwaysOn), METH_NOARGS, nullptr},
    {"isBusy", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_isBusy), METH_NOARGS, nullptr},
    {"isConnectedToBackend", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_isConnectedToBackend), METH_NOARGS, nullptr},
    {"isFeatureSupported", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_isFeatureSupported), METH_O, nullptr},
    {"maxBufferSize", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_maxBufferSize), METH_NOARGS, nullptr},
    {"outputRange", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_outputRange), METH_NOARGS, nullptr},
    {"outputRanges", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_outputRanges), METH_NOARGS, nullptr},
    {"reading", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_reading), METH_NOARGS, nullptr},
    {"removeFilter", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_removeFilter), METH_O, nullptr},
    {"sensorTypes", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_sensorTypes), METH_NOARGS|METH_STATIC, nullptr},
    {"sensorsForType", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_sensorsForType), METH_O|METH_STATIC, nullptr},
    {"setActive", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_setActive), METH_O, nullptr},
    {"setAlwaysOn", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_setAlwaysOn), METH_O, nullptr},
    {"setAxesOrientationMode", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_setAxesOrientationMode), METH_O, nullptr},
    {"setBufferSize", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_setBufferSize), METH_O, nullptr},
    {"setCurrentOrientation", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_setCurrentOrientation), METH_O, nullptr},
    {"setDataRate", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_setDataRate), METH_O, nullptr},
    {"setEfficientBufferSize", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_setEfficientBufferSize), METH_O, nullptr},
    {"setIdentifier", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_setIdentifier), METH_O, nullptr},
    {"setMaxBufferSize", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_setMaxBufferSize), METH_O, nullptr},
    {"setOutputRange", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_setOutputRange), METH_O, nullptr},
    {"setSkipDuplicates", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_setSkipDuplicates), METH_O, nullptr},
    {"setUserOrientation", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_setUserOrientation), METH_O, nullptr},
    {"skipDuplicates", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_skipDuplicates), METH_NOARGS, nullptr},
    {"start", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_start), METH_NOARGS, nullptr},
    {"stop", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_stop), METH_NOARGS, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_type), METH_NOARGS, nullptr},
    {"userOrientation", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_userOrientation), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QSensor_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QSensorWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QSensor_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSensor_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSensor_Type = nullptr;
static PyTypeObject *Sbk_QSensor_TypeF(void)
{
    return _Sbk_QSensor_Type;
}

static PyType_Slot Sbk_QSensor_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QSensor_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSensor_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSensor_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSensor_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSensor_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSensor_spec = {
    "2:PySide6.QtSensors.QSensor",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSensor_slots
};

} //extern "C"

static void *Sbk_QSensor_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QSensor *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QSensor_Feature(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSensor::Feature>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSensor::Feature *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QSensor_Feature_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_Feature_IDX])))
        return Enum_PythonToCpp_QSensor_Feature;
    return {};
}

static PyObject *QSensor_Feature_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QSensor::Feature>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QSensor::Feature *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_Feature_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QSensor_AxesOrientationMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSensor::AxesOrientationMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSensor::AxesOrientationMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QSensor_AxesOrientationMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_AxesOrientationMode_IDX])))
        return Enum_PythonToCpp_QSensor_AxesOrientationMode;
    return {};
}

static PyObject *QSensor_AxesOrientationMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QSensor::AxesOrientationMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QSensor::AxesOrientationMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_AxesOrientationMode_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSensor_PythonToCpp_QSensor_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSensor_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSensor_PythonToCpp_QSensor_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSensor_TypeF()))
        return QSensor_PythonToCpp_QSensor_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSensor_PTR_CppToPython_QSensor(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QSensor *>(const_cast<void *>(cppIn)), Sbk_QSensor_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSensor_SignatureStrings[] = {
    "PySide6.QtSensors.QSensor(self,type:typing.Union[PySide6.QtCore.QByteArray, char*],parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,identifier:QByteArray=None,type:QByteArray=None,connectedToBackend:bool=None,availableDataRates:QList[std.pair[int, int]]=None,dataRate:int=None,reading:QSensorReading=None,busy:bool=None,active:bool=None,outputRanges:QList[PySide6.QtSensors.qoutputrange]=None,outputRange:int=None,description:QString=None,error:int=None,alwaysOn:bool=None,skipDuplicates:bool=None,axesOrientationMode:QSensor.AxesOrientationMode=None,currentOrientation:int=None,userOrientation:int=None,maxBufferSize:int=None,efficientBufferSize:int=None,bufferSize:int=None)",
    "PySide6.QtSensors.QSensor.addFilter(self,filter:PySide6.QtSensors.QSensorFilter)",
    "PySide6.QtSensors.QSensor.availableDataRates(self)->QList[std.pair[int, int]]",
    "PySide6.QtSensors.QSensor.axesOrientationMode(self)->PySide6.QtSensors.QSensor.AxesOrientationMode",
    "PySide6.QtSensors.QSensor.backend(self)->PySide6.QtSensors.QSensorBackend",
    "PySide6.QtSensors.QSensor.bufferSize(self)->int",
    "PySide6.QtSensors.QSensor.connectToBackend(self)->bool",
    "PySide6.QtSensors.QSensor.currentOrientation(self)->int",
    "PySide6.QtSensors.QSensor.dataRate(self)->int",
    "PySide6.QtSensors.QSensor.defaultSensorForType(type:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtCore.QByteArray",
    "PySide6.QtSensors.QSensor.description(self)->QString",
    "PySide6.QtSensors.QSensor.efficientBufferSize(self)->int",
    "PySide6.QtSensors.QSensor.error(self)->int",
    "PySide6.QtSensors.QSensor.filters(self)->QList[PySide6.QtSensors.QSensorFilter]",
    "PySide6.QtSensors.QSensor.identifier(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtSensors.QSensor.isActive(self)->bool",
    "PySide6.QtSensors.QSensor.isAlwaysOn(self)->bool",
    "PySide6.QtSensors.QSensor.isBusy(self)->bool",
    "PySide6.QtSensors.QSensor.isConnectedToBackend(self)->bool",
    "PySide6.QtSensors.QSensor.isFeatureSupported(self,feature:PySide6.QtSensors.QSensor.Feature)->bool",
    "PySide6.QtSensors.QSensor.maxBufferSize(self)->int",
    "PySide6.QtSensors.QSensor.outputRange(self)->int",
    "PySide6.QtSensors.QSensor.outputRanges(self)->QList[PySide6.QtSensors.qoutputrange]",
    "PySide6.QtSensors.QSensor.reading(self)->PySide6.QtSensors.QSensorReading",
    "PySide6.QtSensors.QSensor.removeFilter(self,filter:PySide6.QtSensors.QSensorFilter)",
    "PySide6.QtSensors.QSensor.sensorTypes()->QList[PySide6.QtCore.QByteArray]",
    "PySide6.QtSensors.QSensor.sensorsForType(type:typing.Union[PySide6.QtCore.QByteArray, char*])->QList[PySide6.QtCore.QByteArray]",
    "PySide6.QtSensors.QSensor.setActive(self,active:bool)",
    "PySide6.QtSensors.QSensor.setAlwaysOn(self,alwaysOn:bool)",
    "PySide6.QtSensors.QSensor.setAxesOrientationMode(self,axesOrientationMode:PySide6.QtSensors.QSensor.AxesOrientationMode)",
    "PySide6.QtSensors.QSensor.setBufferSize(self,bufferSize:int)",
    "PySide6.QtSensors.QSensor.setCurrentOrientation(self,currentOrientation:int)",
    "PySide6.QtSensors.QSensor.setDataRate(self,rate:int)",
    "PySide6.QtSensors.QSensor.setEfficientBufferSize(self,efficientBufferSize:int)",
    "PySide6.QtSensors.QSensor.setIdentifier(self,identifier:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "PySide6.QtSensors.QSensor.setMaxBufferSize(self,maxBufferSize:int)",
    "PySide6.QtSensors.QSensor.setOutputRange(self,index:int)",
    "PySide6.QtSensors.QSensor.setSkipDuplicates(self,skipDuplicates:bool)",
    "PySide6.QtSensors.QSensor.setUserOrientation(self,userOrientation:int)",
    "PySide6.QtSensors.QSensor.skipDuplicates(self)->bool",
    "PySide6.QtSensors.QSensor.start(self)->bool",
    "PySide6.QtSensors.QSensor.stop(self)",
    "PySide6.QtSensors.QSensor.type(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtSensors.QSensor.userOrientation(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t QSensor_SignatureByteSize = 713;
static constexpr uint8_t QSensor_SignatureBytes[713] = {
    0x78, 0xda, 0xad, 0x56, 0x4b, 0x6f, 0xdb, 0x30, 0x0c, 0xbe, 0xef, 0x57, 0xf4, 0x98, 0x14, 0x9e,
    0x8f, 0x3b, 0x18, 0xe8, 0x80, 0x3c, 0x16, 0x60, 0xd8, 0xba, 0xbc, 0xda, 0x53, 0x91, 0x83, 0x62,
    0xd3, 0x9d, 0x56, 0x57, 0xf2, 0x28, 0xb9, 0x8d, 0xf7, 0xeb, 0x27, 0x5b, 0x8a, 0xe3, 0xa7, 0xe4,
    0xae, 0xbb, 0x38, 0x8e, 0xf4, 0xf1, 0xa3, 0x44, 0x93, 0x1f, 0xb9, 0xc9, 0xf7, 0x34, 0x82, 0x4f,
    0xfe, 0x56, 0xee, 0x81, 0x09, 0x8e, 0xc2, 0xdf, 0xea, 0x97, 0x89, 0x80, 0x24, 0xf6, 0x64, 0x9e,
    0x42, 0xa0, 0x1e, 0x94, 0x3d, 0xfa, 0xf7, 0x8c, 0x72, 0xf6, 0xb0, 0xa9, 0x0c, 0x16, 0x1c, 0xc1,
    0xdf, 0xce, 0x73, 0x09, 0x33, 0x44, 0x92, 0x7b, 0x57, 0xe1, 0x4f, 0x82, 0xd7, 0x07, 0x2f, 0x25,
    0x08, 0x4c, 0x06, 0x6d, 0xe0, 0xfa, 0xf8, 0x0b, 0x42, 0x79, 0xc3, 0xb2, 0x24, 0x49, 0x25, 0x7a,
    0xd7, 0xc1, 0x37, 0xc8, 0x5f, 0x39, 0x46, 0x6b, 0x96, 0xe4, 0x37, 0x3f, 0x38, 0x03, 0x4f, 0xc1,
    0x99, 0xa4, 0x31, 0x05, 0x0c, 0x2e, 0xb4, 0x7a, 0xab, 0x3c, 0x47, 0x7b, 0x31, 0xe4, 0x8c, 0x29,
    0x4a, 0x88, 0xee, 0xf8, 0x9c, 0x84, 0x4f, 0xc0, 0xa2, 0xe0, 0xc8, 0x79, 0xa2, 0x37, 0xc9, 0x0b,
    0xa1, 0x09, 0x39, 0x26, 0xb0, 0x24, 0x92, 0xec, 0x88, 0x04, 0x11, 0x6c, 0xbf, 0x53, 0x21, 0x1f,
    0x84, 0x8c, 0xfc, 0x94, 0x50, 0x7c, 0xa0, 0x4c, 0x7a, 0x57, 0xea, 0x71, 0x38, 0x68, 0x8b, 0xc8,
    0x00, 0x03, 0xb5, 0xa6, 0x57, 0x10, 0x48, 0xa4, 0x6e, 0x1e, 0x98, 0x90, 0xec, 0xf4, 0x5f, 0xbd,
    0x77, 0xcc, 0x44, 0x5e, 0x77, 0x17, 0x4a, 0xfa, 0x02, 0xb5, 0x05, 0x9e, 0xc9, 0x34, 0x93, 0x3b,
    0xc2, 0x1e, 0x2b, 0xcf, 0x9b, 0x4e, 0xac, 0x7f, 0x6b, 0x14, 0x16, 0xa8, 0x43, 0xc7, 0xee, 0x72,
    0x90, 0x08, 0x44, 0x88, 0x34, 0x95, 0xea, 0x03, 0xa8, 0xc3, 0x48, 0xac, 0x4e, 0x01, 0x88, 0x1c,
    0x2f, 0x38, 0x92, 0xbc, 0x92, 0x5c, 0xac, 0x59, 0xed, 0x1c, 0xe2, 0x89, 0xa6, 0xcb, 0x2c, 0x4d,
    0x68, 0x58, 0xc6, 0xa0, 0x76, 0xe2, 0x13, 0x88, 0x35, 0x52, 0x15, 0x72, 0x52, 0xf0, 0xde, 0xf2,
    0x08, 0xce, 0x17, 0xf5, 0x67, 0xdd, 0x3d, 0x13, 0xf2, 0x0c, 0x8b, 0x8f, 0x5b, 0xdb, 0xbb, 0x38,
    0xcf, 0x04, 0x60, 0xef, 0xc6, 0x33, 0x39, 0xcd, 0xb3, 0x38, 0x06, 0xdc, 0xd3, 0x3f, 0xb5, 0x4b,
    0x41, 0x1c, 0xd3, 0xb0, 0x80, 0xf7, 0x6d, 0x1e, 0xbb, 0x6b, 0xd3, 0x0f, 0x9b, 0xa1, 0x64, 0xf5,
    0x49, 0x14, 0xad, 0x68, 0x22, 0xc1, 0xa4, 0x6d, 0x5c, 0xbe, 0x07, 0x83, 0x78, 0x8d, 0xb5, 0x12,
    0x76, 0xd2, 0xa7, 0x64, 0x9e, 0x7e, 0xfc, 0x3c, 0x98, 0x45, 0x36, 0xb6, 0x6e, 0x3c, 0xcf, 0x74,
    0xc3, 0x46, 0x3d, 0x1f, 0xc1, 0xe2, 0xe2, 0xa8, 0x2b, 0xc0, 0x49, 0x6b, 0x2a, 0xc5, 0xc6, 0x54,
    0x85, 0xfe, 0x4c, 0xa6, 0xae, 0x67, 0xc1, 0x9b, 0x32, 0xac, 0x8a, 0xf0, 0x6c, 0x55, 0xa4, 0x9a,
    0xcd, 0xac, 0x93, 0x4a, 0xe3, 0xdc, 0x9d, 0xcb, 0x74, 0x24, 0x1a, 0x62, 0x92, 0x25, 0x66, 0x79,
    0xc5, 0xf1, 0x4e, 0x09, 0xc9, 0xe4, 0x1f, 0x54, 0xad, 0x11, 0xd2, 0x16, 0xc6, 0xea, 0xbe, 0x2a,
    0xdc, 0x2a, 0x7f, 0x74, 0xfd, 0x5a, 0x8c, 0x7a, 0x0a, 0x63, 0xdc, 0x65, 0x4b, 0x35, 0x18, 0x07,
    0xd5, 0x15, 0xd2, 0x4a, 0x6a, 0x47, 0xbd, 0xd8, 0x32, 0xfc, 0xa2, 0xdd, 0xdd, 0x0c, 0x1c, 0x1f,
    0x2e, 0x2a, 0x66, 0xa5, 0x8e, 0x8e, 0x4c, 0x21, 0x05, 0x37, 0x82, 0x37, 0xda, 0x60, 0xae, 0x64,
    0x7b, 0x34, 0x78, 0xd1, 0x69, 0x30, 0xa3, 0x4d, 0x57, 0x40, 0x64, 0x86, 0xb0, 0xcf, 0xd2, 0x94,
    0xa3, 0x62, 0x30, 0xba, 0xa4, 0x57, 0x87, 0x85, 0xc9, 0x37, 0x76, 0x6e, 0x17, 0x0d, 0x51, 0x1d,
    0xf7, 0xcd, 0x6b, 0xad, 0xe5, 0xcd, 0x06, 0xce, 0x4c, 0x69, 0xb4, 0x32, 0x0b, 0xa7, 0xe9, 0xa9,
    0x4e, 0x9d, 0x32, 0xcd, 0xd6, 0xca, 0xf4, 0xcc, 0x5f, 0xe0, 0xff, 0xca, 0xbe, 0x28, 0x7f, 0x0a,
    0x91, 0x10, 0x93, 0x9e, 0xcb, 0xb6, 0x32, 0xf9, 0xe0, 0x64, 0x12, 0xef, 0x93, 0x9c, 0x77, 0xf9,
    0x97, 0xb5, 0x5a, 0xaa, 0xcf, 0x27, 0x53, 0x87, 0x55, 0xbd, 0xa4, 0x9a, 0x13, 0x85, 0xcb, 0x72,
    0xa0, 0xcb, 0xf5, 0x8e, 0x1a, 0x6f, 0xea, 0x7b, 0x0e, 0xc7, 0xad, 0x42, 0x68, 0x0d, 0x0f, 0x0e,
    0xe3, 0x45, 0x7f, 0x1f, 0x1a, 0x18, 0x75, 0x1c, 0x64, 0xcb, 0x7a, 0x73, 0xf2, 0xd0, 0x4c, 0x93,
    0x0e, 0xa3, 0x2f, 0x03, 0x7a, 0x3f, 0x34, 0x21, 0x39, 0xe8, 0xbe, 0x36, 0xa5, 0xb8, 0x3e, 0x56,
    0xbf, 0x31, 0x01, 0xed, 0x7e, 0x6e, 0x3b, 0x0a, 0xd4, 0x9d, 0xf4, 0x1c, 0x14, 0xeb, 0x96, 0x22,
    0x79, 0x94, 0x45, 0x70, 0x1a, 0x61, 0xb8, 0x6f, 0x4c, 0xb5, 0xda, 0xb6, 0x67, 0xd2, 0x75, 0xb0,
    0xdc, 0x37, 0x27, 0x56, 0x4d, 0xd3, 0x33, 0xc6, 0x5a, 0x69, 0xba, 0x27, 0x71, 0x8b, 0xb7, 0x90,
    0x04, 0xe5, 0x68, 0x2c, 0x4f, 0x35, 0xd4, 0x02, 0x2a, 0xe4, 0xe5, 0x3d, 0x8d, 0x37, 0xeb, 0x89,
    0x84, 0x69, 0x0f, 0x7f, 0x01, 0x25, 0x25, 0x38, 0xe6
};
#endif

PyTypeObject *init_QSensor(PyObject *module)
{
    if (SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX].type != nullptr)
        return SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX].type;

    Shiboken::AutoDecRef Sbk_QSensor_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QSensor_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSensor",
        "QSensor*",
        &Sbk_QSensor_spec,
        &Shiboken::callCppDestructor< QSensor >,
        Sbk_QSensor_Type_bases.object(),
        0);
    auto *pyType = Sbk_QSensor_TypeF(); // references _Sbk_QSensor_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSensor_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSensor_SignatureBytes, QSensor_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSensor_PropertyStrings);
    SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSensor_PythonToCpp_QSensor_PTR,
        is_QSensor_PythonToCpp_QSensor_PTR_Convertible,
        QSensor_PTR_CppToPython_QSensor);

    Shiboken::Conversions::registerConverterName(converter, "QSensor");
    Shiboken::Conversions::registerConverterName(converter, "QSensor*");
    Shiboken::Conversions::registerConverterName(converter, "QSensor&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSensor).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QSensorWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QSensor_TypeF(), &Sbk_QSensor_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QSensor_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Feature'.
    const char *Feature_Initializer[] = {
        "Buffering",
        "AlwaysOn",
        "GeoValues",
        "FieldOfView",
        "AccelerationMode",
        "SkipDuplicates",
        "AxesOrientation",
        "PressureSensorTemperature",
        "Reserved",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t Feature_InitializerValues[] = {
        uint16_t(QSensor::Feature::Buffering),                 //  0x0000  0
        uint16_t(QSensor::Feature::AlwaysOn),                  //  0x0001  1
        uint16_t(QSensor::Feature::GeoValues),                 //  0x0002  2
        uint16_t(QSensor::Feature::FieldOfView),               //  0x0003  3
        uint16_t(QSensor::Feature::AccelerationMode),          //  0x0004  4
        uint16_t(QSensor::Feature::SkipDuplicates),            //  0x0005  5
        uint16_t(QSensor::Feature::AxesOrientation),           //  0x0006  6
        uint16_t(QSensor::Feature::PressureSensorTemperature), //  0x0007  7
        uint16_t(QSensor::Feature::Reserved)                   //  0x0101  257
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSensor_TypeF(),
        "2:PySide6.QtSensors.QSensor.Feature",
        Feature_Initializer, Feature_InitializerValues);
    SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_Feature_IDX].type = EType;
    // Register converter for enum 'QSensor::Feature'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSensor_Feature_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QSensor_Feature,
            is_Enum_PythonToCpp_QSensor_Feature_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QSensor::Feature");
        Shiboken::Conversions::registerConverterAlias(converter, "Feature");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Feature' enum.

    // Initialization of enum 'AxesOrientationMode'.
    const char *AxesOrientationMode_Initializer[] = {
        "FixedOrientation",
        "AutomaticOrientation",
        "UserOrientation",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t AxesOrientationMode_InitializerValues[] = {
        uint8_t(QSensor::AxesOrientationMode::FixedOrientation),     //  0x00  0
        uint8_t(QSensor::AxesOrientationMode::AutomaticOrientation), //  0x01  1
        uint8_t(QSensor::AxesOrientationMode::UserOrientation)       //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSensor_TypeF(),
        "2:PySide6.QtSensors.QSensor.AxesOrientationMode",
        AxesOrientationMode_Initializer, AxesOrientationMode_InitializerValues);
    SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_AxesOrientationMode_IDX].type = EType;
    // Register converter for enum 'QSensor::AxesOrientationMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSensor_AxesOrientationMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QSensor_AxesOrientationMode,
            is_Enum_PythonToCpp_QSensor_AxesOrientationMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QSensor::AxesOrientationMode");
        Shiboken::Conversions::registerConverterAlias(converter, "AxesOrientationMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'AxesOrientationMode' enum.

    PySide::Signal::registerSignals(pyType, &::QSensor::staticMetaObject);
    qRegisterMetaType< ::QSensor::Feature >("QSensor::Feature");
    qRegisterMetaType< ::QSensor::AxesOrientationMode >("QSensor::AxesOrientationMode");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QSensor::staticMetaObject, sizeof(QSensorWrapper));

    return pyType;
}
