// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtsensors_python.h"

// main header
#include "qsensorbackendfactory_wrapper.h"

// Argument includes
#include <QtSensors/qsensor.h>
#include <QtSensors/qsensorbackend.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QSensorBackendFactoryWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QSensorBackendFactoryWrapper::QSensorBackendFactoryWrapper()
{
}

::QSensorBackend * QSensorBackendFactoryWrapper::createBackend(::QSensor * sensor)
{
    if (m_PyMethodCache[0]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QSensorBackendFactory.createBackend");
        return nullptr;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "createBackend";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        Shiboken::Errors::setPureVirtualMethodError("QSensorBackendFactory.createBackend");
        return nullptr;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), sensor)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), sensor)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSensorBackendFactory", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensorBackend_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSensorBackendFactory", funcName, Shiboken::SbkType< QSensorBackend >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QSensorBackend *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QSensorBackendFactoryWrapper::~QSensorBackendFactoryWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSensorBackendFactory_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensorBackendFactory_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QSensorBackendFactory");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSensorBackendFactory >()))
        return -1;

    QSensorBackendFactoryWrapper *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtSensorsTypeStructs[SBK_QSensorBackendFactory_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QSensorBackendFactory()
        cptr = new QSensorBackendFactoryWrapper();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QSensorBackendFactory >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSensorBackendFactoryFunc_createBackend(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensorBackendFactory *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensorBackendFactory_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSensorBackendFactory::createBackend(QSensor*)->QSensorBackend*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), (pyArg)))) {
        overloadId = 0; // createBackend(QSensor*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "createBackend", errInfo, SbkPySide6_QtSensorsTypeStructs[SBK_QSensorBackendFactory_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSensor *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createBackend(QSensor*)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QSensorBackendFactory.createBackend");
                return {};
            }
            QSensorBackend * cppResult = cppSelf->createBackend(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensorBackend_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QSensorBackendFactory_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSensorBackendFactory_methods[] = {
    {"createBackend", reinterpret_cast<PyCFunction>(Sbk_QSensorBackendFactoryFunc_createBackend), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QSensorBackendFactory_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QSensorBackendFactory *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensorBackendFactory_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QSensorBackendFactoryWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QSensorBackendFactory_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSensorBackendFactory_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSensorBackendFactory_Type = nullptr;
static PyTypeObject *Sbk_QSensorBackendFactory_TypeF(void)
{
    return _Sbk_QSensorBackendFactory_Type;
}

static PyType_Slot Sbk_QSensorBackendFactory_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QSensorBackendFactory_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSensorBackendFactory_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSensorBackendFactory_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSensorBackendFactory_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSensorBackendFactory_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSensorBackendFactory_spec = {
    "2:PySide6.QtSensors.QSensorBackendFactory",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSensorBackendFactory_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSensorBackendFactory_PythonToCpp_QSensorBackendFactory_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSensorBackendFactory_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSensorBackendFactory_PythonToCpp_QSensorBackendFactory_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSensorBackendFactory_TypeF()))
        return QSensorBackendFactory_PythonToCpp_QSensorBackendFactory_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSensorBackendFactory_PTR_CppToPython_QSensorBackendFactory(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QSensorBackendFactory *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QSensorBackendFactory_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSensorBackendFactory_SignatureStrings[] = {
    "PySide6.QtSensors.QSensorBackendFactory(self)",
    "PySide6.QtSensors.QSensorBackendFactory.createBackend(self,sensor:PySide6.QtSensors.QSensor)->PySide6.QtSensors.QSensorBackend",
    nullptr}; // Sentinel
#else
static constexpr size_t QSensorBackendFactory_SignatureByteSize = 77;
static constexpr uint8_t QSensorBackendFactory_SignatureBytes[77] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x09, 0x4e, 0xcd, 0x2b,
    0xce, 0x2f, 0x2a, 0xd6, 0x0b, 0x84, 0x30, 0x9c, 0x12, 0x93, 0xb3, 0x53, 0xf3, 0x52, 0xdc, 0x12,
    0x93, 0x4b, 0xf2, 0x8b, 0x2a, 0x35, 0x8a, 0x53, 0x73, 0xd2, 0x34, 0xb9, 0x02, 0x88, 0x53, 0xad,
    0x97, 0x5c, 0x94, 0x9a, 0x58, 0x92, 0x0a, 0x15, 0x04, 0xeb, 0xd5, 0x29, 0x06, 0xab, 0xb3, 0xc2,
    0x69, 0x82, 0xa6, 0xae, 0x1d, 0x21, 0xd3, 0xb9, 0x00, 0xce, 0x1c, 0x3f, 0xdc
};
#endif

PyTypeObject *init_QSensorBackendFactory(PyObject *module)
{
    if (SbkPySide6_QtSensorsTypeStructs[SBK_QSensorBackendFactory_IDX].type != nullptr)
        return SbkPySide6_QtSensorsTypeStructs[SBK_QSensorBackendFactory_IDX].type;

    Shiboken::AutoDecRef Sbk_QSensorBackendFactory_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QSensorBackendFactory_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSensorBackendFactory",
        "QSensorBackendFactory*",
        &Sbk_QSensorBackendFactory_spec,
        &Shiboken::callCppDestructor< QSensorBackendFactory >,
        Sbk_QSensorBackendFactory_Type_bases.object(),
        0);
    auto *pyType = Sbk_QSensorBackendFactory_TypeF(); // references _Sbk_QSensorBackendFactory_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSensorBackendFactory_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSensorBackendFactory_SignatureBytes, QSensorBackendFactory_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSensorBackendFactory_PropertyStrings);
    SbkPySide6_QtSensorsTypeStructs[SBK_QSensorBackendFactory_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSensorBackendFactory_PythonToCpp_QSensorBackendFactory_PTR,
        is_QSensorBackendFactory_PythonToCpp_QSensorBackendFactory_PTR_Convertible,
        QSensorBackendFactory_PTR_CppToPython_QSensorBackendFactory);

    Shiboken::Conversions::registerConverterName(converter, "QSensorBackendFactory");
    Shiboken::Conversions::registerConverterName(converter, "QSensorBackendFactory*");
    Shiboken::Conversions::registerConverterName(converter, "QSensorBackendFactory&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSensorBackendFactory).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QSensorBackendFactoryWrapper).name());

    qRegisterMetaType< ::QSensorBackendFactory *>();

    return pyType;
}
