// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtsensors_python.h"

// main header
#include "qsensormanager_wrapper.h"

// Argument includes
#include <QtSensors/qsensor.h>
#include <QtSensors/qsensorbackend.h>
#include <QtSensors/qsensormanager.h>
#include <qbytearray.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSensorManager_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSensorManager >()))
        return -1;

    ::QSensorManager *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtSensorsTypeStructs[SBK_QSensorManager_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QSensorManager()
        cptr = new ::QSensorManager();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QSensorManager >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSensorManagerFunc_createBackend(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QSensorManager::createBackend(QSensor*)->QSensorBackend*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), (pyArg)))) {
        overloadId = 0; // createBackend(QSensor*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "createBackend", errInfo, SbkPySide6_QtSensorsTypeStructs[SBK_QSensorManager_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSensor *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createBackend(QSensor*)
            QSensorBackend * cppResult = ::QSensorManager::createBackend(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensorBackend_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorManagerFunc_isBackendRegistered(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "isBackendRegistered", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QSensorManager::isBackendRegistered(QByteArray,QByteArray)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
        overloadId = 0; // isBackendRegistered(QByteArray,QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "isBackendRegistered", errInfo, SbkPySide6_QtSensorsTypeStructs[SBK_QSensorManager_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QByteArray cppArg1_local;
        ::QByteArray *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // isBackendRegistered(QByteArray,QByteArray)
            bool cppResult = ::QSensorManager::isBackendRegistered(*cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorManagerFunc_registerBackend(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "registerBackend", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QSensorManager::registerBackend(QByteArray,QByteArray,QSensorBackendFactory*)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensorBackendFactory_IDX]), (pyArgs[2])))) {
        overloadId = 0; // registerBackend(QByteArray,QByteArray,QSensorBackendFactory*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "registerBackend", errInfo, SbkPySide6_QtSensorsTypeStructs[SBK_QSensorManager_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QByteArray cppArg1_local;
        ::QByteArray *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QSensorBackendFactory *cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // registerBackend(QByteArray,QByteArray,QSensorBackendFactory*)
            ::QSensorManager::registerBackend(*cppArg0, *cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSensorManagerFunc_setDefaultBackend(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setDefaultBackend", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QSensorManager::setDefaultBackend(QByteArray,QByteArray)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
        overloadId = 0; // setDefaultBackend(QByteArray,QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setDefaultBackend", errInfo, SbkPySide6_QtSensorsTypeStructs[SBK_QSensorManager_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QByteArray cppArg1_local;
        ::QByteArray *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setDefaultBackend(QByteArray,QByteArray)
            ::QSensorManager::setDefaultBackend(*cppArg0, *cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSensorManagerFunc_unregisterBackend(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "unregisterBackend", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QSensorManager::unregisterBackend(QByteArray,QByteArray)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
        overloadId = 0; // unregisterBackend(QByteArray,QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "unregisterBackend", errInfo, SbkPySide6_QtSensorsTypeStructs[SBK_QSensorManager_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QByteArray cppArg1_local;
        ::QByteArray *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // unregisterBackend(QByteArray,QByteArray)
            ::QSensorManager::unregisterBackend(*cppArg0, *cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QSensorManager_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSensorManager_methods[] = {
    {"createBackend", reinterpret_cast<PyCFunction>(Sbk_QSensorManagerFunc_createBackend), METH_O|METH_STATIC, nullptr},
    {"isBackendRegistered", reinterpret_cast<PyCFunction>(Sbk_QSensorManagerFunc_isBackendRegistered), METH_VARARGS|METH_STATIC, nullptr},
    {"registerBackend", reinterpret_cast<PyCFunction>(Sbk_QSensorManagerFunc_registerBackend), METH_VARARGS|METH_STATIC, nullptr},
    {"setDefaultBackend", reinterpret_cast<PyCFunction>(Sbk_QSensorManagerFunc_setDefaultBackend), METH_VARARGS|METH_STATIC, nullptr},
    {"unregisterBackend", reinterpret_cast<PyCFunction>(Sbk_QSensorManagerFunc_unregisterBackend), METH_VARARGS|METH_STATIC, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QSensorManager_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSensorManager_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSensorManager_Type = nullptr;
static PyTypeObject *Sbk_QSensorManager_TypeF(void)
{
    return _Sbk_QSensorManager_Type;
}

static PyType_Slot Sbk_QSensorManager_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSensorManager_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSensorManager_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSensorManager_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSensorManager_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSensorManager_spec = {
    "2:PySide6.QtSensors.QSensorManager",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSensorManager_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSensorManager_PythonToCpp_QSensorManager_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSensorManager_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSensorManager_PythonToCpp_QSensorManager_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSensorManager_TypeF()))
        return QSensorManager_PythonToCpp_QSensorManager_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSensorManager_PTR_CppToPython_QSensorManager(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QSensorManager_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSensorManager_SignatureStrings[] = {
    "PySide6.QtSensors.QSensorManager(self)",
    "PySide6.QtSensors.QSensorManager.createBackend(sensor:PySide6.QtSensors.QSensor)->PySide6.QtSensors.QSensorBackend",
    "PySide6.QtSensors.QSensorManager.isBackendRegistered(type:typing.Union[PySide6.QtCore.QByteArray, char*],identifier:typing.Union[PySide6.QtCore.QByteArray, char*])->bool",
    "PySide6.QtSensors.QSensorManager.registerBackend(type:typing.Union[PySide6.QtCore.QByteArray, char*],identifier:typing.Union[PySide6.QtCore.QByteArray, char*],factory:PySide6.QtSensors.QSensorBackendFactory)",
    "PySide6.QtSensors.QSensorManager.setDefaultBackend(type:typing.Union[PySide6.QtCore.QByteArray, char*],identifier:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "PySide6.QtSensors.QSensorManager.unregisterBackend(type:typing.Union[PySide6.QtCore.QByteArray, char*],identifier:typing.Union[PySide6.QtCore.QByteArray, char*])",
    nullptr}; // Sentinel
#else
static constexpr size_t QSensorManager_SignatureByteSize = 193;
static constexpr uint8_t QSensorManager_SignatureBytes[193] = {
    0x78, 0xda, 0xc5, 0x51, 0xb1, 0x0e, 0x82, 0x30, 0x10, 0xdd, 0xf9, 0x0a, 0x47, 0x30, 0xd8, 0xd1,
    0x81, 0xc1, 0x44, 0x34, 0x6e, 0x26, 0x20, 0x71, 0x32, 0x0e, 0xb5, 0x5c, 0xb1, 0x91, 0xb4, 0xe6,
    0x7a, 0x0c, 0xfd, 0x7b, 0x6b, 0xc0, 0x38, 0x91, 0xe2, 0x22, 0xcb, 0xe5, 0x92, 0xf7, 0xde, 0xdd,
    0xbb, 0x77, 0x85, 0xab, 0x54, 0x0d, 0x6b, 0x56, 0x52, 0x05, 0xda, 0x1a, 0xb4, 0xac, 0xec, 0x9b,
    0x23, 0xd7, 0xbc, 0x01, 0x8c, 0x2d, 0xb4, 0x32, 0x89, 0x8a, 0x00, 0x8d, 0x09, 0x04, 0x4e, 0x90,
    0x73, 0xf1, 0x00, 0x5d, 0x7b, 0xd1, 0x1b, 0xcb, 0x46, 0x55, 0xc9, 0x6a, 0x33, 0x8a, 0x0d, 0x33,
    0xc2, 0x2b, 0x95, 0x1d, 0xa8, 0x27, 0x68, 0x94, 0x25, 0x40, 0xa8, 0x63, 0x72, 0x4f, 0xc8, 0x7c,
    0x51, 0xba, 0x61, 0x67, 0xad, 0x8c, 0xbe, 0x7c, 0xc7, 0xec, 0x0c, 0x02, 0x2b, 0x73, 0x47, 0xb0,
    0x45, 0xe4, 0x2e, 0x5d, 0x88, 0x3b, 0xc7, 0xe5, 0x35, 0xf5, 0xb0, 0x26, 0x25, 0x15, 0xe0, 0x8f,
    0x4a, 0x7f, 0xc5, 0xcd, 0x98, 0x36, 0xec, 0x14, 0x07, 0x83, 0x9f, 0x78, 0xfe, 0xea, 0x32, 0x95,
    0x5c, 0x90, 0x41, 0x97, 0x85, 0x12, 0x3f, 0xf4, 0xbc, 0x09, 0xcf, 0xb6, 0x40, 0x7b, 0x90, 0xbc,
    0x6b, 0x69, 0x96, 0x8b, 0x26, 0x38, 0xec, 0xf4, 0xac, 0x99, 0x27, 0xd1, 0x0b, 0x87, 0x81, 0x3a,
    0x3d
};
#endif

PyTypeObject *init_QSensorManager(PyObject *module)
{
    if (SbkPySide6_QtSensorsTypeStructs[SBK_QSensorManager_IDX].type != nullptr)
        return SbkPySide6_QtSensorsTypeStructs[SBK_QSensorManager_IDX].type;

    Shiboken::AutoDecRef Sbk_QSensorManager_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QSensorManager_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSensorManager",
        "QSensorManager*",
        &Sbk_QSensorManager_spec,
        &Shiboken::callCppDestructor< ::QSensorManager >,
        Sbk_QSensorManager_Type_bases.object(),
        0);
    auto *pyType = Sbk_QSensorManager_TypeF(); // references _Sbk_QSensorManager_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSensorManager_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSensorManager_SignatureBytes, QSensorManager_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSensorManager_PropertyStrings);
    SbkPySide6_QtSensorsTypeStructs[SBK_QSensorManager_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSensorManager_PythonToCpp_QSensorManager_PTR,
        is_QSensorManager_PythonToCpp_QSensorManager_PTR_Convertible,
        QSensorManager_PTR_CppToPython_QSensorManager);

    Shiboken::Conversions::registerConverterName(converter, "QSensorManager");
    Shiboken::Conversions::registerConverterName(converter, "QSensorManager*");
    Shiboken::Conversions::registerConverterName(converter, "QSensorManager&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSensorManager).name());

    qRegisterMetaType< ::QSensorManager *>();

    return pyType;
}
