// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtsensors_python.h"

// main header
#include "qtiltfilter_wrapper.h"

// Argument includes
#include <QtSensors/qsensor.h>
#include <QtSensors/qtiltsensor.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QTiltFilterWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

bool QTiltFilterWrapper::filter(::QTiltReading * reading)
{
    if (m_PyMethodCache[0]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QTiltFilter.filter");
        return false;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "filter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        Shiboken::Errors::setPureVirtualMethodError("QTiltFilter.filter");
        return false;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QTiltReading_IDX]), reading)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QTiltReading_IDX]), reading)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QTiltFilter", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QTiltFilter", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QTiltFilterWrapper::setSensor(::QSensor * sensor)
{
    if (m_PyMethodCache[1]) {
        return this->::QSensorFilter::setSensor(sensor);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setSensor";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QSensorFilter::setSensor(sensor);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), sensor)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), sensor)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QTiltFilter", funcName);
        return;
    }
}

QTiltFilterWrapper::~QTiltFilterWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QTiltFilterFunc_filter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTiltFilter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QTiltFilter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTiltFilter::filter(QTiltReading*)->bool
    // 1: QSensorFilter::filter(QSensorReading*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QTiltReading_IDX]), (pyArg)))) {
        overloadId = 0; // filter(QTiltReading*)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensorReading_IDX]), (pyArg)))) {
        overloadId = 1; // filter(QSensorReading*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "filter", errInfo, SbkPySide6_QtSensorsTypeStructs[SBK_QTiltFilter_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // filter(QTiltReading *reading)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QTiltReading *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // filter(QTiltReading*)
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                    Shiboken::Errors::setPureVirtualMethodError("QTiltFilter.filter");
                    return {};
                }
                bool cppResult = cppSelf->filter(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // filter(QSensorReading *reading)
        {
            Shiboken::Errors::setPrivateMethod("filter(QSensorReading *reading)");
            return {};
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QTiltFilter_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QTiltFilter_methods[] = {
    {"filter", reinterpret_cast<PyCFunction>(Sbk_QTiltFilterFunc_filter), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QTiltFilter_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QTiltFilter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QTiltFilter_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QTiltFilterWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QTiltFilter_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QTiltFilter_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QTiltFilter_Type = nullptr;
static PyTypeObject *Sbk_QTiltFilter_TypeF(void)
{
    return _Sbk_QTiltFilter_Type;
}

static PyType_Slot Sbk_QTiltFilter_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QTiltFilter_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QTiltFilter_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QTiltFilter_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QTiltFilter_methods)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QTiltFilter_spec = {
    "2:PySide6.QtSensors.QTiltFilter",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QTiltFilter_slots
};

} //extern "C"

static void *Sbk_QTiltFilter_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QSensorFilter >())
        return dynamic_cast< ::QTiltFilter *>(reinterpret_cast< ::QSensorFilter *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QTiltFilter_PythonToCpp_QTiltFilter_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QTiltFilter_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QTiltFilter_PythonToCpp_QTiltFilter_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QTiltFilter_TypeF()))
        return QTiltFilter_PythonToCpp_QTiltFilter_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QTiltFilter_PTR_CppToPython_QTiltFilter(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QTiltFilter *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QTiltFilter_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QTiltFilter_SignatureStrings[] = {
    "1:PySide6.QtSensors.QTiltFilter.filter(self,reading:PySide6.QtSensors.QTiltReading)->bool",
    "0:PySide6.QtSensors.QTiltFilter.filter(self,reading:PySide6.QtSensors.QSensorReading)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QTiltFilter_SignatureByteSize = 75;
static constexpr uint8_t QTiltFilter_SignatureBytes[75] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x09, 0x4e,
    0xcd, 0x2b, 0xce, 0x2f, 0x2a, 0xd6, 0x0b, 0x0c, 0xc9, 0xcc, 0x29, 0x71, 0x03, 0xe2, 0xd4, 0x22,
    0xbd, 0x34, 0x30, 0xa5, 0x51, 0x9c, 0x9a, 0x93, 0xa6, 0x53, 0x94, 0x9a, 0x98, 0x92, 0x99, 0x97,
    0x8e, 0x4b, 0x47, 0x10, 0x44, 0x5a, 0x53, 0xd7, 0x2e, 0x29, 0x3f, 0x3f, 0x87, 0xcb, 0x80, 0x3a,
    0x26, 0x43, 0x18, 0x68, 0x66, 0x03, 0x00, 0xa1, 0xf5, 0x42, 0x13
};
#endif

PyTypeObject *init_QTiltFilter(PyObject *module)
{
    if (SbkPySide6_QtSensorsTypeStructs[SBK_QTiltFilter_IDX].type != nullptr)
        return SbkPySide6_QtSensorsTypeStructs[SBK_QTiltFilter_IDX].type;

    Shiboken::AutoDecRef Sbk_QTiltFilter_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensorFilter_IDX]))));

    _Sbk_QTiltFilter_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QTiltFilter",
        "QTiltFilter*",
        &Sbk_QTiltFilter_spec,
        &Shiboken::callCppDestructor< QTiltFilter >,
        Sbk_QTiltFilter_Type_bases.object(),
        0);
    auto *pyType = Sbk_QTiltFilter_TypeF(); // references _Sbk_QTiltFilter_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QTiltFilter_SignatureStrings);
#else
    InitSignatureBytes(pyType, QTiltFilter_SignatureBytes, QTiltFilter_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QTiltFilter_PropertyStrings);
    SbkPySide6_QtSensorsTypeStructs[SBK_QTiltFilter_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QTiltFilter_PythonToCpp_QTiltFilter_PTR,
        is_QTiltFilter_PythonToCpp_QTiltFilter_PTR_Convertible,
        QTiltFilter_PTR_CppToPython_QTiltFilter);

    Shiboken::Conversions::registerConverterName(converter, "QTiltFilter");
    Shiboken::Conversions::registerConverterName(converter, "QTiltFilter*");
    Shiboken::Conversions::registerConverterName(converter, "QTiltFilter&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QTiltFilter).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QTiltFilterWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QTiltFilter_TypeF(), &Sbk_QTiltFilter_typeDiscovery);

    qRegisterMetaType< ::QTiltFilter *>();

    return pyType;
}
