// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtserialbus_python.h"

// main header
#include "qcanbusdevice_wrapper.h"

// inner classes
#include "qcanbusdevice_filter_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QtSerialBus/qcanbusdevice.h>
#include <QtSerialBus/qcanbusdeviceinfo.h>
#include <QtSerialBus/qcanbusframe.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QCanBusDeviceWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QCanBusDeviceWrapper::QCanBusDeviceWrapper(::QObject * parent) : QCanBusDevice(parent)
{
}

::QCanBusDevice::CanBusStatus QCanBusDeviceWrapper::busStatus()
{
    if (m_PyMethodCache[0])
        return this->::QCanBusDevice::busStatus();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return QCanBusDevice::CanBusStatus::Unknown;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "busStatus";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QCanBusDevice::busStatus();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QCanBusDevice", funcName);
        return QCanBusDevice::CanBusStatus::Unknown;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_CanBusStatus_IDX])))->converter, pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QCanBusDevice", funcName, Shiboken::SbkType< QCanBusDevice::CanBusStatus >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return QCanBusDevice::CanBusStatus::Unknown;
    }
    ::QCanBusDevice::CanBusStatus cppResult{QCanBusDevice::CanBusStatus::Unknown};
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QCanBusDeviceWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QCanBusDevice", funcName);
        return;
    }
}

void QCanBusDeviceWrapper::close()
{
    if (m_PyMethodCache[2]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QCanBusDevice.close");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "close";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        Shiboken::Errors::setPureVirtualMethodError("QCanBusDevice.close");
        return;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QCanBusDevice", funcName);
        return;
    }
}

void QCanBusDeviceWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QCanBusDevice", funcName);
        return;
    }
}

void QCanBusDeviceWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[4]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QCanBusDevice", funcName);
        return;
    }
}

void QCanBusDeviceWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[5]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QCanBusDevice", funcName);
        return;
    }
}

bool QCanBusDeviceWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[6])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QCanBusDevice", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QCanBusDevice", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QCanBusDeviceWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[7])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[7] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QCanBusDevice", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QCanBusDevice", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QCanBusDeviceWrapper::hasBusStatus() const
{
    if (m_PyMethodCache[8])
        return this->::QCanBusDevice::hasBusStatus();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "hasBusStatus";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[8] = true;
        gil.release();
        return this->::QCanBusDevice::hasBusStatus();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QCanBusDevice", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QCanBusDevice", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QString QCanBusDeviceWrapper::interpretErrorFrame(const ::QCanBusFrame & errorFrame)
{
    if (m_PyMethodCache[9]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QCanBusDevice.interpretErrorFrame");
        return ::QString();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return ::QString();
    static PyObject *nameCache[2] = {};
    static const char *funcName = "interpretErrorFrame";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[9] = true;
        Shiboken::Errors::setPureVirtualMethodError("QCanBusDevice.interpretErrorFrame");
        return ::QString();
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusFrame_IDX]), &errorFrame)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusFrame_IDX]), &errorFrame)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QCanBusDevice", funcName);
        return ::QString();
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QCanBusDevice", funcName, "QString", Py_TYPE(pyResult)->tp_name);
        return ::QString();
    }
    ::QString cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QCanBusDeviceWrapper::open()
{
    if (m_PyMethodCache[10]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QCanBusDevice.open");
        return false;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "open";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[10] = true;
        Shiboken::Errors::setPureVirtualMethodError("QCanBusDevice.open");
        return false;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QCanBusDevice", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QCanBusDevice", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QCanBusDeviceWrapper::resetController()
{
    if (m_PyMethodCache[11]) {
        return this->::QCanBusDevice::resetController();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "resetController";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[11] = true;
        gil.release();
        return this->::QCanBusDevice::resetController();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QCanBusDevice", funcName);
        return;
    }
}

void QCanBusDeviceWrapper::setConfigurationParameter(::QCanBusDevice::ConfigurationKey key, const ::QVariant & value)
{
    if (m_PyMethodCache[12]) {
        return this->::QCanBusDevice::setConfigurationParameter(key, value);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setConfigurationParameter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[12] = true;
        gil.release();
        return this->::QCanBusDevice::setConfigurationParameter(key, value);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_ConfigurationKey_IDX])))->converter, &key),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &value)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_ConfigurationKey_IDX])))->converter, &key),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &value)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QCanBusDevice", funcName);
        return;
    }
}

void QCanBusDeviceWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[13]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[13] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QCanBusDevice", funcName);
        return;
    }
}

bool QCanBusDeviceWrapper::waitForFramesReceived(int msecs)
{
    if (m_PyMethodCache[14])
        return this->::QCanBusDevice::waitForFramesReceived(msecs);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "waitForFramesReceived";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[14] = true;
        gil.release();
        return this->::QCanBusDevice::waitForFramesReceived(msecs);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &msecs)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(i)",
        msecs
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QCanBusDevice", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QCanBusDevice", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QCanBusDeviceWrapper::waitForFramesWritten(int msecs)
{
    if (m_PyMethodCache[15])
        return this->::QCanBusDevice::waitForFramesWritten(msecs);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "waitForFramesWritten";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[15] = true;
        gil.release();
        return this->::QCanBusDevice::waitForFramesWritten(msecs);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &msecs)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(i)",
        msecs
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QCanBusDevice", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QCanBusDevice", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QCanBusDeviceWrapper::writeFrame(const ::QCanBusFrame & frame)
{
    if (m_PyMethodCache[16]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QCanBusDevice.writeFrame");
        return false;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "writeFrame";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[16] = true;
        Shiboken::Errors::setPureVirtualMethodError("QCanBusDevice.writeFrame");
        return false;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusFrame_IDX]), &frame)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusFrame_IDX]), &frame)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QCanBusDevice", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QCanBusDevice", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

const QMetaObject *QCanBusDeviceWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QCanBusDevice::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QCanBusDeviceWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QCanBusDevice::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QCanBusDeviceWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QCanBusDeviceWrapper *>(this));
    return QCanBusDevice::qt_metacast(_clname);
}

QCanBusDeviceWrapper::~QCanBusDeviceWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QCanBusDevice_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QCanBusDevice");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QCanBusDevice >()))
        return -1;

    QCanBusDeviceWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QCanBusDevice", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QCanBusDevice::QCanBusDevice(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QCanBusDevice(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QCanBusDevice(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                // fall through to handle extra keyword signals and properties
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QCanBusDevice(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QCanBusDeviceWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QCanBusDeviceWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QCanBusDevice >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QCanBusDeviceFunc_busStatus(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanBusDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // busStatus()
        QCanBusDevice::CanBusStatus cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QCanBusDevice::busStatus()
            : cppSelf->busStatus();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_CanBusStatus_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanBusDeviceFunc_clear(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanBusDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "clear", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]);

    if (PyArg_ParseTuple(args, "|O:clear", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCanBusDevice::clear(QFlags<QCanBusDevice::Direction>=)
    if (numArgs == 0) {
        overloadId = 0; // clear(QFlags<QCanBusDevice::Direction>)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QFlags_QCanBusDevice_Direction_IDX])))->flagsConverter, (pyArgs[0])))) {
        overloadId = 0; // clear(QFlags<QCanBusDevice::Direction>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "clear", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_direction = Shiboken::String::createStaticString("direction");
            if (PyDict_Contains(kwds, key_direction) != 0) {
                value = PyDict_GetItem(kwds, key_direction);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_direction);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "clear", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QFlags_QCanBusDevice_Direction_IDX])))->flagsConverter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "clear", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_direction);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "clear", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]);
            }
        }
        ::QFlags<QCanBusDevice::Direction> cppArg0(QCanBusDevice::Direction::AllDirections);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // clear(QFlags<QCanBusDevice::Direction>)
            cppSelf->clear(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCanBusDeviceFunc_clearError(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanBusDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clearError()
        cppSelf->clearError();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCanBusDeviceFunc_close(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanBusDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // close()
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QCanBusDevice.close");
            return {};
        }
        cppSelf->close();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCanBusDeviceFunc_configurationKeys(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanBusDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // configurationKeys()const
        QList<QCanBusDevice::ConfigurationKey> cppResult = const_cast<const ::QCanBusDevice *>(cppSelf)->configurationKeys();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QCanBusDevice_ConfigurationKey_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanBusDeviceFunc_configurationParameter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanBusDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCanBusDevice::configurationParameter(QCanBusDevice::ConfigurationKey)const->QVariant
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_ConfigurationKey_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // configurationParameter(QCanBusDevice::ConfigurationKey)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "configurationParameter", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]);

    // Call function/method
    {
        ::QCanBusDevice::ConfigurationKey cppArg0{QCanBusDevice::RawFilterKey};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // configurationParameter(QCanBusDevice::ConfigurationKey)const
            QVariant cppResult = const_cast<const ::QCanBusDevice *>(cppSelf)->configurationParameter(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanBusDeviceFunc_connectDevice(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanBusDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // connectDevice()
        bool cppResult = cppSelf->connectDevice();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanBusDeviceFunc_createDeviceInfo(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[8];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 5 || numArgs == 6 || numArgs == 7)
        return Shiboken::returnWrongArguments(args, "createDeviceInfo", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]);

    if (PyArg_UnpackTuple(args, "createDeviceInfo", 4, 8, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QCanBusDevice::createDeviceInfo(QString,QString,bool,bool)->QCanBusDeviceInfo
    // 1: static QCanBusDevice::createDeviceInfo(QString,QString,QString,QString,QString,int,bool,bool)->QCanBusDeviceInfo
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        if (numArgs == 8
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3])))
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[4])))
            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5])))
            && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[6])))
            && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[7])))) {
            overloadId = 1; // createDeviceInfo(QString,QString,QString,QString,QString,int,bool,bool)
        } else if (numArgs == 4
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[2])))
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[3])))) {
            overloadId = 0; // createDeviceInfo(QString,QString,bool,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "createDeviceInfo", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // createDeviceInfo(const QString &plugin, const QString &name, bool isVirtual, bool isFlexibleDataRateCapable)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            bool cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            bool cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // createDeviceInfo(QString,QString,bool,bool)
                QCanBusDeviceInfo cppResult = ::QCanBusDevice::createDeviceInfo(cppArg0, cppArg1, cppArg2, cppArg3);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDeviceInfo_IDX]), &cppResult);
            }
            break;
        }
        case 1: // createDeviceInfo(const QString &plugin, const QString &name, const QString &serialNumber, const QString &description, const QString &alias, int channel, bool isVirtual, bool isFlexibleDataRateCapable)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QString cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            ::QString cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            int cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);
            bool cppArg6;
            pythonToCpp[6](pyArgs[6], &cppArg6);
            bool cppArg7;
            pythonToCpp[7](pyArgs[7], &cppArg7);

            if (Shiboken::Errors::occurred() == nullptr) {
                // createDeviceInfo(QString,QString,QString,QString,QString,int,bool,bool)
                QCanBusDeviceInfo cppResult = ::QCanBusDevice::createDeviceInfo(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDeviceInfo_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanBusDeviceFunc_dequeueOutgoingFrame(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanBusDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // dequeueOutgoingFrame()
        QCanBusFrame cppResult = cppSelf->dequeueOutgoingFrame();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusFrame_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanBusDeviceFunc_deviceInfo(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanBusDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // deviceInfo()const
        QCanBusDeviceInfo cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QCanBusDevice *>(cppSelf)->::QCanBusDevice::deviceInfo()
            : const_cast<const ::QCanBusDevice *>(cppSelf)->deviceInfo();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDeviceInfo_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanBusDeviceFunc_disconnectDevice(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanBusDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // disconnectDevice()
        cppSelf->disconnectDevice();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCanBusDeviceFunc_enqueueOutgoingFrame(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanBusDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCanBusDevice::enqueueOutgoingFrame(QCanBusFrame)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusFrame_IDX]), (pyArg)))) {
        overloadId = 0; // enqueueOutgoingFrame(QCanBusFrame)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "enqueueOutgoingFrame", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QCanBusFrame cppArg0_local;
        ::QCanBusFrame *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // enqueueOutgoingFrame(QCanBusFrame)
            cppSelf->enqueueOutgoingFrame(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCanBusDeviceFunc_enqueueReceivedFrames(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanBusDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCanBusDevice::enqueueReceivedFrames(QList<QCanBusFrame>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QCanBusFrame_IDX], (pyArg)))) {
        overloadId = 0; // enqueueReceivedFrames(QList<QCanBusFrame>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "enqueueReceivedFrames", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]);

    // Call function/method
    {
        ::QList<QCanBusFrame> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // enqueueReceivedFrames(QList<QCanBusFrame>)
            cppSelf->enqueueReceivedFrames(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCanBusDeviceFunc_error(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanBusDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // error()const
        QCanBusDevice::CanBusError cppResult = const_cast<const ::QCanBusDevice *>(cppSelf)->error();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_CanBusError_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanBusDeviceFunc_errorString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanBusDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // errorString()const
        QString cppResult = const_cast<const ::QCanBusDevice *>(cppSelf)->errorString();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanBusDeviceFunc_framesAvailable(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanBusDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // framesAvailable()const
        qint64 cppResult = const_cast<const ::QCanBusDevice *>(cppSelf)->framesAvailable();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanBusDeviceFunc_framesToWrite(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanBusDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // framesToWrite()const
        qint64 cppResult = const_cast<const ::QCanBusDevice *>(cppSelf)->framesToWrite();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanBusDeviceFunc_hasBusStatus(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanBusDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hasBusStatus()const
        bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QCanBusDevice *>(cppSelf)->::QCanBusDevice::hasBusStatus()
            : const_cast<const ::QCanBusDevice *>(cppSelf)->hasBusStatus();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanBusDeviceFunc_hasOutgoingFrames(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanBusDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hasOutgoingFrames()const
        bool cppResult = const_cast<const ::QCanBusDevice *>(cppSelf)->hasOutgoingFrames();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanBusDeviceFunc_interpretErrorFrame(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanBusDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCanBusDevice::interpretErrorFrame(QCanBusFrame)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusFrame_IDX]), (pyArg)))) {
        overloadId = 0; // interpretErrorFrame(QCanBusFrame)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "interpretErrorFrame", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QCanBusFrame cppArg0_local;
        ::QCanBusFrame *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // interpretErrorFrame(QCanBusFrame)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QCanBusDevice.interpretErrorFrame");
                return {};
            }
            QString cppResult = cppSelf->interpretErrorFrame(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanBusDeviceFunc_open(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanBusDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // open()
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QCanBusDevice.open");
            return {};
        }
        bool cppResult = cppSelf->open();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanBusDeviceFunc_readAllFrames(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanBusDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // readAllFrames()
        QList<QCanBusFrame> cppResult = cppSelf->readAllFrames();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QCanBusFrame_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanBusDeviceFunc_readFrame(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanBusDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // readFrame()
        QCanBusFrame cppResult = cppSelf->readFrame();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusFrame_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanBusDeviceFunc_resetController(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanBusDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // resetController()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QCanBusDevice::resetController()
            : cppSelf->resetController();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCanBusDeviceFunc_setConfigurationParameter(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanBusDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setConfigurationParameter", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCanBusDevice::setConfigurationParameter(QCanBusDevice::ConfigurationKey,QVariant)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_ConfigurationKey_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[1])))) {
        overloadId = 0; // setConfigurationParameter(QCanBusDevice::ConfigurationKey,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setConfigurationParameter", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]);

    // Call function/method
    {
        ::QCanBusDevice::ConfigurationKey cppArg0{QCanBusDevice::RawFilterKey};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QVariant cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setConfigurationParameter(QCanBusDevice::ConfigurationKey,QVariant)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QCanBusDevice::setConfigurationParameter(cppArg0, cppArg1)
                : cppSelf->setConfigurationParameter(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCanBusDeviceFunc_setError(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanBusDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setError", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCanBusDevice::setError(QString,QCanBusDevice::CanBusError)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_CanBusError_IDX])))->converter, (pyArgs[1])))) {
        overloadId = 0; // setError(QString,QCanBusDevice::CanBusError)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setError", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QCanBusDevice::CanBusError cppArg1{QCanBusDevice::NoError};
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setError(QString,QCanBusDevice::CanBusError)
            cppSelf->setError(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCanBusDeviceFunc_setState(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanBusDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCanBusDevice::setState(QCanBusDevice::CanBusDeviceState)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_CanBusDeviceState_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setState(QCanBusDevice::CanBusDeviceState)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setState", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]);

    // Call function/method
    {
        ::QCanBusDevice::CanBusDeviceState cppArg0{QCanBusDevice::UnconnectedState};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setState(QCanBusDevice::CanBusDeviceState)
            cppSelf->setState(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCanBusDeviceFunc_state(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanBusDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // state()const
        QCanBusDevice::CanBusDeviceState cppResult = const_cast<const ::QCanBusDevice *>(cppSelf)->state();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_CanBusDeviceState_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanBusDeviceFunc_waitForFramesReceived(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanBusDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCanBusDevice::waitForFramesReceived(int)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // waitForFramesReceived(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "waitForFramesReceived", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // waitForFramesReceived(int)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QCanBusDevice::waitForFramesReceived(cppArg0)
                : cppSelf->waitForFramesReceived(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanBusDeviceFunc_waitForFramesWritten(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanBusDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCanBusDevice::waitForFramesWritten(int)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // waitForFramesWritten(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "waitForFramesWritten", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // waitForFramesWritten(int)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QCanBusDevice::waitForFramesWritten(cppArg0)
                : cppSelf->waitForFramesWritten(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanBusDeviceFunc_writeFrame(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanBusDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCanBusDevice::writeFrame(QCanBusFrame)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusFrame_IDX]), (pyArg)))) {
        overloadId = 0; // writeFrame(QCanBusFrame)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "writeFrame", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QCanBusFrame cppArg0_local;
        ::QCanBusFrame *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // writeFrame(QCanBusFrame)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QCanBusDevice.writeFrame");
                return {};
            }
            bool cppResult = cppSelf->writeFrame(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QCanBusDevice_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QCanBusDevice_EnumFlagInfo[] = {
    "CanBusDeviceState:Enum",
    "CanBusError:Enum",
    "CanBusStatus:Enum",
    "ConfigurationKey:Enum",
    "Direction:Flag:Directions",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QCanBusDevice_methods[] = {
    {"busStatus", reinterpret_cast<PyCFunction>(Sbk_QCanBusDeviceFunc_busStatus), METH_NOARGS, nullptr},
    {"clear", reinterpret_cast<PyCFunction>(Sbk_QCanBusDeviceFunc_clear), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"clearError", reinterpret_cast<PyCFunction>(Sbk_QCanBusDeviceFunc_clearError), METH_NOARGS, nullptr},
    {"close", reinterpret_cast<PyCFunction>(Sbk_QCanBusDeviceFunc_close), METH_NOARGS, nullptr},
    {"configurationKeys", reinterpret_cast<PyCFunction>(Sbk_QCanBusDeviceFunc_configurationKeys), METH_NOARGS, nullptr},
    {"configurationParameter", reinterpret_cast<PyCFunction>(Sbk_QCanBusDeviceFunc_configurationParameter), METH_O, nullptr},
    {"connectDevice", reinterpret_cast<PyCFunction>(Sbk_QCanBusDeviceFunc_connectDevice), METH_NOARGS, nullptr},
    {"createDeviceInfo", reinterpret_cast<PyCFunction>(Sbk_QCanBusDeviceFunc_createDeviceInfo), METH_VARARGS|METH_STATIC, nullptr},
    {"dequeueOutgoingFrame", reinterpret_cast<PyCFunction>(Sbk_QCanBusDeviceFunc_dequeueOutgoingFrame), METH_NOARGS, nullptr},
    {"deviceInfo", reinterpret_cast<PyCFunction>(Sbk_QCanBusDeviceFunc_deviceInfo), METH_NOARGS, nullptr},
    {"disconnectDevice", reinterpret_cast<PyCFunction>(Sbk_QCanBusDeviceFunc_disconnectDevice), METH_NOARGS, nullptr},
    {"enqueueOutgoingFrame", reinterpret_cast<PyCFunction>(Sbk_QCanBusDeviceFunc_enqueueOutgoingFrame), METH_O, nullptr},
    {"enqueueReceivedFrames", reinterpret_cast<PyCFunction>(Sbk_QCanBusDeviceFunc_enqueueReceivedFrames), METH_O, nullptr},
    {"error", reinterpret_cast<PyCFunction>(Sbk_QCanBusDeviceFunc_error), METH_NOARGS, nullptr},
    {"errorString", reinterpret_cast<PyCFunction>(Sbk_QCanBusDeviceFunc_errorString), METH_NOARGS, nullptr},
    {"framesAvailable", reinterpret_cast<PyCFunction>(Sbk_QCanBusDeviceFunc_framesAvailable), METH_NOARGS, nullptr},
    {"framesToWrite", reinterpret_cast<PyCFunction>(Sbk_QCanBusDeviceFunc_framesToWrite), METH_NOARGS, nullptr},
    {"hasBusStatus", reinterpret_cast<PyCFunction>(Sbk_QCanBusDeviceFunc_hasBusStatus), METH_NOARGS, nullptr},
    {"hasOutgoingFrames", reinterpret_cast<PyCFunction>(Sbk_QCanBusDeviceFunc_hasOutgoingFrames), METH_NOARGS, nullptr},
    {"interpretErrorFrame", reinterpret_cast<PyCFunction>(Sbk_QCanBusDeviceFunc_interpretErrorFrame), METH_O, nullptr},
    {"open", reinterpret_cast<PyCFunction>(Sbk_QCanBusDeviceFunc_open), METH_NOARGS, nullptr},
    {"readAllFrames", reinterpret_cast<PyCFunction>(Sbk_QCanBusDeviceFunc_readAllFrames), METH_NOARGS, nullptr},
    {"readFrame", reinterpret_cast<PyCFunction>(Sbk_QCanBusDeviceFunc_readFrame), METH_NOARGS, nullptr},
    {"resetController", reinterpret_cast<PyCFunction>(Sbk_QCanBusDeviceFunc_resetController), METH_NOARGS, nullptr},
    {"setConfigurationParameter", reinterpret_cast<PyCFunction>(Sbk_QCanBusDeviceFunc_setConfigurationParameter), METH_VARARGS, nullptr},
    {"setError", reinterpret_cast<PyCFunction>(Sbk_QCanBusDeviceFunc_setError), METH_VARARGS, nullptr},
    {"setState", reinterpret_cast<PyCFunction>(Sbk_QCanBusDeviceFunc_setState), METH_O, nullptr},
    {"state", reinterpret_cast<PyCFunction>(Sbk_QCanBusDeviceFunc_state), METH_NOARGS, nullptr},
    {"waitForFramesReceived", reinterpret_cast<PyCFunction>(Sbk_QCanBusDeviceFunc_waitForFramesReceived), METH_O, nullptr},
    {"waitForFramesWritten", reinterpret_cast<PyCFunction>(Sbk_QCanBusDeviceFunc_waitForFramesWritten), METH_O, nullptr},
    {"writeFrame", reinterpret_cast<PyCFunction>(Sbk_QCanBusDeviceFunc_writeFrame), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QCanBusDevice_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QCanBusDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QCanBusDeviceWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QCanBusDevice_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QCanBusDevice_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QCanBusDevice_Type = nullptr;
static PyTypeObject *Sbk_QCanBusDevice_TypeF(void)
{
    return _Sbk_QCanBusDevice_Type;
}

static PyType_Slot Sbk_QCanBusDevice_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QCanBusDevice_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QCanBusDevice_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QCanBusDevice_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QCanBusDevice_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QCanBusDevice_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QCanBusDevice_spec = {
    "2:PySide6.QtSerialBus.QCanBusDevice",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QCanBusDevice_slots
};

} //extern "C"

static void *Sbk_QCanBusDevice_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QCanBusDevice *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QCanBusDevice_CanBusError(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QCanBusDevice::CanBusError>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QCanBusDevice::CanBusError *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QCanBusDevice_CanBusError_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_CanBusError_IDX])))
        return Enum_PythonToCpp_QCanBusDevice_CanBusError;
    return {};
}

static PyObject *QCanBusDevice_CanBusError_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QCanBusDevice::CanBusError>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QCanBusDevice::CanBusError *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_CanBusError_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QCanBusDevice_CanBusDeviceState(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QCanBusDevice::CanBusDeviceState>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QCanBusDevice::CanBusDeviceState *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QCanBusDevice_CanBusDeviceState_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_CanBusDeviceState_IDX])))
        return Enum_PythonToCpp_QCanBusDevice_CanBusDeviceState;
    return {};
}

static PyObject *QCanBusDevice_CanBusDeviceState_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QCanBusDevice::CanBusDeviceState>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QCanBusDevice::CanBusDeviceState *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_CanBusDeviceState_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QCanBusDevice_CanBusStatus(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QCanBusDevice::CanBusStatus>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QCanBusDevice::CanBusStatus *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QCanBusDevice_CanBusStatus_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_CanBusStatus_IDX])))
        return Enum_PythonToCpp_QCanBusDevice_CanBusStatus;
    return {};
}

static PyObject *QCanBusDevice_CanBusStatus_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QCanBusDevice::CanBusStatus>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QCanBusDevice::CanBusStatus *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_CanBusStatus_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QCanBusDevice_ConfigurationKey(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QCanBusDevice::ConfigurationKey>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QCanBusDevice::ConfigurationKey *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QCanBusDevice_ConfigurationKey_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_ConfigurationKey_IDX])))
        return Enum_PythonToCpp_QCanBusDevice_ConfigurationKey;
    return {};
}

static PyObject *QCanBusDevice_ConfigurationKey_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QCanBusDevice::ConfigurationKey>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QCanBusDevice::ConfigurationKey *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_ConfigurationKey_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QCanBusDevice_Direction(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QCanBusDevice::Direction>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QCanBusDevice::Direction *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QCanBusDevice_Direction_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_Direction_IDX])))
        return Enum_PythonToCpp_QCanBusDevice_Direction;
    return {};
}

static PyObject *QCanBusDevice_Direction_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QCanBusDevice::Direction>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QCanBusDevice::Direction *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_Direction_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QCanBusDevice_Direction(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QCanBusDevice::Direction>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QCanBusDevice::Direction> *>(cppOut) = value;

}

static PyObject *QCanBusDevice_Direction_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QCanBusDevice::Direction> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_Direction_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QCanBusDevice_PythonToCpp_QCanBusDevice_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QCanBusDevice_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QCanBusDevice_PythonToCpp_QCanBusDevice_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QCanBusDevice_TypeF()))
        return QCanBusDevice_PythonToCpp_QCanBusDevice_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QCanBusDevice_PTR_CppToPython_QCanBusDevice(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QCanBusDevice *>(const_cast<void *>(cppIn)), Sbk_QCanBusDevice_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QCanBusDevice_SignatureStrings[] = {
    "PySide6.QtSerialBus.QCanBusDevice(self,parent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtSerialBus.QCanBusDevice.busStatus(self)->PySide6.QtSerialBus.QCanBusDevice.CanBusStatus",
    "PySide6.QtSerialBus.QCanBusDevice.clear(self,direction:PySide6.QtSerialBus.QCanBusDevice.Direction=QCanBusDevice.Direction.AllDirections)",
    "PySide6.QtSerialBus.QCanBusDevice.clearError(self)",
    "PySide6.QtSerialBus.QCanBusDevice.close(self)",
    "PySide6.QtSerialBus.QCanBusDevice.configurationKeys(self)->QList[PySide6.QtSerialBus.QCanBusDevice.ConfigurationKey]",
    "PySide6.QtSerialBus.QCanBusDevice.configurationParameter(self,key:PySide6.QtSerialBus.QCanBusDevice.ConfigurationKey)->QVariant",
    "PySide6.QtSerialBus.QCanBusDevice.connectDevice(self)->bool",
    "1:PySide6.QtSerialBus.QCanBusDevice.createDeviceInfo(plugin:QString,name:QString,isVirtual:bool,isFlexibleDataRateCapable:bool)->PySide6.QtSerialBus.QCanBusDeviceInfo",
    "0:PySide6.QtSerialBus.QCanBusDevice.createDeviceInfo(plugin:QString,name:QString,serialNumber:QString,description:QString,alias:QString,channel:int,isVirtual:bool,isFlexibleDataRateCapable:bool)->PySide6.QtSerialBus.QCanBusDeviceInfo",
    "PySide6.QtSerialBus.QCanBusDevice.dequeueOutgoingFrame(self)->PySide6.QtSerialBus.QCanBusFrame",
    "PySide6.QtSerialBus.QCanBusDevice.deviceInfo(self)->PySide6.QtSerialBus.QCanBusDeviceInfo",
    "PySide6.QtSerialBus.QCanBusDevice.disconnectDevice(self)",
    "PySide6.QtSerialBus.QCanBusDevice.enqueueOutgoingFrame(self,newFrame:typing.Union[PySide6.QtSerialBus.QCanBusFrame, PySide6.QtSerialBus.QCanBusFrame.FrameType])",
    "PySide6.QtSerialBus.QCanBusDevice.enqueueReceivedFrames(self,newFrames:QList[PySide6.QtSerialBus.QCanBusFrame])",
    "PySide6.QtSerialBus.QCanBusDevice.error(self)->PySide6.QtSerialBus.QCanBusDevice.CanBusError",
    "PySide6.QtSerialBus.QCanBusDevice.errorString(self)->QString",
    "PySide6.QtSerialBus.QCanBusDevice.framesAvailable(self)->qint64",
    "PySide6.QtSerialBus.QCanBusDevice.framesToWrite(self)->qint64",
    "PySide6.QtSerialBus.QCanBusDevice.hasBusStatus(self)->bool",
    "PySide6.QtSerialBus.QCanBusDevice.hasOutgoingFrames(self)->bool",
    "PySide6.QtSerialBus.QCanBusDevice.interpretErrorFrame(self,errorFrame:typing.Union[PySide6.QtSerialBus.QCanBusFrame, PySide6.QtSerialBus.QCanBusFrame.FrameType])->QString",
    "PySide6.QtSerialBus.QCanBusDevice.open(self)->bool",
    "PySide6.QtSerialBus.QCanBusDevice.readAllFrames(self)->QList[PySide6.QtSerialBus.QCanBusFrame]",
    "PySide6.QtSerialBus.QCanBusDevice.readFrame(self)->PySide6.QtSerialBus.QCanBusFrame",
    "PySide6.QtSerialBus.QCanBusDevice.resetController(self)",
    "PySide6.QtSerialBus.QCanBusDevice.setConfigurationParameter(self,key:PySide6.QtSerialBus.QCanBusDevice.ConfigurationKey,value:QVariant)",
    "PySide6.QtSerialBus.QCanBusDevice.setError(self,errorText:QString,arg__2:PySide6.QtSerialBus.QCanBusDevice.CanBusError)",
    "PySide6.QtSerialBus.QCanBusDevice.setState(self,newState:PySide6.QtSerialBus.QCanBusDevice.CanBusDeviceState)",
    "PySide6.QtSerialBus.QCanBusDevice.state(self)->PySide6.QtSerialBus.QCanBusDevice.CanBusDeviceState",
    "PySide6.QtSerialBus.QCanBusDevice.waitForFramesReceived(self,msecs:int)->bool",
    "PySide6.QtSerialBus.QCanBusDevice.waitForFramesWritten(self,msecs:int)->bool",
    "PySide6.QtSerialBus.QCanBusDevice.writeFrame(self,frame:typing.Union[PySide6.QtSerialBus.QCanBusFrame, PySide6.QtSerialBus.QCanBusFrame.FrameType])->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QCanBusDevice_SignatureByteSize = 610;
static constexpr uint8_t QCanBusDevice_SignatureBytes[610] = {
    0x78, 0xda, 0xb5, 0x56, 0x51, 0x6f, 0xda, 0x30, 0x10, 0x7e, 0xe7, 0x57, 0xec, 0xb1, 0x48, 0x2c,
    0x5a, 0xa7, 0xa9, 0x0f, 0x91, 0x3a, 0xa9, 0x85, 0x21, 0x4d, 0x9b, 0x56, 0x28, 0xb4, 0x7b, 0xa8,
    0xaa, 0xea, 0x92, 0x1c, 0xd4, 0x9b, 0xb1, 0x53, 0xfb, 0x4c, 0xcb, 0xbf, 0x9f, 0x63, 0x43, 0x80,
    0xaa, 0x55, 0x2e, 0x13, 0xbc, 0x80, 0x2e, 0xb9, 0xef, 0xee, 0xbb, 0xcb, 0xf9, 0x3b, 0x8f, 0x56,
    0x13, 0x51, 0xe0, 0x59, 0x32, 0xa6, 0x09, 0x1a, 0x01, 0xf2, 0xd2, 0xd9, 0x64, 0xdc, 0x07, 0xe5,
    0xff, 0x07, 0xb8, 0x14, 0x39, 0x9e, 0x58, 0x94, 0xb3, 0x5e, 0x09, 0x06, 0x15, 0xa5, 0xa3, 0xda,
    0xbb, 0xaf, 0x0d, 0x26, 0xe3, 0xab, 0xec, 0x0f, 0xe6, 0x74, 0xae, 0x9c, 0x94, 0x25, 0x99, 0x6e,
    0x67, 0xd4, 0x14, 0x2d, 0xc9, 0x9c, 0x9d, 0x10, 0x90, 0xb3, 0x21, 0x6e, 0xf7, 0xe3, 0xd7, 0x66,
    0x48, 0x34, 0x22, 0x8a, 0x91, 0x21, 0x97, 0x08, 0x26, 0xb2, 0x2e, 0x84, 0xf1, 0xf4, 0x84, 0x56,
    0x69, 0x33, 0x6c, 0xb0, 0xf1, 0x3d, 0x7f, 0xe7, 0x79, 0x72, 0x21, 0x65, 0x6d, 0xd8, 0x2e, 0x97,
    0xc9, 0x37, 0x63, 0x74, 0xa4, 0xc3, 0x83, 0x68, 0x8b, 0x7c, 0x6f, 0xad, 0x66, 0x62, 0xee, 0x0c,
    0x54, 0x94, 0x7e, 0xe0, 0xaa, 0x6e, 0xea, 0xf8, 0xa7, 0xb0, 0x74, 0xc7, 0x68, 0xed, 0xab, 0x00,
    0xf7, 0x6d, 0x93, 0x8e, 0xc0, 0xc0, 0x02, 0x09, 0xd7, 0x0d, 0xff, 0x8b, 0xab, 0xb4, 0x7d, 0xd6,
    0x8a, 0xf0, 0x2d, 0x78, 0x5f, 0x45, 0xbc, 0xfc, 0xca, 0x7f, 0x84, 0x9d, 0xe9, 0xf4, 0xf8, 0x4c,
    0x6b, 0xd9, 0x39, 0x65, 0xe4, 0xce, 0x0d, 0x02, 0x61, 0x34, 0xbe, 0xab, 0x99, 0x3e, 0x29, 0xa5,
    0x9b, 0x0b, 0x95, 0x8e, 0x27, 0x64, 0x84, 0x9a, 0xf7, 0x94, 0x2f, 0xa7, 0x36, 0x84, 0xbd, 0x15,
    0x86, 0x1c, 0xc8, 0xb4, 0x8a, 0xef, 0xcd, 0xa1, 0xc4, 0x17, 0x91, 0x49, 0x1c, 0x00, 0xc1, 0xb5,
    0x8f, 0xd3, 0x87, 0x12, 0xbc, 0x19, 0x5e, 0x73, 0x66, 0xb9, 0xca, 0xd8, 0xf9, 0x74, 0x68, 0x9a,
    0x36, 0x04, 0xf9, 0xe5, 0x16, 0x19, 0x9a, 0xfa, 0x61, 0x81, 0x36, 0x37, 0xa2, 0x0c, 0xd3, 0xbf,
    0x79, 0x06, 0x52, 0x80, 0xad, 0xad, 0xfc, 0x11, 0x7c, 0x27, 0x65, 0x2a, 0x14, 0x1d, 0xa9, 0xd2,
    0xe6, 0x3a, 0x0b, 0x7c, 0x72, 0xe8, 0xf0, 0xca, 0xd1, 0x5c, 0x7b, 0x4e, 0xc3, 0x6a, 0x9a, 0x18,
    0xca, 0x10, 0xfc, 0x58, 0xe1, 0xeb, 0x06, 0x72, 0xe5, 0x86, 0x4b, 0x5c, 0xd8, 0x37, 0x06, 0x91,
    0x01, 0x44, 0xf5, 0x4e, 0xc5, 0x3d, 0x85, 0xcf, 0xc1, 0x4a, 0x69, 0x55, 0xfa, 0x37, 0xc9, 0x8d,
    0xf2, 0xdf, 0xee, 0xae, 0xa9, 0x0b, 0xbd, 0x0f, 0x4d, 0x1e, 0x49, 0xf8, 0x9d, 0xae, 0x4a, 0xbc,
    0x6f, 0x41, 0xf0, 0x1a, 0x73, 0x14, 0x4b, 0x2c, 0x02, 0xd8, 0xee, 0x33, 0xf4, 0x33, 0xd4, 0x24,
    0x30, 0xc1, 0x8f, 0x97, 0x6f, 0x2b, 0x90, 0xfc, 0x6d, 0x10, 0x54, 0x95, 0x1b, 0x3c, 0xce, 0x7b,
    0xad, 0x8d, 0xd1, 0x64, 0x80, 0x67, 0xa1, 0xd6, 0x8b, 0x25, 0x08, 0x59, 0xcd, 0xfe, 0x26, 0xc0,
    0x93, 0x3f, 0x30, 0x67, 0x5f, 0xd8, 0xf8, 0xa9, 0xfe, 0x6d, 0x04, 0xb5, 0x47, 0x3f, 0x82, 0xbd,
    0x7c, 0xbd, 0x2c, 0x83, 0xcc, 0xb1, 0xa0, 0x7b, 0xf3, 0xd5, 0x16, 0xef, 0x29, 0xa2, 0x29, 0x0d,
    0x52, 0x68, 0xf3, 0xce, 0x88, 0x62, 0x6d, 0x1f, 0x73, 0x48, 0xdb, 0x7c, 0x23, 0x5d, 0xa2, 0x6a,
    0x59, 0x9d, 0x97, 0xd6, 0xc2, 0xef, 0xf2, 0xfd, 0xce, 0x30, 0x07, 0x9a, 0x19, 0xfe, 0xd0, 0x3a,
    0x66, 0xd0, 0xa2, 0xbf, 0x72, 0x29, 0x32, 0x5a, 0x4a, 0xe4, 0x5f, 0x27, 0x22, 0xea, 0xc0, 0xeb,
    0xba, 0xb7, 0x04, 0xe9, 0xfc, 0xf6, 0x59, 0xaf, 0x6c, 0x26, 0x8f, 0xed, 0x3d, 0x28, 0x4e, 0xd1,
    0x14, 0x5f, 0x68, 0xbb, 0x98, 0xcc, 0xfc, 0xe1, 0xe1, 0x73, 0xda, 0xea, 0xf4, 0x33, 0xf3, 0x56,
    0x07, 0x68, 0x2b, 0xb0, 0xc1, 0x62, 0xe7, 0x89, 0x46, 0xc0, 0xb0, 0xb2, 0xd5, 0xa9, 0x5a, 0x28,
    0xd9, 0x4e, 0x0e, 0x46, 0x8a, 0x67, 0x10, 0x34, 0x5c, 0x1f, 0x41, 0xbb, 0x91, 0xe8, 0x58, 0xdd,
    0xc2, 0x62, 0x6e, 0xab, 0x65, 0xce, 0x3f, 0x09, 0x7b, 0xd1, 0x2a, 0x95, 0xa2, 0xf5, 0x61, 0xfa,
    0xaf, 0x60, 0x95, 0xca, 0xed, 0x68, 0xc5, 0xec, 0xf8, 0x32, 0x11, 0x98, 0xfd, 0x03, 0x48, 0x44,
    0xa4, 0xeb
};
#endif

PyTypeObject *init_QCanBusDevice(PyObject *module)
{
    if (SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX].type != nullptr)
        return SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX].type;

    Shiboken::AutoDecRef Sbk_QCanBusDevice_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QCanBusDevice_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QCanBusDevice",
        "QCanBusDevice*",
        &Sbk_QCanBusDevice_spec,
        &Shiboken::callCppDestructor< QCanBusDevice >,
        Sbk_QCanBusDevice_Type_bases.object(),
        0);
    auto *pyType = Sbk_QCanBusDevice_TypeF(); // references _Sbk_QCanBusDevice_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QCanBusDevice_SignatureStrings);
#else
    InitSignatureBytes(pyType, QCanBusDevice_SignatureBytes, QCanBusDevice_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QCanBusDevice_PropertyStrings);
    SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QCanBusDevice_PythonToCpp_QCanBusDevice_PTR,
        is_QCanBusDevice_PythonToCpp_QCanBusDevice_PTR_Convertible,
        QCanBusDevice_PTR_CppToPython_QCanBusDevice);

    Shiboken::Conversions::registerConverterName(converter, "QCanBusDevice");
    Shiboken::Conversions::registerConverterName(converter, "QCanBusDevice*");
    Shiboken::Conversions::registerConverterName(converter, "QCanBusDevice&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QCanBusDevice).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QCanBusDeviceWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QCanBusDevice_TypeF(), &Sbk_QCanBusDevice_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QCanBusDevice_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'CanBusError'.
    const char *CanBusError_Initializer[] = {
        "NoError",
        "ReadError",
        "WriteError",
        "ConnectionError",
        "ConfigurationError",
        "UnknownError",
        "OperationError",
        "TimeoutError",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t CanBusError_InitializerValues[] = {
        uint8_t(QCanBusDevice::CanBusError::NoError),            //  0x00  0
        uint8_t(QCanBusDevice::CanBusError::ReadError),          //  0x01  1
        uint8_t(QCanBusDevice::CanBusError::WriteError),         //  0x02  2
        uint8_t(QCanBusDevice::CanBusError::ConnectionError),    //  0x03  3
        uint8_t(QCanBusDevice::CanBusError::ConfigurationError), //  0x04  4
        uint8_t(QCanBusDevice::CanBusError::UnknownError),       //  0x05  5
        uint8_t(QCanBusDevice::CanBusError::OperationError),     //  0x06  6
        uint8_t(QCanBusDevice::CanBusError::TimeoutError)        //  0x07  7
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QCanBusDevice_TypeF(),
        "2:PySide6.QtSerialBus.QCanBusDevice.CanBusError",
        CanBusError_Initializer, CanBusError_InitializerValues);
    SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_CanBusError_IDX].type = EType;
    // Register converter for enum 'QCanBusDevice::CanBusError'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QCanBusDevice_CanBusError_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QCanBusDevice_CanBusError,
            is_Enum_PythonToCpp_QCanBusDevice_CanBusError_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QCanBusDevice::CanBusError");
        Shiboken::Conversions::registerConverterAlias(converter, "CanBusError");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'CanBusError' enum.

    // Initialization of enum 'CanBusDeviceState'.
    const char *CanBusDeviceState_Initializer[] = {
        "UnconnectedState",
        "ConnectingState",
        "ConnectedState",
        "ClosingState",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t CanBusDeviceState_InitializerValues[] = {
        uint8_t(QCanBusDevice::CanBusDeviceState::UnconnectedState), //  0x00  0
        uint8_t(QCanBusDevice::CanBusDeviceState::ConnectingState),  //  0x01  1
        uint8_t(QCanBusDevice::CanBusDeviceState::ConnectedState),   //  0x02  2
        uint8_t(QCanBusDevice::CanBusDeviceState::ClosingState)      //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QCanBusDevice_TypeF(),
        "2:PySide6.QtSerialBus.QCanBusDevice.CanBusDeviceState",
        CanBusDeviceState_Initializer, CanBusDeviceState_InitializerValues);
    SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_CanBusDeviceState_IDX].type = EType;
    // Register converter for enum 'QCanBusDevice::CanBusDeviceState'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QCanBusDevice_CanBusDeviceState_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QCanBusDevice_CanBusDeviceState,
            is_Enum_PythonToCpp_QCanBusDevice_CanBusDeviceState_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QCanBusDevice::CanBusDeviceState");
        Shiboken::Conversions::registerConverterAlias(converter, "CanBusDeviceState");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'CanBusDeviceState' enum.

    // Initialization of enum 'CanBusStatus'.
    const char *CanBusStatus_Initializer[] = {
        "Unknown",
        "Good",
        "Warning",
        "Error",
        "BusOff",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t CanBusStatus_InitializerValues[] = {
        int8_t(QCanBusDevice::CanBusStatus::Unknown), //  0x00  0
        int8_t(QCanBusDevice::CanBusStatus::Good),    //  0x01  1
        int8_t(QCanBusDevice::CanBusStatus::Warning), //  0x02  2
        int8_t(QCanBusDevice::CanBusStatus::Error),   //  0x03  3
        int8_t(QCanBusDevice::CanBusStatus::BusOff)   //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QCanBusDevice_TypeF(),
        "2:PySide6.QtSerialBus.QCanBusDevice.CanBusStatus",
        CanBusStatus_Initializer, CanBusStatus_InitializerValues);
    SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_CanBusStatus_IDX].type = EType;
    // Register converter for enum 'QCanBusDevice::CanBusStatus'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QCanBusDevice_CanBusStatus_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QCanBusDevice_CanBusStatus,
            is_Enum_PythonToCpp_QCanBusDevice_CanBusStatus_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QCanBusDevice::CanBusStatus");
        Shiboken::Conversions::registerConverterAlias(converter, "CanBusStatus");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'CanBusStatus' enum.

    // Initialization of enum 'ConfigurationKey'.
    const char *ConfigurationKey_Initializer[] = {
        "RawFilterKey",
        "ErrorFilterKey",
        "LoopbackKey",
        "ReceiveOwnKey",
        "BitRateKey",
        "CanFdKey",
        "DataBitRateKey",
        "ProtocolKey",
        "UserKey",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ConfigurationKey_InitializerValues[] = {
        uint8_t(QCanBusDevice::ConfigurationKey::RawFilterKey),   //  0x00  0
        uint8_t(QCanBusDevice::ConfigurationKey::ErrorFilterKey), //  0x01  1
        uint8_t(QCanBusDevice::ConfigurationKey::LoopbackKey),    //  0x02  2
        uint8_t(QCanBusDevice::ConfigurationKey::ReceiveOwnKey),  //  0x03  3
        uint8_t(QCanBusDevice::ConfigurationKey::BitRateKey),     //  0x04  4
        uint8_t(QCanBusDevice::ConfigurationKey::CanFdKey),       //  0x05  5
        uint8_t(QCanBusDevice::ConfigurationKey::DataBitRateKey), //  0x06  6
        uint8_t(QCanBusDevice::ConfigurationKey::ProtocolKey),    //  0x07  7
        uint8_t(QCanBusDevice::ConfigurationKey::UserKey)         //  0x1e  30
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QCanBusDevice_TypeF(),
        "2:PySide6.QtSerialBus.QCanBusDevice.ConfigurationKey",
        ConfigurationKey_Initializer, ConfigurationKey_InitializerValues);
    SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_ConfigurationKey_IDX].type = EType;
    // Register converter for enum 'QCanBusDevice::ConfigurationKey'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QCanBusDevice_ConfigurationKey_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QCanBusDevice_ConfigurationKey,
            is_Enum_PythonToCpp_QCanBusDevice_ConfigurationKey_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QCanBusDevice::ConfigurationKey");
        Shiboken::Conversions::registerConverterAlias(converter, "ConfigurationKey");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ConfigurationKey' enum.

    // Initialization of enum 'Direction'.
    const char *Direction_Initializer[] = {
        "Input",
        "Output",
        "AllDirections",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Direction_InitializerValues[] = {
        uint8_t(QCanBusDevice::Direction::Input),        //  0x01  1
        uint8_t(QCanBusDevice::Direction::Output),       //  0x02  2
        uint8_t(QCanBusDevice::Direction::AllDirections) //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QCanBusDevice_TypeF(),
        "2:PySide6.QtSerialBus.QCanBusDevice.Direction",
        Direction_Initializer, Direction_InitializerValues);
    SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_Direction_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtSerialBusTypeStructs[SBK_QFlags_QCanBusDevice_Direction_IDX].type =
        EType;
    // Register converter for enum 'QCanBusDevice::Direction'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QCanBusDevice_Direction_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QCanBusDevice_Direction,
            is_Enum_PythonToCpp_QCanBusDevice_Direction_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QCanBusDevice::Direction");
        Shiboken::Conversions::registerConverterAlias(converter, "Direction");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QCanBusDevice_Direction_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QCanBusDevice_Direction,
            is_Enum_PythonToCpp_QCanBusDevice_Direction_Convertible);
        // Register converter for flag 'QFlags<QCanBusDevice::Direction>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QCanBusDevice::Direction>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QCanBusDevice::Directions");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'Direction' enum/flags.

    PySide::Signal::registerSignals(pyType, &::QCanBusDevice::staticMetaObject);
    qRegisterMetaType< ::QCanBusDevice::CanBusError >("QCanBusDevice::CanBusError");
    qRegisterMetaType< ::QCanBusDevice::CanBusDeviceState >("QCanBusDevice::CanBusDeviceState");
    qRegisterMetaType< ::QCanBusDevice::CanBusStatus >("QCanBusDevice::CanBusStatus");
    qRegisterMetaType< ::QCanBusDevice::ConfigurationKey >("QCanBusDevice::ConfigurationKey");
    qRegisterMetaType< ::QCanBusDevice::Direction >("QCanBusDevice::Direction");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QCanBusDevice::staticMetaObject, sizeof(QCanBusDeviceWrapper));

    return pyType;
}
