// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtserialbus_python.h"

// main header
#include "qcanbusdeviceinfo_wrapper.h"

// Argument includes
#include <QString>
#include <QtSerialBus/qcanbusdeviceinfo.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QCanBusDeviceInfo_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QCanBusDeviceInfo >()))
        return -1;

    ::QCanBusDeviceInfo *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QCanBusDeviceInfo", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QCanBusDeviceInfo::QCanBusDeviceInfo(QCanBusDeviceInfo)
    if (numArgs == 1
        && (pyArgs[0] != Py_None && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDeviceInfo_IDX]), (pyArgs[0]))))) {
        overloadId = 0; // QCanBusDeviceInfo(QCanBusDeviceInfo)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDeviceInfo_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDeviceInfo_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QCanBusDeviceInfo *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QCanBusDeviceInfo(QCanBusDeviceInfo)
            cptr = new ::QCanBusDeviceInfo(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QCanBusDeviceInfo >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDeviceInfo_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QCanBusDeviceInfoFunc_alias(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanBusDeviceInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDeviceInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // alias()const
        QString cppResult = const_cast<const ::QCanBusDeviceInfo *>(cppSelf)->alias();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanBusDeviceInfoFunc_channel(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanBusDeviceInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDeviceInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // channel()const
        int cppResult = const_cast<const ::QCanBusDeviceInfo *>(cppSelf)->channel();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanBusDeviceInfoFunc_description(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanBusDeviceInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDeviceInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // description()const
        QString cppResult = const_cast<const ::QCanBusDeviceInfo *>(cppSelf)->description();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanBusDeviceInfoFunc_hasFlexibleDataRate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanBusDeviceInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDeviceInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hasFlexibleDataRate()const
        bool cppResult = const_cast<const ::QCanBusDeviceInfo *>(cppSelf)->hasFlexibleDataRate();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanBusDeviceInfoFunc_isVirtual(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanBusDeviceInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDeviceInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isVirtual()const
        bool cppResult = const_cast<const ::QCanBusDeviceInfo *>(cppSelf)->isVirtual();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanBusDeviceInfoFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanBusDeviceInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDeviceInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // name()const
        QString cppResult = const_cast<const ::QCanBusDeviceInfo *>(cppSelf)->name();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanBusDeviceInfoFunc_plugin(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanBusDeviceInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDeviceInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // plugin()const
        QString cppResult = const_cast<const ::QCanBusDeviceInfo *>(cppSelf)->plugin();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanBusDeviceInfoFunc_serialNumber(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanBusDeviceInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDeviceInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // serialNumber()const
        QString cppResult = const_cast<const ::QCanBusDeviceInfo *>(cppSelf)->serialNumber();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanBusDeviceInfo__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QCanBusDeviceInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDeviceInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDeviceInfo_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QCanBusDeviceInfo_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QCanBusDeviceInfo_methods[] = {
    {"alias", reinterpret_cast<PyCFunction>(Sbk_QCanBusDeviceInfoFunc_alias), METH_NOARGS, nullptr},
    {"channel", reinterpret_cast<PyCFunction>(Sbk_QCanBusDeviceInfoFunc_channel), METH_NOARGS, nullptr},
    {"description", reinterpret_cast<PyCFunction>(Sbk_QCanBusDeviceInfoFunc_description), METH_NOARGS, nullptr},
    {"hasFlexibleDataRate", reinterpret_cast<PyCFunction>(Sbk_QCanBusDeviceInfoFunc_hasFlexibleDataRate), METH_NOARGS, nullptr},
    {"isVirtual", reinterpret_cast<PyCFunction>(Sbk_QCanBusDeviceInfoFunc_isVirtual), METH_NOARGS, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_QCanBusDeviceInfoFunc_name), METH_NOARGS, nullptr},
    {"plugin", reinterpret_cast<PyCFunction>(Sbk_QCanBusDeviceInfoFunc_plugin), METH_NOARGS, nullptr},
    {"serialNumber", reinterpret_cast<PyCFunction>(Sbk_QCanBusDeviceInfoFunc_serialNumber), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QCanBusDeviceInfo__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QCanBusDeviceInfo_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QCanBusDeviceInfo_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QCanBusDeviceInfo_Type = nullptr;
static PyTypeObject *Sbk_QCanBusDeviceInfo_TypeF(void)
{
    return _Sbk_QCanBusDeviceInfo_Type;
}

static PyType_Slot Sbk_QCanBusDeviceInfo_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QCanBusDeviceInfo_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QCanBusDeviceInfo_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QCanBusDeviceInfo_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QCanBusDeviceInfo_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QCanBusDeviceInfo_spec = {
    "2:PySide6.QtSerialBus.QCanBusDeviceInfo",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QCanBusDeviceInfo_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QCanBusDeviceInfo_PythonToCpp_QCanBusDeviceInfo_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QCanBusDeviceInfo_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QCanBusDeviceInfo_PythonToCpp_QCanBusDeviceInfo_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QCanBusDeviceInfo_TypeF()))
        return QCanBusDeviceInfo_PythonToCpp_QCanBusDeviceInfo_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QCanBusDeviceInfo_PTR_CppToPython_QCanBusDeviceInfo(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QCanBusDeviceInfo_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QCanBusDeviceInfo_COPY_CppToPython_QCanBusDeviceInfo(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QCanBusDeviceInfo *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QCanBusDeviceInfo_TypeF(), new ::QCanBusDeviceInfo(*source), true, true);
}

// Python to C++ copy conversion.
static void QCanBusDeviceInfo_PythonToCpp_QCanBusDeviceInfo_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QCanBusDeviceInfo *>(cppOut) = *reinterpret_cast< ::QCanBusDeviceInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDeviceInfo_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QCanBusDeviceInfo_PythonToCpp_QCanBusDeviceInfo_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QCanBusDeviceInfo_TypeF()))
        return QCanBusDeviceInfo_PythonToCpp_QCanBusDeviceInfo_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QCanBusDeviceInfo_SignatureStrings[] = {
    "PySide6.QtSerialBus.QCanBusDeviceInfo(self,other:PySide6.QtSerialBus.QCanBusDeviceInfo)",
    "PySide6.QtSerialBus.QCanBusDeviceInfo.alias(self)->QString",
    "PySide6.QtSerialBus.QCanBusDeviceInfo.channel(self)->int",
    "PySide6.QtSerialBus.QCanBusDeviceInfo.description(self)->QString",
    "PySide6.QtSerialBus.QCanBusDeviceInfo.hasFlexibleDataRate(self)->bool",
    "PySide6.QtSerialBus.QCanBusDeviceInfo.isVirtual(self)->bool",
    "PySide6.QtSerialBus.QCanBusDeviceInfo.name(self)->QString",
    "PySide6.QtSerialBus.QCanBusDeviceInfo.plugin(self)->QString",
    "PySide6.QtSerialBus.QCanBusDeviceInfo.serialNumber(self)->QString",
    "PySide6.QtSerialBus.QCanBusDeviceInfo.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QCanBusDeviceInfo_SignatureByteSize = 177;
static constexpr uint8_t QCanBusDeviceInfo_SignatureBytes[177] = {
    0x78, 0xda, 0x9d, 0x8f, 0xb1, 0x0a, 0x83, 0x40, 0x0c, 0x86, 0x77, 0x9f, 0xa4, 0x42, 0xeb, 0xd8,
    0xa1, 0x43, 0x87, 0x56, 0x0a, 0x5d, 0x8a, 0x56, 0xe8, 0x7a, 0xc4, 0x33, 0x6a, 0x20, 0xde, 0xc9,
    0x5d, 0xae, 0xd4, 0xb7, 0xaf, 0x08, 0xee, 0xc7, 0x4d, 0x21, 0xe4, 0xff, 0xbe, 0x24, 0xd5, 0xd2,
    0x50, 0x87, 0xe7, 0xa2, 0x96, 0x06, 0x1d, 0x01, 0xdf, 0x82, 0x2f, 0xea, 0x3b, 0x98, 0xb5, 0x96,
    0xf8, 0x25, 0x8d, 0x4f, 0xd3, 0xdb, 0x83, 0x47, 0xee, 0x8f, 0x56, 0x46, 0x74, 0x97, 0x2a, 0x06,
    0xc8, 0xb3, 0xa8, 0x58, 0x01, 0x4c, 0xe0, 0x37, 0x7b, 0x7e, 0xba, 0xd6, 0x8d, 0x38, 0x32, 0x43,
    0x24, 0xaa, 0x47, 0x30, 0x06, 0x79, 0x87, 0xc9, 0x48, 0x24, 0xd8, 0xa1, 0xd7, 0x8e, 0x66, 0x21,
    0x6b, 0xd2, 0x36, 0x8f, 0xe0, 0x1f, 0x8c, 0x3f, 0x6a, 0x19, 0x4b, 0x10, 0x78, 0x83, 0xe0, 0x2e,
    0x6a, 0xad, 0xe5, 0x48, 0x0b, 0xf9, 0x0f, 0x39, 0x09, 0xc0, 0x09, 0xac, 0x81, 0x09, 0xd3, 0x6e,
    0x9f, 0x39, 0x0c, 0x94, 0xf8, 0xb7, 0xdf, 0x66, 0xaf, 0x30, 0xb5, 0xe8, 0xd2, 0x0c, 0x4a, 0x69,
    0x3b, 0x2f, 0x4a, 0xed, 0xb4, 0x2c, 0xf3, 0x0a, 0x17, 0xcd, 0xda, 0x65, 0x7f, 0xc4, 0xc6, 0xe9,
    0x89
};
#endif

PyTypeObject *init_QCanBusDeviceInfo(PyObject *module)
{
    if (SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDeviceInfo_IDX].type != nullptr)
        return SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDeviceInfo_IDX].type;

    Shiboken::AutoDecRef Sbk_QCanBusDeviceInfo_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QCanBusDeviceInfo_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QCanBusDeviceInfo",
        "QCanBusDeviceInfo",
        &Sbk_QCanBusDeviceInfo_spec,
        &Shiboken::callCppDestructor< ::QCanBusDeviceInfo >,
        Sbk_QCanBusDeviceInfo_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QCanBusDeviceInfo_TypeF(); // references _Sbk_QCanBusDeviceInfo_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QCanBusDeviceInfo_SignatureStrings);
#else
    InitSignatureBytes(pyType, QCanBusDeviceInfo_SignatureBytes, QCanBusDeviceInfo_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QCanBusDeviceInfo_PropertyStrings);
    SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDeviceInfo_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QCanBusDeviceInfo_PythonToCpp_QCanBusDeviceInfo_PTR,
        is_QCanBusDeviceInfo_PythonToCpp_QCanBusDeviceInfo_PTR_Convertible,
        QCanBusDeviceInfo_PTR_CppToPython_QCanBusDeviceInfo,
        QCanBusDeviceInfo_COPY_CppToPython_QCanBusDeviceInfo);

    Shiboken::Conversions::registerConverterName(converter, "QCanBusDeviceInfo");
    Shiboken::Conversions::registerConverterName(converter, "QCanBusDeviceInfo*");
    Shiboken::Conversions::registerConverterName(converter, "QCanBusDeviceInfo&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QCanBusDeviceInfo).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QCanBusDeviceInfo_PythonToCpp_QCanBusDeviceInfo_COPY,
        is_QCanBusDeviceInfo_PythonToCpp_QCanBusDeviceInfo_COPY_Convertible);


    return pyType;
}
