// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtserialbus_python.h"

// main header
#include "qcandbcfileparser_wrapper.h"

// Argument includes
#include <QHash>
#include <QList>
#include <QString>
#include <QStringList>
#include <QStringView>
#include <QtSerialBus/qcancommondefinitions.h>
#include <QtSerialBus/qcandbcfileparser.h>
#include <QtSerialBus/qcanmessagedescription.h>
#include <QtSerialBus/qcanuniqueiddescription.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QCanDbcFileParser_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QCanDbcFileParser >()))
        return -1;

    ::QCanDbcFileParser *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanDbcFileParser_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QCanDbcFileParser()
        cptr = new ::QCanDbcFileParser();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QCanDbcFileParser >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QCanDbcFileParserFunc_error(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanDbcFileParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanDbcFileParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // error()const
        QCanDbcFileParser::Error cppResult = const_cast<const ::QCanDbcFileParser *>(cppSelf)->error();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanDbcFileParser_Error_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanDbcFileParserFunc_errorString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanDbcFileParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanDbcFileParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // errorString()const
        QString cppResult = const_cast<const ::QCanDbcFileParser *>(cppSelf)->errorString();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanDbcFileParserFunc_messageDescriptions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanDbcFileParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanDbcFileParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // messageDescriptions()const
        QList<QCanMessageDescription> cppResult = const_cast<const ::QCanDbcFileParser *>(cppSelf)->messageDescriptions();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QCanMessageDescription_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanDbcFileParserFunc_messageValueDescriptions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanDbcFileParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanDbcFileParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // messageValueDescriptions()const
        QHash<QtCanBus::UniqueId,QHash<QString,QHash<unsigned int,QString>>> cppResult = const_cast<const ::QCanDbcFileParser *>(cppSelf)->messageValueDescriptions();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QHash_QtCanBus_UniqueId_QHash_QString_QHash_unsignedint_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanDbcFileParserFunc_parse(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanDbcFileParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanDbcFileParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCanDbcFileParser::parse(QString)->bool
    // 1: QCanDbcFileParser::parse(QStringList)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 1; // parse(QStringList)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // parse(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "parse", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanDbcFileParser_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // parse(const QString &fileName)
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // parse(QString)
                bool cppResult = cppSelf->parse(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // parse(const QStringList &fileNames)
        {
            ::QStringList cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // parse(QStringList)
                bool cppResult = cppSelf->parse(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanDbcFileParserFunc_parseData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanDbcFileParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanDbcFileParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCanDbcFileParser::parseData(QStringView)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // parseData(QStringView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "parseData", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanDbcFileParser_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // parseData(QStringView)
            bool cppResult = cppSelf->parseData(QStringView(cppArg0));
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanDbcFileParserFunc_uniqueIdDescription(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // uniqueIdDescription()
        QCanUniqueIdDescription cppResult = ::QCanDbcFileParser::uniqueIdDescription();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanUniqueIdDescription_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanDbcFileParserFunc_warnings(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanDbcFileParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanDbcFileParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // warnings()const
        QStringList cppResult = const_cast<const ::QCanDbcFileParser *>(cppSelf)->warnings();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QCanDbcFileParser_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QCanDbcFileParser_EnumFlagInfo[] = {
    "Error:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QCanDbcFileParser_methods[] = {
    {"error", reinterpret_cast<PyCFunction>(Sbk_QCanDbcFileParserFunc_error), METH_NOARGS, nullptr},
    {"errorString", reinterpret_cast<PyCFunction>(Sbk_QCanDbcFileParserFunc_errorString), METH_NOARGS, nullptr},
    {"messageDescriptions", reinterpret_cast<PyCFunction>(Sbk_QCanDbcFileParserFunc_messageDescriptions), METH_NOARGS, nullptr},
    {"messageValueDescriptions", reinterpret_cast<PyCFunction>(Sbk_QCanDbcFileParserFunc_messageValueDescriptions), METH_NOARGS, nullptr},
    {"parse", reinterpret_cast<PyCFunction>(Sbk_QCanDbcFileParserFunc_parse), METH_O, nullptr},
    {"parseData", reinterpret_cast<PyCFunction>(Sbk_QCanDbcFileParserFunc_parseData), METH_O, nullptr},
    {"uniqueIdDescription", reinterpret_cast<PyCFunction>(Sbk_QCanDbcFileParserFunc_uniqueIdDescription), METH_NOARGS|METH_STATIC, nullptr},
    {"warnings", reinterpret_cast<PyCFunction>(Sbk_QCanDbcFileParserFunc_warnings), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QCanDbcFileParser_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QCanDbcFileParser_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QCanDbcFileParser_Type = nullptr;
static PyTypeObject *Sbk_QCanDbcFileParser_TypeF(void)
{
    return _Sbk_QCanDbcFileParser_Type;
}

static PyType_Slot Sbk_QCanDbcFileParser_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QCanDbcFileParser_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QCanDbcFileParser_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QCanDbcFileParser_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QCanDbcFileParser_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QCanDbcFileParser_spec = {
    "2:PySide6.QtSerialBus.QCanDbcFileParser",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QCanDbcFileParser_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QCanDbcFileParser_Error(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QCanDbcFileParser::Error>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QCanDbcFileParser::Error *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QCanDbcFileParser_Error_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanDbcFileParser_Error_IDX])))
        return Enum_PythonToCpp_QCanDbcFileParser_Error;
    return {};
}

static PyObject *QCanDbcFileParser_Error_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QCanDbcFileParser::Error>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QCanDbcFileParser::Error *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanDbcFileParser_Error_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QCanDbcFileParser_PythonToCpp_QCanDbcFileParser_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QCanDbcFileParser_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QCanDbcFileParser_PythonToCpp_QCanDbcFileParser_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QCanDbcFileParser_TypeF()))
        return QCanDbcFileParser_PythonToCpp_QCanDbcFileParser_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QCanDbcFileParser_PTR_CppToPython_QCanDbcFileParser(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QCanDbcFileParser_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QCanDbcFileParser_SignatureStrings[] = {
    "PySide6.QtSerialBus.QCanDbcFileParser(self)",
    "PySide6.QtSerialBus.QCanDbcFileParser.error(self)->PySide6.QtSerialBus.QCanDbcFileParser.Error",
    "PySide6.QtSerialBus.QCanDbcFileParser.errorString(self)->QString",
    "PySide6.QtSerialBus.QCanDbcFileParser.messageDescriptions(self)->QList[PySide6.QtSerialBus.QCanMessageDescription]",
    "PySide6.QtSerialBus.QCanDbcFileParser.messageValueDescriptions(self)->QHash[PySide6.QtSerialBus.QtCanBus.UniqueId, QHash[QString, QHash[unsigned int, QString]]]",
    "1:PySide6.QtSerialBus.QCanDbcFileParser.parse(self,fileName:QString)->bool",
    "0:PySide6.QtSerialBus.QCanDbcFileParser.parse(self,fileNames:QStringList)->bool",
    "PySide6.QtSerialBus.QCanDbcFileParser.parseData(self,data:QString)->bool",
    "PySide6.QtSerialBus.QCanDbcFileParser.uniqueIdDescription()->PySide6.QtSerialBus.QCanUniqueIdDescription",
    "PySide6.QtSerialBus.QCanDbcFileParser.warnings(self)->QStringList",
    nullptr}; // Sentinel
#else
static constexpr size_t QCanDbcFileParser_SignatureByteSize = 249;
static constexpr uint8_t QCanDbcFileParser_SignatureBytes[249] = {
    0x78, 0xda, 0x9d, 0x92, 0x4d, 0x6f, 0xc2, 0x30, 0x0c, 0x86, 0xef, 0xfd, 0x15, 0x1c, 0x41, 0x62,
    0xd5, 0xb8, 0xec, 0xc0, 0x61, 0x87, 0xd1, 0x4d, 0x20, 0x01, 0x6a, 0x55, 0xb1, 0xcb, 0xd4, 0x83,
    0xa1, 0x6e, 0x67, 0x29, 0xa4, 0x2c, 0x4e, 0x84, 0xf8, 0xf7, 0x24, 0x6b, 0x8b, 0x10, 0x5f, 0x4a,
    0x39, 0x25, 0x76, 0xec, 0xe7, 0x7d, 0xe3, 0x24, 0x3e, 0xa4, 0x94, 0xe3, 0x5b, 0x98, 0xe8, 0x14,
    0x15, 0x81, 0xf8, 0x30, 0x1c, 0x26, 0x13, 0x90, 0xd1, 0x7a, 0xf3, 0x45, 0x02, 0x63, 0x50, 0x8c,
    0xaa, 0xcf, 0x28, 0x8a, 0x41, 0x10, 0xfb, 0xd4, 0x86, 0xa8, 0x54, 0xd5, 0x74, 0xbc, 0xbc, 0xfb,
    0xb5, 0x7c, 0xba, 0x96, 0x2e, 0xf8, 0x54, 0x2b, 0x92, 0x65, 0x2b, 0x92, 0xd4, 0xa1, 0x27, 0x60,
    0x8b, 0xcc, 0x50, 0x62, 0x84, 0xbc, 0x51, 0xb4, 0xd3, 0x54, 0x49, 0x3e, 0x81, 0xe6, 0xc4, 0xfa,
    0xe7, 0x1e, 0x66, 0x71, 0xd5, 0x98, 0x75, 0x93, 0xfc, 0x06, 0x61, 0x6e, 0xeb, 0x4e, 0x81, 0x7f,
    0x6f, 0xeb, 0x6a, 0x0b, 0x73, 0x9b, 0x95, 0xa4, 0x3f, 0x83, 0xb3, 0x7c, 0xd8, 0xab, 0x8b, 0x9b,
    0x3b, 0xb7, 0xa1, 0x91, 0x4c, 0xa5, 0xc4, 0xbc, 0x47, 0x52, 0xdb, 0x5c, 0x7d, 0x98, 0x65, 0x59,
    0x30, 0x1a, 0xfb, 0x59, 0xdc, 0xb9, 0xe5, 0xdf, 0xcf, 0xb0, 0xb0, 0xd9, 0x25, 0x6c, 0x71, 0xdc,
    0x60, 0xac, 0xc1, 0x75, 0x55, 0x89, 0xe0, 0xf5, 0x79, 0x14, 0xb7, 0x2c, 0x37, 0xe0, 0x96, 0xd7,
    0x81, 0x16, 0x81, 0x86, 0x9a, 0x98, 0xdb, 0xdd, 0xa5, 0x31, 0x3f, 0x90, 0x69, 0x26, 0x78, 0xf6,
    0x00, 0xfd, 0x07, 0x3f, 0x74, 0x75, 0x5d, 0xee, 0x29, 0xb4, 0x07, 0x25, 0xad, 0x3b, 0xbe, 0xf8,
    0x9e, 0xee, 0xea, 0xc1, 0x11, 0x68, 0x0d, 0x3e, 0x1e
};
#endif

PyTypeObject *init_QCanDbcFileParser(PyObject *module)
{
    if (SbkPySide6_QtSerialBusTypeStructs[SBK_QCanDbcFileParser_IDX].type != nullptr)
        return SbkPySide6_QtSerialBusTypeStructs[SBK_QCanDbcFileParser_IDX].type;

    Shiboken::AutoDecRef Sbk_QCanDbcFileParser_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QCanDbcFileParser_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QCanDbcFileParser",
        "QCanDbcFileParser*",
        &Sbk_QCanDbcFileParser_spec,
        &Shiboken::callCppDestructor< ::QCanDbcFileParser >,
        Sbk_QCanDbcFileParser_Type_bases.object(),
        0);
    auto *pyType = Sbk_QCanDbcFileParser_TypeF(); // references _Sbk_QCanDbcFileParser_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QCanDbcFileParser_SignatureStrings);
#else
    InitSignatureBytes(pyType, QCanDbcFileParser_SignatureBytes, QCanDbcFileParser_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QCanDbcFileParser_PropertyStrings);
    SbkPySide6_QtSerialBusTypeStructs[SBK_QCanDbcFileParser_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QCanDbcFileParser_PythonToCpp_QCanDbcFileParser_PTR,
        is_QCanDbcFileParser_PythonToCpp_QCanDbcFileParser_PTR_Convertible,
        QCanDbcFileParser_PTR_CppToPython_QCanDbcFileParser);

    Shiboken::Conversions::registerConverterName(converter, "QCanDbcFileParser");
    Shiboken::Conversions::registerConverterName(converter, "QCanDbcFileParser*");
    Shiboken::Conversions::registerConverterName(converter, "QCanDbcFileParser&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QCanDbcFileParser).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QCanDbcFileParser_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Error'.
    const char *Error_Initializer[] = {
        "None_",
        "FileReading",
        "Parsing",
        nullptr};
    // "uint8_t" used instead of "unsigned char"
    constexpr uint8_t Error_InitializerValues[] = {
        uint8_t(QCanDbcFileParser::Error::None),        //  0x00  0
        uint8_t(QCanDbcFileParser::Error::FileReading), //  0x01  1
        uint8_t(QCanDbcFileParser::Error::Parsing)      //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QCanDbcFileParser_TypeF(),
        "2:PySide6.QtSerialBus.QCanDbcFileParser.Error",
        Error_Initializer, Error_InitializerValues);
    SbkPySide6_QtSerialBusTypeStructs[SBK_QCanDbcFileParser_Error_IDX].type = EType;
    // Register converter for enum 'QCanDbcFileParser::Error'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QCanDbcFileParser_Error_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QCanDbcFileParser_Error,
            is_Enum_PythonToCpp_QCanDbcFileParser_Error_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QCanDbcFileParser::Error");
        Shiboken::Conversions::registerConverterAlias(converter, "Error");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Error' enum.

    qRegisterMetaType< ::QCanDbcFileParser *>();
    qRegisterMetaType< ::QCanDbcFileParser::Error >("QCanDbcFileParser::Error");

    return pyType;
}
