// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtserialbus_python.h"

// main header
#include "qcanframeprocessor_wrapper.h"

// inner classes
#include "qcanframeprocessor_parseresult_wrapper.h"

// Argument includes
#include <QList>
#include <QMap>
#include <QString>
#include <QStringList>
#include <QtSerialBus/qcanbusframe.h>
#include <QtSerialBus/qcancommondefinitions.h>
#include <QtSerialBus/qcanframeprocessor.h>
#include <QtSerialBus/qcanmessagedescription.h>
#include <QtSerialBus/qcanuniqueiddescription.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QCanFrameProcessor_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QCanFrameProcessor >()))
        return -1;

    ::QCanFrameProcessor *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanFrameProcessor_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QCanFrameProcessor()
        cptr = new ::QCanFrameProcessor();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QCanFrameProcessor >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QCanFrameProcessorFunc_addMessageDescriptions(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanFrameProcessor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanFrameProcessor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCanFrameProcessor::addMessageDescriptions(QList<QCanMessageDescription>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QCanMessageDescription_IDX], (pyArg)))) {
        overloadId = 0; // addMessageDescriptions(QList<QCanMessageDescription>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addMessageDescriptions", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanFrameProcessor_IDX]);

    // Call function/method
    {
        ::QList<QCanMessageDescription> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addMessageDescriptions(QList<QCanMessageDescription>)
            cppSelf->addMessageDescriptions(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCanFrameProcessorFunc_clearMessageDescriptions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanFrameProcessor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanFrameProcessor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clearMessageDescriptions()
        cppSelf->clearMessageDescriptions();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCanFrameProcessorFunc_error(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanFrameProcessor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanFrameProcessor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // error()const
        QCanFrameProcessor::Error cppResult = const_cast<const ::QCanFrameProcessor *>(cppSelf)->error();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanFrameProcessor_Error_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanFrameProcessorFunc_errorString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanFrameProcessor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanFrameProcessor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // errorString()const
        QString cppResult = const_cast<const ::QCanFrameProcessor *>(cppSelf)->errorString();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanFrameProcessorFunc_messageDescriptions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanFrameProcessor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanFrameProcessor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // messageDescriptions()const
        QList<QCanMessageDescription> cppResult = const_cast<const ::QCanFrameProcessor *>(cppSelf)->messageDescriptions();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QCanMessageDescription_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanFrameProcessorFunc_parseFrame(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanFrameProcessor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanFrameProcessor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCanFrameProcessor::parseFrame(QCanBusFrame)->QCanFrameProcessor::ParseResult
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusFrame_IDX]), (pyArg)))) {
        overloadId = 0; // parseFrame(QCanBusFrame)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "parseFrame", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanFrameProcessor_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QCanBusFrame cppArg0_local;
        ::QCanBusFrame *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // parseFrame(QCanBusFrame)
            QCanFrameProcessor::ParseResult cppResult = cppSelf->parseFrame(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanFrameProcessor_ParseResult_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanFrameProcessorFunc_prepareFrame(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanFrameProcessor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanFrameProcessor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "prepareFrame", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCanFrameProcessor::prepareFrame(QtCanBus::UniqueId,QMap<QString,QVariant>)->QCanBusFrame
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QtCanBus_UniqueId_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QMap_QString_QVariant_IDX], (pyArgs[1])))) {
        overloadId = 0; // prepareFrame(QtCanBus::UniqueId,QMap<QString,QVariant>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "prepareFrame", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanFrameProcessor_IDX]);

    // Call function/method
    {
        ::QtCanBus::UniqueId cppArg0 = static_cast< ::QtCanBus::UniqueId>(0);
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QMap<QString,QVariant> cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // prepareFrame(QtCanBus::UniqueId,QMap<QString,QVariant>)
            QCanBusFrame cppResult = cppSelf->prepareFrame(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusFrame_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanFrameProcessorFunc_setMessageDescriptions(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanFrameProcessor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanFrameProcessor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCanFrameProcessor::setMessageDescriptions(QList<QCanMessageDescription>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QCanMessageDescription_IDX], (pyArg)))) {
        overloadId = 0; // setMessageDescriptions(QList<QCanMessageDescription>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMessageDescriptions", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanFrameProcessor_IDX]);

    // Call function/method
    {
        ::QList<QCanMessageDescription> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMessageDescriptions(QList<QCanMessageDescription>)
            cppSelf->setMessageDescriptions(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCanFrameProcessorFunc_setUniqueIdDescription(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanFrameProcessor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanFrameProcessor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCanFrameProcessor::setUniqueIdDescription(QCanUniqueIdDescription)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanUniqueIdDescription_IDX]), (pyArg)))) {
        overloadId = 0; // setUniqueIdDescription(QCanUniqueIdDescription)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUniqueIdDescription", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanFrameProcessor_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QCanUniqueIdDescription cppArg0_local;
        ::QCanUniqueIdDescription *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setUniqueIdDescription(QCanUniqueIdDescription)
            cppSelf->setUniqueIdDescription(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCanFrameProcessorFunc_uniqueIdDescription(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanFrameProcessor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanFrameProcessor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // uniqueIdDescription()const
        QCanUniqueIdDescription cppResult = const_cast<const ::QCanFrameProcessor *>(cppSelf)->uniqueIdDescription();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanUniqueIdDescription_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanFrameProcessorFunc_warnings(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanFrameProcessor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanFrameProcessor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // warnings()const
        QStringList cppResult = const_cast<const ::QCanFrameProcessor *>(cppSelf)->warnings();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QCanFrameProcessor_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QCanFrameProcessor_EnumFlagInfo[] = {
    "Error:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QCanFrameProcessor_methods[] = {
    {"addMessageDescriptions", reinterpret_cast<PyCFunction>(Sbk_QCanFrameProcessorFunc_addMessageDescriptions), METH_O, nullptr},
    {"clearMessageDescriptions", reinterpret_cast<PyCFunction>(Sbk_QCanFrameProcessorFunc_clearMessageDescriptions), METH_NOARGS, nullptr},
    {"error", reinterpret_cast<PyCFunction>(Sbk_QCanFrameProcessorFunc_error), METH_NOARGS, nullptr},
    {"errorString", reinterpret_cast<PyCFunction>(Sbk_QCanFrameProcessorFunc_errorString), METH_NOARGS, nullptr},
    {"messageDescriptions", reinterpret_cast<PyCFunction>(Sbk_QCanFrameProcessorFunc_messageDescriptions), METH_NOARGS, nullptr},
    {"parseFrame", reinterpret_cast<PyCFunction>(Sbk_QCanFrameProcessorFunc_parseFrame), METH_O, nullptr},
    {"prepareFrame", reinterpret_cast<PyCFunction>(Sbk_QCanFrameProcessorFunc_prepareFrame), METH_VARARGS, nullptr},
    {"setMessageDescriptions", reinterpret_cast<PyCFunction>(Sbk_QCanFrameProcessorFunc_setMessageDescriptions), METH_O, nullptr},
    {"setUniqueIdDescription", reinterpret_cast<PyCFunction>(Sbk_QCanFrameProcessorFunc_setUniqueIdDescription), METH_O, nullptr},
    {"uniqueIdDescription", reinterpret_cast<PyCFunction>(Sbk_QCanFrameProcessorFunc_uniqueIdDescription), METH_NOARGS, nullptr},
    {"warnings", reinterpret_cast<PyCFunction>(Sbk_QCanFrameProcessorFunc_warnings), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QCanFrameProcessor_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QCanFrameProcessor_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QCanFrameProcessor_Type = nullptr;
static PyTypeObject *Sbk_QCanFrameProcessor_TypeF(void)
{
    return _Sbk_QCanFrameProcessor_Type;
}

static PyType_Slot Sbk_QCanFrameProcessor_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QCanFrameProcessor_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QCanFrameProcessor_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QCanFrameProcessor_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QCanFrameProcessor_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QCanFrameProcessor_spec = {
    "2:PySide6.QtSerialBus.QCanFrameProcessor",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QCanFrameProcessor_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QCanFrameProcessor_Error(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QCanFrameProcessor::Error>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QCanFrameProcessor::Error *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QCanFrameProcessor_Error_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanFrameProcessor_Error_IDX])))
        return Enum_PythonToCpp_QCanFrameProcessor_Error;
    return {};
}

static PyObject *QCanFrameProcessor_Error_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QCanFrameProcessor::Error>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QCanFrameProcessor::Error *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanFrameProcessor_Error_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QCanFrameProcessor_PythonToCpp_QCanFrameProcessor_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QCanFrameProcessor_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QCanFrameProcessor_PythonToCpp_QCanFrameProcessor_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QCanFrameProcessor_TypeF()))
        return QCanFrameProcessor_PythonToCpp_QCanFrameProcessor_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QCanFrameProcessor_PTR_CppToPython_QCanFrameProcessor(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QCanFrameProcessor_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QCanFrameProcessor_SignatureStrings[] = {
    "PySide6.QtSerialBus.QCanFrameProcessor(self)",
    "PySide6.QtSerialBus.QCanFrameProcessor.addMessageDescriptions(self,descriptions:QList[PySide6.QtSerialBus.QCanMessageDescription])",
    "PySide6.QtSerialBus.QCanFrameProcessor.clearMessageDescriptions(self)",
    "PySide6.QtSerialBus.QCanFrameProcessor.error(self)->PySide6.QtSerialBus.QCanFrameProcessor.Error",
    "PySide6.QtSerialBus.QCanFrameProcessor.errorString(self)->QString",
    "PySide6.QtSerialBus.QCanFrameProcessor.messageDescriptions(self)->QList[PySide6.QtSerialBus.QCanMessageDescription]",
    "PySide6.QtSerialBus.QCanFrameProcessor.parseFrame(self,frame:typing.Union[PySide6.QtSerialBus.QCanBusFrame, PySide6.QtSerialBus.QCanBusFrame.FrameType])->PySide6.QtSerialBus.QCanFrameProcessor.ParseResult",
    "PySide6.QtSerialBus.QCanFrameProcessor.prepareFrame(self,uniqueId:PySide6.QtSerialBus.QtCanBus.UniqueId,signalValues:QMap[QString, QVariant])->PySide6.QtSerialBus.QCanBusFrame",
    "PySide6.QtSerialBus.QCanFrameProcessor.setMessageDescriptions(self,descriptions:QList[PySide6.QtSerialBus.QCanMessageDescription])",
    "PySide6.QtSerialBus.QCanFrameProcessor.setUniqueIdDescription(self,description:PySide6.QtSerialBus.QCanUniqueIdDescription)",
    "PySide6.QtSerialBus.QCanFrameProcessor.uniqueIdDescription(self)->PySide6.QtSerialBus.QCanUniqueIdDescription",
    "PySide6.QtSerialBus.QCanFrameProcessor.warnings(self)->QStringList",
    nullptr}; // Sentinel
#else
static constexpr size_t QCanFrameProcessor_SignatureByteSize = 291;
static constexpr uint8_t QCanFrameProcessor_SignatureBytes[291] = {
    0x78, 0xda, 0xc5, 0x53, 0x3b, 0x6f, 0x83, 0x30, 0x10, 0xde, 0xf3, 0x2b, 0x32, 0xb6, 0x12, 0x65,
    0xec, 0xc0, 0xd0, 0xa1, 0x2f, 0xa9, 0x52, 0x23, 0x41, 0x69, 0xb3, 0x44, 0x19, 0x4e, 0x70, 0x41,
    0x96, 0x1c, 0xe3, 0xde, 0xd9, 0xaa, 0xf8, 0xf7, 0x35, 0x50, 0x24, 0xd4, 0xe0, 0xf4, 0x32, 0x75,
    0x31, 0xc6, 0xba, 0xef, 0x75, 0x67, 0xe7, 0x5d, 0xa9, 0x6a, 0xbc, 0x4d, 0x0b, 0x57, 0x22, 0x29,
    0xd0, 0xf7, 0x9e, 0xd3, 0xe2, 0x01, 0xcc, 0x33, 0xc1, 0x11, 0x73, 0x6a, 0x2b, 0x64, 0x6e, 0xe9,
    0x8a, 0x51, 0x1f, 0xae, 0x57, 0xb9, 0xa8, 0x38, 0x85, 0xba, 0xde, 0x84, 0x1d, 0x34, 0xf8, 0x88,
    0x5c, 0x91, 0xb2, 0x4e, 0xb5, 0x86, 0x07, 0x8e, 0xa4, 0x9e, 0x9d, 0x64, 0xc5, 0xab, 0x62, 0xb7,
    0x8b, 0xb1, 0x9e, 0x72, 0xec, 0xc5, 0x16, 0x2a, 0x8d, 0x40, 0x31, 0x13, 0x62, 0x16, 0x24, 0x9a,
    0xb2, 0xdf, 0xdc, 0x09, 0x31, 0x4f, 0x3d, 0xe6, 0x22, 0x81, 0xd2, 0x91, 0x32, 0xcd, 0x24, 0x53,
    0x8c, 0xbf, 0x52, 0x86, 0x63, 0x2c, 0x63, 0x60, 0xba, 0xb4, 0xbb, 0x52, 0x4d, 0x0b, 0xc4, 0x38,
    0x9c, 0x8d, 0x33, 0x3d, 0xf4, 0xdb, 0xcc, 0x75, 0x36, 0xf8, 0x4e, 0x3f, 0x4c, 0xa0, 0x8a, 0xaa,
    0x86, 0xef, 0x00, 0x4c, 0xd6, 0x7f, 0x55, 0xa4, 0xc3, 0xfa, 0xde, 0x59, 0xdc, 0xcb, 0x9b, 0x9f,
    0xf7, 0xce, 0xde, 0x90, 0xbd, 0x76, 0xe2, 0x30, 0x84, 0x21, 0xcf, 0x3c, 0x8e, 0x37, 0xea, 0xd3,
    0xe3, 0x4b, 0x9d, 0x2d, 0x32, 0xb8, 0xd1, 0x63, 0x9f, 0x73, 0xa8, 0x4a, 0x58, 0x35, 0x06, 0xf4,
    0x16, 0xb4, 0xc7, 0x70, 0xa3, 0x37, 0x60, 0x77, 0x3f, 0x23, 0x4c, 0xd6, 0xc5, 0x16, 0x02, 0xce,
    0xb8, 0x73, 0x09, 0xa6, 0xbc, 0x52, 0xbf, 0x8c, 0xee, 0xbf, 0x1f, 0x57, 0xb0, 0x30, 0xa5, 0x9f,
    0xe1, 0x4f, 0x2c, 0x64, 0x31, 0xba, 0x05, 0xb0, 0x58, 0xdb, 0x47, 0x84, 0xcf, 0x74, 0x78, 0x41,
    0x4e, 0xaa, 0xf6, 0x05, 0x64, 0xc2, 0x24, 0xf9, 0xd7, 0xe3, 0xec, 0x3b, 0xbb, 0xfa, 0x06, 0xf0,
    0x2b, 0xef, 0xc1
};
#endif

PyTypeObject *init_QCanFrameProcessor(PyObject *module)
{
    if (SbkPySide6_QtSerialBusTypeStructs[SBK_QCanFrameProcessor_IDX].type != nullptr)
        return SbkPySide6_QtSerialBusTypeStructs[SBK_QCanFrameProcessor_IDX].type;

    Shiboken::AutoDecRef Sbk_QCanFrameProcessor_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QCanFrameProcessor_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QCanFrameProcessor",
        "QCanFrameProcessor*",
        &Sbk_QCanFrameProcessor_spec,
        &Shiboken::callCppDestructor< ::QCanFrameProcessor >,
        Sbk_QCanFrameProcessor_Type_bases.object(),
        0);
    auto *pyType = Sbk_QCanFrameProcessor_TypeF(); // references _Sbk_QCanFrameProcessor_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QCanFrameProcessor_SignatureStrings);
#else
    InitSignatureBytes(pyType, QCanFrameProcessor_SignatureBytes, QCanFrameProcessor_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QCanFrameProcessor_PropertyStrings);
    SbkPySide6_QtSerialBusTypeStructs[SBK_QCanFrameProcessor_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QCanFrameProcessor_PythonToCpp_QCanFrameProcessor_PTR,
        is_QCanFrameProcessor_PythonToCpp_QCanFrameProcessor_PTR_Convertible,
        QCanFrameProcessor_PTR_CppToPython_QCanFrameProcessor);

    Shiboken::Conversions::registerConverterName(converter, "QCanFrameProcessor");
    Shiboken::Conversions::registerConverterName(converter, "QCanFrameProcessor*");
    Shiboken::Conversions::registerConverterName(converter, "QCanFrameProcessor&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QCanFrameProcessor).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QCanFrameProcessor_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Error'.
    const char *Error_Initializer[] = {
        "None_",
        "InvalidFrame",
        "UnsupportedFrameFormat",
        "Decoding",
        "Encoding",
        nullptr};
    // "uint8_t" used instead of "unsigned char"
    constexpr uint8_t Error_InitializerValues[] = {
        uint8_t(QCanFrameProcessor::Error::None),                   //  0x00  0
        uint8_t(QCanFrameProcessor::Error::InvalidFrame),           //  0x01  1
        uint8_t(QCanFrameProcessor::Error::UnsupportedFrameFormat), //  0x02  2
        uint8_t(QCanFrameProcessor::Error::Decoding),               //  0x03  3
        uint8_t(QCanFrameProcessor::Error::Encoding)                //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QCanFrameProcessor_TypeF(),
        "2:PySide6.QtSerialBus.QCanFrameProcessor.Error",
        Error_Initializer, Error_InitializerValues);
    SbkPySide6_QtSerialBusTypeStructs[SBK_QCanFrameProcessor_Error_IDX].type = EType;
    // Register converter for enum 'QCanFrameProcessor::Error'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QCanFrameProcessor_Error_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QCanFrameProcessor_Error,
            is_Enum_PythonToCpp_QCanFrameProcessor_Error_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QCanFrameProcessor::Error");
        Shiboken::Conversions::registerConverterAlias(converter, "Error");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Error' enum.

    qRegisterMetaType< ::QCanFrameProcessor *>();
    qRegisterMetaType< ::QCanFrameProcessor::Error >("QCanFrameProcessor::Error");

    return pyType;
}
