// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtserialbus_python.h"

// main header
#include "qcanmessagedescription_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtSerialBus/qcancommondefinitions.h>
#include <QtSerialBus/qcanmessagedescription.h>
#include <QtSerialBus/qcansignaldescription.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QCanMessageDescription_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QCanMessageDescription >()))
        return -1;

    ::QCanMessageDescription *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QCanMessageDescription", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QCanMessageDescription::QCanMessageDescription()
    // 1: QCanMessageDescription::QCanMessageDescription(QCanMessageDescription)
    if (numArgs == 0) {
        overloadId = 0; // QCanMessageDescription()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanMessageDescription_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QCanMessageDescription(QCanMessageDescription)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanMessageDescription_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanMessageDescription_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QCanMessageDescription()
        {

            // QCanMessageDescription()
            cptr = new ::QCanMessageDescription();
            break;
        }
        case 1: // QCanMessageDescription(const QCanMessageDescription &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QCanMessageDescription cppArg0_local;
            ::QCanMessageDescription *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QCanMessageDescription(QCanMessageDescription)
                cptr = new ::QCanMessageDescription(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QCanMessageDescription >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanMessageDescription_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QCanMessageDescriptionFunc_addSignalDescription(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanMessageDescription *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanMessageDescription_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCanMessageDescription::addSignalDescription(QCanSignalDescription)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanSignalDescription_IDX]), (pyArg)))) {
        overloadId = 0; // addSignalDescription(QCanSignalDescription)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addSignalDescription", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanMessageDescription_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QCanSignalDescription cppArg0_local;
        ::QCanSignalDescription *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // addSignalDescription(QCanSignalDescription)
            cppSelf->addSignalDescription(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCanMessageDescriptionFunc_clearSignalDescriptions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanMessageDescription *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanMessageDescription_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clearSignalDescriptions()
        cppSelf->clearSignalDescriptions();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCanMessageDescriptionFunc_comment(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanMessageDescription *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanMessageDescription_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // comment()const
        QString cppResult = const_cast<const ::QCanMessageDescription *>(cppSelf)->comment();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanMessageDescriptionFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanMessageDescription *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanMessageDescription_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QCanMessageDescription *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanMessageDescriptionFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanMessageDescription *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanMessageDescription_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // name()const
        QString cppResult = const_cast<const ::QCanMessageDescription *>(cppSelf)->name();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanMessageDescriptionFunc_setComment(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanMessageDescription *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanMessageDescription_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCanMessageDescription::setComment(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setComment(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setComment", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanMessageDescription_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setComment(QString)
            cppSelf->setComment(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCanMessageDescriptionFunc_setName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanMessageDescription *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanMessageDescription_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCanMessageDescription::setName(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setName", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanMessageDescription_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setName(QString)
            cppSelf->setName(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCanMessageDescriptionFunc_setSignalDescriptions(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanMessageDescription *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanMessageDescription_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCanMessageDescription::setSignalDescriptions(QList<QCanSignalDescription>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QCanSignalDescription_IDX], (pyArg)))) {
        overloadId = 0; // setSignalDescriptions(QList<QCanSignalDescription>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSignalDescriptions", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanMessageDescription_IDX]);

    // Call function/method
    {
        ::QList<QCanSignalDescription> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSignalDescriptions(QList<QCanSignalDescription>)
            cppSelf->setSignalDescriptions(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCanMessageDescriptionFunc_setSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanMessageDescription *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanMessageDescription_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCanMessageDescription::setSize(quint8)
    if (SbkChar_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint8>(), (pyArg)))) {
        overloadId = 0; // setSize(quint8)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSize", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanMessageDescription_IDX]);

    // Call function/method
    {
        quint8 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSize(quint8)
            cppSelf->setSize(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCanMessageDescriptionFunc_setTransmitter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanMessageDescription *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanMessageDescription_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCanMessageDescription::setTransmitter(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setTransmitter(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTransmitter", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanMessageDescription_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTransmitter(QString)
            cppSelf->setTransmitter(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCanMessageDescriptionFunc_setUniqueId(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanMessageDescription *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanMessageDescription_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCanMessageDescription::setUniqueId(QtCanBus::UniqueId)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QtCanBus_UniqueId_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setUniqueId(QtCanBus::UniqueId)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUniqueId", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanMessageDescription_IDX]);

    // Call function/method
    {
        ::QtCanBus::UniqueId cppArg0 = static_cast< ::QtCanBus::UniqueId>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setUniqueId(QtCanBus::UniqueId)
            cppSelf->setUniqueId(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCanMessageDescriptionFunc_signalDescriptionForName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanMessageDescription *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanMessageDescription_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCanMessageDescription::signalDescriptionForName(QString)const->QCanSignalDescription
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // signalDescriptionForName(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "signalDescriptionForName", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanMessageDescription_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // signalDescriptionForName(QString)const
            QCanSignalDescription cppResult = const_cast<const ::QCanMessageDescription *>(cppSelf)->signalDescriptionForName(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanSignalDescription_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanMessageDescriptionFunc_signalDescriptions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanMessageDescription *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanMessageDescription_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // signalDescriptions()const
        QList<QCanSignalDescription> cppResult = const_cast<const ::QCanMessageDescription *>(cppSelf)->signalDescriptions();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QCanSignalDescription_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanMessageDescriptionFunc_size(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanMessageDescription *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanMessageDescription_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // size()const
        quint8 cppResult = const_cast<const ::QCanMessageDescription *>(cppSelf)->size();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint8>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanMessageDescriptionFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanMessageDescription *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanMessageDescription_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCanMessageDescription::swap(QCanMessageDescription&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanMessageDescription_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QCanMessageDescription&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanMessageDescription_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QCanMessageDescription cppArg0_local;
        ::QCanMessageDescription *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QCanMessageDescription&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCanMessageDescriptionFunc_transmitter(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanMessageDescription *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanMessageDescription_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // transmitter()const
        QString cppResult = const_cast<const ::QCanMessageDescription *>(cppSelf)->transmitter();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanMessageDescriptionFunc_uniqueId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanMessageDescription *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanMessageDescription_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // uniqueId()const
        QtCanBus::UniqueId cppResult = const_cast<const ::QCanMessageDescription *>(cppSelf)->uniqueId();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QtCanBus_UniqueId_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanMessageDescription__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QCanMessageDescription *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanMessageDescription_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanMessageDescription_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QCanMessageDescription_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QCanMessageDescription_methods[] = {
    {"addSignalDescription", reinterpret_cast<PyCFunction>(Sbk_QCanMessageDescriptionFunc_addSignalDescription), METH_O, nullptr},
    {"clearSignalDescriptions", reinterpret_cast<PyCFunction>(Sbk_QCanMessageDescriptionFunc_clearSignalDescriptions), METH_NOARGS, nullptr},
    {"comment", reinterpret_cast<PyCFunction>(Sbk_QCanMessageDescriptionFunc_comment), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QCanMessageDescriptionFunc_isValid), METH_NOARGS, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_QCanMessageDescriptionFunc_name), METH_NOARGS, nullptr},
    {"setComment", reinterpret_cast<PyCFunction>(Sbk_QCanMessageDescriptionFunc_setComment), METH_O, nullptr},
    {"setName", reinterpret_cast<PyCFunction>(Sbk_QCanMessageDescriptionFunc_setName), METH_O, nullptr},
    {"setSignalDescriptions", reinterpret_cast<PyCFunction>(Sbk_QCanMessageDescriptionFunc_setSignalDescriptions), METH_O, nullptr},
    {"setSize", reinterpret_cast<PyCFunction>(Sbk_QCanMessageDescriptionFunc_setSize), METH_O, nullptr},
    {"setTransmitter", reinterpret_cast<PyCFunction>(Sbk_QCanMessageDescriptionFunc_setTransmitter), METH_O, nullptr},
    {"setUniqueId", reinterpret_cast<PyCFunction>(Sbk_QCanMessageDescriptionFunc_setUniqueId), METH_O, nullptr},
    {"signalDescriptionForName", reinterpret_cast<PyCFunction>(Sbk_QCanMessageDescriptionFunc_signalDescriptionForName), METH_O, nullptr},
    {"signalDescriptions", reinterpret_cast<PyCFunction>(Sbk_QCanMessageDescriptionFunc_signalDescriptions), METH_NOARGS, nullptr},
    {"size", reinterpret_cast<PyCFunction>(Sbk_QCanMessageDescriptionFunc_size), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QCanMessageDescriptionFunc_swap), METH_O, nullptr},
    {"transmitter", reinterpret_cast<PyCFunction>(Sbk_QCanMessageDescriptionFunc_transmitter), METH_NOARGS, nullptr},
    {"uniqueId", reinterpret_cast<PyCFunction>(Sbk_QCanMessageDescriptionFunc_uniqueId), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QCanMessageDescription__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QCanMessageDescription_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QCanMessageDescription_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QCanMessageDescription__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanMessageDescription *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanMessageDescription_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QCanMessageDescription_Type = nullptr;
static PyTypeObject *Sbk_QCanMessageDescription_TypeF(void)
{
    return _Sbk_QCanMessageDescription_Type;
}

static PyType_Slot Sbk_QCanMessageDescription_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QCanMessageDescription__repr__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QCanMessageDescription_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QCanMessageDescription_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QCanMessageDescription_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QCanMessageDescription_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QCanMessageDescription_spec = {
    "2:PySide6.QtSerialBus.QCanMessageDescription",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QCanMessageDescription_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QCanMessageDescription_PythonToCpp_QCanMessageDescription_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QCanMessageDescription_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QCanMessageDescription_PythonToCpp_QCanMessageDescription_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QCanMessageDescription_TypeF()))
        return QCanMessageDescription_PythonToCpp_QCanMessageDescription_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QCanMessageDescription_PTR_CppToPython_QCanMessageDescription(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QCanMessageDescription_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QCanMessageDescription_COPY_CppToPython_QCanMessageDescription(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QCanMessageDescription *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QCanMessageDescription_TypeF(), new ::QCanMessageDescription(*source), true, true);
}

// Python to C++ copy conversion.
static void QCanMessageDescription_PythonToCpp_QCanMessageDescription_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QCanMessageDescription *>(cppOut) = *reinterpret_cast< ::QCanMessageDescription *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanMessageDescription_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QCanMessageDescription_PythonToCpp_QCanMessageDescription_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QCanMessageDescription_TypeF()))
        return QCanMessageDescription_PythonToCpp_QCanMessageDescription_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QCanMessageDescription_SignatureStrings[] = {
    "1:PySide6.QtSerialBus.QCanMessageDescription(self)",
    "0:PySide6.QtSerialBus.QCanMessageDescription(self,other:PySide6.QtSerialBus.QCanMessageDescription)",
    "PySide6.QtSerialBus.QCanMessageDescription.addSignalDescription(self,description:PySide6.QtSerialBus.QCanSignalDescription)",
    "PySide6.QtSerialBus.QCanMessageDescription.clearSignalDescriptions(self)",
    "PySide6.QtSerialBus.QCanMessageDescription.comment(self)->QString",
    "PySide6.QtSerialBus.QCanMessageDescription.isValid(self)->bool",
    "PySide6.QtSerialBus.QCanMessageDescription.name(self)->QString",
    "PySide6.QtSerialBus.QCanMessageDescription.setComment(self,text:QString)",
    "PySide6.QtSerialBus.QCanMessageDescription.setName(self,name:QString)",
    "PySide6.QtSerialBus.QCanMessageDescription.setSignalDescriptions(self,descriptions:QList[PySide6.QtSerialBus.QCanSignalDescription])",
    "PySide6.QtSerialBus.QCanMessageDescription.setSize(self,size:quint8)",
    "PySide6.QtSerialBus.QCanMessageDescription.setTransmitter(self,transmitter:QString)",
    "PySide6.QtSerialBus.QCanMessageDescription.setUniqueId(self,id:PySide6.QtSerialBus.QtCanBus.UniqueId)",
    "PySide6.QtSerialBus.QCanMessageDescription.signalDescriptionForName(self,name:QString)->PySide6.QtSerialBus.QCanSignalDescription",
    "PySide6.QtSerialBus.QCanMessageDescription.signalDescriptions(self)->QList[PySide6.QtSerialBus.QCanSignalDescription]",
    "PySide6.QtSerialBus.QCanMessageDescription.size(self)->quint8",
    "PySide6.QtSerialBus.QCanMessageDescription.swap(self,other:PySide6.QtSerialBus.QCanMessageDescription)",
    "PySide6.QtSerialBus.QCanMessageDescription.transmitter(self)->QString",
    "PySide6.QtSerialBus.QCanMessageDescription.uniqueId(self)->PySide6.QtSerialBus.QtCanBus.UniqueId",
    "PySide6.QtSerialBus.QCanMessageDescription.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QCanMessageDescription_SignatureByteSize = 310;
static constexpr uint8_t QCanMessageDescription_SignatureBytes[310] = {
    0x78, 0xda, 0xbd, 0x54, 0xc1, 0x4a, 0xc3, 0x40, 0x10, 0xbd, 0xe7, 0x4b, 0x0c, 0xa4, 0x41, 0x2f,
    0x22, 0x39, 0xf4, 0x60, 0x45, 0x10, 0x54, 0x0c, 0x51, 0x2f, 0x22, 0x61, 0xcd, 0x8e, 0x75, 0x20,
    0xd9, 0x4d, 0x77, 0x26, 0x68, 0xfb, 0xf5, 0xa6, 0x34, 0x69, 0x4b, 0x62, 0x20, 0x93, 0x82, 0xb7,
    0xdd, 0x65, 0xdf, 0x7b, 0xb3, 0xf3, 0xde, 0xec, 0x45, 0xf4, 0xb4, 0x4e, 0x50, 0xc3, 0x65, 0x18,
    0x73, 0x02, 0x0e, 0x55, 0x7e, 0x5d, 0x51, 0x18, 0x2f, 0x94, 0x79, 0x00, 0x22, 0xb5, 0x84, 0x1b,
    0xa0, 0xcc, 0x61, 0xc9, 0x68, 0xcd, 0x19, 0x41, 0xfe, 0xe9, 0x7b, 0xe7, 0x52, 0x48, 0x60, 0xf9,
    0x0b, 0x9c, 0x00, 0xe5, 0x7b, 0xe3, 0xef, 0x86, 0x4a, 0xeb, 0x04, 0x97, 0x46, 0xe5, 0x3d, 0x59,
    0x7d, 0x38, 0x18, 0x14, 0xef, 0x41, 0x45, 0xda, 0x59, 0x0e, 0xca, 0xf5, 0x28, 0xa8, 0x69, 0x94,
    0x84, 0xc8, 0x16, 0x05, 0x18, 0xde, 0x01, 0x67, 0xf3, 0x38, 0x61, 0x87, 0x66, 0x29, 0x61, 0x40,
    0x7a, 0x55, 0x39, 0xea, 0x96, 0xe1, 0xc3, 0xda, 0x5c, 0x02, 0x37, 0xaa, 0x80, 0x13, 0xd4, 0x09,
    0x78, 0x71, 0xf4, 0x84, 0x80, 0xe1, 0x87, 0xa3, 0x86, 0xc7, 0x17, 0x12, 0x3d, 0xb6, 0xa5, 0x04,
    0xdb, 0xa2, 0xa6, 0xb2, 0x0c, 0xb8, 0x72, 0x1c, 0x0a, 0x8a, 0xe2, 0x7b, 0x24, 0x7e, 0x1b, 0x9d,
    0x8d, 0x77, 0x79, 0x11, 0x9b, 0xe6, 0x29, 0x54, 0xaf, 0xa2, 0x55, 0x85, 0x86, 0xaf, 0xa4, 0x24,
    0xcf, 0x4e, 0x19, 0x2a, 0x90, 0x19, 0x5c, 0xd3, 0xdc, 0xc3, 0xc1, 0xd4, 0xee, 0xbc, 0x18, 0x5c,
    0x55, 0x70, 0xb7, 0x8b, 0x4b, 0x80, 0xfa, 0xef, 0xf9, 0xe0, 0x1a, 0xbf, 0x5d, 0xb4, 0xb7, 0x65,
    0x2a, 0xdd, 0xee, 0xdd, 0x5a, 0x37, 0x60, 0xed, 0x6c, 0x3e, 0xda, 0x82, 0x93, 0x2a, 0xa0, 0x7d,
    0xc2, 0x85, 0xbe, 0xcb, 0x54, 0x37, 0xfb, 0x49, 0xda, 0x19, 0x2e, 0x42, 0x7f, 0xab, 0xf2, 0x1f,
    0x3e, 0x4d, 0xee, 0x64, 0x6a, 0xda, 0xd4, 0x57, 0xc7, 0x29, 0x1a, 0x72, 0xb1, 0x1b, 0x22, 0x89,
    0x40, 0x9a, 0x66, 0xb6, 0x5c, 0xa7, 0x69, 0x2b, 0xc0, 0xeb, 0xb2, 0x2e, 0x31, 0x4c, 0xea, 0x9d,
    0xf7, 0x0b, 0xc6, 0x22, 0x7d, 0x38
};
#endif

PyTypeObject *init_QCanMessageDescription(PyObject *module)
{
    if (SbkPySide6_QtSerialBusTypeStructs[SBK_QCanMessageDescription_IDX].type != nullptr)
        return SbkPySide6_QtSerialBusTypeStructs[SBK_QCanMessageDescription_IDX].type;

    Shiboken::AutoDecRef Sbk_QCanMessageDescription_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QCanMessageDescription_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QCanMessageDescription",
        "QCanMessageDescription",
        &Sbk_QCanMessageDescription_spec,
        &Shiboken::callCppDestructor< ::QCanMessageDescription >,
        Sbk_QCanMessageDescription_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QCanMessageDescription_TypeF(); // references _Sbk_QCanMessageDescription_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QCanMessageDescription_SignatureStrings);
#else
    InitSignatureBytes(pyType, QCanMessageDescription_SignatureBytes, QCanMessageDescription_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QCanMessageDescription_PropertyStrings);
    SbkPySide6_QtSerialBusTypeStructs[SBK_QCanMessageDescription_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QCanMessageDescription_PythonToCpp_QCanMessageDescription_PTR,
        is_QCanMessageDescription_PythonToCpp_QCanMessageDescription_PTR_Convertible,
        QCanMessageDescription_PTR_CppToPython_QCanMessageDescription,
        QCanMessageDescription_COPY_CppToPython_QCanMessageDescription);

    Shiboken::Conversions::registerConverterName(converter, "QCanMessageDescription");
    Shiboken::Conversions::registerConverterName(converter, "QCanMessageDescription*");
    Shiboken::Conversions::registerConverterName(converter, "QCanMessageDescription&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QCanMessageDescription).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QCanMessageDescription_PythonToCpp_QCanMessageDescription_COPY,
        is_QCanMessageDescription_PythonToCpp_QCanMessageDescription_COPY_Convertible);

    qRegisterMetaType< ::QCanMessageDescription >("QCanMessageDescription");

    return pyType;
}
