// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtserialbus_python.h"

// main header
#include "qmodbusdataunit_wrapper.h"

// Argument includes
#include <QList>
#include <QtSerialBus/qmodbusdataunit.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QModbusDataUnit_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QModbusDataUnit >()))
        return -1;

    ::QModbusDataUnit *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 2)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_IDX]);

    if (PyArg_UnpackTuple(args, "QModbusDataUnit", 0, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QModbusDataUnit::QModbusDataUnit()
    // 1: QModbusDataUnit::QModbusDataUnit(QModbusDataUnit::RegisterType)
    // 2: QModbusDataUnit::QModbusDataUnit(QModbusDataUnit::RegisterType,int,QList<quint16>)
    // 3: QModbusDataUnit::QModbusDataUnit(QModbusDataUnit::RegisterType,int,quint16)
    // 4: QModbusDataUnit::QModbusDataUnit(QModbusDataUnit)
    if (numArgs == 0) {
        overloadId = 0; // QModbusDataUnit()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_IDX]), (pyArgs[0])))) {
        overloadId = 4; // QModbusDataUnit(QModbusDataUnit)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_RegisterType_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QModbusDataUnit(QModbusDataUnit::RegisterType)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            if (numArgs == 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArgs[2])))) {
                overloadId = 3; // QModbusDataUnit(QModbusDataUnit::RegisterType,int,quint16)
            } else if (numArgs == 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_quint16_IDX], (pyArgs[2])))) {
                overloadId = 2; // QModbusDataUnit(QModbusDataUnit::RegisterType,int,QList<quint16>)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QModbusDataUnit()
        {

            // QModbusDataUnit()
            cptr = new ::QModbusDataUnit();
            break;
        }
        case 1: // QModbusDataUnit(QModbusDataUnit::RegisterType type)
        {
            ::QModbusDataUnit::RegisterType cppArg0{QModbusDataUnit::Invalid};
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QModbusDataUnit(QModbusDataUnit::RegisterType)
                cptr = new ::QModbusDataUnit(cppArg0);
            }
            break;
        }
        case 2: // QModbusDataUnit(QModbusDataUnit::RegisterType type, int newStartAddress, const QList<quint16> &newValues)
        {
            ::QModbusDataUnit::RegisterType cppArg0{QModbusDataUnit::Invalid};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QList<quint16> cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QModbusDataUnit(QModbusDataUnit::RegisterType,int,QList<quint16>)
                cptr = new ::QModbusDataUnit(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
        case 3: // QModbusDataUnit(QModbusDataUnit::RegisterType type, int newStartAddress, quint16 newValueCount)
        {
            ::QModbusDataUnit::RegisterType cppArg0{QModbusDataUnit::Invalid};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            quint16 cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QModbusDataUnit(QModbusDataUnit::RegisterType,int,quint16)
                cptr = new ::QModbusDataUnit(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
        case 4: // QModbusDataUnit(const QModbusDataUnit &QModbusDataUnit)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QModbusDataUnit cppArg0_local;
            ::QModbusDataUnit *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QModbusDataUnit(QModbusDataUnit)
                cptr = new ::QModbusDataUnit(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QModbusDataUnit >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QModbusDataUnitFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusDataUnit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QModbusDataUnit *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModbusDataUnitFunc_registerType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusDataUnit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // registerType()const
        QModbusDataUnit::RegisterType cppResult = const_cast<const ::QModbusDataUnit *>(cppSelf)->registerType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_RegisterType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModbusDataUnitFunc_setRegisterType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusDataUnit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QModbusDataUnit::setRegisterType(QModbusDataUnit::RegisterType)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_RegisterType_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setRegisterType(QModbusDataUnit::RegisterType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRegisterType", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_IDX]);

    // Call function/method
    {
        ::QModbusDataUnit::RegisterType cppArg0{QModbusDataUnit::Invalid};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRegisterType(QModbusDataUnit::RegisterType)
            cppSelf->setRegisterType(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QModbusDataUnitFunc_setStartAddress(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusDataUnit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QModbusDataUnit::setStartAddress(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setStartAddress(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStartAddress", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStartAddress(int)
            cppSelf->setStartAddress(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QModbusDataUnitFunc_setValue(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusDataUnit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setValue", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QModbusDataUnit::setValue(qsizetype,quint16)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArgs[1])))) {
        overloadId = 0; // setValue(qsizetype,quint16)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setValue", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        quint16 cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setValue(qsizetype,quint16)
            cppSelf->setValue(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QModbusDataUnitFunc_setValueCount(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusDataUnit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QModbusDataUnit::setValueCount(qsizetype)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // setValueCount(qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setValueCount", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setValueCount(qsizetype)
            cppSelf->setValueCount(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QModbusDataUnitFunc_setValues(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusDataUnit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QModbusDataUnit::setValues(QList<quint16>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_quint16_IDX], (pyArg)))) {
        overloadId = 0; // setValues(QList<quint16>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setValues", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_IDX]);

    // Call function/method
    {
        ::QList<quint16> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setValues(QList<quint16>)
            cppSelf->setValues(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QModbusDataUnitFunc_startAddress(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusDataUnit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // startAddress()const
        int cppResult = const_cast<const ::QModbusDataUnit *>(cppSelf)->startAddress();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModbusDataUnitFunc_value(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusDataUnit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QModbusDataUnit::value(qsizetype)const->quint16
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // value(qsizetype)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "value", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // value(qsizetype)const
            quint16 cppResult = const_cast<const ::QModbusDataUnit *>(cppSelf)->value(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModbusDataUnitFunc_valueCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusDataUnit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // valueCount()const
        qsizetype cppResult = const_cast<const ::QModbusDataUnit *>(cppSelf)->valueCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModbusDataUnitFunc_values(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusDataUnit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // values()const
        QList<quint16> cppResult = const_cast<const ::QModbusDataUnit *>(cppSelf)->values();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_quint16_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModbusDataUnit__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QModbusDataUnit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QModbusDataUnit_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QModbusDataUnit_EnumFlagInfo[] = {
    "RegisterType:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QModbusDataUnit_methods[] = {
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QModbusDataUnitFunc_isValid), METH_NOARGS, nullptr},
    {"registerType", reinterpret_cast<PyCFunction>(Sbk_QModbusDataUnitFunc_registerType), METH_NOARGS, nullptr},
    {"setRegisterType", reinterpret_cast<PyCFunction>(Sbk_QModbusDataUnitFunc_setRegisterType), METH_O, nullptr},
    {"setStartAddress", reinterpret_cast<PyCFunction>(Sbk_QModbusDataUnitFunc_setStartAddress), METH_O, nullptr},
    {"setValue", reinterpret_cast<PyCFunction>(Sbk_QModbusDataUnitFunc_setValue), METH_VARARGS, nullptr},
    {"setValueCount", reinterpret_cast<PyCFunction>(Sbk_QModbusDataUnitFunc_setValueCount), METH_O, nullptr},
    {"setValues", reinterpret_cast<PyCFunction>(Sbk_QModbusDataUnitFunc_setValues), METH_O, nullptr},
    {"startAddress", reinterpret_cast<PyCFunction>(Sbk_QModbusDataUnitFunc_startAddress), METH_NOARGS, nullptr},
    {"value", reinterpret_cast<PyCFunction>(Sbk_QModbusDataUnitFunc_value), METH_O, nullptr},
    {"valueCount", reinterpret_cast<PyCFunction>(Sbk_QModbusDataUnitFunc_valueCount), METH_NOARGS, nullptr},
    {"values", reinterpret_cast<PyCFunction>(Sbk_QModbusDataUnitFunc_values), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QModbusDataUnit__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QModbusDataUnit_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QModbusDataUnit_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QModbusDataUnit_Type = nullptr;
static PyTypeObject *Sbk_QModbusDataUnit_TypeF(void)
{
    return _Sbk_QModbusDataUnit_Type;
}

static PyType_Slot Sbk_QModbusDataUnit_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QModbusDataUnit_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QModbusDataUnit_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QModbusDataUnit_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QModbusDataUnit_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QModbusDataUnit_spec = {
    "2:PySide6.QtSerialBus.QModbusDataUnit",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QModbusDataUnit_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QModbusDataUnit_RegisterType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QModbusDataUnit::RegisterType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QModbusDataUnit::RegisterType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QModbusDataUnit_RegisterType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_RegisterType_IDX])))
        return Enum_PythonToCpp_QModbusDataUnit_RegisterType;
    return {};
}

static PyObject *QModbusDataUnit_RegisterType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QModbusDataUnit::RegisterType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QModbusDataUnit::RegisterType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_RegisterType_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QModbusDataUnit_PythonToCpp_QModbusDataUnit_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QModbusDataUnit_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QModbusDataUnit_PythonToCpp_QModbusDataUnit_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QModbusDataUnit_TypeF()))
        return QModbusDataUnit_PythonToCpp_QModbusDataUnit_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QModbusDataUnit_PTR_CppToPython_QModbusDataUnit(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QModbusDataUnit_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QModbusDataUnit_COPY_CppToPython_QModbusDataUnit(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QModbusDataUnit *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QModbusDataUnit_TypeF(), new ::QModbusDataUnit(*source), true, true);
}

// Python to C++ copy conversion.
static void QModbusDataUnit_PythonToCpp_QModbusDataUnit_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QModbusDataUnit *>(cppOut) = *reinterpret_cast< ::QModbusDataUnit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QModbusDataUnit_PythonToCpp_QModbusDataUnit_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QModbusDataUnit_TypeF()))
        return QModbusDataUnit_PythonToCpp_QModbusDataUnit_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QModbusDataUnit_SignatureStrings[] = {
    "4:PySide6.QtSerialBus.QModbusDataUnit(self)",
    "3:PySide6.QtSerialBus.QModbusDataUnit(self,type:PySide6.QtSerialBus.QModbusDataUnit.RegisterType)",
    "2:PySide6.QtSerialBus.QModbusDataUnit(self,type:PySide6.QtSerialBus.QModbusDataUnit.RegisterType,newStartAddress:int,newValues:QList[quint16])",
    "1:PySide6.QtSerialBus.QModbusDataUnit(self,type:PySide6.QtSerialBus.QModbusDataUnit.RegisterType,newStartAddress:int,newValueCount:quint16)",
    "0:PySide6.QtSerialBus.QModbusDataUnit(self,QModbusDataUnit:PySide6.QtSerialBus.QModbusDataUnit)",
    "PySide6.QtSerialBus.QModbusDataUnit.isValid(self)->bool",
    "PySide6.QtSerialBus.QModbusDataUnit.registerType(self)->PySide6.QtSerialBus.QModbusDataUnit.RegisterType",
    "PySide6.QtSerialBus.QModbusDataUnit.setRegisterType(self,type:PySide6.QtSerialBus.QModbusDataUnit.RegisterType)",
    "PySide6.QtSerialBus.QModbusDataUnit.setStartAddress(self,newAddress:int)",
    "PySide6.QtSerialBus.QModbusDataUnit.setValue(self,index:qsizetype,newValue:quint16)",
    "PySide6.QtSerialBus.QModbusDataUnit.setValueCount(self,newCount:qsizetype)",
    "PySide6.QtSerialBus.QModbusDataUnit.setValues(self,newValues:QList[quint16])",
    "PySide6.QtSerialBus.QModbusDataUnit.startAddress(self)->int",
    "PySide6.QtSerialBus.QModbusDataUnit.value(self,index:qsizetype)->quint16",
    "PySide6.QtSerialBus.QModbusDataUnit.valueCount(self)->qsizetype",
    "PySide6.QtSerialBus.QModbusDataUnit.values(self)->QList[quint16]",
    "PySide6.QtSerialBus.QModbusDataUnit.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QModbusDataUnit_SignatureByteSize = 286;
static constexpr uint8_t QModbusDataUnit_SignatureBytes[286] = {
    0x78, 0xda, 0xc5, 0x53, 0x4b, 0x4b, 0xc4, 0x30, 0x10, 0xbe, 0xe7, 0x97, 0x18, 0x58, 0x8b, 0xab,
    0xb2, 0x87, 0x1c, 0x04, 0x1f, 0x47, 0x05, 0xbb, 0x55, 0x2f, 0x22, 0x25, 0x6b, 0xc6, 0x65, 0xa0,
    0x24, 0xbb, 0xc9, 0x54, 0xad, 0xbf, 0xde, 0x6c, 0x1f, 0xdb, 0x5a, 0x58, 0x98, 0x0a, 0xe2, 0x31,
    0x93, 0xf9, 0x1e, 0x99, 0xf9, 0x72, 0xae, 0xee, 0xab, 0x0c, 0x0d, 0x2c, 0x92, 0x94, 0x32, 0xf0,
    0xa8, 0x8b, 0xab, 0x32, 0x24, 0xe9, 0x9d, 0x33, 0xab, 0x32, 0xdc, 0x68, 0xd2, 0x8f, 0x16, 0xe9,
    0x28, 0x40, 0xf1, 0x26, 0xc5, 0x19, 0xbb, 0x77, 0x46, 0xd5, 0x06, 0x38, 0xdd, 0xc9, 0x12, 0xd6,
    0x18, 0x08, 0xfc, 0x43, 0x04, 0x48, 0x71, 0xfa, 0xc7, 0x0a, 0x33, 0x0b, 0x1f, 0x19, 0x69, 0x4f,
    0x97, 0xc6, 0x78, 0x08, 0x41, 0xa1, 0xa5, 0x5d, 0xed, 0x49, 0x17, 0x25, 0x04, 0x95, 0xde, 0xc6,
    0xce, 0xe7, 0x6d, 0x19, 0xab, 0xf3, 0xc5, 0x8b, 0x14, 0xf3, 0xff, 0xb4, 0x73, 0xed, 0x4a, 0x4b,
    0xaa, 0x35, 0x23, 0xc5, 0x09, 0xdf, 0xcb, 0xa8, 0xc8, 0x01, 0x4a, 0xc1, 0xf1, 0x8e, 0x21, 0x3a,
    0x43, 0xd3, 0xc4, 0xe1, 0xf8, 0x62, 0xe5, 0x5c, 0xc1, 0xc2, 0xf9, 0xc1, 0x9b, 0x3b, 0xf0, 0xd4,
    0x59, 0xb1, 0x84, 0x02, 0xd0, 0x72, 0xac, 0xf5, 0xdb, 0x2c, 0x32, 0xf5, 0x86, 0xfb, 0x6b, 0xf4,
    0xe2, 0x02, 0x07, 0xfb, 0x64, 0x13, 0xd5, 0x4b, 0x6f, 0x18, 0xd0, 0x1a, 0xf8, 0x54, 0xdb, 0x80,
    0x5f, 0x40, 0x6d, 0x4c, 0xea, 0xdb, 0x3e, 0x0d, 0x53, 0x38, 0xeb, 0x20, 0xed, 0xad, 0xb5, 0xb1,
    0xea, 0xb8, 0xa7, 0x51, 0xf5, 0x2f, 0x3c, 0xf0, 0x63, 0x58, 0x64, 0xe3, 0x89, 0xc5, 0x34, 0x44,
    0x3c, 0x0b, 0xfb, 0x7e, 0x70, 0x48, 0x91, 0xa4, 0xb5, 0xc1, 0x27, 0xea, 0x27, 0xb3, 0x43, 0x77,
    0x4c, 0x7c, 0xfc, 0xde, 0xfe, 0xcf, 0x31, 0xb0, 0x08, 0xf2, 0xfc, 0xd5, 0x6d, 0xaa, 0x3c, 0xef,
    0x28, 0xa2, 0x32, 0xda, 0x75, 0x92, 0xc5, 0x93, 0xf8, 0x06, 0xdd, 0x49, 0x0c, 0xf8
};
#endif

PyTypeObject *init_QModbusDataUnit(PyObject *module)
{
    if (SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_IDX].type != nullptr)
        return SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_IDX].type;

    Shiboken::AutoDecRef Sbk_QModbusDataUnit_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QModbusDataUnit_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QModbusDataUnit",
        "QModbusDataUnit",
        &Sbk_QModbusDataUnit_spec,
        &Shiboken::callCppDestructor< ::QModbusDataUnit >,
        Sbk_QModbusDataUnit_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QModbusDataUnit_TypeF(); // references _Sbk_QModbusDataUnit_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QModbusDataUnit_SignatureStrings);
#else
    InitSignatureBytes(pyType, QModbusDataUnit_SignatureBytes, QModbusDataUnit_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QModbusDataUnit_PropertyStrings);
    SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QModbusDataUnit_PythonToCpp_QModbusDataUnit_PTR,
        is_QModbusDataUnit_PythonToCpp_QModbusDataUnit_PTR_Convertible,
        QModbusDataUnit_PTR_CppToPython_QModbusDataUnit,
        QModbusDataUnit_COPY_CppToPython_QModbusDataUnit);

    Shiboken::Conversions::registerConverterName(converter, "QModbusDataUnit");
    Shiboken::Conversions::registerConverterName(converter, "QModbusDataUnit*");
    Shiboken::Conversions::registerConverterName(converter, "QModbusDataUnit&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QModbusDataUnit).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QModbusDataUnit_PythonToCpp_QModbusDataUnit_COPY,
        is_QModbusDataUnit_PythonToCpp_QModbusDataUnit_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QModbusDataUnit_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'RegisterType'.
    const char *RegisterType_Initializer[] = {
        "Invalid",
        "DiscreteInputs",
        "Coils",
        "InputRegisters",
        "HoldingRegisters",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t RegisterType_InitializerValues[] = {
        uint8_t(QModbusDataUnit::RegisterType::Invalid),         //  0x00  0
        uint8_t(QModbusDataUnit::RegisterType::DiscreteInputs),  //  0x01  1
        uint8_t(QModbusDataUnit::RegisterType::Coils),           //  0x02  2
        uint8_t(QModbusDataUnit::RegisterType::InputRegisters),  //  0x03  3
        uint8_t(QModbusDataUnit::RegisterType::HoldingRegisters) //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QModbusDataUnit_TypeF(),
        "2:PySide6.QtSerialBus.QModbusDataUnit.RegisterType",
        RegisterType_Initializer, RegisterType_InitializerValues);
    SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_RegisterType_IDX].type = EType;
    // Register converter for enum 'QModbusDataUnit::RegisterType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QModbusDataUnit_RegisterType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QModbusDataUnit_RegisterType,
            is_Enum_PythonToCpp_QModbusDataUnit_RegisterType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QModbusDataUnit::RegisterType");
        Shiboken::Conversions::registerConverterAlias(converter, "RegisterType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'RegisterType' enum.

    qRegisterMetaType< ::QModbusDataUnit >("QModbusDataUnit");
    qRegisterMetaType< ::QModbusDataUnit::RegisterType >("QModbusDataUnit::RegisterType");

    return pyType;
}
