// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtserialbus_python.h"

// main header
#include "qmodbusdevice_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QtSerialBus/qmodbusdevice.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qiodevice.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QModbusDeviceWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QModbusDeviceWrapper::QModbusDeviceWrapper(::QObject * parent) : QModbusDevice(parent)
{
}

void QModbusDeviceWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QModbusDevice", funcName);
        return;
    }
}

void QModbusDeviceWrapper::close()
{
    if (m_PyMethodCache[1]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QModbusDevice.close");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "close";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        Shiboken::Errors::setPureVirtualMethodError("QModbusDevice.close");
        return;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QModbusDevice", funcName);
        return;
    }
}

void QModbusDeviceWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QModbusDevice", funcName);
        return;
    }
}

void QModbusDeviceWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QModbusDevice", funcName);
        return;
    }
}

void QModbusDeviceWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[4]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QModbusDevice", funcName);
        return;
    }
}

bool QModbusDeviceWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QModbusDevice", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QModbusDevice", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QModbusDeviceWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[6])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QModbusDevice", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QModbusDevice", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QModbusDeviceWrapper::open()
{
    if (m_PyMethodCache[7]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QModbusDevice.open");
        return false;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "open";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[7] = true;
        Shiboken::Errors::setPureVirtualMethodError("QModbusDevice.open");
        return false;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QModbusDevice", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QModbusDevice", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QModbusDeviceWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[8]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[8] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QModbusDevice", funcName);
        return;
    }
}

const QMetaObject *QModbusDeviceWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QModbusDevice::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QModbusDeviceWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QModbusDevice::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QModbusDeviceWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QModbusDeviceWrapper *>(this));
    return QModbusDevice::qt_metacast(_clname);
}

QModbusDeviceWrapper::~QModbusDeviceWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QModbusDevice_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QModbusDevice");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QModbusDevice >()))
        return -1;

    QModbusDeviceWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QModbusDevice", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QModbusDevice::QModbusDevice(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QModbusDevice(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QModbusDevice(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                // fall through to handle extra keyword signals and properties
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QModbusDevice(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QModbusDeviceWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QModbusDeviceWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QModbusDevice >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QModbusDeviceFunc_close(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // close()
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QModbusDevice.close");
            return {};
        }
        cppSelf->close();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QModbusDeviceFunc_connectDevice(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // connectDevice()
        bool cppResult = cppSelf->connectDevice();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModbusDeviceFunc_connectionParameter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QModbusDevice::connectionParameter(QModbusDevice::ConnectionParameter)const->QVariant
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_ConnectionParameter_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // connectionParameter(QModbusDevice::ConnectionParameter)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "connectionParameter", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_IDX]);

    // Call function/method
    {
        ::QModbusDevice::ConnectionParameter cppArg0{QModbusDevice::SerialPortNameParameter};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // connectionParameter(QModbusDevice::ConnectionParameter)const
            QVariant cppResult = const_cast<const ::QModbusDevice *>(cppSelf)->connectionParameter(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModbusDeviceFunc_device(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // device()const
        QIODevice * cppResult = const_cast<const ::QModbusDevice *>(cppSelf)->device();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModbusDeviceFunc_disconnectDevice(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // disconnectDevice()
        cppSelf->disconnectDevice();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QModbusDeviceFunc_error(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // error()const
        QModbusDevice::Error cppResult = const_cast<const ::QModbusDevice *>(cppSelf)->error();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_Error_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModbusDeviceFunc_errorString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // errorString()const
        QString cppResult = const_cast<const ::QModbusDevice *>(cppSelf)->errorString();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModbusDeviceFunc_open(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // open()
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QModbusDevice.open");
            return {};
        }
        bool cppResult = cppSelf->open();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModbusDeviceFunc_setConnectionParameter(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setConnectionParameter", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QModbusDevice::setConnectionParameter(QModbusDevice::ConnectionParameter,QVariant)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_ConnectionParameter_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[1])))) {
        overloadId = 0; // setConnectionParameter(QModbusDevice::ConnectionParameter,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setConnectionParameter", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_IDX]);

    // Call function/method
    {
        ::QModbusDevice::ConnectionParameter cppArg0{QModbusDevice::SerialPortNameParameter};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QVariant cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setConnectionParameter(QModbusDevice::ConnectionParameter,QVariant)
            cppSelf->setConnectionParameter(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QModbusDeviceFunc_setError(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setError", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QModbusDevice::setError(QString,QModbusDevice::Error)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_Error_IDX])))->converter, (pyArgs[1])))) {
        overloadId = 0; // setError(QString,QModbusDevice::Error)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setError", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QModbusDevice::Error cppArg1{QModbusDevice::NoError};
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setError(QString,QModbusDevice::Error)
            cppSelf->setError(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QModbusDeviceFunc_setState(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QModbusDevice::setState(QModbusDevice::State)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_State_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setState(QModbusDevice::State)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setState", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_IDX]);

    // Call function/method
    {
        ::QModbusDevice::State cppArg0{QModbusDevice::UnconnectedState};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setState(QModbusDevice::State)
            cppSelf->setState(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QModbusDeviceFunc_state(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // state()const
        QModbusDevice::State cppResult = const_cast<const ::QModbusDevice *>(cppSelf)->state();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_State_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QModbusDevice_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QModbusDevice_EnumFlagInfo[] = {
    "ConnectionParameter:Enum",
    "Error:Enum",
    "IntermediateError:Enum",
    "State:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QModbusDevice_methods[] = {
    {"close", reinterpret_cast<PyCFunction>(Sbk_QModbusDeviceFunc_close), METH_NOARGS, nullptr},
    {"connectDevice", reinterpret_cast<PyCFunction>(Sbk_QModbusDeviceFunc_connectDevice), METH_NOARGS, nullptr},
    {"connectionParameter", reinterpret_cast<PyCFunction>(Sbk_QModbusDeviceFunc_connectionParameter), METH_O, nullptr},
    {"device", reinterpret_cast<PyCFunction>(Sbk_QModbusDeviceFunc_device), METH_NOARGS, nullptr},
    {"disconnectDevice", reinterpret_cast<PyCFunction>(Sbk_QModbusDeviceFunc_disconnectDevice), METH_NOARGS, nullptr},
    {"error", reinterpret_cast<PyCFunction>(Sbk_QModbusDeviceFunc_error), METH_NOARGS, nullptr},
    {"errorString", reinterpret_cast<PyCFunction>(Sbk_QModbusDeviceFunc_errorString), METH_NOARGS, nullptr},
    {"open", reinterpret_cast<PyCFunction>(Sbk_QModbusDeviceFunc_open), METH_NOARGS, nullptr},
    {"setConnectionParameter", reinterpret_cast<PyCFunction>(Sbk_QModbusDeviceFunc_setConnectionParameter), METH_VARARGS, nullptr},
    {"setError", reinterpret_cast<PyCFunction>(Sbk_QModbusDeviceFunc_setError), METH_VARARGS, nullptr},
    {"setState", reinterpret_cast<PyCFunction>(Sbk_QModbusDeviceFunc_setState), METH_O, nullptr},
    {"state", reinterpret_cast<PyCFunction>(Sbk_QModbusDeviceFunc_state), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QModbusDevice_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QModbusDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QModbusDeviceWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QModbusDevice_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QModbusDevice_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QModbusDevice_Type = nullptr;
static PyTypeObject *Sbk_QModbusDevice_TypeF(void)
{
    return _Sbk_QModbusDevice_Type;
}

static PyType_Slot Sbk_QModbusDevice_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QModbusDevice_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QModbusDevice_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QModbusDevice_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QModbusDevice_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QModbusDevice_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QModbusDevice_spec = {
    "2:PySide6.QtSerialBus.QModbusDevice",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QModbusDevice_slots
};

} //extern "C"

static void *Sbk_QModbusDevice_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QModbusDevice *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QModbusDevice_Error(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QModbusDevice::Error>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QModbusDevice::Error *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QModbusDevice_Error_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_Error_IDX])))
        return Enum_PythonToCpp_QModbusDevice_Error;
    return {};
}

static PyObject *QModbusDevice_Error_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QModbusDevice::Error>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QModbusDevice::Error *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_Error_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QModbusDevice_State(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QModbusDevice::State>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QModbusDevice::State *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QModbusDevice_State_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_State_IDX])))
        return Enum_PythonToCpp_QModbusDevice_State;
    return {};
}

static PyObject *QModbusDevice_State_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QModbusDevice::State>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QModbusDevice::State *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_State_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QModbusDevice_ConnectionParameter(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QModbusDevice::ConnectionParameter>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QModbusDevice::ConnectionParameter *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QModbusDevice_ConnectionParameter_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_ConnectionParameter_IDX])))
        return Enum_PythonToCpp_QModbusDevice_ConnectionParameter;
    return {};
}

static PyObject *QModbusDevice_ConnectionParameter_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QModbusDevice::ConnectionParameter>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QModbusDevice::ConnectionParameter *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_ConnectionParameter_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QModbusDevice_IntermediateError(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QModbusDevice::IntermediateError>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QModbusDevice::IntermediateError *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QModbusDevice_IntermediateError_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_IntermediateError_IDX])))
        return Enum_PythonToCpp_QModbusDevice_IntermediateError;
    return {};
}

static PyObject *QModbusDevice_IntermediateError_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QModbusDevice::IntermediateError>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QModbusDevice::IntermediateError *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_IntermediateError_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QModbusDevice_PythonToCpp_QModbusDevice_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QModbusDevice_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QModbusDevice_PythonToCpp_QModbusDevice_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QModbusDevice_TypeF()))
        return QModbusDevice_PythonToCpp_QModbusDevice_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QModbusDevice_PTR_CppToPython_QModbusDevice(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QModbusDevice *>(const_cast<void *>(cppIn)), Sbk_QModbusDevice_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QModbusDevice_SignatureStrings[] = {
    "PySide6.QtSerialBus.QModbusDevice(self,parent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtSerialBus.QModbusDevice.close(self)",
    "PySide6.QtSerialBus.QModbusDevice.connectDevice(self)->bool",
    "PySide6.QtSerialBus.QModbusDevice.connectionParameter(self,parameter:PySide6.QtSerialBus.QModbusDevice.ConnectionParameter)->QVariant",
    "PySide6.QtSerialBus.QModbusDevice.device(self)->PySide6.QtCore.QIODevice",
    "PySide6.QtSerialBus.QModbusDevice.disconnectDevice(self)",
    "PySide6.QtSerialBus.QModbusDevice.error(self)->PySide6.QtSerialBus.QModbusDevice.Error",
    "PySide6.QtSerialBus.QModbusDevice.errorString(self)->QString",
    "PySide6.QtSerialBus.QModbusDevice.open(self)->bool",
    "PySide6.QtSerialBus.QModbusDevice.setConnectionParameter(self,parameter:PySide6.QtSerialBus.QModbusDevice.ConnectionParameter,value:QVariant)",
    "PySide6.QtSerialBus.QModbusDevice.setError(self,errorText:QString,error:PySide6.QtSerialBus.QModbusDevice.Error)",
    "PySide6.QtSerialBus.QModbusDevice.setState(self,newState:PySide6.QtSerialBus.QModbusDevice.State)",
    "PySide6.QtSerialBus.QModbusDevice.state(self)->PySide6.QtSerialBus.QModbusDevice.State",
    nullptr}; // Sentinel
#else
static constexpr size_t QModbusDevice_SignatureByteSize = 248;
static constexpr uint8_t QModbusDevice_SignatureBytes[248] = {
    0x78, 0xda, 0xb5, 0x93, 0x41, 0x4f, 0xc3, 0x30, 0x0c, 0x85, 0xef, 0xfb, 0x25, 0xab, 0x54, 0x7a,
    0xe4, 0x10, 0x89, 0x1d, 0x28, 0x3b, 0x70, 0x40, 0x6b, 0xd4, 0x89, 0x7b, 0xda, 0x1a, 0x14, 0x94,
    0xd9, 0x95, 0xe3, 0x0e, 0xf8, 0xf7, 0x94, 0x66, 0xab, 0x06, 0x03, 0xcd, 0x1c, 0x38, 0x3a, 0x7a,
    0xfe, 0xfc, 0xf2, 0x9c, 0x54, 0xef, 0xb5, 0xef, 0xe0, 0xba, 0xb0, 0x52, 0x03, 0x7b, 0x17, 0x6e,
    0x87, 0x58, 0xd8, 0x07, 0xea, 0x9a, 0x21, 0xde, 0xc1, 0xde, 0xb7, 0xb0, 0x8c, 0x10, 0x9e, 0xf2,
    0xde, 0x31, 0xa0, 0x98, 0x6a, 0x56, 0x97, 0xc4, 0x50, 0xd8, 0x4d, 0xf3, 0x02, 0xad, 0xdc, 0xe0,
    0x10, 0x42, 0x2f, 0x9c, 0x2d, 0xaa, 0x4b, 0xb4, 0xa2, 0x0d, 0x14, 0x13, 0x53, 0xa5, 0x26, 0xc4,
    0x71, 0xc0, 0x89, 0x93, 0xec, 0x6a, 0xd5, 0x10, 0x05, 0x7d, 0xaf, 0x27, 0xac, 0x1c, 0xbb, 0x1d,
    0x08, 0xf0, 0x7c, 0x97, 0x54, 0x9a, 0xcb, 0x90, 0xf2, 0x1c, 0x32, 0x3a, 0xb0, 0x8f, 0x6e, 0x94,
    0xa3, 0x28, 0x5c, 0x74, 0x5f, 0xac, 0x7f, 0xcf, 0xef, 0x7e, 0x93, 0x64, 0x1a, 0x90, 0x8f, 0x3f,
    0xa4, 0xa1, 0x68, 0x04, 0x66, 0xe2, 0x73, 0x03, 0xbf, 0xc9, 0xd7, 0x9f, 0x72, 0x2d, 0xb6, 0x16,
    0xf6, 0xf8, 0x7c, 0x84, 0xdb, 0x54, 0x2a, 0x9a, 0xa9, 0x07, 0xfc, 0xe3, 0x3a, 0x23, 0x48, 0xf9,
    0x4f, 0x1b, 0xcd, 0xf7, 0x2e, 0x0c, 0x60, 0x8e, 0x5b, 0xcd, 0x74, 0x6e, 0xd6, 0x73, 0xae, 0xf9,
    0x94, 0xc5, 0x16, 0xde, 0xc4, 0x1c, 0x22, 0x48, 0x27, 0x46, 0x99, 0xb6, 0x72, 0x60, 0x2d, 0x4e,
    0x0e, 0xdf, 0x11, 0xe1, 0x75, 0xaa, 0x14, 0x13, 0x26, 0x9d, 0x6a, 0xc2, 0x8c, 0x57, 0xbd, 0x93,
    0x89, 0xbb, 0xf8, 0x00, 0x07, 0x55, 0x8d, 0x7f
};
#endif

PyTypeObject *init_QModbusDevice(PyObject *module)
{
    if (SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_IDX].type != nullptr)
        return SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_IDX].type;

    Shiboken::AutoDecRef Sbk_QModbusDevice_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QModbusDevice_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QModbusDevice",
        "QModbusDevice*",
        &Sbk_QModbusDevice_spec,
        &Shiboken::callCppDestructor< QModbusDevice >,
        Sbk_QModbusDevice_Type_bases.object(),
        0);
    auto *pyType = Sbk_QModbusDevice_TypeF(); // references _Sbk_QModbusDevice_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QModbusDevice_SignatureStrings);
#else
    InitSignatureBytes(pyType, QModbusDevice_SignatureBytes, QModbusDevice_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QModbusDevice_PropertyStrings);
    SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QModbusDevice_PythonToCpp_QModbusDevice_PTR,
        is_QModbusDevice_PythonToCpp_QModbusDevice_PTR_Convertible,
        QModbusDevice_PTR_CppToPython_QModbusDevice);

    Shiboken::Conversions::registerConverterName(converter, "QModbusDevice");
    Shiboken::Conversions::registerConverterName(converter, "QModbusDevice*");
    Shiboken::Conversions::registerConverterName(converter, "QModbusDevice&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QModbusDevice).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QModbusDeviceWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QModbusDevice_TypeF(), &Sbk_QModbusDevice_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QModbusDevice_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Error'.
    const char *Error_Initializer[] = {
        "NoError",
        "ReadError",
        "WriteError",
        "ConnectionError",
        "ConfigurationError",
        "TimeoutError",
        "ProtocolError",
        "ReplyAbortedError",
        "UnknownError",
        "InvalidResponseError",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Error_InitializerValues[] = {
        uint8_t(QModbusDevice::Error::NoError),             //  0x00  0
        uint8_t(QModbusDevice::Error::ReadError),           //  0x01  1
        uint8_t(QModbusDevice::Error::WriteError),          //  0x02  2
        uint8_t(QModbusDevice::Error::ConnectionError),     //  0x03  3
        uint8_t(QModbusDevice::Error::ConfigurationError),  //  0x04  4
        uint8_t(QModbusDevice::Error::TimeoutError),        //  0x05  5
        uint8_t(QModbusDevice::Error::ProtocolError),       //  0x06  6
        uint8_t(QModbusDevice::Error::ReplyAbortedError),   //  0x07  7
        uint8_t(QModbusDevice::Error::UnknownError),        //  0x08  8
        uint8_t(QModbusDevice::Error::InvalidResponseError) //  0x09  9
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QModbusDevice_TypeF(),
        "2:PySide6.QtSerialBus.QModbusDevice.Error",
        Error_Initializer, Error_InitializerValues);
    SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_Error_IDX].type = EType;
    // Register converter for enum 'QModbusDevice::Error'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QModbusDevice_Error_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QModbusDevice_Error,
            is_Enum_PythonToCpp_QModbusDevice_Error_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QModbusDevice::Error");
        Shiboken::Conversions::registerConverterAlias(converter, "Error");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Error' enum.

    // Initialization of enum 'State'.
    const char *State_Initializer[] = {
        "UnconnectedState",
        "ConnectingState",
        "ConnectedState",
        "ClosingState",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t State_InitializerValues[] = {
        uint8_t(QModbusDevice::State::UnconnectedState), //  0x00  0
        uint8_t(QModbusDevice::State::ConnectingState),  //  0x01  1
        uint8_t(QModbusDevice::State::ConnectedState),   //  0x02  2
        uint8_t(QModbusDevice::State::ClosingState)      //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QModbusDevice_TypeF(),
        "2:PySide6.QtSerialBus.QModbusDevice.State",
        State_Initializer, State_InitializerValues);
    SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_State_IDX].type = EType;
    // Register converter for enum 'QModbusDevice::State'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QModbusDevice_State_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QModbusDevice_State,
            is_Enum_PythonToCpp_QModbusDevice_State_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QModbusDevice::State");
        Shiboken::Conversions::registerConverterAlias(converter, "State");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'State' enum.

    // Initialization of enum 'ConnectionParameter'.
    const char *ConnectionParameter_Initializer[] = {
        "SerialPortNameParameter",
        "SerialParityParameter",
        "SerialBaudRateParameter",
        "SerialDataBitsParameter",
        "SerialStopBitsParameter",
        "NetworkPortParameter",
        "NetworkAddressParameter",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ConnectionParameter_InitializerValues[] = {
        uint8_t(QModbusDevice::ConnectionParameter::SerialPortNameParameter), //  0x00  0
        uint8_t(QModbusDevice::ConnectionParameter::SerialParityParameter),   //  0x01  1
        uint8_t(QModbusDevice::ConnectionParameter::SerialBaudRateParameter), //  0x02  2
        uint8_t(QModbusDevice::ConnectionParameter::SerialDataBitsParameter), //  0x03  3
        uint8_t(QModbusDevice::ConnectionParameter::SerialStopBitsParameter), //  0x04  4
        uint8_t(QModbusDevice::ConnectionParameter::NetworkPortParameter),    //  0x05  5
        uint8_t(QModbusDevice::ConnectionParameter::NetworkAddressParameter)  //  0x06  6
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QModbusDevice_TypeF(),
        "2:PySide6.QtSerialBus.QModbusDevice.ConnectionParameter",
        ConnectionParameter_Initializer, ConnectionParameter_InitializerValues);
    SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_ConnectionParameter_IDX].type = EType;
    // Register converter for enum 'QModbusDevice::ConnectionParameter'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QModbusDevice_ConnectionParameter_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QModbusDevice_ConnectionParameter,
            is_Enum_PythonToCpp_QModbusDevice_ConnectionParameter_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QModbusDevice::ConnectionParameter");
        Shiboken::Conversions::registerConverterAlias(converter, "ConnectionParameter");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ConnectionParameter' enum.

    // Initialization of enum 'IntermediateError'.
    const char *IntermediateError_Initializer[] = {
        "ResponseCrcError",
        "ResponseRequestMismatch",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t IntermediateError_InitializerValues[] = {
        uint8_t(QModbusDevice::IntermediateError::ResponseCrcError),       //  0x00  0
        uint8_t(QModbusDevice::IntermediateError::ResponseRequestMismatch) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QModbusDevice_TypeF(),
        "2:PySide6.QtSerialBus.QModbusDevice.IntermediateError",
        IntermediateError_Initializer, IntermediateError_InitializerValues);
    SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_IntermediateError_IDX].type = EType;
    // Register converter for enum 'QModbusDevice::IntermediateError'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QModbusDevice_IntermediateError_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QModbusDevice_IntermediateError,
            is_Enum_PythonToCpp_QModbusDevice_IntermediateError_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QModbusDevice::IntermediateError");
        Shiboken::Conversions::registerConverterAlias(converter, "IntermediateError");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'IntermediateError' enum.

    PySide::Signal::registerSignals(pyType, &::QModbusDevice::staticMetaObject);
    qRegisterMetaType< ::QModbusDevice::Error >("QModbusDevice::Error");
    qRegisterMetaType< ::QModbusDevice::State >("QModbusDevice::State");
    qRegisterMetaType< ::QModbusDevice::ConnectionParameter >("QModbusDevice::ConnectionParameter");
    qRegisterMetaType< ::QModbusDevice::IntermediateError >("QModbusDevice::IntermediateError");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QModbusDevice::staticMetaObject, sizeof(QModbusDeviceWrapper));

    return pyType;
}
