// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtserialbus_python.h"

// main header
#include "qmodbusdeviceidentification_wrapper.h"

// Argument includes
#include <QList>
#include <QtSerialBus/qmodbusdeviceidentification.h>
#include <qbytearray.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QModbusDeviceIdentification_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QModbusDeviceIdentification >()))
        return -1;

    ::QModbusDeviceIdentification *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QModbusDeviceIdentification", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QModbusDeviceIdentification::QModbusDeviceIdentification()
    // 1: QModbusDeviceIdentification::QModbusDeviceIdentification(QModbusDeviceIdentification)
    if (numArgs == 0) {
        overloadId = 0; // QModbusDeviceIdentification()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDeviceIdentification_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QModbusDeviceIdentification(QModbusDeviceIdentification)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDeviceIdentification_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDeviceIdentification_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QModbusDeviceIdentification()
        {

            // QModbusDeviceIdentification()
            cptr = new ::QModbusDeviceIdentification();
            break;
        }
        case 1: // QModbusDeviceIdentification(const QModbusDeviceIdentification &QModbusDeviceIdentification)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QModbusDeviceIdentification cppArg0_local;
            ::QModbusDeviceIdentification *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QModbusDeviceIdentification(QModbusDeviceIdentification)
                cptr = new ::QModbusDeviceIdentification(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QModbusDeviceIdentification >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDeviceIdentification_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QModbusDeviceIdentificationFunc_conformityLevel(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusDeviceIdentification *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDeviceIdentification_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // conformityLevel()const
        QModbusDeviceIdentification::ConformityLevel cppResult = const_cast<const ::QModbusDeviceIdentification *>(cppSelf)->conformityLevel();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDeviceIdentification_ConformityLevel_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModbusDeviceIdentificationFunc_contains(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusDeviceIdentification *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDeviceIdentification_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QModbusDeviceIdentification::contains(uint)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArg)))) {
        overloadId = 0; // contains(uint)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "contains", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDeviceIdentification_IDX]);

    // Call function/method
    {
        uint cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // contains(uint)const
            bool cppResult = const_cast<const ::QModbusDeviceIdentification *>(cppSelf)->contains(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModbusDeviceIdentificationFunc_fromByteArray(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QModbusDeviceIdentification::fromByteArray(QByteArray)->QModbusDeviceIdentification
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // fromByteArray(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fromByteArray", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDeviceIdentification_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // fromByteArray(QByteArray)
            QModbusDeviceIdentification cppResult = ::QModbusDeviceIdentification::fromByteArray(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDeviceIdentification_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModbusDeviceIdentificationFunc_insert(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusDeviceIdentification *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDeviceIdentification_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "insert", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QModbusDeviceIdentification::insert(uint,QByteArray)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
        overloadId = 0; // insert(uint,QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "insert", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDeviceIdentification_IDX]);

    // Call function/method
    {
        uint cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QByteArray cppArg1_local;
        ::QByteArray *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // insert(uint,QByteArray)
            bool cppResult = cppSelf->insert(cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModbusDeviceIdentificationFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusDeviceIdentification *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDeviceIdentification_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QModbusDeviceIdentification *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModbusDeviceIdentificationFunc_objectIds(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusDeviceIdentification *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDeviceIdentification_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // objectIds()const
        QList<int> cppResult = const_cast<const ::QModbusDeviceIdentification *>(cppSelf)->objectIds();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_int_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModbusDeviceIdentificationFunc_remove(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusDeviceIdentification *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDeviceIdentification_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QModbusDeviceIdentification::remove(uint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArg)))) {
        overloadId = 0; // remove(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "remove", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDeviceIdentification_IDX]);

    // Call function/method
    {
        uint cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // remove(uint)
            cppSelf->remove(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QModbusDeviceIdentificationFunc_setConformityLevel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusDeviceIdentification *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDeviceIdentification_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QModbusDeviceIdentification::setConformityLevel(QModbusDeviceIdentification::ConformityLevel)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDeviceIdentification_ConformityLevel_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setConformityLevel(QModbusDeviceIdentification::ConformityLevel)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setConformityLevel", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDeviceIdentification_IDX]);

    // Call function/method
    {
        ::QModbusDeviceIdentification::ConformityLevel cppArg0 = static_cast< ::QModbusDeviceIdentification::ConformityLevel>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setConformityLevel(QModbusDeviceIdentification::ConformityLevel)
            cppSelf->setConformityLevel(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QModbusDeviceIdentificationFunc_value(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusDeviceIdentification *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDeviceIdentification_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QModbusDeviceIdentification::value(uint)const->QByteArray
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArg)))) {
        overloadId = 0; // value(uint)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "value", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDeviceIdentification_IDX]);

    // Call function/method
    {
        uint cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // value(uint)const
            QByteArray cppResult = const_cast<const ::QModbusDeviceIdentification *>(cppSelf)->value(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModbusDeviceIdentification__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QModbusDeviceIdentification *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDeviceIdentification_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDeviceIdentification_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QModbusDeviceIdentification_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QModbusDeviceIdentification_EnumFlagInfo[] = {
    "ConformityLevel:Enum",
    "ObjectId:Enum",
    "ReadDeviceIdCode:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QModbusDeviceIdentification_methods[] = {
    {"conformityLevel", reinterpret_cast<PyCFunction>(Sbk_QModbusDeviceIdentificationFunc_conformityLevel), METH_NOARGS, nullptr},
    {"contains", reinterpret_cast<PyCFunction>(Sbk_QModbusDeviceIdentificationFunc_contains), METH_O, nullptr},
    {"fromByteArray", reinterpret_cast<PyCFunction>(Sbk_QModbusDeviceIdentificationFunc_fromByteArray), METH_O|METH_STATIC, nullptr},
    {"insert", reinterpret_cast<PyCFunction>(Sbk_QModbusDeviceIdentificationFunc_insert), METH_VARARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QModbusDeviceIdentificationFunc_isValid), METH_NOARGS, nullptr},
    {"objectIds", reinterpret_cast<PyCFunction>(Sbk_QModbusDeviceIdentificationFunc_objectIds), METH_NOARGS, nullptr},
    {"remove", reinterpret_cast<PyCFunction>(Sbk_QModbusDeviceIdentificationFunc_remove), METH_O, nullptr},
    {"setConformityLevel", reinterpret_cast<PyCFunction>(Sbk_QModbusDeviceIdentificationFunc_setConformityLevel), METH_O, nullptr},
    {"value", reinterpret_cast<PyCFunction>(Sbk_QModbusDeviceIdentificationFunc_value), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QModbusDeviceIdentification__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QModbusDeviceIdentification_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QModbusDeviceIdentification_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QModbusDeviceIdentification_Type = nullptr;
static PyTypeObject *Sbk_QModbusDeviceIdentification_TypeF(void)
{
    return _Sbk_QModbusDeviceIdentification_Type;
}

static PyType_Slot Sbk_QModbusDeviceIdentification_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QModbusDeviceIdentification_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QModbusDeviceIdentification_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QModbusDeviceIdentification_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QModbusDeviceIdentification_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QModbusDeviceIdentification_spec = {
    "2:PySide6.QtSerialBus.QModbusDeviceIdentification",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QModbusDeviceIdentification_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QModbusDeviceIdentification_ObjectId(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QModbusDeviceIdentification::ObjectId>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QModbusDeviceIdentification::ObjectId *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QModbusDeviceIdentification_ObjectId_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDeviceIdentification_ObjectId_IDX])))
        return Enum_PythonToCpp_QModbusDeviceIdentification_ObjectId;
    return {};
}

static PyObject *QModbusDeviceIdentification_ObjectId_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QModbusDeviceIdentification::ObjectId>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QModbusDeviceIdentification::ObjectId *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDeviceIdentification_ObjectId_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QModbusDeviceIdentification_ReadDeviceIdCode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QModbusDeviceIdentification::ReadDeviceIdCode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QModbusDeviceIdentification::ReadDeviceIdCode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QModbusDeviceIdentification_ReadDeviceIdCode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDeviceIdentification_ReadDeviceIdCode_IDX])))
        return Enum_PythonToCpp_QModbusDeviceIdentification_ReadDeviceIdCode;
    return {};
}

static PyObject *QModbusDeviceIdentification_ReadDeviceIdCode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QModbusDeviceIdentification::ReadDeviceIdCode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QModbusDeviceIdentification::ReadDeviceIdCode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDeviceIdentification_ReadDeviceIdCode_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QModbusDeviceIdentification_ConformityLevel(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QModbusDeviceIdentification::ConformityLevel>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QModbusDeviceIdentification::ConformityLevel *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QModbusDeviceIdentification_ConformityLevel_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDeviceIdentification_ConformityLevel_IDX])))
        return Enum_PythonToCpp_QModbusDeviceIdentification_ConformityLevel;
    return {};
}

static PyObject *QModbusDeviceIdentification_ConformityLevel_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QModbusDeviceIdentification::ConformityLevel>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QModbusDeviceIdentification::ConformityLevel *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDeviceIdentification_ConformityLevel_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QModbusDeviceIdentification_PythonToCpp_QModbusDeviceIdentification_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QModbusDeviceIdentification_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QModbusDeviceIdentification_PythonToCpp_QModbusDeviceIdentification_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QModbusDeviceIdentification_TypeF()))
        return QModbusDeviceIdentification_PythonToCpp_QModbusDeviceIdentification_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QModbusDeviceIdentification_PTR_CppToPython_QModbusDeviceIdentification(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QModbusDeviceIdentification_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QModbusDeviceIdentification_COPY_CppToPython_QModbusDeviceIdentification(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QModbusDeviceIdentification *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QModbusDeviceIdentification_TypeF(), new ::QModbusDeviceIdentification(*source), true, true);
}

// Python to C++ copy conversion.
static void QModbusDeviceIdentification_PythonToCpp_QModbusDeviceIdentification_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QModbusDeviceIdentification *>(cppOut) = *reinterpret_cast< ::QModbusDeviceIdentification *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDeviceIdentification_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QModbusDeviceIdentification_PythonToCpp_QModbusDeviceIdentification_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QModbusDeviceIdentification_TypeF()))
        return QModbusDeviceIdentification_PythonToCpp_QModbusDeviceIdentification_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QModbusDeviceIdentification_SignatureStrings[] = {
    "1:PySide6.QtSerialBus.QModbusDeviceIdentification(self)",
    "0:PySide6.QtSerialBus.QModbusDeviceIdentification(self,QModbusDeviceIdentification:PySide6.QtSerialBus.QModbusDeviceIdentification)",
    "PySide6.QtSerialBus.QModbusDeviceIdentification.conformityLevel(self)->PySide6.QtSerialBus.QModbusDeviceIdentification.ConformityLevel",
    "PySide6.QtSerialBus.QModbusDeviceIdentification.contains(self,objectId:uint)->bool",
    "PySide6.QtSerialBus.QModbusDeviceIdentification.fromByteArray(ba:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtSerialBus.QModbusDeviceIdentification",
    "PySide6.QtSerialBus.QModbusDeviceIdentification.insert(self,objectId:uint,data:typing.Union[PySide6.QtCore.QByteArray, char*])->bool",
    "PySide6.QtSerialBus.QModbusDeviceIdentification.isValid(self)->bool",
    "PySide6.QtSerialBus.QModbusDeviceIdentification.objectIds(self)->QList[int]",
    "PySide6.QtSerialBus.QModbusDeviceIdentification.remove(self,objectId:uint)",
    "PySide6.QtSerialBus.QModbusDeviceIdentification.setConformityLevel(self,level:PySide6.QtSerialBus.QModbusDeviceIdentification.ConformityLevel)",
    "PySide6.QtSerialBus.QModbusDeviceIdentification.value(self,objectId:uint)->PySide6.QtCore.QByteArray",
    "PySide6.QtSerialBus.QModbusDeviceIdentification.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QModbusDeviceIdentification_SignatureByteSize = 268;
static constexpr uint8_t QModbusDeviceIdentification_SignatureBytes[268] = {
    0x78, 0xda, 0xa5, 0x92, 0x41, 0x4b, 0xc4, 0x30, 0x10, 0x85, 0xef, 0xfd, 0x15, 0x1e, 0x77, 0xa5,
    0x06, 0xbd, 0x78, 0xe8, 0x41, 0x70, 0xeb, 0x65, 0x61, 0x05, 0x4b, 0xd1, 0xcb, 0xb2, 0x94, 0x34,
    0x99, 0xea, 0x48, 0x9a, 0x59, 0x92, 0x69, 0x21, 0xff, 0xde, 0xc8, 0x5a, 0x45, 0xa8, 0x42, 0xba,
    0xb7, 0x84, 0xcc, 0x7c, 0x79, 0x6f, 0xe6, 0xdd, 0x14, 0x4f, 0xa1, 0x46, 0x0d, 0xb7, 0xa2, 0xe2,
    0x1a, 0x1c, 0x4a, 0xb3, 0x19, 0xbc, 0xa8, 0x1e, 0x49, 0xb7, 0x83, 0x7f, 0x80, 0x11, 0x15, 0x6c,
    0x35, 0x58, 0xc6, 0x0e, 0x95, 0x64, 0x24, 0xbb, 0xf2, 0x60, 0xba, 0x75, 0x76, 0xbd, 0xa8, 0x2f,
    0xff, 0xa7, 0x20, 0x15, 0xb8, 0xce, 0x12, 0x1b, 0x84, 0x22, 0xdb, 0x91, 0xeb, 0x91, 0xc3, 0x0e,
    0x46, 0x30, 0x27, 0x27, 0x57, 0x77, 0xa9, 0x98, 0xf2, 0x37, 0x66, 0x89, 0x0c, 0x96, 0x68, 0xfd,
    0x69, 0x22, 0xd4, 0xbe, 0x83, 0xe2, 0xad, 0x2e, 0x06, 0xb4, 0x1c, 0xd5, 0xb4, 0x44, 0xe9, 0xc8,
    0xce, 0x51, 0xbf, 0x09, 0x0c, 0xf7, 0xce, 0xc9, 0xb0, 0x6a, 0x65, 0xc1, 0xe1, 0x88, 0xf6, 0x55,
    0x3c, 0xdb, 0xf8, 0xba, 0xff, 0xa1, 0x95, 0xe4, 0x40, 0x54, 0xdf, 0x95, 0xf9, 0x85, 0x7a, 0x93,
    0xee, 0xf2, 0x90, 0x3e, 0x84, 0x64, 0x85, 0xd1, 0x2f, 0x38, 0x9e, 0xb1, 0x9c, 0x6b, 0xc9, 0x0b,
    0xf4, 0x2e, 0x1a, 0x13, 0xfa, 0x17, 0x69, 0x50, 0x4f, 0x8b, 0x5f, 0xc4, 0x98, 0xc4, 0xfb, 0x89,
    0x52, 0xed, 0xd0, 0xf3, 0x3e, 0x3a, 0x39, 0x24, 0xb3, 0x1c, 0xf4, 0x34, 0xc2, 0x5c, 0x0e, 0x92,
    0x51, 0x1e, 0xb8, 0x9c, 0x89, 0x77, 0x6e, 0x3e, 0x8f, 0xc5, 0x99, 0x11, 0x4f, 0x97, 0x33, 0x4a,
    0x33, 0xc0, 0x7c, 0xc0, 0xff, 0xdc, 0x6e, 0xf2, 0x27, 0x4d, 0xa3, 0xe8, 0x18, 0x9a, 0x66, 0xda,
    0xc4, 0x57, 0x88, 0xea, 0x78, 0xcb, 0x3e, 0x00, 0x70, 0xa3, 0xcc, 0x22
};
#endif

PyTypeObject *init_QModbusDeviceIdentification(PyObject *module)
{
    if (SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDeviceIdentification_IDX].type != nullptr)
        return SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDeviceIdentification_IDX].type;

    Shiboken::AutoDecRef Sbk_QModbusDeviceIdentification_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QModbusDeviceIdentification_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QModbusDeviceIdentification",
        "QModbusDeviceIdentification",
        &Sbk_QModbusDeviceIdentification_spec,
        &Shiboken::callCppDestructor< ::QModbusDeviceIdentification >,
        Sbk_QModbusDeviceIdentification_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QModbusDeviceIdentification_TypeF(); // references _Sbk_QModbusDeviceIdentification_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QModbusDeviceIdentification_SignatureStrings);
#else
    InitSignatureBytes(pyType, QModbusDeviceIdentification_SignatureBytes, QModbusDeviceIdentification_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QModbusDeviceIdentification_PropertyStrings);
    SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDeviceIdentification_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QModbusDeviceIdentification_PythonToCpp_QModbusDeviceIdentification_PTR,
        is_QModbusDeviceIdentification_PythonToCpp_QModbusDeviceIdentification_PTR_Convertible,
        QModbusDeviceIdentification_PTR_CppToPython_QModbusDeviceIdentification,
        QModbusDeviceIdentification_COPY_CppToPython_QModbusDeviceIdentification);

    Shiboken::Conversions::registerConverterName(converter, "QModbusDeviceIdentification");
    Shiboken::Conversions::registerConverterName(converter, "QModbusDeviceIdentification*");
    Shiboken::Conversions::registerConverterName(converter, "QModbusDeviceIdentification&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QModbusDeviceIdentification).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QModbusDeviceIdentification_PythonToCpp_QModbusDeviceIdentification_COPY,
        is_QModbusDeviceIdentification_PythonToCpp_QModbusDeviceIdentification_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QModbusDeviceIdentification_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'ObjectId'.
    const char *ObjectId_Initializer[] = {
        "VendorNameObjectId",
        "ProductCodeObjectId",
        "MajorMinorRevisionObjectId",
        "VendorUrlObjectId",
        "ProductNameObjectId",
        "ModelNameObjectId",
        "UserApplicationNameObjectId",
        "ReservedObjectId",
        "ProductDependentObjectId",
        "UndefinedObjectId",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t ObjectId_InitializerValues[] = {
        uint16_t(QModbusDeviceIdentification::ObjectId::VendorNameObjectId),          //  0x0000  0
        uint16_t(QModbusDeviceIdentification::ObjectId::ProductCodeObjectId),         //  0x0001  1
        uint16_t(QModbusDeviceIdentification::ObjectId::MajorMinorRevisionObjectId),  //  0x0002  2
        uint16_t(QModbusDeviceIdentification::ObjectId::VendorUrlObjectId),           //  0x0003  3
        uint16_t(QModbusDeviceIdentification::ObjectId::ProductNameObjectId),         //  0x0004  4
        uint16_t(QModbusDeviceIdentification::ObjectId::ModelNameObjectId),           //  0x0005  5
        uint16_t(QModbusDeviceIdentification::ObjectId::UserApplicationNameObjectId), //  0x0006  6
        uint16_t(QModbusDeviceIdentification::ObjectId::ReservedObjectId),            //  0x0007  7
        uint16_t(QModbusDeviceIdentification::ObjectId::ProductDependentObjectId),    //  0x0080  128
        uint16_t(QModbusDeviceIdentification::ObjectId::UndefinedObjectId)            //  0x0100  256
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QModbusDeviceIdentification_TypeF(),
        "2:PySide6.QtSerialBus.QModbusDeviceIdentification.ObjectId",
        ObjectId_Initializer, ObjectId_InitializerValues);
    SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDeviceIdentification_ObjectId_IDX].type = EType;
    // Register converter for enum 'QModbusDeviceIdentification::ObjectId'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QModbusDeviceIdentification_ObjectId_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QModbusDeviceIdentification_ObjectId,
            is_Enum_PythonToCpp_QModbusDeviceIdentification_ObjectId_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QModbusDeviceIdentification::ObjectId");
        Shiboken::Conversions::registerConverterAlias(converter, "ObjectId");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ObjectId' enum.

    // Initialization of enum 'ReadDeviceIdCode'.
    const char *ReadDeviceIdCode_Initializer[] = {
        "BasicReadDeviceIdCode",
        "RegularReadDeviceIdCode",
        "ExtendedReadDeviceIdCode",
        "IndividualReadDeviceIdCode",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ReadDeviceIdCode_InitializerValues[] = {
        uint8_t(QModbusDeviceIdentification::ReadDeviceIdCode::BasicReadDeviceIdCode),     //  0x01  1
        uint8_t(QModbusDeviceIdentification::ReadDeviceIdCode::RegularReadDeviceIdCode),   //  0x02  2
        uint8_t(QModbusDeviceIdentification::ReadDeviceIdCode::ExtendedReadDeviceIdCode),  //  0x03  3
        uint8_t(QModbusDeviceIdentification::ReadDeviceIdCode::IndividualReadDeviceIdCode) //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QModbusDeviceIdentification_TypeF(),
        "2:PySide6.QtSerialBus.QModbusDeviceIdentification.ReadDeviceIdCode",
        ReadDeviceIdCode_Initializer, ReadDeviceIdCode_InitializerValues);
    SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDeviceIdentification_ReadDeviceIdCode_IDX].type = EType;
    // Register converter for enum 'QModbusDeviceIdentification::ReadDeviceIdCode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QModbusDeviceIdentification_ReadDeviceIdCode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QModbusDeviceIdentification_ReadDeviceIdCode,
            is_Enum_PythonToCpp_QModbusDeviceIdentification_ReadDeviceIdCode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QModbusDeviceIdentification::ReadDeviceIdCode");
        Shiboken::Conversions::registerConverterAlias(converter, "ReadDeviceIdCode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ReadDeviceIdCode' enum.

    // Initialization of enum 'ConformityLevel'.
    const char *ConformityLevel_Initializer[] = {
        "BasicConformityLevel",
        "RegularConformityLevel",
        "ExtendedConformityLevel",
        "BasicIndividualConformityLevel",
        "RegularIndividualConformityLevel",
        "ExtendedIndividualConformityLevel",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ConformityLevel_InitializerValues[] = {
        uint8_t(QModbusDeviceIdentification::ConformityLevel::BasicConformityLevel),             //  0x01  1
        uint8_t(QModbusDeviceIdentification::ConformityLevel::RegularConformityLevel),           //  0x02  2
        uint8_t(QModbusDeviceIdentification::ConformityLevel::ExtendedConformityLevel),          //  0x03  3
        uint8_t(QModbusDeviceIdentification::ConformityLevel::BasicIndividualConformityLevel),   //  0x81  129
        uint8_t(QModbusDeviceIdentification::ConformityLevel::RegularIndividualConformityLevel), //  0x82  130
        uint8_t(QModbusDeviceIdentification::ConformityLevel::ExtendedIndividualConformityLevel) //  0x83  131
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QModbusDeviceIdentification_TypeF(),
        "2:PySide6.QtSerialBus.QModbusDeviceIdentification.ConformityLevel",
        ConformityLevel_Initializer, ConformityLevel_InitializerValues);
    SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDeviceIdentification_ConformityLevel_IDX].type = EType;
    // Register converter for enum 'QModbusDeviceIdentification::ConformityLevel'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QModbusDeviceIdentification_ConformityLevel_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QModbusDeviceIdentification_ConformityLevel,
            is_Enum_PythonToCpp_QModbusDeviceIdentification_ConformityLevel_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QModbusDeviceIdentification::ConformityLevel");
        Shiboken::Conversions::registerConverterAlias(converter, "ConformityLevel");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ConformityLevel' enum.

    qRegisterMetaType< ::QModbusDeviceIdentification >("QModbusDeviceIdentification");
    qRegisterMetaType< ::QModbusDeviceIdentification::ObjectId >("QModbusDeviceIdentification::ObjectId");
    qRegisterMetaType< ::QModbusDeviceIdentification::ReadDeviceIdCode >("QModbusDeviceIdentification::ReadDeviceIdCode");
    qRegisterMetaType< ::QModbusDeviceIdentification::ConformityLevel >("QModbusDeviceIdentification::ConformityLevel");

    return pyType;
}
