// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtserialbus_python.h"

// main header
#include "qmodbuspdu_wrapper.h"

// Argument includes
#include <QtSerialBus/qmodbuspdu.h>
#include <qbytearray.h>
#include <qdatastream.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QModbusPduWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QModbusPduWrapper::QModbusPduWrapper()
{
}

QModbusPduWrapper::QModbusPduWrapper(::QModbusPdu::FunctionCode code, const ::QByteArray & newData) : QModbusPdu(code, newData)
{
}

void QModbusPduWrapper::setFunctionCode(::QModbusPdu::FunctionCode code)
{
    if (m_PyMethodCache[0]) {
        return this->::QModbusPdu::setFunctionCode(code);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setFunctionCode";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QModbusPdu::setFunctionCode(code);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_FunctionCode_IDX])))->converter, &code)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_FunctionCode_IDX])))->converter, &code)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QModbusPdu", funcName);
        return;
    }
}

QModbusPduWrapper::~QModbusPduWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QModbusPdu_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QModbusPdu >()))
        return -1;

    QModbusPduWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QModbusPdu", 0, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QModbusPdu::QModbusPdu()
    // 1: QModbusPdu::QModbusPdu(QModbusPdu::FunctionCode,QByteArray)
    // 2: QModbusPdu::QModbusPdu(QModbusPdu)
    if (numArgs == 0) {
        overloadId = 0; // QModbusPdu()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QModbusPdu(QModbusPdu)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_FunctionCode_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
        overloadId = 1; // QModbusPdu(QModbusPdu::FunctionCode,QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QModbusPdu()
        {

            // QModbusPdu()
            cptr = new QModbusPduWrapper();
            break;
        }
        case 1: // QModbusPdu(QModbusPdu::FunctionCode code, const QByteArray &newData)
        {
            ::QModbusPdu::FunctionCode cppArg0{QModbusPdu::Invalid};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QByteArray cppArg1_local;
            ::QByteArray *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QModbusPdu(QModbusPdu::FunctionCode,QByteArray)
                cptr = new QModbusPduWrapper(cppArg0, *cppArg1);
            }
            break;
        }
        case 2: // QModbusPdu(const QModbusPdu &arg__1)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QModbusPdu *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QModbusPdu(QModbusPdu)
                cptr = new QModbusPduWrapper(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QModbusPdu >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QModbusPduFunc_data(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusPdu *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // data()const
        QByteArray cppResult = const_cast<const ::QModbusPdu *>(cppSelf)->data();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModbusPduFunc_dataSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusPdu *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // dataSize()const
        qint16 cppResult = const_cast<const ::QModbusPdu *>(cppSelf)->dataSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint16>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModbusPduFunc_exceptionCode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusPdu *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // exceptionCode()const
        QModbusPdu::ExceptionCode cppResult = const_cast<const ::QModbusPdu *>(cppSelf)->exceptionCode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_ExceptionCode_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModbusPduFunc_functionCode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusPdu *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // functionCode()const
        QModbusPdu::FunctionCode cppResult = const_cast<const ::QModbusPdu *>(cppSelf)->functionCode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_FunctionCode_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModbusPduFunc_isException(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusPdu *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isException()const
        bool cppResult = const_cast<const ::QModbusPdu *>(cppSelf)->isException();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModbusPduFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusPdu *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QModbusPdu *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModbusPduFunc_setData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusPdu *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QModbusPdu::setData(QByteArray)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // setData(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setData", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setData(QByteArray)
            cppSelf->setData(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QModbusPduFunc_setFunctionCode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusPdu *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QModbusPdu::setFunctionCode(QModbusPdu::FunctionCode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_FunctionCode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setFunctionCode(QModbusPdu::FunctionCode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFunctionCode", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_IDX]);

    // Call function/method
    {
        ::QModbusPdu::FunctionCode cppArg0{QModbusPdu::Invalid};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFunctionCode(QModbusPdu::FunctionCode)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QModbusPdu::setFunctionCode(cppArg0)
                : cppSelf->setFunctionCode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QModbusPduFunc_size(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusPdu *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // size()const
        qint16 cppResult = const_cast<const ::QModbusPdu *>(cppSelf)->size();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint16>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QModbusPdu_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QModbusPdu_EnumFlagInfo[] = {
    "ExceptionCode:Enum",
    "FunctionCode:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QModbusPdu_methods[] = {
    {"data", reinterpret_cast<PyCFunction>(Sbk_QModbusPduFunc_data), METH_NOARGS, nullptr},
    {"dataSize", reinterpret_cast<PyCFunction>(Sbk_QModbusPduFunc_dataSize), METH_NOARGS, nullptr},
    {"exceptionCode", reinterpret_cast<PyCFunction>(Sbk_QModbusPduFunc_exceptionCode), METH_NOARGS, nullptr},
    {"functionCode", reinterpret_cast<PyCFunction>(Sbk_QModbusPduFunc_functionCode), METH_NOARGS, nullptr},
    {"isException", reinterpret_cast<PyCFunction>(Sbk_QModbusPduFunc_isException), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QModbusPduFunc_isValid), METH_NOARGS, nullptr},
    {"setData", reinterpret_cast<PyCFunction>(Sbk_QModbusPduFunc_setData), METH_O, nullptr},
    {"setFunctionCode", reinterpret_cast<PyCFunction>(Sbk_QModbusPduFunc_setFunctionCode), METH_O, nullptr},
    {"size", reinterpret_cast<PyCFunction>(Sbk_QModbusPduFunc_size), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QModbusPdu_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QModbusPdu *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QModbusPduWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

static PyObject *Sbk_QModbusPduFunc___lshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusPdu *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rlshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QModbusPdu::operator<<(QDataStream&)->QDataStream&
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // operator<<(QDataStream&,QModbusPdu)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator<<", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator<<(QDataStream&,QModbusPdu) [reverse operator]
                QDataStream & cppResult = (*cppArg0) << (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

} // extern "C"

static int Sbk_QModbusPdu_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QModbusPdu_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QModbusPdu__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusPdu *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QModbusPdu_Type = nullptr;
static PyTypeObject *Sbk_QModbusPdu_TypeF(void)
{
    return _Sbk_QModbusPdu_Type;
}

static PyType_Slot Sbk_QModbusPdu_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QModbusPdu__repr__)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QModbusPdu_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QModbusPdu_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QModbusPdu_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QModbusPdu_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QModbusPdu_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_lshift,      reinterpret_cast<void *>(Sbk_QModbusPduFunc___lshift__)},
    {0, nullptr}
};
static PyType_Spec Sbk_QModbusPdu_spec = {
    "2:PySide6.QtSerialBus.QModbusPdu",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QModbusPdu_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QModbusPdu_ExceptionCode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QModbusPdu::ExceptionCode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QModbusPdu::ExceptionCode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QModbusPdu_ExceptionCode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_ExceptionCode_IDX])))
        return Enum_PythonToCpp_QModbusPdu_ExceptionCode;
    return {};
}

static PyObject *QModbusPdu_ExceptionCode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QModbusPdu::ExceptionCode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QModbusPdu::ExceptionCode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_ExceptionCode_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QModbusPdu_FunctionCode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QModbusPdu::FunctionCode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QModbusPdu::FunctionCode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QModbusPdu_FunctionCode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_FunctionCode_IDX])))
        return Enum_PythonToCpp_QModbusPdu_FunctionCode;
    return {};
}

static PyObject *QModbusPdu_FunctionCode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QModbusPdu::FunctionCode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QModbusPdu::FunctionCode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_FunctionCode_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QModbusPdu_PythonToCpp_QModbusPdu_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QModbusPdu_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QModbusPdu_PythonToCpp_QModbusPdu_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QModbusPdu_TypeF()))
        return QModbusPdu_PythonToCpp_QModbusPdu_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QModbusPdu_PTR_CppToPython_QModbusPdu(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QModbusPdu *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QModbusPdu_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QModbusPdu_SignatureStrings[] = {
    "2:PySide6.QtSerialBus.QModbusPdu(self)",
    "1:PySide6.QtSerialBus.QModbusPdu(self,code:PySide6.QtSerialBus.QModbusPdu.FunctionCode,newData:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "0:PySide6.QtSerialBus.QModbusPdu(self,arg__1:PySide6.QtSerialBus.QModbusPdu)",
    "PySide6.QtSerialBus.QModbusPdu.data(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtSerialBus.QModbusPdu.dataSize(self)->qint16",
    "PySide6.QtSerialBus.QModbusPdu.exceptionCode(self)->PySide6.QtSerialBus.QModbusPdu.ExceptionCode",
    "PySide6.QtSerialBus.QModbusPdu.functionCode(self)->PySide6.QtSerialBus.QModbusPdu.FunctionCode",
    "PySide6.QtSerialBus.QModbusPdu.isException(self)->bool",
    "PySide6.QtSerialBus.QModbusPdu.isValid(self)->bool",
    "PySide6.QtSerialBus.QModbusPdu.setData(self,newData:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "PySide6.QtSerialBus.QModbusPdu.setFunctionCode(self,code:PySide6.QtSerialBus.QModbusPdu.FunctionCode)",
    "PySide6.QtSerialBus.QModbusPdu.size(self)->qint16",
    "PySide6.QtSerialBus.QModbusPdu.__lshift__(self,stream:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    nullptr}; // Sentinel
#else
static constexpr size_t QModbusPdu_SignatureByteSize = 255;
static constexpr uint8_t QModbusPdu_SignatureBytes[255] = {
    0x78, 0xda, 0x9d, 0x92, 0x41, 0x4f, 0xc3, 0x30, 0x0c, 0x85, 0xef, 0xfd, 0x15, 0x3b, 0xd2, 0xa9,
    0x44, 0x8c, 0xc3, 0x0e, 0x3d, 0x20, 0xb1, 0x8d, 0xdd, 0x90, 0x56, 0x55, 0x70, 0x41, 0x28, 0xca,
    0x1a, 0x77, 0xb3, 0x14, 0x92, 0x91, 0xb8, 0xda, 0xca, 0xaf, 0xa7, 0x30, 0x95, 0x55, 0x63, 0xc8,
    0x2d, 0x67, 0xfb, 0x3d, 0x7f, 0x7e, 0xf6, 0x6d, 0xba, 0xaa, 0x73, 0xd4, 0x30, 0x15, 0x19, 0xe5,
    0xe0, 0x51, 0x99, 0x59, 0x15, 0x44, 0xf6, 0xe8, 0xf4, 0xba, 0x0a, 0x2b, 0x5d, 0x5d, 0x05, 0x30,
    0x65, 0x1c, 0x4d, 0xfa, 0xb4, 0x25, 0x85, 0xd3, 0xc0, 0x34, 0x8a, 0x65, 0x65, 0x0b, 0x42, 0x67,
    0xe7, 0x4d, 0x6f, 0x62, 0x61, 0xbf, 0x50, 0xa4, 0x52, 0xaa, 0x77, 0x68, 0x37, 0xe2, 0xc9, 0x36,
    0x85, 0x97, 0x93, 0xc1, 0xdc, 0x79, 0x10, 0xd9, 0xac, 0x26, 0xb8, 0xf7, 0x5e, 0xd5, 0xc9, 0xa8,
    0xd8, 0x2a, 0x3f, 0x7e, 0x8d, 0xa3, 0x9b, 0x5e, 0x38, 0xca, 0x6f, 0xa4, 0xe4, 0xc8, 0xe3, 0x88,
    0x01, 0xd6, 0x0d, 0xe0, 0x31, 0x85, 0xeb, 0xbb, 0x3f, 0xd1, 0xfa, 0x98, 0xe4, 0xf8, 0x01, 0xad,
    0xd1, 0x3b, 0x5a, 0x9a, 0x4c, 0x39, 0x15, 0x1c, 0x0a, 0xd8, 0xb5, 0x61, 0xfd, 0x66, 0xb8, 0xa8,
    0x79, 0xe8, 0x6a, 0xb8, 0x01, 0x65, 0xe7, 0x18, 0x3d, 0xfd, 0xbb, 0xf7, 0xe3, 0xec, 0x31, 0xfc,
    0xd0, 0xb4, 0xee, 0x6b, 0xe7, 0x0c, 0x2f, 0x7b, 0x56, 0x06, 0xf5, 0x10, 0x49, 0x00, 0x5a, 0xb4,
    0x77, 0xfa, 0xf7, 0x57, 0xf1, 0x33, 0x96, 0xe7, 0x79, 0x0d, 0x7e, 0x79, 0x7e, 0xca, 0xe0, 0x2f,
    0x91, 0xd2, 0x84, 0x2d, 0x96, 0x24, 0xe5, 0x11, 0x29, 0x90, 0x07, 0xf5, 0x96, 0x9e, 0x2f, 0xfc,
    0x15, 0x49, 0xfe, 0x5d, 0xba, 0xf0, 0xc8, 0xa7, 0x62, 0xf4, 0x09, 0x23, 0xbb, 0x75, 0xc7
};
#endif

PyTypeObject *init_QModbusPdu(PyObject *module)
{
    if (SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_IDX].type != nullptr)
        return SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_IDX].type;

    Shiboken::AutoDecRef Sbk_QModbusPdu_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QModbusPdu_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QModbusPdu",
        "QModbusPdu*",
        &Sbk_QModbusPdu_spec,
        &Shiboken::callCppDestructor< QModbusPdu >,
        Sbk_QModbusPdu_Type_bases.object(),
        0);
    auto *pyType = Sbk_QModbusPdu_TypeF(); // references _Sbk_QModbusPdu_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QModbusPdu_SignatureStrings);
#else
    InitSignatureBytes(pyType, QModbusPdu_SignatureBytes, QModbusPdu_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QModbusPdu_PropertyStrings);
    SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QModbusPdu_PythonToCpp_QModbusPdu_PTR,
        is_QModbusPdu_PythonToCpp_QModbusPdu_PTR_Convertible,
        QModbusPdu_PTR_CppToPython_QModbusPdu);

    Shiboken::Conversions::registerConverterName(converter, "QModbusPdu");
    Shiboken::Conversions::registerConverterName(converter, "QModbusPdu*");
    Shiboken::Conversions::registerConverterName(converter, "QModbusPdu&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QModbusPdu).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QModbusPduWrapper).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QModbusPdu_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'ExceptionCode'.
    const char *ExceptionCode_Initializer[] = {
        "IllegalFunction",
        "IllegalDataAddress",
        "IllegalDataValue",
        "ServerDeviceFailure",
        "Acknowledge",
        "ServerDeviceBusy",
        "NegativeAcknowledge",
        "MemoryParityError",
        "GatewayPathUnavailable",
        "GatewayTargetDeviceFailedToRespond",
        "ExtendedException",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ExceptionCode_InitializerValues[] = {
        uint8_t(QModbusPdu::ExceptionCode::IllegalFunction),                    //  0x01  1
        uint8_t(QModbusPdu::ExceptionCode::IllegalDataAddress),                 //  0x02  2
        uint8_t(QModbusPdu::ExceptionCode::IllegalDataValue),                   //  0x03  3
        uint8_t(QModbusPdu::ExceptionCode::ServerDeviceFailure),                //  0x04  4
        uint8_t(QModbusPdu::ExceptionCode::Acknowledge),                        //  0x05  5
        uint8_t(QModbusPdu::ExceptionCode::ServerDeviceBusy),                   //  0x06  6
        uint8_t(QModbusPdu::ExceptionCode::NegativeAcknowledge),                //  0x07  7
        uint8_t(QModbusPdu::ExceptionCode::MemoryParityError),                  //  0x08  8
        uint8_t(QModbusPdu::ExceptionCode::GatewayPathUnavailable),             //  0x0a  10
        uint8_t(QModbusPdu::ExceptionCode::GatewayTargetDeviceFailedToRespond), //  0x0b  11
        uint8_t(QModbusPdu::ExceptionCode::ExtendedException)                   //  0xff  255
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QModbusPdu_TypeF(),
        "2:PySide6.QtSerialBus.QModbusPdu.ExceptionCode",
        ExceptionCode_Initializer, ExceptionCode_InitializerValues);
    SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_ExceptionCode_IDX].type = EType;
    // Register converter for enum 'QModbusPdu::ExceptionCode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QModbusPdu_ExceptionCode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QModbusPdu_ExceptionCode,
            is_Enum_PythonToCpp_QModbusPdu_ExceptionCode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QModbusPdu::ExceptionCode");
        Shiboken::Conversions::registerConverterAlias(converter, "ExceptionCode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ExceptionCode' enum.

    // Initialization of enum 'FunctionCode'.
    const char *FunctionCode_Initializer[] = {
        "Invalid",
        "ReadCoils",
        "ReadDiscreteInputs",
        "ReadHoldingRegisters",
        "ReadInputRegisters",
        "WriteSingleCoil",
        "WriteSingleRegister",
        "ReadExceptionStatus",
        "Diagnostics",
        "GetCommEventCounter",
        "GetCommEventLog",
        "WriteMultipleCoils",
        "WriteMultipleRegisters",
        "ReportServerId",
        "ReadFileRecord",
        "WriteFileRecord",
        "MaskWriteRegister",
        "ReadWriteMultipleRegisters",
        "ReadFifoQueue",
        "EncapsulatedInterfaceTransport",
        "UndefinedFunctionCode",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t FunctionCode_InitializerValues[] = {
        uint16_t(QModbusPdu::FunctionCode::Invalid),                        //  0x0000  0
        uint16_t(QModbusPdu::FunctionCode::ReadCoils),                      //  0x0001  1
        uint16_t(QModbusPdu::FunctionCode::ReadDiscreteInputs),             //  0x0002  2
        uint16_t(QModbusPdu::FunctionCode::ReadHoldingRegisters),           //  0x0003  3
        uint16_t(QModbusPdu::FunctionCode::ReadInputRegisters),             //  0x0004  4
        uint16_t(QModbusPdu::FunctionCode::WriteSingleCoil),                //  0x0005  5
        uint16_t(QModbusPdu::FunctionCode::WriteSingleRegister),            //  0x0006  6
        uint16_t(QModbusPdu::FunctionCode::ReadExceptionStatus),            //  0x0007  7
        uint16_t(QModbusPdu::FunctionCode::Diagnostics),                    //  0x0008  8
        uint16_t(QModbusPdu::FunctionCode::GetCommEventCounter),            //  0x000b  11
        uint16_t(QModbusPdu::FunctionCode::GetCommEventLog),                //  0x000c  12
        uint16_t(QModbusPdu::FunctionCode::WriteMultipleCoils),             //  0x000f  15
        uint16_t(QModbusPdu::FunctionCode::WriteMultipleRegisters),         //  0x0010  16
        uint16_t(QModbusPdu::FunctionCode::ReportServerId),                 //  0x0011  17
        uint16_t(QModbusPdu::FunctionCode::ReadFileRecord),                 //  0x0014  20
        uint16_t(QModbusPdu::FunctionCode::WriteFileRecord),                //  0x0015  21
        uint16_t(QModbusPdu::FunctionCode::MaskWriteRegister),              //  0x0016  22
        uint16_t(QModbusPdu::FunctionCode::ReadWriteMultipleRegisters),     //  0x0017  23
        uint16_t(QModbusPdu::FunctionCode::ReadFifoQueue),                  //  0x0018  24
        uint16_t(QModbusPdu::FunctionCode::EncapsulatedInterfaceTransport), //  0x002b  43
        uint16_t(QModbusPdu::FunctionCode::UndefinedFunctionCode)           //  0x0100  256
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QModbusPdu_TypeF(),
        "2:PySide6.QtSerialBus.QModbusPdu.FunctionCode",
        FunctionCode_Initializer, FunctionCode_InitializerValues);
    SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_FunctionCode_IDX].type = EType;
    // Register converter for enum 'QModbusPdu::FunctionCode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QModbusPdu_FunctionCode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QModbusPdu_FunctionCode,
            is_Enum_PythonToCpp_QModbusPdu_FunctionCode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QModbusPdu::FunctionCode");
        Shiboken::Conversions::registerConverterAlias(converter, "FunctionCode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'FunctionCode' enum.

    qRegisterMetaType< ::QModbusPdu *>();
    qRegisterMetaType< ::QModbusPdu::ExceptionCode >("QModbusPdu::ExceptionCode");
    qRegisterMetaType< ::QModbusPdu::FunctionCode >("QModbusPdu::FunctionCode");

    return pyType;
}
