// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtserialport_python.h"

// main header
#include "qserialportinfo_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtSerialPort/qserialport.h>
#include <QtSerialPort/qserialportinfo.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSerialPortInfo_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSerialPortInfo >()))
        return -1;

    ::QSerialPortInfo *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QSerialPortInfo", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QSerialPortInfo::QSerialPortInfo()
    // 1: QSerialPortInfo::QSerialPortInfo(QSerialPort)
    // 2: QSerialPortInfo::QSerialPortInfo(QSerialPortInfo)
    // 3: QSerialPortInfo::QSerialPortInfo(QString)
    if (numArgs == 0) {
        overloadId = 0; // QSerialPortInfo()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 3; // QSerialPortInfo(QString)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPortInfo_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QSerialPortInfo(QSerialPortInfo)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QSerialPortInfo(QSerialPort)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPortInfo_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPortInfo_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QSerialPortInfo()
        {

            // QSerialPortInfo()
            cptr = new ::QSerialPortInfo();
            break;
        }
        case 1: // QSerialPortInfo(const QSerialPort &port)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QSerialPort *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QSerialPortInfo(QSerialPort)
                cptr = new ::QSerialPortInfo(*cppArg0);
            }
            break;
        }
        case 2: // QSerialPortInfo(const QSerialPortInfo &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QSerialPortInfo cppArg0_local;
            ::QSerialPortInfo *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QSerialPortInfo(QSerialPortInfo)
                cptr = new ::QSerialPortInfo(*cppArg0);
            }
            break;
        }
        case 3: // QSerialPortInfo(const QString &name)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QSerialPortInfo(QString)
                cptr = new ::QSerialPortInfo(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QSerialPortInfo >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPortInfo_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSerialPortInfoFunc_availablePorts(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // availablePorts()
        QList<QSerialPortInfo> cppResult = ::QSerialPortInfo::availablePorts();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtSerialPortTypeConverters[SBK_QtSerialPort_QList_QSerialPortInfo_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSerialPortInfoFunc_description(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPortInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPortInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // description()const
        QString cppResult = const_cast<const ::QSerialPortInfo *>(cppSelf)->description();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSerialPortInfoFunc_hasProductIdentifier(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPortInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPortInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hasProductIdentifier()const
        bool cppResult = const_cast<const ::QSerialPortInfo *>(cppSelf)->hasProductIdentifier();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSerialPortInfoFunc_hasVendorIdentifier(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPortInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPortInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hasVendorIdentifier()const
        bool cppResult = const_cast<const ::QSerialPortInfo *>(cppSelf)->hasVendorIdentifier();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSerialPortInfoFunc_isNull(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPortInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPortInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isNull()const
        bool cppResult = const_cast<const ::QSerialPortInfo *>(cppSelf)->isNull();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSerialPortInfoFunc_manufacturer(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPortInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPortInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // manufacturer()const
        QString cppResult = const_cast<const ::QSerialPortInfo *>(cppSelf)->manufacturer();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSerialPortInfoFunc_portName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPortInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPortInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // portName()const
        QString cppResult = const_cast<const ::QSerialPortInfo *>(cppSelf)->portName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSerialPortInfoFunc_productIdentifier(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPortInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPortInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // productIdentifier()const
        quint16 cppResult = const_cast<const ::QSerialPortInfo *>(cppSelf)->productIdentifier();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSerialPortInfoFunc_serialNumber(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPortInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPortInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // serialNumber()const
        QString cppResult = const_cast<const ::QSerialPortInfo *>(cppSelf)->serialNumber();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSerialPortInfoFunc_standardBaudRates(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // standardBaudRates()
        QList<qint32> cppResult = ::QSerialPortInfo::standardBaudRates();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtSerialPortTypeConverters[SBK_QtSerialPort_QList_qint32_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSerialPortInfoFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPortInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPortInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSerialPortInfo::swap(QSerialPortInfo&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPortInfo_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QSerialPortInfo&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPortInfo_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSerialPortInfo cppArg0_local;
        ::QSerialPortInfo *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QSerialPortInfo&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSerialPortInfoFunc_systemLocation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPortInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPortInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // systemLocation()const
        QString cppResult = const_cast<const ::QSerialPortInfo *>(cppSelf)->systemLocation();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSerialPortInfoFunc_vendorIdentifier(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPortInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPortInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // vendorIdentifier()const
        quint16 cppResult = const_cast<const ::QSerialPortInfo *>(cppSelf)->vendorIdentifier();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSerialPortInfo__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QSerialPortInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPortInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPortInfo_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QSerialPortInfo_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSerialPortInfo_methods[] = {
    {"availablePorts", reinterpret_cast<PyCFunction>(Sbk_QSerialPortInfoFunc_availablePorts), METH_NOARGS|METH_STATIC, nullptr},
    {"description", reinterpret_cast<PyCFunction>(Sbk_QSerialPortInfoFunc_description), METH_NOARGS, nullptr},
    {"hasProductIdentifier", reinterpret_cast<PyCFunction>(Sbk_QSerialPortInfoFunc_hasProductIdentifier), METH_NOARGS, nullptr},
    {"hasVendorIdentifier", reinterpret_cast<PyCFunction>(Sbk_QSerialPortInfoFunc_hasVendorIdentifier), METH_NOARGS, nullptr},
    {"isNull", reinterpret_cast<PyCFunction>(Sbk_QSerialPortInfoFunc_isNull), METH_NOARGS, nullptr},
    {"manufacturer", reinterpret_cast<PyCFunction>(Sbk_QSerialPortInfoFunc_manufacturer), METH_NOARGS, nullptr},
    {"portName", reinterpret_cast<PyCFunction>(Sbk_QSerialPortInfoFunc_portName), METH_NOARGS, nullptr},
    {"productIdentifier", reinterpret_cast<PyCFunction>(Sbk_QSerialPortInfoFunc_productIdentifier), METH_NOARGS, nullptr},
    {"serialNumber", reinterpret_cast<PyCFunction>(Sbk_QSerialPortInfoFunc_serialNumber), METH_NOARGS, nullptr},
    {"standardBaudRates", reinterpret_cast<PyCFunction>(Sbk_QSerialPortInfoFunc_standardBaudRates), METH_NOARGS|METH_STATIC, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QSerialPortInfoFunc_swap), METH_O, nullptr},
    {"systemLocation", reinterpret_cast<PyCFunction>(Sbk_QSerialPortInfoFunc_systemLocation), METH_NOARGS, nullptr},
    {"vendorIdentifier", reinterpret_cast<PyCFunction>(Sbk_QSerialPortInfoFunc_vendorIdentifier), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QSerialPortInfo__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QSerialPortInfo___nb_bool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QSerialPortInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPortInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return !cppSelf->isNull() ? 1 : 0;
}

} // extern "C"

static int Sbk_QSerialPortInfo_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSerialPortInfo_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSerialPortInfo_Type = nullptr;
static PyTypeObject *Sbk_QSerialPortInfo_TypeF(void)
{
    return _Sbk_QSerialPortInfo_Type;
}

static PyType_Slot Sbk_QSerialPortInfo_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSerialPortInfo_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSerialPortInfo_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSerialPortInfo_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSerialPortInfo_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_bool,        reinterpret_cast<void *>(Sbk_QSerialPortInfo___nb_bool)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSerialPortInfo_spec = {
    "2:PySide6.QtSerialPort.QSerialPortInfo",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSerialPortInfo_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSerialPortInfo_PythonToCpp_QSerialPortInfo_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSerialPortInfo_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSerialPortInfo_PythonToCpp_QSerialPortInfo_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSerialPortInfo_TypeF()))
        return QSerialPortInfo_PythonToCpp_QSerialPortInfo_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSerialPortInfo_PTR_CppToPython_QSerialPortInfo(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QSerialPortInfo_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QSerialPortInfo_COPY_CppToPython_QSerialPortInfo(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QSerialPortInfo *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QSerialPortInfo_TypeF(), new ::QSerialPortInfo(*source), true, true);
}

// Python to C++ copy conversion.
static void QSerialPortInfo_PythonToCpp_QSerialPortInfo_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QSerialPortInfo *>(cppOut) = *reinterpret_cast< ::QSerialPortInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPortInfo_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QSerialPortInfo_PythonToCpp_QSerialPortInfo_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QSerialPortInfo_TypeF()))
        return QSerialPortInfo_PythonToCpp_QSerialPortInfo_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSerialPortInfo_SignatureStrings[] = {
    "3:PySide6.QtSerialPort.QSerialPortInfo(self)",
    "2:PySide6.QtSerialPort.QSerialPortInfo(self,port:PySide6.QtSerialPort.QSerialPort)",
    "1:PySide6.QtSerialPort.QSerialPortInfo(self,other:PySide6.QtSerialPort.QSerialPortInfo)",
    "0:PySide6.QtSerialPort.QSerialPortInfo(self,name:QString)",
    "PySide6.QtSerialPort.QSerialPortInfo.availablePorts()->QList[PySide6.QtSerialPort.QSerialPortInfo]",
    "PySide6.QtSerialPort.QSerialPortInfo.description(self)->QString",
    "PySide6.QtSerialPort.QSerialPortInfo.hasProductIdentifier(self)->bool",
    "PySide6.QtSerialPort.QSerialPortInfo.hasVendorIdentifier(self)->bool",
    "PySide6.QtSerialPort.QSerialPortInfo.isNull(self)->bool",
    "PySide6.QtSerialPort.QSerialPortInfo.manufacturer(self)->QString",
    "PySide6.QtSerialPort.QSerialPortInfo.portName(self)->QString",
    "PySide6.QtSerialPort.QSerialPortInfo.productIdentifier(self)->quint16",
    "PySide6.QtSerialPort.QSerialPortInfo.serialNumber(self)->QString",
    "PySide6.QtSerialPort.QSerialPortInfo.standardBaudRates()->QList[qint32]",
    "PySide6.QtSerialPort.QSerialPortInfo.swap(self,other:PySide6.QtSerialPort.QSerialPortInfo)",
    "PySide6.QtSerialPort.QSerialPortInfo.systemLocation(self)->QString",
    "PySide6.QtSerialPort.QSerialPortInfo.vendorIdentifier(self)->quint16",
    "PySide6.QtSerialPort.QSerialPortInfo.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QSerialPortInfo_SignatureByteSize = 275;
static constexpr uint8_t QSerialPortInfo_SignatureBytes[275] = {
    0x78, 0xda, 0xa5, 0x93, 0x31, 0x6b, 0xc3, 0x30, 0x10, 0x85, 0x77, 0xff, 0x92, 0x08, 0x5a, 0xd3,
    0x24, 0x90, 0x21, 0x43, 0x87, 0x6e, 0x81, 0x60, 0xec, 0x1a, 0xba, 0x94, 0x62, 0xce, 0xd6, 0xb9,
    0x39, 0x90, 0x25, 0x47, 0x3a, 0xa5, 0xf8, 0xdf, 0x57, 0x69, 0x08, 0xe9, 0x12, 0x2a, 0xb9, 0x9b,
    0xcf, 0xdc, 0xfb, 0xee, 0xf4, 0xf4, 0xb4, 0xde, 0x96, 0x53, 0x4d, 0x12, 0x37, 0x79, 0xc5, 0x35,
    0x5a, 0x02, 0x55, 0x1a, 0xcb, 0x79, 0x75, 0xfb, 0xde, 0xe9, 0xde, 0x2c, 0x1c, 0xaa, 0x5e, 0x64,
    0xab, 0xf8, 0xe6, 0x87, 0x31, 0x54, 0x7f, 0xb6, 0x8b, 0x6c, 0x99, 0x80, 0x34, 0x7c, 0x40, 0x1b,
    0xd5, 0x2f, 0xb2, 0xa7, 0x04, 0xae, 0x86, 0x01, 0xb7, 0x55, 0xcd, 0x96, 0xf4, 0xa7, 0xc8, 0x62,
    0x74, 0x39, 0x9c, 0x80, 0x14, 0xb4, 0x0a, 0xcf, 0x7f, 0xdc, 0x42, 0x3c, 0x3e, 0x57, 0x7b, 0x72,
    0xfc, 0x1e, 0x23, 0xfe, 0x88, 0x1b, 0x21, 0xd1, 0x75, 0x96, 0x46, 0x26, 0xa3, 0x2f, 0xf6, 0x87,
    0x19, 0x97, 0x1d, 0xe3, 0xf4, 0x07, 0x70, 0xa5, 0x35, 0xd2, 0x77, 0xbc, 0x93, 0xa8, 0x99, 0x7a,
    0x42, 0x7b, 0x05, 0xb5, 0xc6, 0xa8, 0x68, 0xca, 0x1b, 0x6a, 0x69, 0xec, 0x7f, 0x20, 0xe4, 0x0a,
    0xaf, 0x54, 0xba, 0x6e, 0x00, 0xed, 0x7b, 0xe8, 0xd8, 0xdb, 0xdb, 0xd4, 0x24, 0x0f, 0xce, 0x21,
    0x2c, 0xc2, 0xed, 0xce, 0x13, 0xdf, 0x73, 0xef, 0xe8, 0x49, 0xf3, 0x72, 0x13, 0x47, 0x71, 0x3f,
    0x65, 0xe1, 0x87, 0x76, 0xe6, 0x19, 0x1c, 0x83, 0x96, 0x60, 0xe5, 0x0b, 0x78, 0xf9, 0x0a, 0x8c,
    0xbf, 0xd2, 0x76, 0x0c, 0x7b, 0xac, 0x57, 0x91, 0x79, 0x72, 0x5f, 0x30, 0xa6, 0xbf, 0xa3, 0x38,
    0xf4, 0xe4, 0x18, 0x87, 0xbd, 0xe9, 0x60, 0x76, 0x5a, 0x4f, 0x77, 0x42, 0x96, 0xe4, 0x75, 0xd3,
    0x74, 0x66, 0x9c, 0x9a, 0xe6, 0x2a, 0xe6, 0x69, 0x0c, 0x0b, 0xe4, 0x75, 0xa8, 0xb2, 0x6f, 0xc6,
    0xa5, 0xcc, 0x25
};
#endif

PyTypeObject *init_QSerialPortInfo(PyObject *module)
{
    if (SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPortInfo_IDX].type != nullptr)
        return SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPortInfo_IDX].type;

    Shiboken::AutoDecRef Sbk_QSerialPortInfo_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QSerialPortInfo_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSerialPortInfo",
        "QSerialPortInfo",
        &Sbk_QSerialPortInfo_spec,
        &Shiboken::callCppDestructor< ::QSerialPortInfo >,
        Sbk_QSerialPortInfo_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QSerialPortInfo_TypeF(); // references _Sbk_QSerialPortInfo_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSerialPortInfo_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSerialPortInfo_SignatureBytes, QSerialPortInfo_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSerialPortInfo_PropertyStrings);
    SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPortInfo_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSerialPortInfo_PythonToCpp_QSerialPortInfo_PTR,
        is_QSerialPortInfo_PythonToCpp_QSerialPortInfo_PTR_Convertible,
        QSerialPortInfo_PTR_CppToPython_QSerialPortInfo,
        QSerialPortInfo_COPY_CppToPython_QSerialPortInfo);

    Shiboken::Conversions::registerConverterName(converter, "QSerialPortInfo");
    Shiboken::Conversions::registerConverterName(converter, "QSerialPortInfo*");
    Shiboken::Conversions::registerConverterName(converter, "QSerialPortInfo&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSerialPortInfo).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QSerialPortInfo_PythonToCpp_QSerialPortInfo_COPY,
        is_QSerialPortInfo_PythonToCpp_QSerialPortInfo_COPY_Convertible);

    qRegisterMetaType< ::QSerialPortInfo >("QSerialPortInfo");

    return pyType;
}
