// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtspatialaudio_python.h"

// main header
#include "qaudioengine_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QtMultimedia/qaudiodevice.h>
#include <QtSpatialAudio/qaudioengine.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QAudioEngineWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QAudioEngineWrapper::QAudioEngineWrapper()
{
}

QAudioEngineWrapper::QAudioEngineWrapper(::QObject * parent) : QAudioEngine(parent)
{
}

QAudioEngineWrapper::QAudioEngineWrapper(int sampleRate, ::QObject * parent) : QAudioEngine(sampleRate, parent)
{
}

void QAudioEngineWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAudioEngine", funcName);
        return;
    }
}

void QAudioEngineWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAudioEngine", funcName);
        return;
    }
}

void QAudioEngineWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAudioEngine", funcName);
        return;
    }
}

void QAudioEngineWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAudioEngine", funcName);
        return;
    }
}

bool QAudioEngineWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAudioEngine", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAudioEngine", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QAudioEngineWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAudioEngine", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAudioEngine", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QAudioEngineWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAudioEngine", funcName);
        return;
    }
}

const QMetaObject *QAudioEngineWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QAudioEngine::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QAudioEngineWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QAudioEngine::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QAudioEngineWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QAudioEngineWrapper *>(this));
    return QAudioEngine::qt_metacast(_clname);
}

QAudioEngineWrapper::~QAudioEngineWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QAudioEngine_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QAudioEngine >()))
        return -1;

    QAudioEngineWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:QAudioEngine", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QAudioEngine::QAudioEngine()
    // 1: QAudioEngine::QAudioEngine(QObject*)
    // 2: QAudioEngine::QAudioEngine(int,QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QAudioEngine()
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 2; // QAudioEngine(int,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 2; // QAudioEngine(int,QObject*)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QAudioEngine(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioEngine_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioEngine_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QAudioEngine()
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioEngine_IDX]);
            }

            // QAudioEngine()
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QAudioEngineWrapper();
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QAudioEngineWrapper();
            }

            break;
        }
        case 1: // QAudioEngine(QObject *parent)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioEngine_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QAudioEngine(QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QAudioEngineWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QAudioEngineWrapper(cppArg0);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
        case 2: // QAudioEngine(int sampleRate, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioEngine_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioEngine_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QObject *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QAudioEngine(int,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QAudioEngineWrapper(cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QAudioEngineWrapper(cppArg0, cppArg1);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QAudioEngine >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioEngine_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioEngine_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QAudioEngineFunc_distanceScale(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // distanceScale()const
        float cppResult = const_cast<const ::QAudioEngine *>(cppSelf)->distanceScale();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioEngineFunc_masterVolume(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // masterVolume()const
        float cppResult = const_cast<const ::QAudioEngine *>(cppSelf)->masterVolume();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioEngineFunc_outputDevice(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // outputDevice()const
        QAudioDevice cppResult = const_cast<const ::QAudioEngine *>(cppSelf)->outputDevice();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioDevice_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioEngineFunc_outputMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // outputMode()const
        QAudioEngine::OutputMode cppResult = const_cast<const ::QAudioEngine *>(cppSelf)->outputMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioEngine_OutputMode_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioEngineFunc_pause(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pause()
        cppSelf->pause();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAudioEngineFunc_paused(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // paused()const
        bool cppResult = const_cast<const ::QAudioEngine *>(cppSelf)->paused();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioEngineFunc_resume(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // resume()
        cppSelf->resume();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAudioEngineFunc_roomEffectsEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // roomEffectsEnabled()const
        bool cppResult = const_cast<const ::QAudioEngine *>(cppSelf)->roomEffectsEnabled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioEngineFunc_sampleRate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sampleRate()const
        int cppResult = const_cast<const ::QAudioEngine *>(cppSelf)->sampleRate();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioEngineFunc_setDistanceScale(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAudioEngine::setDistanceScale(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setDistanceScale(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDistanceScale", errInfo, SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioEngine_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDistanceScale(float)
            cppSelf->setDistanceScale(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAudioEngineFunc_setMasterVolume(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAudioEngine::setMasterVolume(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setMasterVolume(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMasterVolume", errInfo, SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioEngine_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMasterVolume(float)
            cppSelf->setMasterVolume(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAudioEngineFunc_setOutputDevice(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAudioEngine::setOutputDevice(QAudioDevice)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioDevice_IDX]), (pyArg)))) {
        overloadId = 0; // setOutputDevice(QAudioDevice)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOutputDevice", errInfo, SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioEngine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAudioDevice cppArg0_local;
        ::QAudioDevice *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setOutputDevice(QAudioDevice)
            cppSelf->setOutputDevice(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAudioEngineFunc_setOutputMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAudioEngine::setOutputMode(QAudioEngine::OutputMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioEngine_OutputMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setOutputMode(QAudioEngine::OutputMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOutputMode", errInfo, SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioEngine_IDX]);

    // Call function/method
    {
        ::QAudioEngine::OutputMode cppArg0{QAudioEngine::Surround};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOutputMode(QAudioEngine::OutputMode)
            cppSelf->setOutputMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAudioEngineFunc_setPaused(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAudioEngine::setPaused(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setPaused(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPaused", errInfo, SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioEngine_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPaused(bool)
            cppSelf->setPaused(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAudioEngineFunc_setRoomEffectsEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAudioEngine::setRoomEffectsEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setRoomEffectsEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRoomEffectsEnabled", errInfo, SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioEngine_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRoomEffectsEnabled(bool)
            cppSelf->setRoomEffectsEnabled(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAudioEngineFunc_start(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // start()
        cppSelf->start();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAudioEngineFunc_stop(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // stop()
        cppSelf->stop();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QAudioEngine_PropertyStrings[] = {
    "distanceScale::",
    "masterVolume::",
    "outputDevice::",
    "outputMode::",
    "paused::",
    nullptr // Sentinel
};

static const char *Sbk_QAudioEngine_EnumFlagInfo[] = {
    "OutputMode:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QAudioEngine_methods[] = {
    {"distanceScale", reinterpret_cast<PyCFunction>(Sbk_QAudioEngineFunc_distanceScale), METH_NOARGS, nullptr},
    {"masterVolume", reinterpret_cast<PyCFunction>(Sbk_QAudioEngineFunc_masterVolume), METH_NOARGS, nullptr},
    {"outputDevice", reinterpret_cast<PyCFunction>(Sbk_QAudioEngineFunc_outputDevice), METH_NOARGS, nullptr},
    {"outputMode", reinterpret_cast<PyCFunction>(Sbk_QAudioEngineFunc_outputMode), METH_NOARGS, nullptr},
    {"pause", reinterpret_cast<PyCFunction>(Sbk_QAudioEngineFunc_pause), METH_NOARGS, nullptr},
    {"paused", reinterpret_cast<PyCFunction>(Sbk_QAudioEngineFunc_paused), METH_NOARGS, nullptr},
    {"resume", reinterpret_cast<PyCFunction>(Sbk_QAudioEngineFunc_resume), METH_NOARGS, nullptr},
    {"roomEffectsEnabled", reinterpret_cast<PyCFunction>(Sbk_QAudioEngineFunc_roomEffectsEnabled), METH_NOARGS, nullptr},
    {"sampleRate", reinterpret_cast<PyCFunction>(Sbk_QAudioEngineFunc_sampleRate), METH_NOARGS, nullptr},
    {"setDistanceScale", reinterpret_cast<PyCFunction>(Sbk_QAudioEngineFunc_setDistanceScale), METH_O, nullptr},
    {"setMasterVolume", reinterpret_cast<PyCFunction>(Sbk_QAudioEngineFunc_setMasterVolume), METH_O, nullptr},
    {"setOutputDevice", reinterpret_cast<PyCFunction>(Sbk_QAudioEngineFunc_setOutputDevice), METH_O, nullptr},
    {"setOutputMode", reinterpret_cast<PyCFunction>(Sbk_QAudioEngineFunc_setOutputMode), METH_O, nullptr},
    {"setPaused", reinterpret_cast<PyCFunction>(Sbk_QAudioEngineFunc_setPaused), METH_O, nullptr},
    {"setRoomEffectsEnabled", reinterpret_cast<PyCFunction>(Sbk_QAudioEngineFunc_setRoomEffectsEnabled), METH_O, nullptr},
    {"start", reinterpret_cast<PyCFunction>(Sbk_QAudioEngineFunc_start), METH_NOARGS, nullptr},
    {"stop", reinterpret_cast<PyCFunction>(Sbk_QAudioEngineFunc_stop), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QAudioEngine_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QAudioEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QAudioEngineWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QAudioEngine_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QAudioEngine_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QAudioEngine_Type = nullptr;
static PyTypeObject *Sbk_QAudioEngine_TypeF(void)
{
    return _Sbk_QAudioEngine_Type;
}

static PyType_Slot Sbk_QAudioEngine_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QAudioEngine_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QAudioEngine_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QAudioEngine_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QAudioEngine_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QAudioEngine_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QAudioEngine_spec = {
    "2:PySide6.QtSpatialAudio.QAudioEngine",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QAudioEngine_slots
};

} //extern "C"

static void *Sbk_QAudioEngine_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QAudioEngine *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QAudioEngine_OutputMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAudioEngine::OutputMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAudioEngine::OutputMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAudioEngine_OutputMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioEngine_OutputMode_IDX])))
        return Enum_PythonToCpp_QAudioEngine_OutputMode;
    return {};
}

static PyObject *QAudioEngine_OutputMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAudioEngine::OutputMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAudioEngine::OutputMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioEngine_OutputMode_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAudioEngine_PythonToCpp_QAudioEngine_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QAudioEngine_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAudioEngine_PythonToCpp_QAudioEngine_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QAudioEngine_TypeF()))
        return QAudioEngine_PythonToCpp_QAudioEngine_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAudioEngine_PTR_CppToPython_QAudioEngine(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QAudioEngine *>(const_cast<void *>(cppIn)), Sbk_QAudioEngine_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QAudioEngine_SignatureStrings[] = {
    "2:PySide6.QtSpatialAudio.QAudioEngine(self,*:KeywordOnly=None,outputMode:QAudioEngine.OutputMode=None,outputDevice:QAudioDevice=None,masterVolume:float=None,paused:bool=None,distanceScale:float=None)",
    "1:PySide6.QtSpatialAudio.QAudioEngine(self,parent:PySide6.QtCore.QObject,*:KeywordOnly=None,outputMode:QAudioEngine.OutputMode=None,outputDevice:QAudioDevice=None,masterVolume:float=None,paused:bool=None,distanceScale:float=None)",
    "0:PySide6.QtSpatialAudio.QAudioEngine(self,sampleRate:int,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,outputMode:QAudioEngine.OutputMode=None,outputDevice:QAudioDevice=None,masterVolume:float=None,paused:bool=None,distanceScale:float=None)",
    "PySide6.QtSpatialAudio.QAudioEngine.distanceScale(self)->float",
    "PySide6.QtSpatialAudio.QAudioEngine.masterVolume(self)->float",
    "PySide6.QtSpatialAudio.QAudioEngine.outputDevice(self)->PySide6.QtMultimedia.QAudioDevice",
    "PySide6.QtSpatialAudio.QAudioEngine.outputMode(self)->PySide6.QtSpatialAudio.QAudioEngine.OutputMode",
    "PySide6.QtSpatialAudio.QAudioEngine.pause(self)",
    "PySide6.QtSpatialAudio.QAudioEngine.paused(self)->bool",
    "PySide6.QtSpatialAudio.QAudioEngine.resume(self)",
    "PySide6.QtSpatialAudio.QAudioEngine.roomEffectsEnabled(self)->bool",
    "PySide6.QtSpatialAudio.QAudioEngine.sampleRate(self)->int",
    "PySide6.QtSpatialAudio.QAudioEngine.setDistanceScale(self,scale:float)",
    "PySide6.QtSpatialAudio.QAudioEngine.setMasterVolume(self,volume:float)",
    "PySide6.QtSpatialAudio.QAudioEngine.setOutputDevice(self,device:PySide6.QtMultimedia.QAudioDevice)",
    "PySide6.QtSpatialAudio.QAudioEngine.setOutputMode(self,mode:PySide6.QtSpatialAudio.QAudioEngine.OutputMode)",
    "PySide6.QtSpatialAudio.QAudioEngine.setPaused(self,paused:bool)",
    "PySide6.QtSpatialAudio.QAudioEngine.setRoomEffectsEnabled(self,enabled:bool)",
    "PySide6.QtSpatialAudio.QAudioEngine.start(self)",
    "PySide6.QtSpatialAudio.QAudioEngine.stop(self)",
    nullptr}; // Sentinel
#else
static constexpr size_t QAudioEngine_SignatureByteSize = 348;
static constexpr uint8_t QAudioEngine_SignatureBytes[348] = {
    0x78, 0xda, 0xcd, 0x54, 0x4d, 0x4f, 0xc3, 0x30, 0x0c, 0xbd, 0xf3, 0x4b, 0x18, 0x0a, 0x15, 0x70,
    0xe0, 0x50, 0x69, 0x48, 0x88, 0xed, 0x84, 0x46, 0xf7, 0x21, 0x71, 0x4f, 0x1b, 0x17, 0x05, 0xa5,
    0x71, 0x94, 0x38, 0x43, 0xfb, 0xf7, 0x6c, 0x0d, 0x5d, 0xc3, 0x06, 0x2c, 0xe5, 0xb4, 0x53, 0x15,
    0xe7, 0xbd, 0xe7, 0xd8, 0x7e, 0xee, 0x5d, 0x3e, 0xdf, 0xac, 0xa4, 0x80, 0xfb, 0x6c, 0x41, 0x2b,
    0xc3, 0x49, 0x72, 0xf5, 0xe8, 0x85, 0xc4, 0x6c, 0xd1, 0x7e, 0xa6, 0xfa, 0x4d, 0x6a, 0xb8, 0x74,
    0xa0, 0x6a, 0x76, 0x95, 0x3f, 0xc3, 0xe6, 0x03, 0xad, 0x28, 0xb4, 0xda, 0x8c, 0x5f, 0x50, 0x03,
    0x43, 0x4f, 0xc6, 0xd3, 0x0c, 0x05, 0xe4, 0x31, 0x3e, 0x2b, 0xf6, 0xf1, 0x18, 0x37, 0x81, 0xb5,
    0xac, 0x3a, 0x64, 0x38, 0x84, 0xeb, 0x86, 0x3b, 0x02, 0xfb, 0x8a, 0xca, 0x37, 0x90, 0xd7, 0x0a,
    0x39, 0x85, 0xb8, 0xe1, 0xde, 0x81, 0xc8, 0x4b, 0x44, 0x15, 0x02, 0x42, 0x3a, 0xe2, 0xba, 0x82,
    0x55, 0xc5, 0x55, 0x8c, 0x1c, 0x5d, 0xdc, 0xa6, 0xd7, 0x61, 0xb8, 0x05, 0x4d, 0x11, 0xfe, 0x09,
    0x2d, 0x64, 0x8b, 0xa2, 0x7c, 0x87, 0x8a, 0xce, 0xbb, 0xca, 0x9b, 0xf4, 0x2a, 0x1d, 0x6f, 0x8c,
    0x82, 0x25, 0x27, 0xc8, 0xa5, 0xa6, 0xbf, 0x8b, 0x1e, 0x6b, 0xaf, 0x94, 0x21, 0x7b, 0xde, 0xc5,
    0x27, 0x94, 0x9e, 0x7d, 0x63, 0xb7, 0x8d, 0x18, 0x5d, 0x3f, 0xb4, 0x22, 0x49, 0xf4, 0xf8, 0x95,
    0xc3, 0xd9, 0x71, 0x0b, 0x3a, 0x76, 0xcf, 0x9b, 0x79, 0x45, 0xb2, 0x01, 0x21, 0x79, 0x16, 0xb7,
    0x67, 0x80, 0xf2, 0xae, 0xd9, 0xc7, 0xba, 0xbf, 0xb3, 0xfa, 0x11, 0x25, 0x25, 0x69, 0x47, 0x11,
    0xf4, 0xd3, 0xf1, 0xa2, 0x7b, 0xd0, 0x6e, 0x82, 0x49, 0x34, 0x0b, 0x6e, 0xdf, 0xdd, 0x34, 0x02,
    0x62, 0x33, 0xad, 0xeb, 0xad, 0x4f, 0xdd, 0x54, 0xf3, 0x52, 0xfd, 0x23, 0x67, 0xbf, 0x0c, 0x1d,
    0x75, 0xbb, 0x13, 0x69, 0x4c, 0xa0, 0xc9, 0x91, 0xa7, 0x98, 0xeb, 0xcd, 0x39, 0x4a, 0x95, 0x99,
    0x1d, 0x7a, 0x8b, 0xad, 0xa3, 0x6d, 0x48, 0x96, 0x29, 0x0e, 0x4d, 0xc6, 0x44, 0xd8, 0xb9, 0x93,
    0x4e, 0x1b, 0x98, 0x62, 0xef, 0x36, 0xd6, 0xec, 0x96, 0x7f, 0x98, 0xe1, 0x92, 0x73, 0xcd, 0x7b,
    0x13, 0xc5, 0xff, 0x82, 0x64, 0xfe, 0xf2, 0x67, 0x73, 0x30, 0x08, 0x87, 0x21, 0x62, 0xc4, 0x2d,
    0x0d, 0xb0, 0xa5, 0x23, 0x34, 0x5f, 0xf0, 0x4f, 0xb3, 0xd3, 0xad, 0x2d
};
#endif

PyTypeObject *init_QAudioEngine(PyObject *module)
{
    if (SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioEngine_IDX].type != nullptr)
        return SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioEngine_IDX].type;

    Shiboken::AutoDecRef Sbk_QAudioEngine_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QAudioEngine_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QAudioEngine",
        "QAudioEngine*",
        &Sbk_QAudioEngine_spec,
        &Shiboken::callCppDestructor< QAudioEngine >,
        Sbk_QAudioEngine_Type_bases.object(),
        0);
    auto *pyType = Sbk_QAudioEngine_TypeF(); // references _Sbk_QAudioEngine_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QAudioEngine_SignatureStrings);
#else
    InitSignatureBytes(pyType, QAudioEngine_SignatureBytes, QAudioEngine_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QAudioEngine_PropertyStrings);
    SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioEngine_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAudioEngine_PythonToCpp_QAudioEngine_PTR,
        is_QAudioEngine_PythonToCpp_QAudioEngine_PTR_Convertible,
        QAudioEngine_PTR_CppToPython_QAudioEngine);

    Shiboken::Conversions::registerConverterName(converter, "QAudioEngine");
    Shiboken::Conversions::registerConverterName(converter, "QAudioEngine*");
    Shiboken::Conversions::registerConverterName(converter, "QAudioEngine&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QAudioEngine).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QAudioEngineWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QAudioEngine_TypeF(), &Sbk_QAudioEngine_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QAudioEngine_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'OutputMode'.
    const char *OutputMode_Initializer[] = {
        "Surround",
        "Stereo",
        "Headphone",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t OutputMode_InitializerValues[] = {
        uint8_t(QAudioEngine::OutputMode::Surround), //  0x00  0
        uint8_t(QAudioEngine::OutputMode::Stereo),   //  0x01  1
        uint8_t(QAudioEngine::OutputMode::Headphone) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAudioEngine_TypeF(),
        "2:PySide6.QtSpatialAudio.QAudioEngine.OutputMode",
        OutputMode_Initializer, OutputMode_InitializerValues);
    SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioEngine_OutputMode_IDX].type = EType;
    // Register converter for enum 'QAudioEngine::OutputMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAudioEngine_OutputMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAudioEngine_OutputMode,
            is_Enum_PythonToCpp_QAudioEngine_OutputMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAudioEngine::OutputMode");
        Shiboken::Conversions::registerConverterAlias(converter, "OutputMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'OutputMode' enum.

    PySide::Signal::registerSignals(pyType, &::QAudioEngine::staticMetaObject);
    qRegisterMetaType< ::QAudioEngine::OutputMode >("QAudioEngine::OutputMode");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QAudioEngine::staticMetaObject, sizeof(QAudioEngineWrapper));

    return pyType;
}

PyTypeObject *init_QAudioEngineStaticFields(PyObject *module)
{
    auto *obType = PyObject_GetAttrString(module, "QAudioEngine");
    auto *type = reinterpret_cast<PyTypeObject *>(obType);
    Shiboken::AutoDecRef dict(PepType_GetDict(type));
    PyDict_SetItemString(dict, "DistanceScaleCentimeter",
                         Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &QAudioEngine::DistanceScaleCentimeter));
    PyDict_SetItemString(dict, "DistanceScaleMeter",
                         Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &QAudioEngine::DistanceScaleMeter));
    return type;
}
