// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtspatialaudio_python.h"

// main header
#include "qspatialsound_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QtGui/qquaternion.h>
#include <QtGui/qvectornd.h>
#include <QtSpatialAudio/qaudioengine.h>
#include <QtSpatialAudio/qspatialsound.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qurl.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QSpatialSoundWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QSpatialSoundWrapper::QSpatialSoundWrapper(::QAudioEngine * engine) : QSpatialSound(engine)
{
}

void QSpatialSoundWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSpatialSound", funcName);
        return;
    }
}

void QSpatialSoundWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSpatialSound", funcName);
        return;
    }
}

void QSpatialSoundWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSpatialSound", funcName);
        return;
    }
}

void QSpatialSoundWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSpatialSound", funcName);
        return;
    }
}

bool QSpatialSoundWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSpatialSound", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSpatialSound", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QSpatialSoundWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSpatialSound", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSpatialSound", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QSpatialSoundWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSpatialSound", funcName);
        return;
    }
}

const QMetaObject *QSpatialSoundWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QSpatialSound::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QSpatialSoundWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QSpatialSound::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QSpatialSoundWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QSpatialSoundWrapper *>(this));
    return QSpatialSound::qt_metacast(_clname);
}

QSpatialSoundWrapper::~QSpatialSoundWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSpatialSound_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSpatialSound >()))
        return -1;

    QSpatialSoundWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QSpatialSound", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QSpatialSound::QSpatialSound(QAudioEngine*)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioEngine_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QSpatialSound(QAudioEngine*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QAudioEngine *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QSpatialSound(QAudioEngine*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QSpatialSoundWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QSpatialSoundWrapper(cppArg0);
            }

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QSpatialSound >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QSpatialSoundFunc_autoPlay(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpatialSound *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // autoPlay()const
        bool cppResult = const_cast<const ::QSpatialSound *>(cppSelf)->autoPlay();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSpatialSoundFunc_directivity(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpatialSound *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // directivity()const
        float cppResult = const_cast<const ::QSpatialSound *>(cppSelf)->directivity();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSpatialSoundFunc_directivityOrder(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpatialSound *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // directivityOrder()const
        float cppResult = const_cast<const ::QSpatialSound *>(cppSelf)->directivityOrder();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSpatialSoundFunc_distanceCutoff(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpatialSound *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // distanceCutoff()const
        float cppResult = const_cast<const ::QSpatialSound *>(cppSelf)->distanceCutoff();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSpatialSoundFunc_distanceModel(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpatialSound *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // distanceModel()const
        QSpatialSound::DistanceModel cppResult = const_cast<const ::QSpatialSound *>(cppSelf)->distanceModel();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_DistanceModel_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSpatialSoundFunc_engine(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpatialSound *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // engine()const
        QAudioEngine * cppResult = const_cast<const ::QSpatialSound *>(cppSelf)->engine();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioEngine_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSpatialSoundFunc_loops(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpatialSound *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // loops()const
        int cppResult = const_cast<const ::QSpatialSound *>(cppSelf)->loops();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSpatialSoundFunc_manualAttenuation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpatialSound *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // manualAttenuation()const
        float cppResult = const_cast<const ::QSpatialSound *>(cppSelf)->manualAttenuation();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSpatialSoundFunc_nearFieldGain(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpatialSound *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // nearFieldGain()const
        float cppResult = const_cast<const ::QSpatialSound *>(cppSelf)->nearFieldGain();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSpatialSoundFunc_occlusionIntensity(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpatialSound *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // occlusionIntensity()const
        float cppResult = const_cast<const ::QSpatialSound *>(cppSelf)->occlusionIntensity();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSpatialSoundFunc_pause(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpatialSound *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pause()
        cppSelf->pause();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSpatialSoundFunc_play(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpatialSound *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // play()
        cppSelf->play();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSpatialSoundFunc_position(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpatialSound *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // position()const
        QVector3D cppResult = const_cast<const ::QSpatialSound *>(cppSelf)->position();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSpatialSoundFunc_rotation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpatialSound *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rotation()const
        QQuaternion cppResult = const_cast<const ::QSpatialSound *>(cppSelf)->rotation();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSpatialSoundFunc_setAutoPlay(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpatialSound *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSpatialSound::setAutoPlay(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAutoPlay(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAutoPlay", errInfo, SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAutoPlay(bool)
            cppSelf->setAutoPlay(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSpatialSoundFunc_setDirectivity(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpatialSound *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSpatialSound::setDirectivity(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setDirectivity(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDirectivity", errInfo, SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDirectivity(float)
            cppSelf->setDirectivity(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSpatialSoundFunc_setDirectivityOrder(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpatialSound *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSpatialSound::setDirectivityOrder(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setDirectivityOrder(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDirectivityOrder", errInfo, SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDirectivityOrder(float)
            cppSelf->setDirectivityOrder(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSpatialSoundFunc_setDistanceCutoff(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpatialSound *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSpatialSound::setDistanceCutoff(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setDistanceCutoff(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDistanceCutoff", errInfo, SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDistanceCutoff(float)
            cppSelf->setDistanceCutoff(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSpatialSoundFunc_setDistanceModel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpatialSound *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSpatialSound::setDistanceModel(QSpatialSound::DistanceModel)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_DistanceModel_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setDistanceModel(QSpatialSound::DistanceModel)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDistanceModel", errInfo, SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]);

    // Call function/method
    {
        ::QSpatialSound::DistanceModel cppArg0{QSpatialSound::DistanceModel::Logarithmic};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDistanceModel(QSpatialSound::DistanceModel)
            cppSelf->setDistanceModel(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSpatialSoundFunc_setLoops(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpatialSound *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSpatialSound::setLoops(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setLoops(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLoops", errInfo, SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLoops(int)
            cppSelf->setLoops(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSpatialSoundFunc_setManualAttenuation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpatialSound *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSpatialSound::setManualAttenuation(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setManualAttenuation(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setManualAttenuation", errInfo, SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setManualAttenuation(float)
            cppSelf->setManualAttenuation(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSpatialSoundFunc_setNearFieldGain(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpatialSound *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSpatialSound::setNearFieldGain(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setNearFieldGain(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setNearFieldGain", errInfo, SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setNearFieldGain(float)
            cppSelf->setNearFieldGain(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSpatialSoundFunc_setOcclusionIntensity(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpatialSound *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSpatialSound::setOcclusionIntensity(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setOcclusionIntensity(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOcclusionIntensity", errInfo, SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOcclusionIntensity(float)
            cppSelf->setOcclusionIntensity(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSpatialSoundFunc_setPosition(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpatialSound *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSpatialSound::setPosition(QVector3D)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArg)))) {
        overloadId = 0; // setPosition(QVector3D)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPosition", errInfo, SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QVector3D cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPosition(QVector3D)
            cppSelf->setPosition(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSpatialSoundFunc_setRotation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpatialSound *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSpatialSound::setRotation(QQuaternion)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), (pyArg)))) {
        overloadId = 0; // setRotation(QQuaternion)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRotation", errInfo, SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QQuaternion cppArg0_local;
        ::QQuaternion *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setRotation(QQuaternion)
            cppSelf->setRotation(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSpatialSoundFunc_setSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpatialSound *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSpatialSound::setSize(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setSize(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSize", errInfo, SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSize(float)
            cppSelf->setSize(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSpatialSoundFunc_setSource(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpatialSound *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSpatialSound::setSource(QUrl)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // setSource(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSource", errInfo, SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setSource(QUrl)
            cppSelf->setSource(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSpatialSoundFunc_setVolume(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpatialSound *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSpatialSound::setVolume(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setVolume(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setVolume", errInfo, SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setVolume(float)
            cppSelf->setVolume(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSpatialSoundFunc_size(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpatialSound *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // size()const
        float cppResult = const_cast<const ::QSpatialSound *>(cppSelf)->size();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSpatialSoundFunc_source(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpatialSound *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // source()const
        QUrl cppResult = const_cast<const ::QSpatialSound *>(cppSelf)->source();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSpatialSoundFunc_stop(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpatialSound *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // stop()
        cppSelf->stop();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSpatialSoundFunc_volume(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpatialSound *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // volume()const
        float cppResult = const_cast<const ::QSpatialSound *>(cppSelf)->volume();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QSpatialSound_PropertyStrings[] = {
    "autoPlay::",
    "directivity::",
    "directivityOrder::",
    "distanceCutoff::",
    "distanceModel::",
    "loops::",
    "manualAttenuation::",
    "nearFieldGain::",
    "occlusionIntensity::",
    "position::",
    "rotation::",
    "size::",
    "source::",
    "volume::",
    nullptr // Sentinel
};

static const char *Sbk_QSpatialSound_EnumFlagInfo[] = {
    "DistanceModel:Enum",
    "Loops:IntEnum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSpatialSound_methods[] = {
    {"autoPlay", reinterpret_cast<PyCFunction>(Sbk_QSpatialSoundFunc_autoPlay), METH_NOARGS, nullptr},
    {"directivity", reinterpret_cast<PyCFunction>(Sbk_QSpatialSoundFunc_directivity), METH_NOARGS, nullptr},
    {"directivityOrder", reinterpret_cast<PyCFunction>(Sbk_QSpatialSoundFunc_directivityOrder), METH_NOARGS, nullptr},
    {"distanceCutoff", reinterpret_cast<PyCFunction>(Sbk_QSpatialSoundFunc_distanceCutoff), METH_NOARGS, nullptr},
    {"distanceModel", reinterpret_cast<PyCFunction>(Sbk_QSpatialSoundFunc_distanceModel), METH_NOARGS, nullptr},
    {"engine", reinterpret_cast<PyCFunction>(Sbk_QSpatialSoundFunc_engine), METH_NOARGS, nullptr},
    {"loops", reinterpret_cast<PyCFunction>(Sbk_QSpatialSoundFunc_loops), METH_NOARGS, nullptr},
    {"manualAttenuation", reinterpret_cast<PyCFunction>(Sbk_QSpatialSoundFunc_manualAttenuation), METH_NOARGS, nullptr},
    {"nearFieldGain", reinterpret_cast<PyCFunction>(Sbk_QSpatialSoundFunc_nearFieldGain), METH_NOARGS, nullptr},
    {"occlusionIntensity", reinterpret_cast<PyCFunction>(Sbk_QSpatialSoundFunc_occlusionIntensity), METH_NOARGS, nullptr},
    {"pause", reinterpret_cast<PyCFunction>(Sbk_QSpatialSoundFunc_pause), METH_NOARGS, nullptr},
    {"play", reinterpret_cast<PyCFunction>(Sbk_QSpatialSoundFunc_play), METH_NOARGS, nullptr},
    {"position", reinterpret_cast<PyCFunction>(Sbk_QSpatialSoundFunc_position), METH_NOARGS, nullptr},
    {"rotation", reinterpret_cast<PyCFunction>(Sbk_QSpatialSoundFunc_rotation), METH_NOARGS, nullptr},
    {"setAutoPlay", reinterpret_cast<PyCFunction>(Sbk_QSpatialSoundFunc_setAutoPlay), METH_O, nullptr},
    {"setDirectivity", reinterpret_cast<PyCFunction>(Sbk_QSpatialSoundFunc_setDirectivity), METH_O, nullptr},
    {"setDirectivityOrder", reinterpret_cast<PyCFunction>(Sbk_QSpatialSoundFunc_setDirectivityOrder), METH_O, nullptr},
    {"setDistanceCutoff", reinterpret_cast<PyCFunction>(Sbk_QSpatialSoundFunc_setDistanceCutoff), METH_O, nullptr},
    {"setDistanceModel", reinterpret_cast<PyCFunction>(Sbk_QSpatialSoundFunc_setDistanceModel), METH_O, nullptr},
    {"setLoops", reinterpret_cast<PyCFunction>(Sbk_QSpatialSoundFunc_setLoops), METH_O, nullptr},
    {"setManualAttenuation", reinterpret_cast<PyCFunction>(Sbk_QSpatialSoundFunc_setManualAttenuation), METH_O, nullptr},
    {"setNearFieldGain", reinterpret_cast<PyCFunction>(Sbk_QSpatialSoundFunc_setNearFieldGain), METH_O, nullptr},
    {"setOcclusionIntensity", reinterpret_cast<PyCFunction>(Sbk_QSpatialSoundFunc_setOcclusionIntensity), METH_O, nullptr},
    {"setPosition", reinterpret_cast<PyCFunction>(Sbk_QSpatialSoundFunc_setPosition), METH_O, nullptr},
    {"setRotation", reinterpret_cast<PyCFunction>(Sbk_QSpatialSoundFunc_setRotation), METH_O, nullptr},
    {"setSize", reinterpret_cast<PyCFunction>(Sbk_QSpatialSoundFunc_setSize), METH_O, nullptr},
    {"setSource", reinterpret_cast<PyCFunction>(Sbk_QSpatialSoundFunc_setSource), METH_O, nullptr},
    {"setVolume", reinterpret_cast<PyCFunction>(Sbk_QSpatialSoundFunc_setVolume), METH_O, nullptr},
    {"size", reinterpret_cast<PyCFunction>(Sbk_QSpatialSoundFunc_size), METH_NOARGS, nullptr},
    {"source", reinterpret_cast<PyCFunction>(Sbk_QSpatialSoundFunc_source), METH_NOARGS, nullptr},
    {"stop", reinterpret_cast<PyCFunction>(Sbk_QSpatialSoundFunc_stop), METH_NOARGS, nullptr},
    {"volume", reinterpret_cast<PyCFunction>(Sbk_QSpatialSoundFunc_volume), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QSpatialSound_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QSpatialSound *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QSpatialSoundWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QSpatialSound_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSpatialSound_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSpatialSound_Type = nullptr;
static PyTypeObject *Sbk_QSpatialSound_TypeF(void)
{
    return _Sbk_QSpatialSound_Type;
}

static PyType_Slot Sbk_QSpatialSound_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QSpatialSound_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSpatialSound_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSpatialSound_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSpatialSound_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSpatialSound_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSpatialSound_spec = {
    "2:PySide6.QtSpatialAudio.QSpatialSound",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSpatialSound_slots
};

} //extern "C"

static void *Sbk_QSpatialSound_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QSpatialSound *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QSpatialSound_Loops(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSpatialSound::Loops>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSpatialSound::Loops *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QSpatialSound_Loops_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_Loops_IDX])))
        return Enum_PythonToCpp_QSpatialSound_Loops;
    return {};
}

static PyObject *QSpatialSound_Loops_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QSpatialSound::Loops>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QSpatialSound::Loops *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_Loops_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QSpatialSound_DistanceModel(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSpatialSound::DistanceModel>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSpatialSound::DistanceModel *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QSpatialSound_DistanceModel_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_DistanceModel_IDX])))
        return Enum_PythonToCpp_QSpatialSound_DistanceModel;
    return {};
}

static PyObject *QSpatialSound_DistanceModel_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QSpatialSound::DistanceModel>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QSpatialSound::DistanceModel *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_DistanceModel_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSpatialSound_PythonToCpp_QSpatialSound_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSpatialSound_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSpatialSound_PythonToCpp_QSpatialSound_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSpatialSound_TypeF()))
        return QSpatialSound_PythonToCpp_QSpatialSound_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSpatialSound_PTR_CppToPython_QSpatialSound(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QSpatialSound *>(const_cast<void *>(cppIn)), Sbk_QSpatialSound_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSpatialSound_SignatureStrings[] = {
    "PySide6.QtSpatialAudio.QSpatialSound(self,engine:PySide6.QtSpatialAudio.QAudioEngine,*:KeywordOnly=None,source:QUrl=None,position:QVector3D=None,rotation:QQuaternion=None,volume:float=None,distanceModel:QSpatialSound.DistanceModel=None,size:float=None,distanceCutoff:float=None,manualAttenuation:float=None,occlusionIntensity:float=None,directivity:float=None,directivityOrder:float=None,nearFieldGain:float=None,loops:int=None,autoPlay:bool=None)",
    "PySide6.QtSpatialAudio.QSpatialSound.autoPlay(self)->bool",
    "PySide6.QtSpatialAudio.QSpatialSound.directivity(self)->float",
    "PySide6.QtSpatialAudio.QSpatialSound.directivityOrder(self)->float",
    "PySide6.QtSpatialAudio.QSpatialSound.distanceCutoff(self)->float",
    "PySide6.QtSpatialAudio.QSpatialSound.distanceModel(self)->PySide6.QtSpatialAudio.QSpatialSound.DistanceModel",
    "PySide6.QtSpatialAudio.QSpatialSound.engine(self)->PySide6.QtSpatialAudio.QAudioEngine",
    "PySide6.QtSpatialAudio.QSpatialSound.loops(self)->int",
    "PySide6.QtSpatialAudio.QSpatialSound.manualAttenuation(self)->float",
    "PySide6.QtSpatialAudio.QSpatialSound.nearFieldGain(self)->float",
    "PySide6.QtSpatialAudio.QSpatialSound.occlusionIntensity(self)->float",
    "PySide6.QtSpatialAudio.QSpatialSound.pause(self)",
    "PySide6.QtSpatialAudio.QSpatialSound.play(self)",
    "PySide6.QtSpatialAudio.QSpatialSound.position(self)->PySide6.QtGui.QVector3D",
    "PySide6.QtSpatialAudio.QSpatialSound.rotation(self)->PySide6.QtGui.QQuaternion",
    "PySide6.QtSpatialAudio.QSpatialSound.setAutoPlay(self,autoPlay:bool)",
    "PySide6.QtSpatialAudio.QSpatialSound.setDirectivity(self,alpha:float)",
    "PySide6.QtSpatialAudio.QSpatialSound.setDirectivityOrder(self,alpha:float)",
    "PySide6.QtSpatialAudio.QSpatialSound.setDistanceCutoff(self,cutoff:float)",
    "PySide6.QtSpatialAudio.QSpatialSound.setDistanceModel(self,model:PySide6.QtSpatialAudio.QSpatialSound.DistanceModel)",
    "PySide6.QtSpatialAudio.QSpatialSound.setLoops(self,loops:int)",
    "PySide6.QtSpatialAudio.QSpatialSound.setManualAttenuation(self,attenuation:float)",
    "PySide6.QtSpatialAudio.QSpatialSound.setNearFieldGain(self,gain:float)",
    "PySide6.QtSpatialAudio.QSpatialSound.setOcclusionIntensity(self,occlusion:float)",
    "PySide6.QtSpatialAudio.QSpatialSound.setPosition(self,pos:PySide6.QtGui.QVector3D)",
    "PySide6.QtSpatialAudio.QSpatialSound.setRotation(self,q:PySide6.QtGui.QQuaternion)",
    "PySide6.QtSpatialAudio.QSpatialSound.setSize(self,size:float)",
    "PySide6.QtSpatialAudio.QSpatialSound.setSource(self,url:typing.Union[PySide6.QtCore.QUrl, QString])",
    "PySide6.QtSpatialAudio.QSpatialSound.setVolume(self,volume:float)",
    "PySide6.QtSpatialAudio.QSpatialSound.size(self)->float",
    "PySide6.QtSpatialAudio.QSpatialSound.source(self)->PySide6.QtCore.QUrl",
    "PySide6.QtSpatialAudio.QSpatialSound.stop(self)",
    "PySide6.QtSpatialAudio.QSpatialSound.volume(self)->float",
    nullptr}; // Sentinel
#else
static constexpr size_t QSpatialSound_SignatureByteSize = 532;
static constexpr uint8_t QSpatialSound_SignatureBytes[532] = {
    0x78, 0xda, 0xa5, 0x56, 0x4d, 0x6f, 0xd4, 0x30, 0x10, 0xbd, 0xf3, 0x2b, 0x38, 0xb2, 0xc8, 0xe4,
    0x82, 0xc4, 0xc1, 0x12, 0x48, 0x55, 0x97, 0x56, 0x08, 0xda, 0x4d, 0x88, 0xda, 0x4b, 0xc5, 0xc1,
    0x24, 0xde, 0xc5, 0x92, 0xd7, 0x13, 0x1c, 0x7b, 0x51, 0xf8, 0xf5, 0x78, 0xed, 0x7c, 0x38, 0xcd,
    0x46, 0x4c, 0xd2, 0x53, 0x92, 0x19, 0xbf, 0x37, 0x33, 0xf1, 0xbc, 0xb1, 0xd3, 0x26, 0x17, 0x25,
    0xff, 0x90, 0x64, 0x26, 0xaf, 0x98, 0x11, 0x4c, 0x5e, 0xd9, 0x52, 0x40, 0x92, 0xb5, 0x5f, 0x39,
    0x58, 0x55, 0xbe, 0xa9, 0xb9, 0xdc, 0x13, 0xae, 0x0e, 0x42, 0x71, 0x9a, 0xce, 0x00, 0xfc, 0xe3,
    0xb3, 0x5f, 0x43, 0xde, 0xd2, 0xaf, 0xbc, 0xf9, 0x03, 0xba, 0xdc, 0x29, 0xd9, 0x7c, 0xbc, 0x07,
    0x67, 0xaa, 0xc1, 0xea, 0x82, 0xd3, 0xec, 0x41, 0xcb, 0x60, 0xa8, 0xa0, 0x16, 0x46, 0x80, 0xa2,
    0xd9, 0x23, 0x2f, 0x0c, 0xe8, 0xf7, 0xdb, 0x60, 0xd7, 0x60, 0x58, 0xb0, 0x67, 0x96, 0x19, 0xae,
    0x95, 0x7b, 0x0f, 0x9e, 0x13, 0x48, 0x7b, 0xe4, 0x74, 0x2f, 0x81, 0x99, 0x60, 0x29, 0x45, 0x6d,
    0x98, 0x2a, 0xf8, 0x1d, 0x94, 0x5c, 0xd2, 0x51, 0xce, 0xc9, 0x36, 0xf6, 0xb5, 0x39, 0x88, 0xbf,
    0x17, 0xe1, 0xd7, 0xd6, 0xc0, 0x7e, 0x1f, 0x7b, 0x8e, 0x4c, 0x59, 0x57, 0x99, 0x31, 0xdc, 0x3d,
    0x7d, 0x36, 0x91, 0x13, 0x8a, 0x42, 0xda, 0xda, 0x19, 0xbf, 0x28, 0xe7, 0x77, 0x55, 0x34, 0x63,
    0x52, 0xed, 0xea, 0x11, 0xa7, 0x79, 0xf3, 0x4e, 0x97, 0x5c, 0xc7, 0x3e, 0xc5, 0x99, 0xbe, 0x11,
    0x5c, 0x96, 0xb7, 0x4c, 0x8c, 0x22, 0x49, 0x80, 0xaa, 0xa6, 0x42, 0xb5, 0x9f, 0xcc, 0xe5, 0x99,
    0x4a, 0xd6, 0xd0, 0x9f, 0x00, 0xa1, 0xa4, 0xcd, 0xab, 0x14, 0xb1, 0x7f, 0x49, 0x07, 0xf4, 0x1b,
    0xb9, 0x79, 0xf7, 0xe9, 0x8c, 0xc7, 0x21, 0xa3, 0xb4, 0x3b, 0xb0, 0xcf, 0x6f, 0x31, 0xda, 0x17,
    0xbd, 0x8a, 0x22, 0xde, 0xa3, 0x17, 0x10, 0xf8, 0x3e, 0xe8, 0xf0, 0x28, 0xe4, 0xa8, 0x83, 0x70,
    0xc1, 0x82, 0x46, 0xfe, 0x17, 0x25, 0x92, 0x0a, 0x8e, 0xd6, 0xf7, 0x41, 0xc7, 0xea, 0xda, 0x01,
    0x87, 0x9a, 0x34, 0xf1, 0x8a, 0xbf, 0x37, 0x6a, 0xcd, 0x15, 0xf8, 0xa9, 0x56, 0x56, 0x90, 0x54,
    0xcc, 0xd6, 0xed, 0x4f, 0x45, 0x02, 0xfa, 0x5e, 0x47, 0xae, 0x6f, 0x67, 0xd1, 0x74, 0xe3, 0x6e,
    0xad, 0x48, 0xfa, 0x01, 0x85, 0x23, 0xeb, 0x06, 0xd8, 0x0c, 0xd9, 0x30, 0xd5, 0x70, 0x74, 0x35,
    0x37, 0x57, 0xb1, 0x7c, 0xc7, 0x53, 0x60, 0x83, 0x26, 0xd9, 0x3e, 0x53, 0x32, 0x61, 0xb2, 0xfa,
    0xc5, 0xc2, 0xb4, 0x59, 0xc5, 0x32, 0x28, 0x7a, 0x2d, 0xd5, 0x44, 0xd9, 0xa4, 0x88, 0x26, 0xf1,
    0x72, 0xa6, 0x41, 0xe2, 0xe4, 0xe8, 0x4f, 0x84, 0xe5, 0x32, 0xc7, 0x07, 0xfd, 0xd6, 0x6b, 0x72,
    0x18, 0xd3, 0x78, 0xf4, 0xdd, 0x45, 0x6d, 0x12, 0xf6, 0xfc, 0xc4, 0xc1, 0x33, 0xde, 0x4f, 0x94,
    0x4a, 0x0e, 0xfd, 0x71, 0x82, 0xa7, 0xd9, 0x5d, 0x16, 0xec, 0x70, 0xe8, 0x2d, 0x25, 0x4c, 0x63,
    0x6d, 0x9d, 0x4f, 0x7d, 0x3a, 0xa3, 0x2e, 0x3c, 0xe5, 0xf7, 0x58, 0x61, 0xe4, 0x37, 0x9d, 0x55,
    0x18, 0x9e, 0x32, 0x77, 0x57, 0x83, 0x40, 0x37, 0x5c, 0x12, 0x16, 0xa0, 0xfd, 0xe5, 0x26, 0xe0,
    0xad, 0x96, 0xd4, 0x34, 0x95, 0x50, 0x87, 0xe4, 0xe1, 0x9c, 0xc3, 0xd3, 0x40, 0x72, 0x0d, 0x9a,
    0x27, 0xe7, 0x1b, 0x10, 0x79, 0x9d, 0xe5, 0x46, 0xbb, 0x25, 0x3f, 0xf0, 0x31, 0x1e, 0xfd, 0xed,
    0x27, 0xc4, 0x88, 0x6f, 0x42, 0x58, 0x86, 0xae, 0xc0, 0x65, 0xa3, 0xb7, 0x1e, 0x2a, 0x1b, 0x8d,
    0xb2, 0xbe, 0x14, 0x24, 0x8d, 0x81, 0x6a, 0xc9, 0x40, 0x3e, 0x0d, 0xc5, 0xf6, 0xf9, 0xfe, 0x03,
    0xac, 0x7c, 0xf2, 0xbb
};
#endif

PyTypeObject *init_QSpatialSound(PyObject *module)
{
    if (SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX].type != nullptr)
        return SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX].type;

    Shiboken::AutoDecRef Sbk_QSpatialSound_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QSpatialSound_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSpatialSound",
        "QSpatialSound*",
        &Sbk_QSpatialSound_spec,
        &Shiboken::callCppDestructor< QSpatialSound >,
        Sbk_QSpatialSound_Type_bases.object(),
        0);
    auto *pyType = Sbk_QSpatialSound_TypeF(); // references _Sbk_QSpatialSound_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSpatialSound_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSpatialSound_SignatureBytes, QSpatialSound_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSpatialSound_PropertyStrings);
    SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSpatialSound_PythonToCpp_QSpatialSound_PTR,
        is_QSpatialSound_PythonToCpp_QSpatialSound_PTR_Convertible,
        QSpatialSound_PTR_CppToPython_QSpatialSound);

    Shiboken::Conversions::registerConverterName(converter, "QSpatialSound");
    Shiboken::Conversions::registerConverterName(converter, "QSpatialSound*");
    Shiboken::Conversions::registerConverterName(converter, "QSpatialSound&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSpatialSound).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QSpatialSoundWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QSpatialSound_TypeF(), &Sbk_QSpatialSound_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QSpatialSound_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Loops'.
    const char *Loops_Initializer[] = {
        "Infinite",
        "Once",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t Loops_InitializerValues[] = {
        int8_t(QSpatialSound::Loops::Infinite), // -0x01 -1
        int8_t(QSpatialSound::Loops::Once)      //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSpatialSound_TypeF(),
        "2:PySide6.QtSpatialAudio.QSpatialSound.Loops",
        Loops_Initializer, Loops_InitializerValues);
    SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_Loops_IDX].type = EType;
    // Register converter for enum 'QSpatialSound::Loops'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSpatialSound_Loops_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QSpatialSound_Loops,
            is_Enum_PythonToCpp_QSpatialSound_Loops_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QSpatialSound::Loops");
        Shiboken::Conversions::registerConverterAlias(converter, "Loops");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Loops' enum.

    // Initialization of enum 'DistanceModel'.
    const char *DistanceModel_Initializer[] = {
        "Logarithmic",
        "Linear",
        "ManualAttenuation",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t DistanceModel_InitializerValues[] = {
        int8_t(QSpatialSound::DistanceModel::Logarithmic),      //  0x00  0
        int8_t(QSpatialSound::DistanceModel::Linear),           //  0x01  1
        int8_t(QSpatialSound::DistanceModel::ManualAttenuation) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSpatialSound_TypeF(),
        "2:PySide6.QtSpatialAudio.QSpatialSound.DistanceModel",
        DistanceModel_Initializer, DistanceModel_InitializerValues);
    SbkPySide6_QtSpatialAudioTypeStructs[SBK_QSpatialSound_DistanceModel_IDX].type = EType;
    // Register converter for enum 'QSpatialSound::DistanceModel'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSpatialSound_DistanceModel_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QSpatialSound_DistanceModel,
            is_Enum_PythonToCpp_QSpatialSound_DistanceModel_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QSpatialSound::DistanceModel");
        Shiboken::Conversions::registerConverterAlias(converter, "DistanceModel");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'DistanceModel' enum.

    PySide::Signal::registerSignals(pyType, &::QSpatialSound::staticMetaObject);
    qRegisterMetaType< ::QSpatialSound::Loops >("QSpatialSound::Loops");
    qRegisterMetaType< ::QSpatialSound::DistanceModel >("QSpatialSound::DistanceModel");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QSpatialSound::staticMetaObject, sizeof(QSpatialSoundWrapper));

    return pyType;
}
