// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtsql_python.h"

// main header
#include "qsqldatabase_wrapper.h"

// Extra includes
#include <QSize>
#include <QSqlError>
#include <QSqlIndex>
#include <QSqlQuery>
#include <QSqlRecord>
#include <QStringList>

// Argument includes
#include <QString>
#include <QStringList>
#include <QtSql/qsqldatabase.h>
#include <QtSql/qsqldriver.h>
#include <QtSql/qsqlerror.h>
#include <QtSql/qsqlindex.h>
#include <QtSql/qsqlquery.h>
#include <QtSql/qsqlrecord.h>
#include <QtSql/qtsqlglobal.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSqlDatabase_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSqlDatabase >()))
        return -1;

    ::QSqlDatabase *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QSqlDatabase", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QSqlDatabase::QSqlDatabase()
    // 1: QSqlDatabase::QSqlDatabase(QSqlDriver*)
    // 2: QSqlDatabase::QSqlDatabase(QSqlDatabase)
    // 3: QSqlDatabase::QSqlDatabase(QString)
    if (numArgs == 0) {
        overloadId = 0; // QSqlDatabase()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QSqlDatabase(QSqlDatabase)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QSqlDatabase(QSqlDriver*)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 3; // QSqlDatabase(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QSqlDatabase()
        {

            // QSqlDatabase()
            cptr = new ::QSqlDatabase();
            break;
        }
        case 1: // QSqlDatabase(QSqlDriver *driver)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QSqlDriver *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QSqlDatabase(QSqlDriver*)
                cptr = new ::QSqlDatabase(cppArg0);
            }
            break;
        }
        case 2: // QSqlDatabase(const QSqlDatabase &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QSqlDatabase cppArg0_local;
            ::QSqlDatabase *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QSqlDatabase(QSqlDatabase)
                cptr = new ::QSqlDatabase(*cppArg0);
            }
            break;
        }
        case 3: // QSqlDatabase(const QString &type)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QSqlDatabase(QString)
                cptr = new ::QSqlDatabase(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QSqlDatabase >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSqlDatabaseFunc_addDatabase(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "addDatabase", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);

    if (PyArg_ParseTuple(args, "|OO:addDatabase", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QSqlDatabase::addDatabase(QSqlDriver*,const QString&=)->QSqlDatabase
    // 1: static QSqlDatabase::addDatabase(QString,const QString&=)->QSqlDatabase
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // addDatabase(QSqlDriver*,QString)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 0; // addDatabase(QSqlDriver*,QString)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // addDatabase(QString,QString)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 1; // addDatabase(QString,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addDatabase", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // addDatabase(QSqlDriver *driver, const QString &connectionName)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_connectionName = Shiboken::String::createStaticString("connectionName");
                if (PyDict_Contains(kwds, key_connectionName) != 0) {
                    value = PyDict_GetItem(kwds, key_connectionName);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_connectionName);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "addDatabase", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "addDatabase", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_connectionName);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "addDatabase", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QSqlDriver *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1 = QLatin1StringView(QSqlDatabase::defaultConnection);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // addDatabase(QSqlDriver*,QString)
                QSqlDatabase cppResult = ::QSqlDatabase::addDatabase(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), &cppResult);
            }
            break;
        }
        case 1: // addDatabase(const QString &type, const QString &connectionName)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_connectionName = Shiboken::String::createStaticString("connectionName");
                if (PyDict_Contains(kwds, key_connectionName) != 0) {
                    value = PyDict_GetItem(kwds, key_connectionName);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_connectionName);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "addDatabase", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "addDatabase", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_connectionName);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "addDatabase", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1 = QLatin1StringView(QSqlDatabase::defaultConnection);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // addDatabase(QString,QString)
                QSqlDatabase cppResult = ::QSqlDatabase::addDatabase(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlDatabaseFunc_cloneDatabase(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "cloneDatabase", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QSqlDatabase::cloneDatabase(QSqlDatabase,QString)->QSqlDatabase
    // 1: static QSqlDatabase::cloneDatabase(QString,QString)->QSqlDatabase
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 1; // cloneDatabase(QString,QString)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // cloneDatabase(QSqlDatabase,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "cloneDatabase", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // cloneDatabase(const QSqlDatabase &other, const QString &connectionName)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QSqlDatabase cppArg0_local;
            ::QSqlDatabase *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // cloneDatabase(QSqlDatabase,QString)
                QSqlDatabase cppResult = ::QSqlDatabase::cloneDatabase(*cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), &cppResult);
            }
            break;
        }
        case 1: // cloneDatabase(const QString &other, const QString &connectionName)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // cloneDatabase(QString,QString)
                QSqlDatabase cppResult = ::QSqlDatabase::cloneDatabase(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlDatabaseFunc_close(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDatabase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // close()
        cppSelf->close();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlDatabaseFunc_commit(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDatabase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // commit()
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        bool cppResult = cppSelf->commit();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlDatabaseFunc_connectOptions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDatabase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // connectOptions()const
        QString cppResult = const_cast<const ::QSqlDatabase *>(cppSelf)->connectOptions();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlDatabaseFunc_connectionName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDatabase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // connectionName()const
        QString cppResult = const_cast<const ::QSqlDatabase *>(cppSelf)->connectionName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlDatabaseFunc_connectionNames(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // connectionNames()
        QStringList cppResult = ::QSqlDatabase::connectionNames();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlDatabaseFunc_contains(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "contains", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);

    if (PyArg_ParseTuple(args, "|O:contains", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QSqlDatabase::contains(const QString&=)->bool
    if (numArgs == 0) {
        overloadId = 0; // contains(QString)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 0; // contains(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "contains", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_connectionName = Shiboken::String::createStaticString("connectionName");
            if (PyDict_Contains(kwds, key_connectionName) != 0) {
                value = PyDict_GetItem(kwds, key_connectionName);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_connectionName);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "contains", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "contains", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_connectionName);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "contains", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);
            }
        }
        ::QString cppArg0 = QLatin1StringView(QSqlDatabase::defaultConnection);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // contains(QString)
            bool cppResult = ::QSqlDatabase::contains(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlDatabaseFunc_database(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "database", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);

    if (PyArg_ParseTuple(args, "|OO:database", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QSqlDatabase::database(const QString&=,bool=)->QSqlDatabase
    if (numArgs == 0) {
        overloadId = 0; // database(QString,bool)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // database(QString,bool)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 0; // database(QString,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "database", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_connectionName = Shiboken::String::createStaticString("connectionName");
            if (PyDict_Contains(kwds, key_connectionName) != 0) {
                value = PyDict_GetItem(kwds, key_connectionName);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_connectionName);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "database", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "database", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_connectionName);
            }
            static PyObject *const key_open = Shiboken::String::createStaticString("open");
            if (PyDict_Contains(kwds, key_open) != 0) {
                value = PyDict_GetItem(kwds, key_open);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_open);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "database", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "database", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_open);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "database", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);
            }
        }
        ::QString cppArg0 = QLatin1StringView(QSqlDatabase::defaultConnection);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);
        bool cppArg1 = true;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // database(QString,bool)
            QSqlDatabase cppResult = ::QSqlDatabase::database(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlDatabaseFunc_databaseName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDatabase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // databaseName()const
        QString cppResult = const_cast<const ::QSqlDatabase *>(cppSelf)->databaseName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlDatabaseFunc_driver(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDatabase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // driver()const
        QSqlDriver * cppResult = const_cast<const ::QSqlDatabase *>(cppSelf)->driver();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlDatabaseFunc_driverName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDatabase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // driverName()const
        QString cppResult = const_cast<const ::QSqlDatabase *>(cppSelf)->driverName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlDatabaseFunc_drivers(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // drivers()
        QStringList cppResult = ::QSqlDatabase::drivers();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlDatabaseFunc_exec(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDatabase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    pcm.setBlocking();
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "exec", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);

    if (PyArg_ParseTuple(args, "|O:exec", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSqlDatabase::exec(const QString&=)const->QSqlQuery
    if (numArgs == 0) {
        overloadId = 0; // exec(QString)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 0; // exec(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "exec", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QSqlDatabase", "exec(const QString &query) const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_query = Shiboken::String::createStaticString("query");
            if (PyDict_Contains(kwds, key_query) != 0) {
                value = PyDict_GetItem(kwds, key_query);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_query);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "exec", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "exec", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_query);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "exec", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);
            }
        }
        ::QString cppArg0 = QString();
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // exec(QString)const
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QSqlQuery cppResult = const_cast<const ::QSqlDatabase *>(cppSelf)->exec(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlDatabaseFunc_exec_(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDatabase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    pcm.setBlocking();
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "exec_", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);

    if (PyArg_ParseTuple(args, "|O:exec_", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSqlDatabase::exec_(QString=)const->QSqlQuery
    if (numArgs == 0) {
        overloadId = 0; // exec_(QString)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 0; // exec_(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "exec_", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_query = Shiboken::String::createStaticString("query");
            if (PyDict_Contains(kwds, key_query) != 0) {
                value = PyDict_GetItem(kwds, key_query);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_query);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "exec_", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "exec_", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_query);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "exec_", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);
            }
        }
        ::QString cppArg0 = QString();
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);
        SBK_UNUSED(cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // exec_(QString)const
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtsql.cpp (qsqldatabase-exec)]
            if (PyErr_WarnEx(PyExc_DeprecationWarning,
                             "'exec_' will be removed in the future. "
                             "Use 'exec' instead.",
                             1)) {
                return nullptr;
            }
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QSqlQuery cppResult = cppSelf->exec(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), &cppResult);
            // END of custom code block [file: ../glue/qtsql.cpp (qsqldatabase-exec)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlDatabaseFunc_hostName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDatabase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hostName()const
        QString cppResult = const_cast<const ::QSqlDatabase *>(cppSelf)->hostName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlDatabaseFunc_isDriverAvailable(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QSqlDatabase::isDriverAvailable(QString)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // isDriverAvailable(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isDriverAvailable", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isDriverAvailable(QString)
            bool cppResult = ::QSqlDatabase::isDriverAvailable(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlDatabaseFunc_isOpen(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDatabase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isOpen()const
        bool cppResult = const_cast<const ::QSqlDatabase *>(cppSelf)->isOpen();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlDatabaseFunc_isOpenError(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDatabase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isOpenError()const
        bool cppResult = const_cast<const ::QSqlDatabase *>(cppSelf)->isOpenError();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlDatabaseFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDatabase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QSqlDatabase *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlDatabaseFunc_lastError(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDatabase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lastError()const
        QSqlError cppResult = const_cast<const ::QSqlDatabase *>(cppSelf)->lastError();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlDatabaseFunc_moveToThread(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDatabase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlDatabase::moveToThread(QThread*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]), (pyArg)))) {
        overloadId = 0; // moveToThread(QThread*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "moveToThread", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QThread *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // moveToThread(QThread*)
            bool cppResult = cppSelf->moveToThread(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlDatabaseFunc_numericalPrecisionPolicy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDatabase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // numericalPrecisionPolicy()const
        QSql::NumericalPrecisionPolicy cppResult = const_cast<const ::QSqlDatabase *>(cppSelf)->numericalPrecisionPolicy();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSql_NumericalPrecisionPolicy_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlDatabaseFunc_open(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDatabase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 1)
        return Shiboken::returnWrongArguments(args, "open", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);

    if (PyArg_UnpackTuple(args, "open", 0, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSqlDatabase::open()->bool
    // 1: QSqlDatabase::open(QString,QString)->bool
    if (numArgs == 0) {
        overloadId = 0; // open()
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 1; // open(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "open", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // open()
        {

            // open()
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = cppSelf->open();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            break;
        }
        case 1: // open(const QString &user, const QString &password)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // open(QString,QString)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->open(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlDatabaseFunc_password(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDatabase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // password()const
        QString cppResult = const_cast<const ::QSqlDatabase *>(cppSelf)->password();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlDatabaseFunc_port(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDatabase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // port()const
        int cppResult = const_cast<const ::QSqlDatabase *>(cppSelf)->port();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlDatabaseFunc_primaryIndex(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDatabase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlDatabase::primaryIndex(QString)const->QSqlIndex
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // primaryIndex(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "primaryIndex", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // primaryIndex(QString)const
            QSqlIndex cppResult = const_cast<const ::QSqlDatabase *>(cppSelf)->primaryIndex(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlIndex_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlDatabaseFunc_record(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDatabase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlDatabase::record(QString)const->QSqlRecord
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // record(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "record", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // record(QString)const
            QSqlRecord cppResult = const_cast<const ::QSqlDatabase *>(cppSelf)->record(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlRecord_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlDatabaseFunc_registerSqlDriver(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "registerSqlDriver", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QSqlDatabase::registerSqlDriver(QString,QSqlDriverCreatorBase*)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriverCreatorBase_IDX]), (pyArgs[1])))) {
        overloadId = 0; // registerSqlDriver(QString,QSqlDriverCreatorBase*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "registerSqlDriver", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QSqlDriverCreatorBase *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // registerSqlDriver(QString,QSqlDriverCreatorBase*)
            ::QSqlDatabase::registerSqlDriver(cppArg0, cppArg1);

            // Ownership transferences.
            Shiboken::Object::releaseOwnership(pyArgs[1]);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlDatabaseFunc_removeDatabase(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QSqlDatabase::removeDatabase(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // removeDatabase(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeDatabase", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeDatabase(QString)
            ::QSqlDatabase::removeDatabase(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlDatabaseFunc_rollback(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDatabase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rollback()
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        bool cppResult = cppSelf->rollback();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlDatabaseFunc_setConnectOptions(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDatabase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setConnectOptions", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);

    if (PyArg_ParseTuple(args, "|O:setConnectOptions", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSqlDatabase::setConnectOptions(const QString&=)
    if (numArgs == 0) {
        overloadId = 0; // setConnectOptions(QString)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 0; // setConnectOptions(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setConnectOptions", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_options = Shiboken::String::createStaticString("options");
            if (PyDict_Contains(kwds, key_options) != 0) {
                value = PyDict_GetItem(kwds, key_options);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_options);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setConnectOptions", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "setConnectOptions", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_options);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setConnectOptions", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);
            }
        }
        ::QString cppArg0 = QString();
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setConnectOptions(QString)
            cppSelf->setConnectOptions(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlDatabaseFunc_setDatabaseName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDatabase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlDatabase::setDatabaseName(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setDatabaseName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDatabaseName", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDatabaseName(QString)
            cppSelf->setDatabaseName(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlDatabaseFunc_setHostName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDatabase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlDatabase::setHostName(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setHostName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHostName", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHostName(QString)
            cppSelf->setHostName(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlDatabaseFunc_setNumericalPrecisionPolicy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDatabase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlDatabase::setNumericalPrecisionPolicy(QSql::NumericalPrecisionPolicy)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSql_NumericalPrecisionPolicy_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setNumericalPrecisionPolicy(QSql::NumericalPrecisionPolicy)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setNumericalPrecisionPolicy", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);

    // Call function/method
    {
        ::QSql::NumericalPrecisionPolicy cppArg0{QSql::HighPrecision};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setNumericalPrecisionPolicy(QSql::NumericalPrecisionPolicy)
            cppSelf->setNumericalPrecisionPolicy(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlDatabaseFunc_setPassword(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDatabase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlDatabase::setPassword(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setPassword(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPassword", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPassword(QString)
            cppSelf->setPassword(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlDatabaseFunc_setPort(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDatabase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlDatabase::setPort(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setPort(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPort", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPort(int)
            cppSelf->setPort(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlDatabaseFunc_setUserName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDatabase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlDatabase::setUserName(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setUserName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUserName", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setUserName(QString)
            cppSelf->setUserName(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlDatabaseFunc_tables(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDatabase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "tables", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);

    if (PyArg_ParseTuple(args, "|O:tables", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSqlDatabase::tables(QSql::TableType=)const->QStringList
    if (numArgs == 0) {
        overloadId = 0; // tables(QSql::TableType)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSql_TableType_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // tables(QSql::TableType)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "tables", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_type = Shiboken::String::createStaticString("type");
            if (PyDict_Contains(kwds, key_type) != 0) {
                value = PyDict_GetItem(kwds, key_type);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_type);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "tables", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSql_TableType_IDX])))->converter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "tables", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_type);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "tables", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]);
            }
        }
        ::QSql::TableType cppArg0(QSql::Tables);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // tables(QSql::TableType)const
            QStringList cppResult = const_cast<const ::QSqlDatabase *>(cppSelf)->tables(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlDatabaseFunc_thread(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDatabase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // thread()const
        QThread * cppResult = const_cast<const ::QSqlDatabase *>(cppSelf)->thread();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlDatabaseFunc_transaction(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDatabase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // transaction()
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        bool cppResult = cppSelf->transaction();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlDatabaseFunc_userName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDatabase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // userName()const
        QString cppResult = const_cast<const ::QSqlDatabase *>(cppSelf)->userName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlDatabase__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QSqlDatabase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QSqlDatabase_PropertyStrings[] = {
    "numericalPrecisionPolicy::",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSqlDatabase_methods[] = {
    {"addDatabase", reinterpret_cast<PyCFunction>(Sbk_QSqlDatabaseFunc_addDatabase), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"cloneDatabase", reinterpret_cast<PyCFunction>(Sbk_QSqlDatabaseFunc_cloneDatabase), METH_VARARGS|METH_STATIC, nullptr},
    {"close", reinterpret_cast<PyCFunction>(Sbk_QSqlDatabaseFunc_close), METH_NOARGS, nullptr},
    {"commit", reinterpret_cast<PyCFunction>(Sbk_QSqlDatabaseFunc_commit), METH_NOARGS, nullptr},
    {"connectOptions", reinterpret_cast<PyCFunction>(Sbk_QSqlDatabaseFunc_connectOptions), METH_NOARGS, nullptr},
    {"connectionName", reinterpret_cast<PyCFunction>(Sbk_QSqlDatabaseFunc_connectionName), METH_NOARGS, nullptr},
    {"connectionNames", reinterpret_cast<PyCFunction>(Sbk_QSqlDatabaseFunc_connectionNames), METH_NOARGS|METH_STATIC, nullptr},
    {"contains", reinterpret_cast<PyCFunction>(Sbk_QSqlDatabaseFunc_contains), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"database", reinterpret_cast<PyCFunction>(Sbk_QSqlDatabaseFunc_database), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"databaseName", reinterpret_cast<PyCFunction>(Sbk_QSqlDatabaseFunc_databaseName), METH_NOARGS, nullptr},
    {"driver", reinterpret_cast<PyCFunction>(Sbk_QSqlDatabaseFunc_driver), METH_NOARGS, nullptr},
    {"driverName", reinterpret_cast<PyCFunction>(Sbk_QSqlDatabaseFunc_driverName), METH_NOARGS, nullptr},
    {"drivers", reinterpret_cast<PyCFunction>(Sbk_QSqlDatabaseFunc_drivers), METH_NOARGS|METH_STATIC, nullptr},
    {"exec", reinterpret_cast<PyCFunction>(Sbk_QSqlDatabaseFunc_exec), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"exec_", reinterpret_cast<PyCFunction>(Sbk_QSqlDatabaseFunc_exec_), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"hostName", reinterpret_cast<PyCFunction>(Sbk_QSqlDatabaseFunc_hostName), METH_NOARGS, nullptr},
    {"isDriverAvailable", reinterpret_cast<PyCFunction>(Sbk_QSqlDatabaseFunc_isDriverAvailable), METH_O|METH_STATIC, nullptr},
    {"isOpen", reinterpret_cast<PyCFunction>(Sbk_QSqlDatabaseFunc_isOpen), METH_NOARGS, nullptr},
    {"isOpenError", reinterpret_cast<PyCFunction>(Sbk_QSqlDatabaseFunc_isOpenError), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QSqlDatabaseFunc_isValid), METH_NOARGS, nullptr},
    {"lastError", reinterpret_cast<PyCFunction>(Sbk_QSqlDatabaseFunc_lastError), METH_NOARGS, nullptr},
    {"moveToThread", reinterpret_cast<PyCFunction>(Sbk_QSqlDatabaseFunc_moveToThread), METH_O, nullptr},
    {"numericalPrecisionPolicy", reinterpret_cast<PyCFunction>(Sbk_QSqlDatabaseFunc_numericalPrecisionPolicy), METH_NOARGS, nullptr},
    {"open", reinterpret_cast<PyCFunction>(Sbk_QSqlDatabaseFunc_open), METH_VARARGS, nullptr},
    {"password", reinterpret_cast<PyCFunction>(Sbk_QSqlDatabaseFunc_password), METH_NOARGS, nullptr},
    {"port", reinterpret_cast<PyCFunction>(Sbk_QSqlDatabaseFunc_port), METH_NOARGS, nullptr},
    {"primaryIndex", reinterpret_cast<PyCFunction>(Sbk_QSqlDatabaseFunc_primaryIndex), METH_O, nullptr},
    {"record", reinterpret_cast<PyCFunction>(Sbk_QSqlDatabaseFunc_record), METH_O, nullptr},
    {"registerSqlDriver", reinterpret_cast<PyCFunction>(Sbk_QSqlDatabaseFunc_registerSqlDriver), METH_VARARGS|METH_STATIC, nullptr},
    {"removeDatabase", reinterpret_cast<PyCFunction>(Sbk_QSqlDatabaseFunc_removeDatabase), METH_O|METH_STATIC, nullptr},
    {"rollback", reinterpret_cast<PyCFunction>(Sbk_QSqlDatabaseFunc_rollback), METH_NOARGS, nullptr},
    {"setConnectOptions", reinterpret_cast<PyCFunction>(Sbk_QSqlDatabaseFunc_setConnectOptions), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setDatabaseName", reinterpret_cast<PyCFunction>(Sbk_QSqlDatabaseFunc_setDatabaseName), METH_O, nullptr},
    {"setHostName", reinterpret_cast<PyCFunction>(Sbk_QSqlDatabaseFunc_setHostName), METH_O, nullptr},
    {"setNumericalPrecisionPolicy", reinterpret_cast<PyCFunction>(Sbk_QSqlDatabaseFunc_setNumericalPrecisionPolicy), METH_O, nullptr},
    {"setPassword", reinterpret_cast<PyCFunction>(Sbk_QSqlDatabaseFunc_setPassword), METH_O, nullptr},
    {"setPort", reinterpret_cast<PyCFunction>(Sbk_QSqlDatabaseFunc_setPort), METH_O, nullptr},
    {"setUserName", reinterpret_cast<PyCFunction>(Sbk_QSqlDatabaseFunc_setUserName), METH_O, nullptr},
    {"tables", reinterpret_cast<PyCFunction>(Sbk_QSqlDatabaseFunc_tables), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"thread", reinterpret_cast<PyCFunction>(Sbk_QSqlDatabaseFunc_thread), METH_NOARGS, nullptr},
    {"transaction", reinterpret_cast<PyCFunction>(Sbk_QSqlDatabaseFunc_transaction), METH_NOARGS, nullptr},
    {"userName", reinterpret_cast<PyCFunction>(Sbk_QSqlDatabaseFunc_userName), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QSqlDatabase__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QSqlDatabase_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSqlDatabase_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QSqlDatabase__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDatabase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSqlDatabase_Type = nullptr;
static PyTypeObject *Sbk_QSqlDatabase_TypeF(void)
{
    return _Sbk_QSqlDatabase_Type;
}

static PyType_Slot Sbk_QSqlDatabase_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QSqlDatabase__repr__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSqlDatabase_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSqlDatabase_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSqlDatabase_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSqlDatabase_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSqlDatabase_spec = {
    "2:PySide6.QtSql.QSqlDatabase",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSqlDatabase_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSqlDatabase_PythonToCpp_QSqlDatabase_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSqlDatabase_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSqlDatabase_PythonToCpp_QSqlDatabase_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSqlDatabase_TypeF()))
        return QSqlDatabase_PythonToCpp_QSqlDatabase_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSqlDatabase_PTR_CppToPython_QSqlDatabase(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QSqlDatabase_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QSqlDatabase_COPY_CppToPython_QSqlDatabase(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QSqlDatabase *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QSqlDatabase_TypeF(), new ::QSqlDatabase(*source), true, true);
}

// Python to C++ copy conversion.
static void QSqlDatabase_PythonToCpp_QSqlDatabase_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QSqlDatabase *>(cppOut) = *reinterpret_cast< ::QSqlDatabase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QSqlDatabase_PythonToCpp_QSqlDatabase_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QSqlDatabase_TypeF()))
        return QSqlDatabase_PythonToCpp_QSqlDatabase_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSqlDatabase_SignatureStrings[] = {
    "3:PySide6.QtSql.QSqlDatabase(self,*:KeywordOnly=None,numericalPrecisionPolicy:QSql.NumericalPrecisionPolicy=None)",
    "2:PySide6.QtSql.QSqlDatabase(self,driver:PySide6.QtSql.QSqlDriver,*:KeywordOnly=None,numericalPrecisionPolicy:QSql.NumericalPrecisionPolicy=None)",
    "1:PySide6.QtSql.QSqlDatabase(self,other:PySide6.QtSql.QSqlDatabase,*:KeywordOnly=None,numericalPrecisionPolicy:QSql.NumericalPrecisionPolicy=None)",
    "0:PySide6.QtSql.QSqlDatabase(self,type:QString,*:KeywordOnly=None,numericalPrecisionPolicy:QSql.NumericalPrecisionPolicy=None)",
    "1:PySide6.QtSql.QSqlDatabase.addDatabase(driver:PySide6.QtSql.QSqlDriver,connectionName:QString=QLatin1StringView(QSqlDatabase.defaultConnection))->PySide6.QtSql.QSqlDatabase",
    "0:PySide6.QtSql.QSqlDatabase.addDatabase(type:QString,connectionName:QString=QLatin1StringView(QSqlDatabase.defaultConnection))->PySide6.QtSql.QSqlDatabase",
    "1:PySide6.QtSql.QSqlDatabase.cloneDatabase(other:PySide6.QtSql.QSqlDatabase,connectionName:QString)->PySide6.QtSql.QSqlDatabase",
    "0:PySide6.QtSql.QSqlDatabase.cloneDatabase(other:QString,connectionName:QString)->PySide6.QtSql.QSqlDatabase",
    "PySide6.QtSql.QSqlDatabase.close(self)",
    "PySide6.QtSql.QSqlDatabase.commit(self)->bool",
    "PySide6.QtSql.QSqlDatabase.connectOptions(self)->QString",
    "PySide6.QtSql.QSqlDatabase.connectionName(self)->QString",
    "PySide6.QtSql.QSqlDatabase.connectionNames()->QStringList",
    "PySide6.QtSql.QSqlDatabase.contains(connectionName:QString=QLatin1StringView(QSqlDatabase.defaultConnection))->bool",
    "PySide6.QtSql.QSqlDatabase.database(connectionName:QString=QLatin1StringView(QSqlDatabase.defaultConnection),open:bool=true)->PySide6.QtSql.QSqlDatabase",
    "PySide6.QtSql.QSqlDatabase.databaseName(self)->QString",
    "PySide6.QtSql.QSqlDatabase.driver(self)->PySide6.QtSql.QSqlDriver",
    "PySide6.QtSql.QSqlDatabase.driverName(self)->QString",
    "PySide6.QtSql.QSqlDatabase.drivers()->QStringList",
    "PySide6.QtSql.QSqlDatabase.exec(self,query:QString=QString())->PySide6.QtSql.QSqlQuery",
    "PySide6.QtSql.QSqlDatabase.exec_(self,query:QString=QString())->PySide6.QtSql.QSqlQuery",
    "PySide6.QtSql.QSqlDatabase.hostName(self)->QString",
    "PySide6.QtSql.QSqlDatabase.isDriverAvailable(name:QString)->bool",
    "PySide6.QtSql.QSqlDatabase.isOpen(self)->bool",
    "PySide6.QtSql.QSqlDatabase.isOpenError(self)->bool",
    "PySide6.QtSql.QSqlDatabase.isValid(self)->bool",
    "PySide6.QtSql.QSqlDatabase.lastError(self)->PySide6.QtSql.QSqlError",
    "PySide6.QtSql.QSqlDatabase.moveToThread(self,targetThread:PySide6.QtCore.QThread)->bool",
    "PySide6.QtSql.QSqlDatabase.numericalPrecisionPolicy(self)->PySide6.QtSql.QSql.NumericalPrecisionPolicy",
    "1:PySide6.QtSql.QSqlDatabase.open(self)->bool",
    "0:PySide6.QtSql.QSqlDatabase.open(self,user:QString,password:QString)->bool",
    "PySide6.QtSql.QSqlDatabase.password(self)->QString",
    "PySide6.QtSql.QSqlDatabase.port(self)->int",
    "PySide6.QtSql.QSqlDatabase.primaryIndex(self,tablename:QString)->PySide6.QtSql.QSqlIndex",
    "PySide6.QtSql.QSqlDatabase.record(self,tablename:QString)->PySide6.QtSql.QSqlRecord",
    "PySide6.QtSql.QSqlDatabase.registerSqlDriver(name:QString,creator:PySide6.QtSql.QSqlDriverCreatorBase)",
    "PySide6.QtSql.QSqlDatabase.removeDatabase(connectionName:QString)",
    "PySide6.QtSql.QSqlDatabase.rollback(self)->bool",
    "PySide6.QtSql.QSqlDatabase.setConnectOptions(self,options:QString=QString())",
    "PySide6.QtSql.QSqlDatabase.setDatabaseName(self,name:QString)",
    "PySide6.QtSql.QSqlDatabase.setHostName(self,host:QString)",
    "PySide6.QtSql.QSqlDatabase.setNumericalPrecisionPolicy(self,precisionPolicy:PySide6.QtSql.QSql.NumericalPrecisionPolicy)",
    "PySide6.QtSql.QSqlDatabase.setPassword(self,password:QString)",
    "PySide6.QtSql.QSqlDatabase.setPort(self,p:int)",
    "PySide6.QtSql.QSqlDatabase.setUserName(self,name:QString)",
    "PySide6.QtSql.QSqlDatabase.tables(self,type:PySide6.QtSql.QSql.TableType=QSql.Tables)->QStringList",
    "PySide6.QtSql.QSqlDatabase.thread(self)->PySide6.QtCore.QThread",
    "PySide6.QtSql.QSqlDatabase.transaction(self)->bool",
    "PySide6.QtSql.QSqlDatabase.userName(self)->QString",
    "PySide6.QtSql.QSqlDatabase.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QSqlDatabase_SignatureByteSize = 665;
static constexpr uint8_t QSqlDatabase_SignatureBytes[665] = {
    0x78, 0xda, 0xbd, 0x57, 0x5b, 0x6f, 0x9b, 0x30, 0x14, 0x7e, 0xef, 0x2f, 0x09, 0x15, 0x45, 0xed,
    0x26, 0xed, 0x01, 0x29, 0x95, 0xb6, 0x64, 0xd2, 0xa6, 0x55, 0xb9, 0x2c, 0x59, 0x5f, 0x23, 0x07,
    0x4e, 0x13, 0x6b, 0xc6, 0xa6, 0xb6, 0x49, 0xcb, 0xbf, 0x9f, 0xb9, 0x06, 0x52, 0xb0, 0x4d, 0x96,
    0xf6, 0x25, 0x91, 0xf1, 0xf9, 0xce, 0xf9, 0xf8, 0x7c, 0x2e, 0xe6, 0xb3, 0xbf, 0x48, 0x57, 0x38,
    0x84, 0x2f, 0xde, 0x52, 0xae, 0x9e, 0x89, 0xb7, 0x54, 0x3f, 0x53, 0x24, 0xd1, 0x16, 0x09, 0x18,
    0x09, 0x20, 0x4f, 0xee, 0xb5, 0xff, 0x0b, 0xd2, 0x17, 0xc6, 0xc3, 0x39, 0x25, 0xe9, 0x78, 0xc6,
    0x28, 0xb8, 0x34, 0x89, 0x80, 0xe3, 0x00, 0x91, 0x05, 0x87, 0x00, 0x0b, 0xcc, 0xe8, 0x82, 0x11,
    0x1c, 0xa4, 0x7e, 0x86, 0xf6, 0x66, 0x3d, 0xbb, 0x39, 0xd6, 0xb9, 0xfa, 0x64, 0x8c, 0x18, 0x72,
    0x7c, 0x00, 0xde, 0x65, 0x96, 0x6f, 0x5c, 0x9c, 0xd1, 0x9d, 0x91, 0x11, 0x93, 0xfb, 0x6e, 0x42,
    0xa5, 0xd5, 0xc5, 0x29, 0xdd, 0x1a, 0x29, 0xc9, 0x34, 0x06, 0xe5, 0x4a, 0x72, 0x4c, 0x77, 0x1f,
    0xaa, 0x88, 0x87, 0xc2, 0xb0, 0xa6, 0x62, 0x3a, 0xaa, 0x80, 0x51, 0x0a, 0x81, 0x54, 0xfe, 0x67,
    0x28, 0xaa, 0xf9, 0x8e, 0x97, 0x0f, 0x48, 0x62, 0x7a, 0x57, 0xac, 0x1e, 0x31, 0xbc, 0x8c, 0x5a,
    0x11, 0x42, 0x78, 0x42, 0x09, 0x91, 0x93, 0x1a, 0xec, 0x38, 0x37, 0xf7, 0xfd, 0x8c, 0xb4, 0x6a,
    0xb5, 0xe8, 0xb6, 0x44, 0xfb, 0x18, 0x6e, 0x5a, 0x29, 0x03, 0xa2, 0xe4, 0xae, 0xd9, 0x19, 0xb3,
    0xac, 0x9b, 0xf1, 0x7f, 0x68, 0xd3, 0x15, 0x5f, 0x2f, 0x8f, 0x3e, 0x98, 0x3e, 0x54, 0x99, 0xba,
    0x8e, 0xd6, 0x8c, 0x45, 0x11, 0x96, 0x85, 0xdd, 0xcd, 0xfd, 0x96, 0x31, 0xa2, 0xb7, 0xce, 0x39,
    0xce, 0xe3, 0x8c, 0xa6, 0xa8, 0x50, 0x25, 0x55, 0x0b, 0x60, 0xf9, 0x72, 0x67, 0x03, 0xc5, 0xe8,
    0x88, 0x7a, 0xc0, 0x42, 0x1a, 0x90, 0x12, 0x61, 0xc5, 0xf2, 0x82, 0x79, 0x67, 0xd2, 0x27, 0xac,
    0x8e, 0xf6, 0x52, 0x31, 0x5d, 0x16, 0x03, 0xf5, 0xb3, 0xb0, 0x63, 0xc9, 0x13, 0x38, 0x3b, 0x1b,
    0x2a, 0x62, 0x03, 0xd5, 0x2f, 0xda, 0x4d, 0x05, 0xe8, 0xeb, 0x3a, 0x66, 0x0f, 0x67, 0x85, 0x1d,
    0x72, 0xd8, 0xf0, 0x0a, 0x41, 0xd1, 0xa7, 0x9f, 0x13, 0xe0, 0xe9, 0x51, 0xf0, 0xe2, 0x7f, 0xd4,
    0xdd, 0x34, 0x96, 0x99, 0xad, 0xc9, 0xed, 0xe6, 0x1d, 0xfc, 0xee, 0x99, 0x90, 0x03, 0x35, 0xc1,
    0xa2, 0x10, 0xfb, 0xeb, 0x01, 0x61, 0x82, 0xb6, 0x04, 0x46, 0xb4, 0xdd, 0x26, 0x4c, 0xb9, 0x89,
    0xc5, 0x5c, 0xe5, 0x92, 0x6d, 0xa5, 0x17, 0xd6, 0xdf, 0x39, 0x67, 0xdc, 0x1e, 0xf2, 0x88, 0x08,
    0x0e, 0x6d, 0xcd, 0x09, 0x12, 0xb2, 0xe5, 0xff, 0xad, 0x6d, 0xbe, 0xad, 0xf3, 0x11, 0xb1, 0x03,
    0xac, 0xd9, 0x7a, 0xcf, 0x01, 0x85, 0xe5, 0x98, 0x46, 0x7c, 0x07, 0xb2, 0x78, 0xd2, 0xe8, 0xc4,
    0x13, 0xc6, 0xc1, 0x5b, 0x16, 0x8f, 0x2d, 0xb8, 0xf5, 0x0d, 0xf3, 0x7e, 0xaa, 0xbd, 0x13, 0x5e,
    0x3f, 0x90, 0xd8, 0xe9, 0x91, 0xdc, 0x5a, 0x59, 0xbb, 0x89, 0x68, 0x4c, 0x8e, 0x18, 0x09, 0x91,
    0x5d, 0x46, 0x06, 0x24, 0x43, 0x05, 0x19, 0x90, 0x80, 0x31, 0xe3, 0xf5, 0x9c, 0xc0, 0x54, 0x5b,
    0x8d, 0x31, 0xc7, 0x11, 0xe2, 0xe9, 0x4f, 0x1a, 0xc2, 0x6b, 0x75, 0x2c, 0x2a, 0x63, 0xa9, 0x69,
    0xae, 0xe5, 0x00, 0x9d, 0x63, 0x25, 0x6d, 0x45, 0xda, 0xd2, 0xe5, 0xef, 0x1c, 0xa1, 0xf7, 0xb9,
    0x53, 0xcd, 0x05, 0x78, 0xdd, 0xce, 0x5a, 0x85, 0xe5, 0x06, 0x2a, 0x65, 0x24, 0xeb, 0xbf, 0x72,
    0x4d, 0x8a, 0xfd, 0x6f, 0xca, 0x95, 0xa3, 0x0f, 0x93, 0x25, 0xeb, 0x54, 0x3f, 0x20, 0xf4, 0x1e,
    0x18, 0x21, 0x5b, 0x14, 0xfc, 0xb5, 0x2d, 0x30, 0x01, 0xd5, 0x24, 0x69, 0xce, 0x6b, 0x35, 0x51,
    0xf2, 0x45, 0x47, 0x2b, 0x33, 0x38, 0x9b, 0x9e, 0xce, 0x10, 0x97, 0xda, 0x52, 0x57, 0xe8, 0x1f,
    0xcd, 0x96, 0xe7, 0x66, 0x0d, 0xd0, 0x16, 0x39, 0xd3, 0x15, 0xa3, 0x1b, 0x9f, 0x5c, 0xb7, 0x07,
    0x94, 0xa6, 0x29, 0xf0, 0xa2, 0x59, 0x24, 0x6f, 0xab, 0xcc, 0x84, 0xae, 0xea, 0xc5, 0x8d, 0x7d,
    0x55, 0x2f, 0x26, 0xf3, 0x3f, 0xa2, 0x31, 0x26, 0xed, 0x95, 0xcd, 0xab, 0x40, 0x34, 0x3e, 0x51,
    0x3a, 0xde, 0x7f, 0x9d, 0xd9, 0xac, 0xd5, 0xe6, 0xf8, 0xb8, 0x14, 0xf6, 0xb3, 0x55, 0x1e, 0xdb,
    0x6b, 0xab, 0xc4, 0x9a, 0x3d, 0x55, 0x8b, 0xe7, 0x88, 0x0a, 0x94, 0xe7, 0xba, 0x6d, 0xea, 0x26,
    0x62, 0xf0, 0x9d, 0x61, 0xb3, 0x09, 0x58, 0x9c, 0x6e, 0x36, 0x15, 0x44, 0x89, 0xa1, 0x10, 0xde,
    0x4a, 0xad, 0xae, 0xfe, 0x01, 0x58, 0x83, 0x97, 0xef
};
#endif

PyTypeObject *init_QSqlDatabase(PyObject *module)
{
    if (SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX].type != nullptr)
        return SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX].type;

    Shiboken::AutoDecRef Sbk_QSqlDatabase_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QSqlDatabase_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSqlDatabase",
        "QSqlDatabase",
        &Sbk_QSqlDatabase_spec,
        &Shiboken::callCppDestructor< ::QSqlDatabase >,
        Sbk_QSqlDatabase_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QSqlDatabase_TypeF(); // references _Sbk_QSqlDatabase_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSqlDatabase_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSqlDatabase_SignatureBytes, QSqlDatabase_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSqlDatabase_PropertyStrings);
    SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSqlDatabase_PythonToCpp_QSqlDatabase_PTR,
        is_QSqlDatabase_PythonToCpp_QSqlDatabase_PTR_Convertible,
        QSqlDatabase_PTR_CppToPython_QSqlDatabase,
        QSqlDatabase_COPY_CppToPython_QSqlDatabase);

    Shiboken::Conversions::registerConverterName(converter, "QSqlDatabase");
    Shiboken::Conversions::registerConverterName(converter, "QSqlDatabase*");
    Shiboken::Conversions::registerConverterName(converter, "QSqlDatabase&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSqlDatabase).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QSqlDatabase_PythonToCpp_QSqlDatabase_COPY,
        is_QSqlDatabase_PythonToCpp_QSqlDatabase_COPY_Convertible);

    qRegisterMetaType< ::QSqlDatabase >("QSqlDatabase");

    return pyType;
}

PyTypeObject *init_QSqlDatabaseStaticFields(PyObject *module)
{
    auto *obType = PyObject_GetAttrString(module, "QSqlDatabase");
    auto *type = reinterpret_cast<PyTypeObject *>(obType);
    Shiboken::AutoDecRef dict(PepType_GetDict(type));
    PyDict_SetItemString(dict, "defaultConnection",
                         Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), QSqlDatabase::defaultConnection));
    return type;
}
