// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QSqlDriverWrapper_H
#define SBK_QSqlDriverWrapper_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtSql/qsqldriver.h>

namespace PySide { class DynamicQMetaObject; }

class QSqlDriverWrapper : public QSqlDriver
{
public:
    QSqlDriverWrapper(const QSqlDriverWrapper &) = delete;
    QSqlDriverWrapper& operator=(const QSqlDriverWrapper &) = delete;
    QSqlDriverWrapper(QSqlDriverWrapper &&) = delete;
    QSqlDriverWrapper& operator=(QSqlDriverWrapper &&) = delete;

    QSqlDriverWrapper(::QObject * parent = nullptr);
    bool beginTransaction() override;
    bool cancelQuery() override;
    void childEvent(::QChildEvent * event) override;
    void close() override;
    bool commitTransaction() override;
    void connectNotify(const ::QMetaMethod & signal) override;
    ::QSqlResult * createResult() const override;
    void customEvent(::QEvent * event) override;
    void disconnectNotify(const ::QMetaMethod & signal) override;
    ::QString escapeIdentifier(const ::QString & identifier, ::QSqlDriver::IdentifierType type) const override;
    bool event(::QEvent * event) override;
    bool eventFilter(::QObject * watched, ::QEvent * event) override;
    ::QString formatValue(const ::QSqlField & field, bool trimStrings = false) const override;
    bool hasFeature(::QSqlDriver::DriverFeature f) const override;
    bool isIdentifierEscaped(const ::QString & identifier, ::QSqlDriver::IdentifierType type) const override;
    bool isOpen() const override;
    int maximumIdentifierLength(::QSqlDriver::IdentifierType type) const override;
    bool open(const ::QString & db, const ::QString & user = QString(), const ::QString & password = QString(), const ::QString & host = QString(), int port = -1, const ::QString & connOpts = QString()) override;
    ::QSqlIndex primaryIndex(const ::QString & tableName) const override;
    ::QSqlRecord record(const ::QString & tableName) const override;
    bool rollbackTransaction() override;
    void setLastError(const ::QSqlError & e) override;
    void setOpen(bool o) override;
    void setOpenError(bool e) override;
    ::QString sqlStatement(::QSqlDriver::StatementType type, const ::QString & tableName, const ::QSqlRecord & rec, bool preparedStatement) const override;
    ::QString stripDelimiters(const ::QString & identifier, ::QSqlDriver::IdentifierType type) const override;
    bool subscribeToNotification(const ::QString & name) override;
    ::QStringList subscribedToNotifications() const override;
    ::QStringList tables(::QSql::TableType tableType) const override;
    void timerEvent(::QTimerEvent * event) override;
    bool unsubscribeFromNotification(const ::QString & name) override;
    ~QSqlDriverWrapper() override;

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();
    void resetPyMethodCache();
private:
    mutable bool m_PyMethodCache[31] = {false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QSqlDriverWrapper_H

