// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtsql_python.h"

// main header
#include "qsqldrivercreatorbase_wrapper.h"

// Extra includes
#include <QSqlDriver>

// Argument includes
#include <QtSql/qsqldriver.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QSqlDriverCreatorBaseWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QSqlDriverCreatorBaseWrapper::QSqlDriverCreatorBaseWrapper()
{
}

::QSqlDriver * QSqlDriverCreatorBaseWrapper::createObject() const
{
    if (m_PyMethodCache[0]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QSqlDriverCreatorBase.createObject");
        return nullptr;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "createObject";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        Shiboken::Errors::setPureVirtualMethodError("QSqlDriverCreatorBase.createObject");
        return nullptr;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSqlDriverCreatorBase", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSqlDriverCreatorBase", funcName, Shiboken::SbkType< QSqlDriver >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QSqlDriver *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QSqlDriverCreatorBaseWrapper::~QSqlDriverCreatorBaseWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSqlDriverCreatorBase_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriverCreatorBase_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QSqlDriverCreatorBase");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSqlDriverCreatorBase >()))
        return -1;

    QSqlDriverCreatorBaseWrapper *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriverCreatorBase_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QSqlDriverCreatorBase()
        cptr = new QSqlDriverCreatorBaseWrapper();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QSqlDriverCreatorBase >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSqlDriverCreatorBaseFunc_createObject(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlDriverCreatorBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriverCreatorBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // createObject()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QSqlDriverCreatorBase.createObject");
            return {};
        }
        QSqlDriver * cppResult = const_cast<const ::QSqlDriverCreatorBase *>(cppSelf)->createObject();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QSqlDriverCreatorBase_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSqlDriverCreatorBase_methods[] = {
    {"createObject", reinterpret_cast<PyCFunction>(Sbk_QSqlDriverCreatorBaseFunc_createObject), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QSqlDriverCreatorBase_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QSqlDriverCreatorBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriverCreatorBase_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QSqlDriverCreatorBaseWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QSqlDriverCreatorBase_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSqlDriverCreatorBase_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSqlDriverCreatorBase_Type = nullptr;
static PyTypeObject *Sbk_QSqlDriverCreatorBase_TypeF(void)
{
    return _Sbk_QSqlDriverCreatorBase_Type;
}

static PyType_Slot Sbk_QSqlDriverCreatorBase_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QSqlDriverCreatorBase_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSqlDriverCreatorBase_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSqlDriverCreatorBase_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSqlDriverCreatorBase_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSqlDriverCreatorBase_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSqlDriverCreatorBase_spec = {
    "2:PySide6.QtSql.QSqlDriverCreatorBase",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSqlDriverCreatorBase_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSqlDriverCreatorBase_PythonToCpp_QSqlDriverCreatorBase_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSqlDriverCreatorBase_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSqlDriverCreatorBase_PythonToCpp_QSqlDriverCreatorBase_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSqlDriverCreatorBase_TypeF()))
        return QSqlDriverCreatorBase_PythonToCpp_QSqlDriverCreatorBase_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSqlDriverCreatorBase_PTR_CppToPython_QSqlDriverCreatorBase(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QSqlDriverCreatorBase *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QSqlDriverCreatorBase_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSqlDriverCreatorBase_SignatureStrings[] = {
    "PySide6.QtSql.QSqlDriverCreatorBase(self)",
    "PySide6.QtSql.QSqlDriverCreatorBase.createObject(self)->PySide6.QtSql.QSqlDriver",
    nullptr}; // Sentinel
#else
static constexpr size_t QSqlDriverCreatorBase_SignatureByteSize = 70;
static constexpr uint8_t QSqlDriverCreatorBase_SignatureBytes[70] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x09, 0x2e, 0xcc, 0xd1,
    0x0b, 0x04, 0x12, 0x2e, 0x45, 0x99, 0x65, 0xa9, 0x45, 0xce, 0x45, 0xa9, 0x89, 0x25, 0xf9, 0x45,
    0x4e, 0x89, 0xc5, 0xa9, 0x1a, 0xc5, 0xa9, 0x39, 0x69, 0x9a, 0x5c, 0x01, 0x84, 0x55, 0xea, 0x25,
    0x83, 0xd8, 0xa9, 0xfe, 0x49, 0x59, 0xa9, 0xc9, 0x25, 0x10, 0x6d, 0xba, 0x76, 0xb8, 0xf4, 0x71,
    0x01, 0x00, 0xca, 0x04, 0x2c, 0x4b
};
#endif

PyTypeObject *init_QSqlDriverCreatorBase(PyObject *module)
{
    if (SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriverCreatorBase_IDX].type != nullptr)
        return SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriverCreatorBase_IDX].type;

    Shiboken::AutoDecRef Sbk_QSqlDriverCreatorBase_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QSqlDriverCreatorBase_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSqlDriverCreatorBase",
        "QSqlDriverCreatorBase*",
        &Sbk_QSqlDriverCreatorBase_spec,
        &Shiboken::callCppDestructor< QSqlDriverCreatorBase >,
        Sbk_QSqlDriverCreatorBase_Type_bases.object(),
        0);
    auto *pyType = Sbk_QSqlDriverCreatorBase_TypeF(); // references _Sbk_QSqlDriverCreatorBase_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSqlDriverCreatorBase_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSqlDriverCreatorBase_SignatureBytes, QSqlDriverCreatorBase_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSqlDriverCreatorBase_PropertyStrings);
    SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriverCreatorBase_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSqlDriverCreatorBase_PythonToCpp_QSqlDriverCreatorBase_PTR,
        is_QSqlDriverCreatorBase_PythonToCpp_QSqlDriverCreatorBase_PTR_Convertible,
        QSqlDriverCreatorBase_PTR_CppToPython_QSqlDriverCreatorBase);

    Shiboken::Conversions::registerConverterName(converter, "QSqlDriverCreatorBase");
    Shiboken::Conversions::registerConverterName(converter, "QSqlDriverCreatorBase*");
    Shiboken::Conversions::registerConverterName(converter, "QSqlDriverCreatorBase&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSqlDriverCreatorBase).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QSqlDriverCreatorBaseWrapper).name());

    qRegisterMetaType< ::QSqlDriverCreatorBase *>();

    return pyType;
}
