// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtsql_python.h"

// main header
#include "qsqlerror_wrapper.h"

// Argument includes
#include <QString>
#include <QtSql/qsqlerror.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSqlError_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSqlError >()))
        return -1;

    ::QSqlError *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:QSqlError", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QSqlError::QSqlError(QSqlError)
    // 1: QSqlError::QSqlError(const QString&=,const QString&=,QSqlError::ErrorType=,const QString&=)
    if (numArgs == 0) {
        overloadId = 1; // QSqlError(QString,QString,QSqlError::ErrorType,QString)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QSqlError(QString,QString,QSqlError::ErrorType,QString)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 1; // QSqlError(QString,QString,QSqlError::ErrorType,QString)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_ErrorType_IDX])))->converter, (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 1; // QSqlError(QString,QString,QSqlError::ErrorType,QString)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3])))) {
                    overloadId = 1; // QSqlError(QString,QString,QSqlError::ErrorType,QString)
                }
            }
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QSqlError(QSqlError)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QSqlError(const QSqlError &other)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QSqlError cppArg0_local;
            ::QSqlError *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QSqlError(QSqlError)
                cptr = new ::QSqlError(*cppArg0);
            }
            break;
        }
        case 1: // QSqlError(const QString &driverText, const QString &databaseText, QSqlError::ErrorType type, const QString &errorCode)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_driverText = Shiboken::String::createStaticString("driverText");
                if (PyDict_Contains(kwds, key_driverText) != 0) {
                    value = PyDict_GetItem(kwds, key_driverText);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_driverText);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_driverText);
                }
                static PyObject *const key_databaseText = Shiboken::String::createStaticString("databaseText");
                if (PyDict_Contains(kwds, key_databaseText) != 0) {
                    value = PyDict_GetItem(kwds, key_databaseText);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_databaseText);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_databaseText);
                }
                static PyObject *const key_type = Shiboken::String::createStaticString("type");
                if (PyDict_Contains(kwds, key_type) != 0) {
                    value = PyDict_GetItem(kwds, key_type);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_type);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_ErrorType_IDX])))->converter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_type);
                }
                static PyObject *const key_errorCode = Shiboken::String::createStaticString("errorCode");
                if (PyDict_Contains(kwds, key_errorCode) != 0) {
                    value = PyDict_GetItem(kwds, key_errorCode);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_errorCode);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_errorCode);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_IDX]);
                }
            }
            ::QString cppArg0 = QString();
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1 = QString();
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QSqlError::ErrorType cppArg2(QSqlError::ErrorType::NoError);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QString cppArg3 = QString();
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QSqlError(QString,QString,QSqlError::ErrorType,QString)
                cptr = new ::QSqlError(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QSqlError >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSqlErrorFunc_databaseText(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // databaseText()const
        QString cppResult = const_cast<const ::QSqlError *>(cppSelf)->databaseText();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlErrorFunc_driverText(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // driverText()const
        QString cppResult = const_cast<const ::QSqlError *>(cppSelf)->driverText();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlErrorFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QSqlError *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlErrorFunc_nativeErrorCode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // nativeErrorCode()const
        QString cppResult = const_cast<const ::QSqlError *>(cppSelf)->nativeErrorCode();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlErrorFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlError::swap(QSqlError&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QSqlError&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSqlError cppArg0_local;
        ::QSqlError *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QSqlError&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlErrorFunc_text(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // text()const
        QString cppResult = const_cast<const ::QSqlError *>(cppSelf)->text();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlErrorFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        QSqlError::ErrorType cppResult = const_cast<const ::QSqlError *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_ErrorType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlError__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QSqlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QSqlError_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QSqlError_EnumFlagInfo[] = {
    "ErrorType:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSqlError_methods[] = {
    {"databaseText", reinterpret_cast<PyCFunction>(Sbk_QSqlErrorFunc_databaseText), METH_NOARGS, nullptr},
    {"driverText", reinterpret_cast<PyCFunction>(Sbk_QSqlErrorFunc_driverText), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QSqlErrorFunc_isValid), METH_NOARGS, nullptr},
    {"nativeErrorCode", reinterpret_cast<PyCFunction>(Sbk_QSqlErrorFunc_nativeErrorCode), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QSqlErrorFunc_swap), METH_O, nullptr},
    {"text", reinterpret_cast<PyCFunction>(Sbk_QSqlErrorFunc_text), METH_NOARGS, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QSqlErrorFunc_type), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QSqlError__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QSqlError_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QSqlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_IDX]), (pyArg)))) {
                // operator!=(const QSqlError &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QSqlError cppArg0_local;
                ::QSqlError *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_IDX]), (pyArg)))) {
                // operator==(const QSqlError &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QSqlError cppArg0_local;
                ::QSqlError *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QSqlError_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSqlError_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QSqlError__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSqlError_Type = nullptr;
static PyTypeObject *Sbk_QSqlError_TypeF(void)
{
    return _Sbk_QSqlError_Type;
}

static PyType_Slot Sbk_QSqlError_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QSqlError__repr__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSqlError_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSqlError_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QSqlError_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSqlError_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSqlError_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSqlError_spec = {
    "2:PySide6.QtSql.QSqlError",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSqlError_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QSqlError_ErrorType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSqlError::ErrorType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSqlError::ErrorType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QSqlError_ErrorType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_ErrorType_IDX])))
        return Enum_PythonToCpp_QSqlError_ErrorType;
    return {};
}

static PyObject *QSqlError_ErrorType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QSqlError::ErrorType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QSqlError::ErrorType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_ErrorType_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSqlError_PythonToCpp_QSqlError_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSqlError_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSqlError_PythonToCpp_QSqlError_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSqlError_TypeF()))
        return QSqlError_PythonToCpp_QSqlError_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSqlError_PTR_CppToPython_QSqlError(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QSqlError_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QSqlError_COPY_CppToPython_QSqlError(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QSqlError *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QSqlError_TypeF(), new ::QSqlError(*source), true, true);
}

// Python to C++ copy conversion.
static void QSqlError_PythonToCpp_QSqlError_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QSqlError *>(cppOut) = *reinterpret_cast< ::QSqlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QSqlError_PythonToCpp_QSqlError_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QSqlError_TypeF()))
        return QSqlError_PythonToCpp_QSqlError_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSqlError_SignatureStrings[] = {
    "1:PySide6.QtSql.QSqlError(self,other:PySide6.QtSql.QSqlError)",
    "0:PySide6.QtSql.QSqlError(self,driverText:QString=QString(),databaseText:QString=QString(),type:PySide6.QtSql.QSqlError.ErrorType=QSqlError.ErrorType.NoError,errorCode:QString=QString())",
    "PySide6.QtSql.QSqlError.databaseText(self)->QString",
    "PySide6.QtSql.QSqlError.driverText(self)->QString",
    "PySide6.QtSql.QSqlError.isValid(self)->bool",
    "PySide6.QtSql.QSqlError.nativeErrorCode(self)->QString",
    "PySide6.QtSql.QSqlError.swap(self,other:PySide6.QtSql.QSqlError)",
    "PySide6.QtSql.QSqlError.text(self)->QString",
    "PySide6.QtSql.QSqlError.type(self)->PySide6.QtSql.QSqlError.ErrorType",
    "PySide6.QtSql.QSqlError.__copy__(self)->typing.Self",
    "PySide6.QtSql.QSqlError.__ne__(self,other:PySide6.QtSql.QSqlError)->bool",
    "PySide6.QtSql.QSqlError.__eq__(self,other:PySide6.QtSql.QSqlError)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QSqlError_SignatureByteSize = 210;
static constexpr uint8_t QSqlError_SignatureBytes[210] = {
    0x78, 0xda, 0x95, 0x91, 0x4f, 0x0f, 0x82, 0x20, 0x18, 0xc6, 0xef, 0x7e, 0x12, 0xd9, 0x8c, 0xd5,
    0xa5, 0x83, 0x9b, 0x5d, 0x9a, 0xd7, 0x96, 0xc3, 0x75, 0x65, 0x18, 0x6f, 0xc5, 0xc6, 0x44, 0x81,
    0x55, 0x7e, 0xfb, 0xd0, 0x49, 0x6b, 0x2b, 0xd4, 0x2e, 0x2f, 0xff, 0x9e, 0xe7, 0x07, 0x0f, 0xef,
    0x26, 0x3d, 0x76, 0x44, 0x70, 0xd8, 0xe2, 0xc2, 0x92, 0x56, 0xe2, 0xc2, 0x95, 0x5c, 0x6b, 0xa5,
    0x63, 0x03, 0xf2, 0x92, 0x28, 0x7b, 0x03, 0x1d, 0x92, 0xa0, 0x68, 0x3d, 0xed, 0xe6, 0x5a, 0xdc,
    0x41, 0x97, 0xf0, 0xb4, 0x69, 0x41, 0xac, 0x16, 0xf5, 0x35, 0x1b, 0xc7, 0x18, 0x25, 0x9c, 0x59,
    0x56, 0x31, 0x03, 0x81, 0x63, 0xdb, 0x35, 0x10, 0xa2, 0xe3, 0xa1, 0x96, 0x4e, 0x91, 0xfd, 0xd8,
    0xc3, 0x07, 0x35, 0xcc, 0x13, 0xe8, 0xeb, 0x5e, 0x71, 0xf8, 0xc6, 0xa3, 0x28, 0x84, 0xfe, 0x7c,
    0xd6, 0x90, 0x02, 0xad, 0x76, 0xa3, 0x2d, 0xec, 0x79, 0xe7, 0x5c, 0xea, 0x10, 0xe6, 0xc4, 0xa4,
    0xe0, 0x5e, 0x5e, 0x29, 0x25, 0x83, 0xda, 0x9a, 0x59, 0x87, 0xcf, 0x7d, 0x98, 0xa5, 0x57, 0x98,
    0x07, 0x6b, 0x16, 0x35, 0x31, 0x04, 0xb0, 0x7f, 0xe4, 0xe9, 0xbb, 0xe5, 0xb5, 0xb3, 0x4d, 0x0b,
    0x52, 0x28, 0x3d, 0xab, 0xa6, 0xa3, 0xd4, 0x93, 0x1c, 0xd5, 0x5d, 0x8a, 0x89, 0x5b, 0x4d, 0x78,
    0x6a, 0x18, 0x1d, 0x33, 0x41, 0x67, 0xbe, 0x99, 0x52, 0x68, 0xff, 0x02, 0xbd, 0x00, 0xbe, 0xc2,
    0x27, 0xb3
};
#endif

PyTypeObject *init_QSqlError(PyObject *module)
{
    if (SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_IDX].type != nullptr)
        return SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_IDX].type;

    Shiboken::AutoDecRef Sbk_QSqlError_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QSqlError_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSqlError",
        "QSqlError",
        &Sbk_QSqlError_spec,
        &Shiboken::callCppDestructor< ::QSqlError >,
        Sbk_QSqlError_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QSqlError_TypeF(); // references _Sbk_QSqlError_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSqlError_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSqlError_SignatureBytes, QSqlError_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSqlError_PropertyStrings);
    SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSqlError_PythonToCpp_QSqlError_PTR,
        is_QSqlError_PythonToCpp_QSqlError_PTR_Convertible,
        QSqlError_PTR_CppToPython_QSqlError,
        QSqlError_COPY_CppToPython_QSqlError);

    Shiboken::Conversions::registerConverterName(converter, "QSqlError");
    Shiboken::Conversions::registerConverterName(converter, "QSqlError*");
    Shiboken::Conversions::registerConverterName(converter, "QSqlError&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSqlError).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QSqlError_PythonToCpp_QSqlError_COPY,
        is_QSqlError_PythonToCpp_QSqlError_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QSqlError_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'ErrorType'.
    const char *ErrorType_Initializer[] = {
        "NoError",
        "ConnectionError",
        "StatementError",
        "TransactionError",
        "UnknownError",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ErrorType_InitializerValues[] = {
        uint8_t(QSqlError::ErrorType::NoError),          //  0x00  0
        uint8_t(QSqlError::ErrorType::ConnectionError),  //  0x01  1
        uint8_t(QSqlError::ErrorType::StatementError),   //  0x02  2
        uint8_t(QSqlError::ErrorType::TransactionError), //  0x03  3
        uint8_t(QSqlError::ErrorType::UnknownError)      //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSqlError_TypeF(),
        "2:PySide6.QtSql.QSqlError.ErrorType",
        ErrorType_Initializer, ErrorType_InitializerValues);
    SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_ErrorType_IDX].type = EType;
    // Register converter for enum 'QSqlError::ErrorType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSqlError_ErrorType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QSqlError_ErrorType,
            is_Enum_PythonToCpp_QSqlError_ErrorType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QSqlError::ErrorType");
        Shiboken::Conversions::registerConverterAlias(converter, "ErrorType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ErrorType' enum.

    qRegisterMetaType< ::QSqlError >("QSqlError");
    qRegisterMetaType< ::QSqlError::ErrorType >("QSqlError::ErrorType");

    return pyType;
}
