// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtsql_python.h"

// main header
#include "qsqlfield_wrapper.h"

// Argument includes
#include <QString>
#include <QtSql/qsqlfield.h>
#include <qmetatype.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSqlField_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSqlField >()))
        return -1;

    ::QSqlField *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:QSqlField", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QSqlField::QSqlField(QSqlField)
    // 1: QSqlField::QSqlField(const QString&=,QMetaType=,const QString&=)
    if (numArgs == 0) {
        overloadId = 1; // QSqlField(QString,QMetaType,QString)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QSqlField(QString,QMetaType,QString)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 1; // QSqlField(QString,QMetaType,QString)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
                overloadId = 1; // QSqlField(QString,QMetaType,QString)
            }
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QSqlField(QSqlField)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QSqlField(const QSqlField &other)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QSqlField cppArg0_local;
            ::QSqlField *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QSqlField(QSqlField)
                cptr = new ::QSqlField(*cppArg0);
            }
            break;
        }
        case 1: // QSqlField(const QString &fieldName, QMetaType type, const QString &tableName)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_fieldName = Shiboken::String::createStaticString("fieldName");
                if (PyDict_Contains(kwds, key_fieldName) != 0) {
                    value = PyDict_GetItem(kwds, key_fieldName);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_fieldName);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_fieldName);
                }
                static PyObject *const key_type = Shiboken::String::createStaticString("type");
                if (PyDict_Contains(kwds, key_type) != 0) {
                    value = PyDict_GetItem(kwds, key_type);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_type);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_type);
                }
                static PyObject *const key_tableName = Shiboken::String::createStaticString("tableName");
                if (PyDict_Contains(kwds, key_tableName) != 0) {
                    value = PyDict_GetItem(kwds, key_tableName);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_tableName);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_tableName);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]);
                }
            }
            ::QString cppArg0 = QString();
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QMetaType cppArg1 = QMetaType();
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2 = QString();
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QSqlField(QString,QMetaType,QString)
                cptr = new ::QSqlField(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QSqlField >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSqlFieldFunc_clear(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlField *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clear()
        cppSelf->clear();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlFieldFunc_defaultValue(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlField *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // defaultValue()const
        QVariant cppResult = const_cast<const ::QSqlField *>(cppSelf)->defaultValue();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlFieldFunc_isAutoValue(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlField *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isAutoValue()const
        bool cppResult = const_cast<const ::QSqlField *>(cppSelf)->isAutoValue();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlFieldFunc_isGenerated(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlField *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isGenerated()const
        bool cppResult = const_cast<const ::QSqlField *>(cppSelf)->isGenerated();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlFieldFunc_isNull(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlField *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isNull()const
        bool cppResult = const_cast<const ::QSqlField *>(cppSelf)->isNull();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlFieldFunc_isReadOnly(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlField *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isReadOnly()const
        bool cppResult = const_cast<const ::QSqlField *>(cppSelf)->isReadOnly();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlFieldFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlField *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QSqlField *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlFieldFunc_length(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlField *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // length()const
        int cppResult = const_cast<const ::QSqlField *>(cppSelf)->length();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlFieldFunc_metaType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlField *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // metaType()const
        QMetaType cppResult = const_cast<const ::QSqlField *>(cppSelf)->metaType();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlFieldFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlField *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // name()const
        QString cppResult = const_cast<const ::QSqlField *>(cppSelf)->name();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlFieldFunc_precision(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlField *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // precision()const
        int cppResult = const_cast<const ::QSqlField *>(cppSelf)->precision();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlFieldFunc_requiredStatus(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlField *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // requiredStatus()const
        QSqlField::RequiredStatus cppResult = const_cast<const ::QSqlField *>(cppSelf)->requiredStatus();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_RequiredStatus_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlFieldFunc_setAutoValue(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlField *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlField::setAutoValue(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAutoValue(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAutoValue", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAutoValue(bool)
            cppSelf->setAutoValue(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlFieldFunc_setDefaultValue(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlField *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlField::setDefaultValue(QVariant)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // setDefaultValue(QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDefaultValue", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]);

    // Call function/method
    {
        ::QVariant cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDefaultValue(QVariant)
            cppSelf->setDefaultValue(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlFieldFunc_setGenerated(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlField *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlField::setGenerated(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setGenerated(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setGenerated", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setGenerated(bool)
            cppSelf->setGenerated(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlFieldFunc_setLength(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlField *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlField::setLength(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setLength(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLength", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLength(int)
            cppSelf->setLength(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlFieldFunc_setMetaType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlField *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlField::setMetaType(QMetaType)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), (pyArg)))) {
        overloadId = 0; // setMetaType(QMetaType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMetaType", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMetaType cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMetaType(QMetaType)
            cppSelf->setMetaType(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlFieldFunc_setName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlField *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlField::setName(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setName", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setName(QString)
            cppSelf->setName(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlFieldFunc_setPrecision(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlField *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlField::setPrecision(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setPrecision(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPrecision", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPrecision(int)
            cppSelf->setPrecision(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlFieldFunc_setReadOnly(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlField *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlField::setReadOnly(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setReadOnly(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setReadOnly", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setReadOnly(bool)
            cppSelf->setReadOnly(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlFieldFunc_setRequired(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlField *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlField::setRequired(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setRequired(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRequired", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRequired(bool)
            cppSelf->setRequired(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlFieldFunc_setRequiredStatus(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlField *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlField::setRequiredStatus(QSqlField::RequiredStatus)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_RequiredStatus_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setRequiredStatus(QSqlField::RequiredStatus)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRequiredStatus", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]);

    // Call function/method
    {
        ::QSqlField::RequiredStatus cppArg0{QSqlField::Optional};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRequiredStatus(QSqlField::RequiredStatus)
            cppSelf->setRequiredStatus(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlFieldFunc_setSqlType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlField *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlField::setSqlType(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setSqlType(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSqlType", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]);

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QSqlField", "setSqlType(int type)");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSqlType(int)
            cppSelf->setSqlType(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlFieldFunc_setTableName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlField *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlField::setTableName(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setTableName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTableName", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTableName(QString)
            cppSelf->setTableName(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlFieldFunc_setValue(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlField *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlField::setValue(QVariant)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // setValue(QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setValue", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]);

    // Call function/method
    {
        ::QVariant cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setValue(QVariant)
            cppSelf->setValue(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlFieldFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlField *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlField::swap(QSqlField&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QSqlField&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSqlField cppArg0_local;
        ::QSqlField *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QSqlField&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlFieldFunc_tableName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlField *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // tableName()const
        QString cppResult = const_cast<const ::QSqlField *>(cppSelf)->tableName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlFieldFunc_typeID(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlField *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QSqlField", "typeID() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // typeID()const
        int cppResult = const_cast<const ::QSqlField *>(cppSelf)->typeID();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlFieldFunc_value(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlField *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // value()const
        QVariant cppResult = const_cast<const ::QSqlField *>(cppSelf)->value();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlField__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QSqlField *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QSqlField_PropertyStrings[] = {
    "autoValue:isAutoValue:",
    "defaultValue::",
    "generated:isGenerated:",
    "length::",
    "metaType::",
    "name::",
    "precision::",
    "readOnly:isReadOnly:",
    "requiredStatus::",
    "tableName::",
    "value::",
    nullptr // Sentinel
};

static const char *Sbk_QSqlField_EnumFlagInfo[] = {
    "RequiredStatus:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSqlField_methods[] = {
    {"clear", reinterpret_cast<PyCFunction>(Sbk_QSqlFieldFunc_clear), METH_NOARGS, nullptr},
    {"defaultValue", reinterpret_cast<PyCFunction>(Sbk_QSqlFieldFunc_defaultValue), METH_NOARGS, nullptr},
    {"isAutoValue", reinterpret_cast<PyCFunction>(Sbk_QSqlFieldFunc_isAutoValue), METH_NOARGS, nullptr},
    {"isGenerated", reinterpret_cast<PyCFunction>(Sbk_QSqlFieldFunc_isGenerated), METH_NOARGS, nullptr},
    {"isNull", reinterpret_cast<PyCFunction>(Sbk_QSqlFieldFunc_isNull), METH_NOARGS, nullptr},
    {"isReadOnly", reinterpret_cast<PyCFunction>(Sbk_QSqlFieldFunc_isReadOnly), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QSqlFieldFunc_isValid), METH_NOARGS, nullptr},
    {"length", reinterpret_cast<PyCFunction>(Sbk_QSqlFieldFunc_length), METH_NOARGS, nullptr},
    {"metaType", reinterpret_cast<PyCFunction>(Sbk_QSqlFieldFunc_metaType), METH_NOARGS, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_QSqlFieldFunc_name), METH_NOARGS, nullptr},
    {"precision", reinterpret_cast<PyCFunction>(Sbk_QSqlFieldFunc_precision), METH_NOARGS, nullptr},
    {"requiredStatus", reinterpret_cast<PyCFunction>(Sbk_QSqlFieldFunc_requiredStatus), METH_NOARGS, nullptr},
    {"setAutoValue", reinterpret_cast<PyCFunction>(Sbk_QSqlFieldFunc_setAutoValue), METH_O, nullptr},
    {"setDefaultValue", reinterpret_cast<PyCFunction>(Sbk_QSqlFieldFunc_setDefaultValue), METH_O, nullptr},
    {"setGenerated", reinterpret_cast<PyCFunction>(Sbk_QSqlFieldFunc_setGenerated), METH_O, nullptr},
    {"setLength", reinterpret_cast<PyCFunction>(Sbk_QSqlFieldFunc_setLength), METH_O, nullptr},
    {"setMetaType", reinterpret_cast<PyCFunction>(Sbk_QSqlFieldFunc_setMetaType), METH_O, nullptr},
    {"setName", reinterpret_cast<PyCFunction>(Sbk_QSqlFieldFunc_setName), METH_O, nullptr},
    {"setPrecision", reinterpret_cast<PyCFunction>(Sbk_QSqlFieldFunc_setPrecision), METH_O, nullptr},
    {"setReadOnly", reinterpret_cast<PyCFunction>(Sbk_QSqlFieldFunc_setReadOnly), METH_O, nullptr},
    {"setRequired", reinterpret_cast<PyCFunction>(Sbk_QSqlFieldFunc_setRequired), METH_O, nullptr},
    {"setRequiredStatus", reinterpret_cast<PyCFunction>(Sbk_QSqlFieldFunc_setRequiredStatus), METH_O, nullptr},
    {"setSqlType", reinterpret_cast<PyCFunction>(Sbk_QSqlFieldFunc_setSqlType), METH_O, nullptr},
    {"setTableName", reinterpret_cast<PyCFunction>(Sbk_QSqlFieldFunc_setTableName), METH_O, nullptr},
    {"setValue", reinterpret_cast<PyCFunction>(Sbk_QSqlFieldFunc_setValue), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QSqlFieldFunc_swap), METH_O, nullptr},
    {"tableName", reinterpret_cast<PyCFunction>(Sbk_QSqlFieldFunc_tableName), METH_NOARGS, nullptr},
    {"typeID", reinterpret_cast<PyCFunction>(Sbk_QSqlFieldFunc_typeID), METH_NOARGS, nullptr},
    {"value", reinterpret_cast<PyCFunction>(Sbk_QSqlFieldFunc_value), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QSqlField__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QSqlField___nb_bool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QSqlField *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return !cppSelf->isNull() ? 1 : 0;
}

// Rich comparison
static PyObject * Sbk_QSqlField_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QSqlField *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]), (pyArg)))) {
                // operator!=(const QSqlField &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QSqlField cppArg0_local;
                ::QSqlField *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]), (pyArg)))) {
                // operator==(const QSqlField &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QSqlField cppArg0_local;
                ::QSqlField *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QSqlField_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSqlField_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QSqlField__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlField *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSqlField_Type = nullptr;
static PyTypeObject *Sbk_QSqlField_TypeF(void)
{
    return _Sbk_QSqlField_Type;
}

static PyType_Slot Sbk_QSqlField_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QSqlField__repr__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSqlField_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSqlField_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QSqlField_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSqlField_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSqlField_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_bool,        reinterpret_cast<void *>(Sbk_QSqlField___nb_bool)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSqlField_spec = {
    "2:PySide6.QtSql.QSqlField",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSqlField_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QSqlField_RequiredStatus(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSqlField::RequiredStatus>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSqlField::RequiredStatus *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QSqlField_RequiredStatus_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_RequiredStatus_IDX])))
        return Enum_PythonToCpp_QSqlField_RequiredStatus;
    return {};
}

static PyObject *QSqlField_RequiredStatus_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QSqlField::RequiredStatus>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QSqlField::RequiredStatus *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_RequiredStatus_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSqlField_PythonToCpp_QSqlField_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSqlField_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSqlField_PythonToCpp_QSqlField_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSqlField_TypeF()))
        return QSqlField_PythonToCpp_QSqlField_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSqlField_PTR_CppToPython_QSqlField(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QSqlField_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QSqlField_COPY_CppToPython_QSqlField(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QSqlField *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QSqlField_TypeF(), new ::QSqlField(*source), true, true);
}

// Python to C++ copy conversion.
static void QSqlField_PythonToCpp_QSqlField_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QSqlField *>(cppOut) = *reinterpret_cast< ::QSqlField *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QSqlField_PythonToCpp_QSqlField_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QSqlField_TypeF()))
        return QSqlField_PythonToCpp_QSqlField_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSqlField_SignatureStrings[] = {
    "1:PySide6.QtSql.QSqlField(self,other:PySide6.QtSql.QSqlField,*:KeywordOnly=None,value:QVariant=None,defaultValue:QVariant=None,name:QString=None,tableName:QString=None,metaType:QMetaType=None,requiredStatus:QSqlField.RequiredStatus=None,readOnly:bool=None,generated:bool=None,autoValue:bool=None,length:int=None,precision:int=None)",
    "0:PySide6.QtSql.QSqlField(self,fieldName:QString=QString(),type:typing.Union[PySide6.QtCore.QMetaType, PySide6.QtCore.QMetaType.Type]=QMetaType(),tableName:QString=QString(),*:KeywordOnly=None,value:QVariant=None,defaultValue:QVariant=None,name:QString=None,tableName:QString=None,metaType:QMetaType=None,requiredStatus:QSqlField.RequiredStatus=None,readOnly:bool=None,generated:bool=None,autoValue:bool=None,length:int=None,precision:int=None)",
    "PySide6.QtSql.QSqlField.clear(self)",
    "PySide6.QtSql.QSqlField.defaultValue(self)->QVariant",
    "PySide6.QtSql.QSqlField.isAutoValue(self)->bool",
    "PySide6.QtSql.QSqlField.isGenerated(self)->bool",
    "PySide6.QtSql.QSqlField.isNull(self)->bool",
    "PySide6.QtSql.QSqlField.isReadOnly(self)->bool",
    "PySide6.QtSql.QSqlField.isValid(self)->bool",
    "PySide6.QtSql.QSqlField.length(self)->int",
    "PySide6.QtSql.QSqlField.metaType(self)->PySide6.QtCore.QMetaType",
    "PySide6.QtSql.QSqlField.name(self)->QString",
    "PySide6.QtSql.QSqlField.precision(self)->int",
    "PySide6.QtSql.QSqlField.requiredStatus(self)->PySide6.QtSql.QSqlField.RequiredStatus",
    "PySide6.QtSql.QSqlField.setAutoValue(self,autoVal:bool)",
    "PySide6.QtSql.QSqlField.setDefaultValue(self,value:QVariant)",
    "PySide6.QtSql.QSqlField.setGenerated(self,gen:bool)",
    "PySide6.QtSql.QSqlField.setLength(self,fieldLength:int)",
    "PySide6.QtSql.QSqlField.setMetaType(self,type:typing.Union[PySide6.QtCore.QMetaType, PySide6.QtCore.QMetaType.Type])",
    "PySide6.QtSql.QSqlField.setName(self,name:QString)",
    "PySide6.QtSql.QSqlField.setPrecision(self,precision:int)",
    "PySide6.QtSql.QSqlField.setReadOnly(self,readOnly:bool)",
    "PySide6.QtSql.QSqlField.setRequired(self,required:bool)",
    "PySide6.QtSql.QSqlField.setRequiredStatus(self,status:PySide6.QtSql.QSqlField.RequiredStatus)",
    "PySide6.QtSql.QSqlField.setSqlType(self,type:int)",
    "PySide6.QtSql.QSqlField.setTableName(self,tableName:QString)",
    "PySide6.QtSql.QSqlField.setValue(self,value:QVariant)",
    "PySide6.QtSql.QSqlField.swap(self,other:PySide6.QtSql.QSqlField)",
    "PySide6.QtSql.QSqlField.tableName(self)->QString",
    "PySide6.QtSql.QSqlField.typeID(self)->int",
    "PySide6.QtSql.QSqlField.value(self)->QVariant",
    "PySide6.QtSql.QSqlField.__copy__(self)->typing.Self",
    "PySide6.QtSql.QSqlField.__ne__(self,other:PySide6.QtSql.QSqlField)->bool",
    "PySide6.QtSql.QSqlField.__eq__(self,other:PySide6.QtSql.QSqlField)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QSqlField_SignatureByteSize = 493;
static constexpr uint8_t QSqlField_SignatureBytes[493] = {
    0x78, 0xda, 0xed, 0x56, 0xcf, 0x4f, 0xc2, 0x30, 0x14, 0xbe, 0xfb, 0x57, 0x78, 0x14, 0x33, 0x17,
    0xbd, 0x78, 0x58, 0xa2, 0x89, 0xd1, 0x68, 0x8c, 0x30, 0xc1, 0xa9, 0x17, 0x63, 0x96, 0xc2, 0x1e,
    0xd0, 0xa4, 0xb4, 0xa3, 0xeb, 0x30, 0xfb, 0xef, 0xed, 0xe8, 0x3a, 0x28, 0xd8, 0xae, 0x18, 0x8f,
    0x5e, 0xca, 0xfa, 0xfa, 0x7d, 0xaf, 0xef, 0xc7, 0xd7, 0x17, 0x2e, 0xa2, 0x61, 0x95, 0xe0, 0x0c,
    0x2e, 0xc3, 0x91, 0x48, 0x96, 0x24, 0x1c, 0xc9, 0xe5, 0x1e, 0x03, 0xc9, 0x4e, 0x0a, 0x20, 0xd3,
    0x80, 0x89, 0x39, 0x70, 0x1b, 0x24, 0x38, 0x8d, 0x9e, 0xa0, 0xfa, 0x62, 0x3c, 0x7b, 0xa6, 0xa4,
    0xba, 0x8a, 0x19, 0x85, 0x60, 0x85, 0x48, 0x09, 0xd1, 0xe8, 0x1d, 0x71, 0x8c, 0xa8, 0x50, 0xb6,
    0x0c, 0xa6, 0xa8, 0x24, 0xe2, 0xfd, 0x87, 0x23, 0x8a, 0x16, 0xd2, 0x94, 0x08, 0x8e, 0xe9, 0x4c,
    0x59, 0x04, 0x1a, 0x13, 0x88, 0xf7, 0xcc, 0x0b, 0x10, 0xe8, 0xb5, 0xca, 0xa5, 0x75, 0xd0, 0x7c,
    0x29, 0x3b, 0x87, 0x65, 0x89, 0x39, 0x64, 0x89, 0x40, 0xa2, 0x2c, 0xa2, 0x36, 0xb6, 0xf0, 0xc5,
    0x38, 0xd0, 0x60, 0xb4, 0x0e, 0x35, 0x1a, 0x33, 0x46, 0x94, 0x69, 0x06, 0x14, 0x38, 0x12, 0x90,
    0x6d, 0xd9, 0x50, 0x29, 0x98, 0x0a, 0x76, 0x63, 0x23, 0x40, 0x67, 0x62, 0x1e, 0x61, 0x1d, 0x78,
    0xce, 0x61, 0x82, 0x0b, 0xcc, 0x68, 0x6b, 0xea, 0x1d, 0x9d, 0xbb, 0x6b, 0x39, 0xad, 0x3f, 0x8d,
    0xcc, 0x9a, 0xdf, 0x93, 0x5e, 0x20, 0xea, 0xd4, 0xe4, 0x22, 0x77, 0xe1, 0x1b, 0x95, 0x6e, 0x3f,
    0x36, 0xae, 0x6e, 0x19, 0x87, 0xb0, 0x4d, 0x3b, 0x38, 0xb6, 0x9d, 0x84, 0xf5, 0xf2, 0x79, 0xd5,
    0xee, 0x6b, 0xb7, 0x7b, 0xc5, 0xdc, 0x5c, 0xf9, 0xdf, 0x3c, 0xa3, 0x79, 0x96, 0xd6, 0x85, 0x13,
    0x02, 0x88, 0xaf, 0x1b, 0x68, 0xc7, 0x6c, 0xd7, 0x48, 0x41, 0xcf, 0xae, 0x75, 0xa9, 0xac, 0x24,
    0x5c, 0xdc, 0xe8, 0x50, 0x35, 0xa7, 0x8e, 0xd8, 0x81, 0x7f, 0xd0, 0xe9, 0x7a, 0xe2, 0xe3, 0x92,
    0x10, 0x4f, 0xe8, 0x4b, 0x53, 0x5c, 0x4f, 0xb8, 0x8c, 0x1a, 0xfb, 0x45, 0xa1, 0x4a, 0xaf, 0xa1,
    0xd8, 0x51, 0x0f, 0x2d, 0x12, 0x8d, 0xb5, 0xc9, 0xdc, 0xea, 0xa0, 0x96, 0x63, 0x5b, 0x7d, 0x25,
    0x3f, 0x2b, 0xb6, 0x55, 0x80, 0x4f, 0x64, 0xa6, 0x4c, 0xf7, 0xe3, 0x33, 0xd1, 0xa6, 0x76, 0xad,
    0x4e, 0x0b, 0x10, 0x66, 0xff, 0xb5, 0x72, 0xd7, 0xba, 0xed, 0xb9, 0x78, 0x77, 0xbb, 0x72, 0xdb,
    0x79, 0xb8, 0x4e, 0xb2, 0x29, 0xa2, 0xfa, 0x09, 0x75, 0x5f, 0xd8, 0xdf, 0x34, 0x51, 0x4d, 0xb1,
    0x7e, 0xfb, 0xa0, 0x9c, 0xbc, 0xc1, 0x76, 0x4b, 0xff, 0x70, 0xc6, 0x39, 0x2f, 0x8d, 0xb5, 0x0c,
    0x8c, 0xf9, 0xe4, 0xa4, 0x0c, 0x0d, 0x35, 0x98, 0xe3, 0xc1, 0x49, 0x34, 0x9e, 0x8d, 0x39, 0xa1,
    0x3a, 0x78, 0x4a, 0x23, 0x9a, 0xa7, 0x76, 0xfe, 0xbc, 0x2d, 0x25, 0x06, 0x85, 0x1a, 0x9e, 0x7e,
    0x72, 0x74, 0x7a, 0x97, 0xdf, 0x3b, 0xdd, 0xea, 0xca, 0xff, 0x55, 0xcf, 0xfb, 0x86, 0xb3, 0x3b,
    0xfe, 0x9d, 0xe4, 0xdf, 0xe8, 0xf7, 0x0b, 0xe5, 0x1e, 0x7f, 0x4c, 0xec, 0x0e, 0x84, 0x11, 0xb0,
    0xc7, 0xa0, 0xa8, 0xcb, 0xf0, 0x78, 0xe7, 0x33, 0x25, 0x56, 0x07, 0x4d, 0xff, 0x34, 0x9d, 0xb0,
    0xbc, 0x4a, 0x53, 0x4d, 0x68, 0xde, 0x45, 0x22, 0x77, 0x0e, 0x0e, 0x85, 0x86, 0xd1, 0x91, 0x7f,
    0xc7, 0x50, 0x4e, 0x53, 0x58, 0x1e, 0xe4, 0xe8, 0x1b, 0xaa, 0x09, 0xa7, 0x13
};
#endif

PyTypeObject *init_QSqlField(PyObject *module)
{
    if (SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX].type != nullptr)
        return SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX].type;

    Shiboken::AutoDecRef Sbk_QSqlField_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QSqlField_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSqlField",
        "QSqlField",
        &Sbk_QSqlField_spec,
        &Shiboken::callCppDestructor< ::QSqlField >,
        Sbk_QSqlField_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QSqlField_TypeF(); // references _Sbk_QSqlField_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSqlField_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSqlField_SignatureBytes, QSqlField_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSqlField_PropertyStrings);
    SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSqlField_PythonToCpp_QSqlField_PTR,
        is_QSqlField_PythonToCpp_QSqlField_PTR_Convertible,
        QSqlField_PTR_CppToPython_QSqlField,
        QSqlField_COPY_CppToPython_QSqlField);

    Shiboken::Conversions::registerConverterName(converter, "QSqlField");
    Shiboken::Conversions::registerConverterName(converter, "QSqlField*");
    Shiboken::Conversions::registerConverterName(converter, "QSqlField&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSqlField).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QSqlField_PythonToCpp_QSqlField_COPY,
        is_QSqlField_PythonToCpp_QSqlField_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QSqlField_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'RequiredStatus'.
    const char *RequiredStatus_Initializer[] = {
        "Unknown",
        "Optional",
        "Required",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t RequiredStatus_InitializerValues[] = {
        int8_t(QSqlField::RequiredStatus::Unknown),  // -0x01 -1
        int8_t(QSqlField::RequiredStatus::Optional), //  0x00  0
        int8_t(QSqlField::RequiredStatus::Required)  //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSqlField_TypeF(),
        "2:PySide6.QtSql.QSqlField.RequiredStatus",
        RequiredStatus_Initializer, RequiredStatus_InitializerValues);
    SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_RequiredStatus_IDX].type = EType;
    // Register converter for enum 'QSqlField::RequiredStatus'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSqlField_RequiredStatus_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QSqlField_RequiredStatus,
            is_Enum_PythonToCpp_QSqlField_RequiredStatus_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QSqlField::RequiredStatus");
        Shiboken::Conversions::registerConverterAlias(converter, "RequiredStatus");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'RequiredStatus' enum.

    qRegisterMetaType< ::QSqlField >("QSqlField");
    qRegisterMetaType< ::QSqlField::RequiredStatus >("QSqlField::RequiredStatus");

    return pyType;
}
