// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtsql_python.h"

// main header
#include "qsqlindex_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QString>
#include <QtSql/qsqlfield.h>
#include <QtSql/qsqlindex.h>
#include <QtSql/qsqlrecord.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSqlIndex_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSqlIndex >()))
        return -1;

    ::QSqlIndex *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlIndex_IDX]);

    if (PyArg_ParseTuple(args, "|OO:QSqlIndex", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QSqlIndex::QSqlIndex(QSqlIndex)
    // 1: QSqlIndex::QSqlIndex(const QString&=,const QString&=)
    if (numArgs == 0) {
        overloadId = 1; // QSqlIndex(QString,QString)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QSqlIndex(QString,QString)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 1; // QSqlIndex(QString,QString)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlIndex_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QSqlIndex(QSqlIndex)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlIndex_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtSqlTypeStructs[SBK_QSqlIndex_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QSqlIndex(const QSqlIndex &other)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlIndex_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QSqlIndex cppArg0_local;
            ::QSqlIndex *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QSqlIndex(QSqlIndex)
                cptr = new ::QSqlIndex(*cppArg0);
            }
            break;
        }
        case 1: // QSqlIndex(const QString &cursorName, const QString &name)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_cursorName = Shiboken::String::createStaticString("cursorName");
                if (PyDict_Contains(kwds, key_cursorName) != 0) {
                    value = PyDict_GetItem(kwds, key_cursorName);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_cursorName);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlIndex_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlIndex_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_cursorName);
                }
                static PyObject *const key_name = Shiboken::String::createStaticString("name");
                if (PyDict_Contains(kwds, key_name) != 0) {
                    value = PyDict_GetItem(kwds, key_name);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_name);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlIndex_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlIndex_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_name);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlIndex_IDX]);
                }
            }
            ::QString cppArg0 = QString();
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1 = QString();
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QSqlIndex(QString,QString)
                cptr = new ::QSqlIndex(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QSqlIndex >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlIndex_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSqlIndexFunc_append(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlIndex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "append", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSqlRecord::append(QSqlField)
    // 1: QSqlIndex::append(QSqlField,bool)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlField_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // append(QSqlField)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 1; // append(QSqlField,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "append", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlIndex_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // append(const QSqlField &field)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QSqlField cppArg0_local;
            ::QSqlField *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // append(QSqlField)
                cppSelf->append(*cppArg0);
            }
            break;
        }
        case 1: // append(const QSqlField &field, bool desc)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QSqlField cppArg0_local;
            ::QSqlField *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            bool cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // append(QSqlField,bool)
                cppSelf->append(*cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlIndexFunc_cursorName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlIndex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cursorName()const
        QString cppResult = const_cast<const ::QSqlIndex *>(cppSelf)->cursorName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlIndexFunc_isDescending(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlIndex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlIndex::isDescending(int)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // isDescending(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isDescending", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlIndex_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isDescending(int)const
            bool cppResult = const_cast<const ::QSqlIndex *>(cppSelf)->isDescending(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlIndexFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlIndex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // name()const
        QString cppResult = const_cast<const ::QSqlIndex *>(cppSelf)->name();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlIndexFunc_setCursorName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlIndex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlIndex::setCursorName(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setCursorName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCursorName", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlIndex_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCursorName(QString)
            cppSelf->setCursorName(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlIndexFunc_setDescending(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlIndex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setDescending", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSqlIndex::setDescending(int,bool)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
        overloadId = 0; // setDescending(int,bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setDescending", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlIndex_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        bool cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDescending(int,bool)
            cppSelf->setDescending(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlIndexFunc_setName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlIndex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlIndex::setName(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setName", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlIndex_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setName(QString)
            cppSelf->setName(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlIndexFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlIndex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlIndex::swap(QSqlIndex&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlIndex_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QSqlIndex&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlIndex_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSqlIndex cppArg0_local;
        ::QSqlIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QSqlIndex&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlIndex__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QSqlIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlIndex_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlIndex_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QSqlIndex_PropertyStrings[] = {
    "cursorName::",
    "name::",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSqlIndex_methods[] = {
    {"append", reinterpret_cast<PyCFunction>(Sbk_QSqlIndexFunc_append), METH_VARARGS, nullptr},
    {"cursorName", reinterpret_cast<PyCFunction>(Sbk_QSqlIndexFunc_cursorName), METH_NOARGS, nullptr},
    {"isDescending", reinterpret_cast<PyCFunction>(Sbk_QSqlIndexFunc_isDescending), METH_O, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_QSqlIndexFunc_name), METH_NOARGS, nullptr},
    {"setCursorName", reinterpret_cast<PyCFunction>(Sbk_QSqlIndexFunc_setCursorName), METH_O, nullptr},
    {"setDescending", reinterpret_cast<PyCFunction>(Sbk_QSqlIndexFunc_setDescending), METH_VARARGS, nullptr},
    {"setName", reinterpret_cast<PyCFunction>(Sbk_QSqlIndexFunc_setName), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QSqlIndexFunc_swap), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QSqlIndex__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QSqlIndex_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSqlIndex_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSqlIndex_Type = nullptr;
static PyTypeObject *Sbk_QSqlIndex_TypeF(void)
{
    return _Sbk_QSqlIndex_Type;
}

static PyType_Slot Sbk_QSqlIndex_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSqlIndex_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSqlIndex_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSqlIndex_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSqlIndex_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSqlIndex_spec = {
    "2:PySide6.QtSql.QSqlIndex",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSqlIndex_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSqlIndex_PythonToCpp_QSqlIndex_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSqlIndex_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSqlIndex_PythonToCpp_QSqlIndex_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSqlIndex_TypeF()))
        return QSqlIndex_PythonToCpp_QSqlIndex_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSqlIndex_PTR_CppToPython_QSqlIndex(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QSqlIndex_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QSqlIndex_COPY_CppToPython_QSqlIndex(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QSqlIndex *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QSqlIndex_TypeF(), new ::QSqlIndex(*source), true, true);
}

// Python to C++ copy conversion.
static void QSqlIndex_PythonToCpp_QSqlIndex_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QSqlIndex *>(cppOut) = *reinterpret_cast< ::QSqlIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlIndex_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QSqlIndex_PythonToCpp_QSqlIndex_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QSqlIndex_TypeF()))
        return QSqlIndex_PythonToCpp_QSqlIndex_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSqlIndex_SignatureStrings[] = {
    "1:PySide6.QtSql.QSqlIndex(self,other:PySide6.QtSql.QSqlIndex,*:KeywordOnly=None,name:QString=None,cursorName:QString=None)",
    "0:PySide6.QtSql.QSqlIndex(self,cursorName:QString=QString(),name:QString=QString(),*:KeywordOnly=None,name:QString=None,cursorName:QString=None)",
    "1:PySide6.QtSql.QSqlIndex.append(self,field:PySide6.QtSql.QSqlField)",
    "0:PySide6.QtSql.QSqlIndex.append(self,field:PySide6.QtSql.QSqlField,desc:bool)",
    "PySide6.QtSql.QSqlIndex.cursorName(self)->QString",
    "PySide6.QtSql.QSqlIndex.isDescending(self,i:int)->bool",
    "PySide6.QtSql.QSqlIndex.name(self)->QString",
    "PySide6.QtSql.QSqlIndex.setCursorName(self,cursorName:QString)",
    "PySide6.QtSql.QSqlIndex.setDescending(self,i:int,desc:bool)",
    "PySide6.QtSql.QSqlIndex.setName(self,name:QString)",
    "PySide6.QtSql.QSqlIndex.swap(self,other:PySide6.QtSql.QSqlIndex)",
    "PySide6.QtSql.QSqlIndex.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QSqlIndex_SignatureByteSize = 228;
static constexpr uint8_t QSqlIndex_SignatureBytes[228] = {
    0x78, 0xda, 0xa5, 0x52, 0x4b, 0x0a, 0xc2, 0x30, 0x10, 0xdd, 0xf7, 0x24, 0x46, 0x6a, 0xd1, 0x8d,
    0x8b, 0x80, 0x6e, 0x14, 0x41, 0x04, 0xb5, 0xf4, 0x00, 0xa5, 0x36, 0xa3, 0x06, 0xe2, 0x24, 0x26,
    0x11, 0xcd, 0xed, 0x4d, 0xfd, 0x50, 0x94, 0xa6, 0x54, 0xdc, 0x24, 0xe4, 0x31, 0xef, 0x33, 0x8f,
    0x8c, 0xe8, 0xd6, 0x65, 0x9c, 0xc1, 0x38, 0x49, 0x6d, 0x76, 0x16, 0x49, 0xea, 0x8f, 0x25, 0x32,
    0xb8, 0xf5, 0x0c, 0x88, 0x7d, 0x2c, 0xed, 0x11, 0x74, 0x68, 0x24, 0xee, 0xd3, 0x15, 0xb8, 0xab,
    0xd4, 0x6c, 0x83, 0xc2, 0x4d, 0xd6, 0x12, 0x21, 0xc6, 0xe2, 0x04, 0x34, 0xcd, 0xac, 0xe6, 0x78,
    0x78, 0x22, 0xe5, 0x45, 0x1b, 0xa9, 0xd7, 0xdf, 0x38, 0x89, 0x86, 0xed, 0xd6, 0x0d, 0xbc, 0xd7,
    0xdd, 0x23, 0x9f, 0x36, 0x35, 0xfc, 0x5f, 0xa0, 0x51, 0x28, 0x50, 0x52, 0x28, 0x05, 0xc8, 0x9e,
    0xb9, 0xf6, 0x1c, 0x04, 0x6b, 0x98, 0x5c, 0x54, 0x78, 0xcb, 0x56, 0xdd, 0x45, 0x62, 0x06, 0xa6,
    0xa4, 0x3b, 0x29, 0x05, 0x89, 0x42, 0x62, 0xf5, 0x12, 0x0f, 0x41, 0x32, 0x98, 0xbe, 0x76, 0x09,
    0x32, 0xb8, 0x99, 0x7b, 0x59, 0x9f, 0xa0, 0xaa, 0xea, 0x11, 0x82, 0x53, 0x8e, 0xd6, 0x33, 0x2b,
    0xa7, 0x20, 0x0d, 0x7f, 0xb0, 0x30, 0x60, 0x67, 0x9f, 0xb9, 0x1a, 0xca, 0x26, 0x6d, 0xf4, 0xc6,
    0x88, 0x5d, 0xfa, 0xf0, 0xdc, 0xda, 0x14, 0xbb, 0xd9, 0x5d, 0x0b, 0xd5, 0xe1, 0x97, 0x87, 0x05,
    0xf2, 0xbc, 0x94, 0xca, 0xe5, 0xf9, 0xbb, 0x1e, 0xeb, 0x94, 0x37, 0x4c, 0x32, 0xff, 0x8a, 0xee,
    0x30, 0x57, 0x31, 0x11
};
#endif

PyTypeObject *init_QSqlIndex(PyObject *module)
{
    if (SbkPySide6_QtSqlTypeStructs[SBK_QSqlIndex_IDX].type != nullptr)
        return SbkPySide6_QtSqlTypeStructs[SBK_QSqlIndex_IDX].type;

    Shiboken::AutoDecRef Sbk_QSqlIndex_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlRecord_IDX]))));

    _Sbk_QSqlIndex_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSqlIndex",
        "QSqlIndex",
        &Sbk_QSqlIndex_spec,
        &Shiboken::callCppDestructor< ::QSqlIndex >,
        Sbk_QSqlIndex_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QSqlIndex_TypeF(); // references _Sbk_QSqlIndex_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSqlIndex_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSqlIndex_SignatureBytes, QSqlIndex_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSqlIndex_PropertyStrings);
    SbkPySide6_QtSqlTypeStructs[SBK_QSqlIndex_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSqlIndex_PythonToCpp_QSqlIndex_PTR,
        is_QSqlIndex_PythonToCpp_QSqlIndex_PTR_Convertible,
        QSqlIndex_PTR_CppToPython_QSqlIndex,
        QSqlIndex_COPY_CppToPython_QSqlIndex);

    Shiboken::Conversions::registerConverterName(converter, "QSqlIndex");
    Shiboken::Conversions::registerConverterName(converter, "QSqlIndex*");
    Shiboken::Conversions::registerConverterName(converter, "QSqlIndex&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSqlIndex).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QSqlIndex_PythonToCpp_QSqlIndex_COPY,
        is_QSqlIndex_PythonToCpp_QSqlIndex_COPY_Convertible);

    qRegisterMetaType< ::QSqlIndex >("QSqlIndex");

    return pyType;
}
