// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtsql_python.h"

// main header
#include "qsqlquery_wrapper.h"

// Extra includes
#include <QSize>
#include <QSqlError>
#include <QSqlRecord>
#include <QStringList>

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QStringList>
#include <QtSql/qsqldatabase.h>
#include <QtSql/qsqldriver.h>
#include <QtSql/qsqlerror.h>
#include <QtSql/qsqlquery.h>
#include <QtSql/qsqlrecord.h>
#include <QtSql/qsqlresult.h>
#include <QtSql/qtsqlglobal.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSqlQuery_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSqlQuery >()))
        return -1;

    ::QSqlQuery *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]);

    if (PyArg_ParseTuple(args, "|OO:QSqlQuery", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QSqlQuery::QSqlQuery(QSqlResult*)
    // 1: QSqlQuery::QSqlQuery(QSqlDatabase)
    // 2: QSqlQuery::QSqlQuery(QSqlQuery)
    // 3: QSqlQuery::QSqlQuery(const QString&=,const QSqlDatabase&=)
    if (numArgs == 0) {
        overloadId = 3; // QSqlQuery(QString,QSqlDatabase)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QSqlQuery(QSqlQuery)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QSqlQuery(QSqlDatabase)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QSqlQuery(QSqlResult*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 3; // QSqlQuery(QString,QSqlDatabase)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), (pyArgs[1])))) {
            overloadId = 3; // QSqlQuery(QString,QSqlDatabase)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QSqlQuery(QSqlResult *r)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QSqlResult *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QSqlQuery(QSqlResult*)
                cptr = new ::QSqlQuery(cppArg0);
            }
            break;
        }
        case 1: // QSqlQuery(const QSqlDatabase &db)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QSqlDatabase cppArg0_local;
            ::QSqlDatabase *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QSqlQuery(QSqlDatabase)
                cptr = new ::QSqlQuery(*cppArg0);
            }
            break;
        }
        case 2: // QSqlQuery(const QSqlQuery &other)
        {
            Shiboken::Warnings::warnDeprecated("QSqlQuery", "QSqlQuery(const QSqlQuery &other)");
            if (Shiboken::Errors::occurred() != nullptr)
                return -1;
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QSqlQuery cppArg0_local;
            ::QSqlQuery *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QSqlQuery(QSqlQuery)
                cptr = new ::QSqlQuery(*cppArg0);
            }
            break;
        }
        case 3: // QSqlQuery(const QString &query, const QSqlDatabase &db)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_query = Shiboken::String::createStaticString("query");
                if (PyDict_Contains(kwds, key_query) != 0) {
                    value = PyDict_GetItem(kwds, key_query);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_query);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_query);
                }
                static PyObject *const key_db = Shiboken::String::createStaticString("db");
                if (PyDict_Contains(kwds, key_db) != 0) {
                    value = PyDict_GetItem(kwds, key_db);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_db);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_db);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]);
                }
            }
            ::QString cppArg0 = QString();
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QSqlDatabase cppArg1_local = QSqlDatabase();
            ::QSqlDatabase *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1]) {
                if (pythonToCpp[1].isValue())
                    pythonToCpp[1](pyArgs[1], &cppArg1_local);
                else
                    pythonToCpp[1](pyArgs[1], &cppArg1);
                }

            if (Shiboken::Errors::occurred() == nullptr) {
                // QSqlQuery(QString,QSqlDatabase)
                cptr = new ::QSqlQuery(cppArg0, *cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QSqlQuery >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSqlQueryFunc_addBindValue(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "addBindValue", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]);

    if (PyArg_ParseTuple(args, "|OO:addBindValue", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSqlQuery::addBindValue(QVariant,QFlags<QSql::ParamTypeFlag>=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // addBindValue(QVariant,QFlags<QSql::ParamTypeFlag>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QFlags_QSql_ParamTypeFlag_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 0; // addBindValue(QVariant,QFlags<QSql::ParamTypeFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addBindValue", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_type = Shiboken::String::createStaticString("type");
            if (PyDict_Contains(kwds, key_type) != 0) {
                value = PyDict_GetItem(kwds, key_type);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_type);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "addBindValue", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QFlags_QSql_ParamTypeFlag_IDX])))->flagsConverter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "addBindValue", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_type);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "addBindValue", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]);
            }
        }
        ::QVariant cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<QSql::ParamTypeFlag> cppArg1(QSql::In);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addBindValue(QVariant,QFlags<QSql::ParamTypeFlag>)
            cppSelf->addBindValue(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlQueryFunc_at(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // at()const
        int cppResult = const_cast<const ::QSqlQuery *>(cppSelf)->at();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlQueryFunc_bindValue(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "bindValue", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:bindValue", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSqlQuery::bindValue(QString,QVariant,QFlags<QSql::ParamTypeFlag>=)
    // 1: QSqlQuery::bindValue(int,QVariant,QFlags<QSql::ParamTypeFlag>=)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 1; // bindValue(int,QVariant,QFlags<QSql::ParamTypeFlag>)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QFlags_QSql_ParamTypeFlag_IDX])))->flagsConverter, (pyArgs[2])))) {
            overloadId = 1; // bindValue(int,QVariant,QFlags<QSql::ParamTypeFlag>)
        }
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // bindValue(QString,QVariant,QFlags<QSql::ParamTypeFlag>)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QFlags_QSql_ParamTypeFlag_IDX])))->flagsConverter, (pyArgs[2])))) {
            overloadId = 0; // bindValue(QString,QVariant,QFlags<QSql::ParamTypeFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "bindValue", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // bindValue(const QString &placeholder, const QVariant &val, QFlags<QSql::ParamTypeFlag> type)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_type = Shiboken::String::createStaticString("type");
                if (PyDict_Contains(kwds, key_type) != 0) {
                    value = PyDict_GetItem(kwds, key_type);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_type);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "bindValue", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QFlags_QSql_ParamTypeFlag_IDX])))->flagsConverter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "bindValue", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_type);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "bindValue", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QVariant cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<QSql::ParamTypeFlag> cppArg2(QSql::In);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // bindValue(QString,QVariant,QFlags<QSql::ParamTypeFlag>)
                cppSelf->bindValue(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
        case 1: // bindValue(int pos, const QVariant &val, QFlags<QSql::ParamTypeFlag> type)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_type = Shiboken::String::createStaticString("type");
                if (PyDict_Contains(kwds, key_type) != 0) {
                    value = PyDict_GetItem(kwds, key_type);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_type);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "bindValue", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QFlags_QSql_ParamTypeFlag_IDX])))->flagsConverter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "bindValue", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_type);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "bindValue", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]);
                }
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QVariant cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<QSql::ParamTypeFlag> cppArg2(QSql::In);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // bindValue(int,QVariant,QFlags<QSql::ParamTypeFlag>)
                cppSelf->bindValue(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlQueryFunc_boundValue(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlQuery::boundValue(QString)const->QVariant
    // 1: QSqlQuery::boundValue(int)const->QVariant
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 1; // boundValue(int)const
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // boundValue(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "boundValue", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // boundValue(const QString &placeholder) const
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // boundValue(QString)const
                QVariant cppResult = const_cast<const ::QSqlQuery *>(cppSelf)->boundValue(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
            }
            break;
        }
        case 1: // boundValue(int pos) const
        {
            int cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // boundValue(int)const
                QVariant cppResult = const_cast<const ::QSqlQuery *>(cppSelf)->boundValue(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlQueryFunc_boundValueName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlQuery::boundValueName(int)const->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // boundValueName(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "boundValueName", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // boundValueName(int)const
            QString cppResult = const_cast<const ::QSqlQuery *>(cppSelf)->boundValueName(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlQueryFunc_boundValueNames(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // boundValueNames()const
        QStringList cppResult = const_cast<const ::QSqlQuery *>(cppSelf)->boundValueNames();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlQueryFunc_boundValues(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // boundValues()const
        QList<QVariant> cppResult = const_cast<const ::QSqlQuery *>(cppSelf)->boundValues();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtSqlTypeConverters[SBK_QtSql_QList_QVariant_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlQueryFunc_clear(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clear()
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        cppSelf->clear();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlQueryFunc_driver(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // driver()const
        const QSqlDriver * cppResult = const_cast<const ::QSqlQuery *>(cppSelf)->driver();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlQueryFunc_exec(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    pcm.setBlocking();
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "exec", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSqlQuery::exec()->bool
    // 1: QSqlQuery::exec(QString)->bool
    if (numArgs == 0) {
        overloadId = 0; // exec()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 1; // exec(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "exec", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // exec()
        {

            // exec()
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = cppSelf->exec();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            break;
        }
        case 1: // exec(const QString &query)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // exec(QString)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->exec(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlQueryFunc_execBatch(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "execBatch", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]);

    if (PyArg_ParseTuple(args, "|O:execBatch", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSqlQuery::execBatch(QSqlQuery::BatchExecutionMode=)->bool
    if (numArgs == 0) {
        overloadId = 0; // execBatch(QSqlQuery::BatchExecutionMode)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_BatchExecutionMode_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // execBatch(QSqlQuery::BatchExecutionMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "execBatch", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
            if (PyDict_Contains(kwds, key_mode) != 0) {
                value = PyDict_GetItem(kwds, key_mode);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_mode);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "execBatch", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_BatchExecutionMode_IDX])))->converter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "execBatch", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_mode);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "execBatch", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]);
            }
        }
        ::QSqlQuery::BatchExecutionMode cppArg0(QSqlQuery::BatchExecutionMode::ValuesAsRows);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // execBatch(QSqlQuery::BatchExecutionMode)
            bool cppResult = cppSelf->execBatch(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlQueryFunc_exec_(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    pcm.setBlocking();
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "exec_", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSqlQuery::exec_()->bool
    // 1: QSqlQuery::exec_(QString)->bool
    if (numArgs == 0) {
        overloadId = 0; // exec_()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 1; // exec_(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "exec_", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // exec_()
        {

            // exec_()
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtsql.cpp (simple-exec)]
            if (PyErr_WarnEx(PyExc_DeprecationWarning,
                             "'exec_' will be removed in the future. "
                             "Use 'exec' instead.",
                             1)) {
                return nullptr;
            }
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = cppSelf->exec();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            // END of custom code block [file: ../glue/qtsql.cpp (simple-exec)]
            // ========================================================================
            // End of code injection

            break;
        }
        case 1: // exec_(const QString &arg__1)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)

            if (Shiboken::Errors::occurred() == nullptr) {
                // exec_(QString)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtsql.cpp (qsqlquery-exec)]
                if (PyErr_WarnEx(PyExc_DeprecationWarning,
                                 "'exec_' will be removed in the future. "
                                 "Use 'exec' instead.",
                                 1)) {
                    return nullptr;
                }
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->exec(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
                // END of custom code block [file: ../glue/qtsql.cpp (qsqlquery-exec)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlQueryFunc_executedQuery(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // executedQuery()const
        QString cppResult = const_cast<const ::QSqlQuery *>(cppSelf)->executedQuery();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlQueryFunc_finish(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // finish()
        cppSelf->finish();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlQueryFunc_first(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // first()
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        bool cppResult = cppSelf->first();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlQueryFunc_isActive(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isActive()const
        bool cppResult = const_cast<const ::QSqlQuery *>(cppSelf)->isActive();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlQueryFunc_isForwardOnly(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isForwardOnly()const
        bool cppResult = const_cast<const ::QSqlQuery *>(cppSelf)->isForwardOnly();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlQueryFunc_isNull(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlQuery::isNull(QAnyStringView)const->bool
    // 1: QSqlQuery::isNull(int)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 1; // isNull(int)const
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // isNull(QAnyStringView)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isNull", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // isNull(QAnyStringView name) const
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // isNull(QAnyStringView)const
                bool cppResult = const_cast<const ::QSqlQuery *>(cppSelf)->isNull(QAnyStringView(cppArg0));
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // isNull(int field) const
        {
            int cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // isNull(int)const
                bool cppResult = const_cast<const ::QSqlQuery *>(cppSelf)->isNull(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlQueryFunc_isPositionalBindingEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isPositionalBindingEnabled()const
        bool cppResult = const_cast<const ::QSqlQuery *>(cppSelf)->isPositionalBindingEnabled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlQueryFunc_isSelect(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isSelect()const
        bool cppResult = const_cast<const ::QSqlQuery *>(cppSelf)->isSelect();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlQueryFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QSqlQuery *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlQueryFunc_last(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // last()
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        bool cppResult = cppSelf->last();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlQueryFunc_lastError(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lastError()const
        QSqlError cppResult = const_cast<const ::QSqlQuery *>(cppSelf)->lastError();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlQueryFunc_lastInsertId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lastInsertId()const
        QVariant cppResult = const_cast<const ::QSqlQuery *>(cppSelf)->lastInsertId();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlQueryFunc_lastQuery(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lastQuery()const
        QString cppResult = const_cast<const ::QSqlQuery *>(cppSelf)->lastQuery();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlQueryFunc_next(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // next()
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        bool cppResult = cppSelf->next();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlQueryFunc_nextResult(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // nextResult()
        bool cppResult = cppSelf->nextResult();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlQueryFunc_numRowsAffected(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // numRowsAffected()const
        int cppResult = const_cast<const ::QSqlQuery *>(cppSelf)->numRowsAffected();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlQueryFunc_numericalPrecisionPolicy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // numericalPrecisionPolicy()const
        QSql::NumericalPrecisionPolicy cppResult = const_cast<const ::QSqlQuery *>(cppSelf)->numericalPrecisionPolicy();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSql_NumericalPrecisionPolicy_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlQueryFunc_prepare(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlQuery::prepare(QString)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // prepare(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "prepare", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // prepare(QString)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = cppSelf->prepare(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlQueryFunc_previous(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // previous()
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        bool cppResult = cppSelf->previous();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlQueryFunc_record(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // record()const
        QSqlRecord cppResult = const_cast<const ::QSqlQuery *>(cppSelf)->record();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlRecord_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlQueryFunc_result(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // result()const
        const QSqlResult * cppResult = const_cast<const ::QSqlQuery *>(cppSelf)->result();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlQueryFunc_seek(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "seek", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]);

    if (PyArg_ParseTuple(args, "|OO:seek", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSqlQuery::seek(int,bool=)->bool
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // seek(int,bool)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 0; // seek(int,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "seek", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_relative = Shiboken::String::createStaticString("relative");
            if (PyDict_Contains(kwds, key_relative) != 0) {
                value = PyDict_GetItem(kwds, key_relative);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_relative);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "seek", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "seek", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_relative);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "seek", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]);
            }
        }
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        bool cppArg1 = false;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // seek(int,bool)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = cppSelf->seek(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlQueryFunc_setForwardOnly(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlQuery::setForwardOnly(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setForwardOnly(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setForwardOnly", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setForwardOnly(bool)
            cppSelf->setForwardOnly(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlQueryFunc_setNumericalPrecisionPolicy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlQuery::setNumericalPrecisionPolicy(QSql::NumericalPrecisionPolicy)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSql_NumericalPrecisionPolicy_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setNumericalPrecisionPolicy(QSql::NumericalPrecisionPolicy)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setNumericalPrecisionPolicy", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]);

    // Call function/method
    {
        ::QSql::NumericalPrecisionPolicy cppArg0{QSql::HighPrecision};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setNumericalPrecisionPolicy(QSql::NumericalPrecisionPolicy)
            cppSelf->setNumericalPrecisionPolicy(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlQueryFunc_setPositionalBindingEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlQuery::setPositionalBindingEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setPositionalBindingEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPositionalBindingEnabled", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPositionalBindingEnabled(bool)
            cppSelf->setPositionalBindingEnabled(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlQueryFunc_size(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // size()const
        int cppResult = const_cast<const ::QSqlQuery *>(cppSelf)->size();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlQueryFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlQuery::swap(QSqlQuery&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QSqlQuery&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSqlQuery cppArg0_local;
        ::QSqlQuery *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QSqlQuery&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlQueryFunc_value(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlQuery::value(QAnyStringView)const->QVariant
    // 1: QSqlQuery::value(int)const->QVariant
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 1; // value(int)const
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // value(QAnyStringView)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "value", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // value(QAnyStringView name) const
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // value(QAnyStringView)const
                QVariant cppResult = const_cast<const ::QSqlQuery *>(cppSelf)->value(QAnyStringView(cppArg0));
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
            }
            break;
        }
        case 1: // value(int i) const
        {
            int cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // value(int)const
                QVariant cppResult = const_cast<const ::QSqlQuery *>(cppSelf)->value(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlQuery__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QSqlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QSqlQuery_PropertyStrings[] = {
    "forwardOnly:isForwardOnly:",
    "numericalPrecisionPolicy::",
    "positionalBindingEnabled:isPositionalBindingEnabled:",
    nullptr // Sentinel
};

static const char *Sbk_QSqlQuery_EnumFlagInfo[] = {
    "BatchExecutionMode:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSqlQuery_methods[] = {
    {"addBindValue", reinterpret_cast<PyCFunction>(Sbk_QSqlQueryFunc_addBindValue), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"at", reinterpret_cast<PyCFunction>(Sbk_QSqlQueryFunc_at), METH_NOARGS, nullptr},
    {"bindValue", reinterpret_cast<PyCFunction>(Sbk_QSqlQueryFunc_bindValue), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"boundValue", reinterpret_cast<PyCFunction>(Sbk_QSqlQueryFunc_boundValue), METH_O, nullptr},
    {"boundValueName", reinterpret_cast<PyCFunction>(Sbk_QSqlQueryFunc_boundValueName), METH_O, nullptr},
    {"boundValueNames", reinterpret_cast<PyCFunction>(Sbk_QSqlQueryFunc_boundValueNames), METH_NOARGS, nullptr},
    {"boundValues", reinterpret_cast<PyCFunction>(Sbk_QSqlQueryFunc_boundValues), METH_NOARGS, nullptr},
    {"clear", reinterpret_cast<PyCFunction>(Sbk_QSqlQueryFunc_clear), METH_NOARGS, nullptr},
    {"driver", reinterpret_cast<PyCFunction>(Sbk_QSqlQueryFunc_driver), METH_NOARGS, nullptr},
    {"exec", reinterpret_cast<PyCFunction>(Sbk_QSqlQueryFunc_exec), METH_VARARGS, nullptr},
    {"execBatch", reinterpret_cast<PyCFunction>(Sbk_QSqlQueryFunc_execBatch), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"exec_", reinterpret_cast<PyCFunction>(Sbk_QSqlQueryFunc_exec_), METH_VARARGS, nullptr},
    {"executedQuery", reinterpret_cast<PyCFunction>(Sbk_QSqlQueryFunc_executedQuery), METH_NOARGS, nullptr},
    {"finish", reinterpret_cast<PyCFunction>(Sbk_QSqlQueryFunc_finish), METH_NOARGS, nullptr},
    {"first", reinterpret_cast<PyCFunction>(Sbk_QSqlQueryFunc_first), METH_NOARGS, nullptr},
    {"isActive", reinterpret_cast<PyCFunction>(Sbk_QSqlQueryFunc_isActive), METH_NOARGS, nullptr},
    {"isForwardOnly", reinterpret_cast<PyCFunction>(Sbk_QSqlQueryFunc_isForwardOnly), METH_NOARGS, nullptr},
    {"isNull", reinterpret_cast<PyCFunction>(Sbk_QSqlQueryFunc_isNull), METH_O, nullptr},
    {"isPositionalBindingEnabled", reinterpret_cast<PyCFunction>(Sbk_QSqlQueryFunc_isPositionalBindingEnabled), METH_NOARGS, nullptr},
    {"isSelect", reinterpret_cast<PyCFunction>(Sbk_QSqlQueryFunc_isSelect), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QSqlQueryFunc_isValid), METH_NOARGS, nullptr},
    {"last", reinterpret_cast<PyCFunction>(Sbk_QSqlQueryFunc_last), METH_NOARGS, nullptr},
    {"lastError", reinterpret_cast<PyCFunction>(Sbk_QSqlQueryFunc_lastError), METH_NOARGS, nullptr},
    {"lastInsertId", reinterpret_cast<PyCFunction>(Sbk_QSqlQueryFunc_lastInsertId), METH_NOARGS, nullptr},
    {"lastQuery", reinterpret_cast<PyCFunction>(Sbk_QSqlQueryFunc_lastQuery), METH_NOARGS, nullptr},
    {"next", reinterpret_cast<PyCFunction>(Sbk_QSqlQueryFunc_next), METH_NOARGS, nullptr},
    {"nextResult", reinterpret_cast<PyCFunction>(Sbk_QSqlQueryFunc_nextResult), METH_NOARGS, nullptr},
    {"numRowsAffected", reinterpret_cast<PyCFunction>(Sbk_QSqlQueryFunc_numRowsAffected), METH_NOARGS, nullptr},
    {"numericalPrecisionPolicy", reinterpret_cast<PyCFunction>(Sbk_QSqlQueryFunc_numericalPrecisionPolicy), METH_NOARGS, nullptr},
    {"prepare", reinterpret_cast<PyCFunction>(Sbk_QSqlQueryFunc_prepare), METH_O, nullptr},
    {"previous", reinterpret_cast<PyCFunction>(Sbk_QSqlQueryFunc_previous), METH_NOARGS, nullptr},
    {"record", reinterpret_cast<PyCFunction>(Sbk_QSqlQueryFunc_record), METH_NOARGS, nullptr},
    {"result", reinterpret_cast<PyCFunction>(Sbk_QSqlQueryFunc_result), METH_NOARGS, nullptr},
    {"seek", reinterpret_cast<PyCFunction>(Sbk_QSqlQueryFunc_seek), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setForwardOnly", reinterpret_cast<PyCFunction>(Sbk_QSqlQueryFunc_setForwardOnly), METH_O, nullptr},
    {"setNumericalPrecisionPolicy", reinterpret_cast<PyCFunction>(Sbk_QSqlQueryFunc_setNumericalPrecisionPolicy), METH_O, nullptr},
    {"setPositionalBindingEnabled", reinterpret_cast<PyCFunction>(Sbk_QSqlQueryFunc_setPositionalBindingEnabled), METH_O, nullptr},
    {"size", reinterpret_cast<PyCFunction>(Sbk_QSqlQueryFunc_size), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QSqlQueryFunc_swap), METH_O, nullptr},
    {"value", reinterpret_cast<PyCFunction>(Sbk_QSqlQueryFunc_value), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QSqlQuery__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QSqlQuery_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSqlQuery_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSqlQuery_Type = nullptr;
static PyTypeObject *Sbk_QSqlQuery_TypeF(void)
{
    return _Sbk_QSqlQuery_Type;
}

static PyType_Slot Sbk_QSqlQuery_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSqlQuery_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSqlQuery_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSqlQuery_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSqlQuery_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSqlQuery_spec = {
    "2:PySide6.QtSql.QSqlQuery",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSqlQuery_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QSqlQuery_BatchExecutionMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSqlQuery::BatchExecutionMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSqlQuery::BatchExecutionMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QSqlQuery_BatchExecutionMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_BatchExecutionMode_IDX])))
        return Enum_PythonToCpp_QSqlQuery_BatchExecutionMode;
    return {};
}

static PyObject *QSqlQuery_BatchExecutionMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QSqlQuery::BatchExecutionMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QSqlQuery::BatchExecutionMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_BatchExecutionMode_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSqlQuery_PythonToCpp_QSqlQuery_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSqlQuery_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSqlQuery_PythonToCpp_QSqlQuery_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSqlQuery_TypeF()))
        return QSqlQuery_PythonToCpp_QSqlQuery_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSqlQuery_PTR_CppToPython_QSqlQuery(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QSqlQuery_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QSqlQuery_COPY_CppToPython_QSqlQuery(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QSqlQuery *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QSqlQuery_TypeF(), new ::QSqlQuery(*source), true, true);
}

// Python to C++ copy conversion.
static void QSqlQuery_PythonToCpp_QSqlQuery_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QSqlQuery *>(cppOut) = *reinterpret_cast< ::QSqlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QSqlQuery_PythonToCpp_QSqlQuery_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QSqlQuery_TypeF()))
        return QSqlQuery_PythonToCpp_QSqlQuery_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSqlQuery_SignatureStrings[] = {
    "3:PySide6.QtSql.QSqlQuery(self,r:PySide6.QtSql.QSqlResult,*:KeywordOnly=None,forwardOnly:bool=None,positionalBindingEnabled:bool=None,numericalPrecisionPolicy:QSql.NumericalPrecisionPolicy=None)",
    "2:PySide6.QtSql.QSqlQuery(self,db:PySide6.QtSql.QSqlDatabase,*:KeywordOnly=None,forwardOnly:bool=None,positionalBindingEnabled:bool=None,numericalPrecisionPolicy:QSql.NumericalPrecisionPolicy=None)",
    "1:PySide6.QtSql.QSqlQuery(self,other:PySide6.QtSql.QSqlQuery,*:KeywordOnly=None,forwardOnly:bool=None,positionalBindingEnabled:bool=None,numericalPrecisionPolicy:QSql.NumericalPrecisionPolicy=None)",
    "0:PySide6.QtSql.QSqlQuery(self,query:QString=QString(),db:PySide6.QtSql.QSqlDatabase=QSqlDatabase(),*:KeywordOnly=None,forwardOnly:bool=None,positionalBindingEnabled:bool=None,numericalPrecisionPolicy:QSql.NumericalPrecisionPolicy=None)",
    "PySide6.QtSql.QSqlQuery.addBindValue(self,val:QVariant,type:PySide6.QtSql.QSql.ParamTypeFlag=QSql.In)",
    "PySide6.QtSql.QSqlQuery.at(self)->int",
    "1:PySide6.QtSql.QSqlQuery.bindValue(self,placeholder:QString,val:QVariant,type:PySide6.QtSql.QSql.ParamTypeFlag=QSql.In)",
    "0:PySide6.QtSql.QSqlQuery.bindValue(self,pos:int,val:QVariant,type:PySide6.QtSql.QSql.ParamTypeFlag=QSql.In)",
    "1:PySide6.QtSql.QSqlQuery.boundValue(self,placeholder:QString)->QVariant",
    "0:PySide6.QtSql.QSqlQuery.boundValue(self,pos:int)->QVariant",
    "PySide6.QtSql.QSqlQuery.boundValueName(self,pos:int)->QString",
    "PySide6.QtSql.QSqlQuery.boundValueNames(self)->QStringList",
    "PySide6.QtSql.QSqlQuery.boundValues(self)->QList[QVariant]",
    "PySide6.QtSql.QSqlQuery.clear(self)",
    "PySide6.QtSql.QSqlQuery.driver(self)->PySide6.QtSql.QSqlDriver",
    "1:PySide6.QtSql.QSqlQuery.exec(self)->bool",
    "0:PySide6.QtSql.QSqlQuery.exec(self,query:QString)->bool",
    "PySide6.QtSql.QSqlQuery.execBatch(self,mode:PySide6.QtSql.QSqlQuery.BatchExecutionMode=QSqlQuery.BatchExecutionMode.ValuesAsRows)->bool",
    "1:PySide6.QtSql.QSqlQuery.exec_(self)->bool",
    "0:PySide6.QtSql.QSqlQuery.exec_(self,arg__1:QString)->bool",
    "PySide6.QtSql.QSqlQuery.executedQuery(self)->QString",
    "PySide6.QtSql.QSqlQuery.finish(self)",
    "PySide6.QtSql.QSqlQuery.first(self)->bool",
    "PySide6.QtSql.QSqlQuery.isActive(self)->bool",
    "PySide6.QtSql.QSqlQuery.isForwardOnly(self)->bool",
    "1:PySide6.QtSql.QSqlQuery.isNull(self,name:QString)->bool",
    "0:PySide6.QtSql.QSqlQuery.isNull(self,field:int)->bool",
    "PySide6.QtSql.QSqlQuery.isPositionalBindingEnabled(self)->bool",
    "PySide6.QtSql.QSqlQuery.isSelect(self)->bool",
    "PySide6.QtSql.QSqlQuery.isValid(self)->bool",
    "PySide6.QtSql.QSqlQuery.last(self)->bool",
    "PySide6.QtSql.QSqlQuery.lastError(self)->PySide6.QtSql.QSqlError",
    "PySide6.QtSql.QSqlQuery.lastInsertId(self)->QVariant",
    "PySide6.QtSql.QSqlQuery.lastQuery(self)->QString",
    "PySide6.QtSql.QSqlQuery.next(self)->bool",
    "PySide6.QtSql.QSqlQuery.nextResult(self)->bool",
    "PySide6.QtSql.QSqlQuery.numRowsAffected(self)->int",
    "PySide6.QtSql.QSqlQuery.numericalPrecisionPolicy(self)->PySide6.QtSql.QSql.NumericalPrecisionPolicy",
    "PySide6.QtSql.QSqlQuery.prepare(self,query:QString)->bool",
    "PySide6.QtSql.QSqlQuery.previous(self)->bool",
    "PySide6.QtSql.QSqlQuery.record(self)->PySide6.QtSql.QSqlRecord",
    "PySide6.QtSql.QSqlQuery.result(self)->PySide6.QtSql.QSqlResult",
    "PySide6.QtSql.QSqlQuery.seek(self,i:int,relative:bool=false)->bool",
    "PySide6.QtSql.QSqlQuery.setForwardOnly(self,forward:bool)",
    "PySide6.QtSql.QSqlQuery.setNumericalPrecisionPolicy(self,precisionPolicy:PySide6.QtSql.QSql.NumericalPrecisionPolicy)",
    "PySide6.QtSql.QSqlQuery.setPositionalBindingEnabled(self,enable:bool)",
    "PySide6.QtSql.QSqlQuery.size(self)->int",
    "PySide6.QtSql.QSqlQuery.swap(self,other:PySide6.QtSql.QSqlQuery)",
    "1:PySide6.QtSql.QSqlQuery.value(self,name:QString)->QVariant",
    "0:PySide6.QtSql.QSqlQuery.value(self,i:int)->QVariant",
    "PySide6.QtSql.QSqlQuery.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QSqlQuery_SignatureByteSize = 683;
static constexpr uint8_t QSqlQuery_SignatureBytes[683] = {
    0x78, 0xda, 0xcd, 0x57, 0x4d, 0x8f, 0xda, 0x30, 0x10, 0xbd, 0xef, 0x2f, 0x59, 0xaa, 0x34, 0x62,
    0x5b, 0xa9, 0x07, 0x24, 0x2a, 0xb1, 0x2a, 0x2b, 0xa1, 0xb6, 0x14, 0xd8, 0x6a, 0x2f, 0xab, 0x2a,
    0x1a, 0xe2, 0x09, 0x58, 0x35, 0x76, 0xd6, 0x76, 0x60, 0xd3, 0x5f, 0x5f, 0x27, 0x26, 0x7c, 0x15,
    0x3b, 0xa6, 0x7b, 0xe1, 0x02, 0x24, 0x33, 0xcf, 0xf3, 0xde, 0x8c, 0x3d, 0x1e, 0x3e, 0xf6, 0x26,
    0xe5, 0x23, 0x25, 0xf8, 0x29, 0x9e, 0xea, 0xc7, 0x17, 0x16, 0x4f, 0xcd, 0xc7, 0xb4, 0x40, 0x59,
    0xde, 0x2a, 0x64, 0x59, 0x24, 0xcf, 0x98, 0x67, 0xa8, 0x0a, 0xa6, 0xa3, 0x77, 0xbd, 0xaf, 0x58,
    0x6e, 0x84, 0x24, 0x3f, 0x38, 0x2b, 0xfb, 0x63, 0xc1, 0x31, 0xca, 0x84, 0xdc, 0x80, 0x7d, 0xd1,
    0x9b, 0x0b, 0xc1, 0xec, 0xdb, 0x5c, 0x28, 0xaa, 0xa9, 0xe0, 0xc0, 0xee, 0x29, 0x27, 0x94, 0x2f,
    0x86, 0x1c, 0xe6, 0x0c, 0xc9, 0x81, 0x0b, 0x2f, 0x56, 0x28, 0x69, 0x0a, 0x6c, 0x22, 0x31, 0xa5,
    0xca, 0x38, 0x4f, 0x04, 0xa3, 0x69, 0xd9, 0xab, 0xe2, 0xc5, 0x63, 0x87, 0xb5, 0xc6, 0x76, 0x6e,
    0x3e, 0xf8, 0x25, 0x90, 0xf9, 0x19, 0xfb, 0x17, 0xd0, 0x30, 0x07, 0x85, 0xd7, 0xa3, 0xe2, 0xce,
    0xaf, 0x42, 0xe8, 0x25, 0x4a, 0x97, 0xcb, 0xf5, 0xa8, 0xe8, 0xfa, 0x55, 0xbc, 0x54, 0x3f, 0xcd,
    0x42, 0x5a, 0x9a, 0xd0, 0xfd, 0xed, 0xf7, 0x6d, 0xc7, 0x5f, 0xa3, 0xfe, 0xe1, 0x83, 0x71, 0xbe,
    0x1a, 0xb1, 0x0e, 0xa9, 0x31, 0x10, 0x52, 0x05, 0x7c, 0x02, 0x56, 0xa0, 0xd5, 0xbd, 0x06, 0xd6,
    0x9b, 0x3e, 0x81, 0xa4, 0xc0, 0x75, 0xa4, 0xcb, 0x1c, 0xcf, 0xc8, 0x8d, 0x27, 0x20, 0x61, 0xf5,
    0xd3, 0x18, 0x1f, 0x18, 0x2c, 0x6a, 0xd1, 0xf1, 0x88, 0x7b, 0xa2, 0xe8, 0x7a, 0xed, 0xce, 0xfb,
    0xcf, 0x94, 0x6b, 0xf7, 0xf6, 0x89, 0xe7, 0xc7, 0x54, 0x72, 0x06, 0x29, 0x2e, 0x05, 0x23, 0x66,
    0x3b, 0x6d, 0x0b, 0xf0, 0x26, 0x7a, 0xdd, 0xe0, 0xc0, 0x42, 0xf5, 0x0c, 0xd3, 0x37, 0x05, 0xf3,
    0xa8, 0x14, 0x45, 0x9b, 0x4c, 0x93, 0xa9, 0x26, 0xae, 0x8f, 0xf5, 0xe9, 0x42, 0x96, 0xf6, 0x21,
    0xb8, 0x1d, 0x3a, 0x86, 0xd5, 0xbf, 0x70, 0xcb, 0x22, 0x10, 0xad, 0x9a, 0xe2, 0x6e, 0x61, 0xdf,
    0xa8, 0x0a, 0x09, 0xbc, 0x87, 0x55, 0x80, 0xe7, 0x86, 0xf2, 0x2f, 0x27, 0x34, 0x65, 0x08, 0xd2,
    0x82, 0x9c, 0x3e, 0x44, 0xd2, 0x35, 0xca, 0x66, 0xe5, 0x33, 0x07, 0xb5, 0xb6, 0x7b, 0x8a, 0x83,
    0xaf, 0x98, 0x36, 0xf0, 0xea, 0xec, 0x79, 0xd2, 0xbf, 0x73, 0x3d, 0xee, 0x15, 0x0d, 0xd0, 0x07,
    0xbb, 0x07, 0x9d, 0x2e, 0x2d, 0x76, 0x25, 0x08, 0x3a, 0x43, 0xd4, 0x7e, 0x43, 0x03, 0x28, 0xaa,
    0xe6, 0xf0, 0xdd, 0xb8, 0xf6, 0x7d, 0xc6, 0xd8, 0x26, 0x76, 0xa0, 0x66, 0x62, 0xa3, 0x1a, 0x1e,
    0x7e, 0xad, 0xc9, 0x05, 0x62, 0xad, 0x6f, 0x04, 0x72, 0x91, 0x24, 0x77, 0x97, 0xc8, 0x2d, 0x34,
    0x92, 0x7d, 0x6b, 0x0d, 0xd8, 0x60, 0x19, 0xe5, 0x54, 0x2d, 0x5b, 0x6a, 0x9d, 0x51, 0xa9, 0xf4,
    0x11, 0x7d, 0x97, 0x27, 0x55, 0x83, 0x54, 0x9b, 0xc2, 0x07, 0x3a, 0x3f, 0xec, 0x5b, 0xf4, 0x11,
    0xc2, 0x9d, 0x49, 0xaa, 0xc6, 0x05, 0x63, 0x36, 0x3d, 0xdc, 0x1c, 0x89, 0xd3, 0xe4, 0x74, 0x83,
    0x90, 0x19, 0x45, 0x46, 0xb6, 0x47, 0xb0, 0x85, 0xe2, 0xc4, 0x71, 0x5f, 0x04, 0x2a, 0x7c, 0x44,
    0x86, 0x69, 0x68, 0xee, 0xcc, 0xa6, 0xa2, 0x61, 0x0b, 0x33, 0x08, 0x2c, 0x48, 0xe5, 0x38, 0x94,
    0x52, 0x78, 0x4e, 0x6a, 0x6d, 0xf6, 0x2e, 0x30, 0xe2, 0x0a, 0xa5, 0x1e, 0xed, 0xa8, 0xb5, 0x36,
    0xbd, 0x0a, 0x74, 0xd1, 0x36, 0xe4, 0xf8, 0x1a, 0xa6, 0xa7, 0x72, 0xb4, 0xb3, 0x66, 0x98, 0x7b,
    0xb1, 0xaa, 0x4e, 0xe8, 0x20, 0xcb, 0x4c, 0x15, 0xf6, 0x45, 0xa3, 0x1e, 0xee, 0xae, 0xdb, 0xdf,
    0x9d, 0x40, 0xe7, 0x48, 0xe0, 0x8c, 0x91, 0x4b, 0xcc, 0x41, 0xe2, 0x7f, 0xf4, 0x34, 0x83, 0x5c,
    0x53, 0x51, 0xa8, 0x20, 0xf5, 0x86, 0x8d, 0x99, 0x88, 0xdc, 0xc4, 0x67, 0xb5, 0xdd, 0x03, 0x3f,
    0xcc, 0xb3, 0x6b, 0xe6, 0x77, 0xc2, 0x15, 0xe2, 0x6f, 0xab, 0x90, 0xd6, 0x77, 0xbc, 0x44, 0x06,
    0x55, 0x6f, 0xb0, 0x93, 0x56, 0x06, 0x4c, 0x61, 0x9b, 0x00, 0x85, 0xfa, 0xb4, 0x45, 0x34, 0x63,
    0x5d, 0xbd, 0x4a, 0xc7, 0x87, 0x1c, 0xfb, 0x0a, 0x19, 0xe5, 0x27, 0xb3, 0xdd, 0x05, 0x65, 0xf5,
    0x46, 0xf5, 0xf6, 0x8b, 0x08, 0xeb, 0x87, 0x36, 0xee, 0xf4, 0x0f, 0x86, 0xec, 0x54, 0xb5, 0x81,
    0x3c, 0xe0, 0x8f, 0x80, 0x6f, 0x42, 0x5a, 0xef, 0x67, 0x9a, 0x93, 0x6e, 0x1a, 0x30, 0x15, 0x1d,
    0x80, 0x69, 0xe8, 0x38, 0x94, 0x24, 0xa9, 0xc8, 0xcb, 0x64, 0x77, 0x19, 0x9a, 0x59, 0xcf, 0xc4,
    0x8b, 0x4d, 0x9b, 0xcc, 0x6e, 0xfe, 0x02, 0xe2, 0x1f, 0x3c, 0x9d
};
#endif

PyTypeObject *init_QSqlQuery(PyObject *module)
{
    if (SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX].type != nullptr)
        return SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX].type;

    Shiboken::AutoDecRef Sbk_QSqlQuery_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QSqlQuery_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSqlQuery",
        "QSqlQuery",
        &Sbk_QSqlQuery_spec,
        &Shiboken::callCppDestructor< ::QSqlQuery >,
        Sbk_QSqlQuery_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QSqlQuery_TypeF(); // references _Sbk_QSqlQuery_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSqlQuery_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSqlQuery_SignatureBytes, QSqlQuery_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSqlQuery_PropertyStrings);
    SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSqlQuery_PythonToCpp_QSqlQuery_PTR,
        is_QSqlQuery_PythonToCpp_QSqlQuery_PTR_Convertible,
        QSqlQuery_PTR_CppToPython_QSqlQuery,
        QSqlQuery_COPY_CppToPython_QSqlQuery);

    Shiboken::Conversions::registerConverterName(converter, "QSqlQuery");
    Shiboken::Conversions::registerConverterName(converter, "QSqlQuery*");
    Shiboken::Conversions::registerConverterName(converter, "QSqlQuery&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSqlQuery).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QSqlQuery_PythonToCpp_QSqlQuery_COPY,
        is_QSqlQuery_PythonToCpp_QSqlQuery_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QSqlQuery_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'BatchExecutionMode'.
    const char *BatchExecutionMode_Initializer[] = {
        "ValuesAsRows",
        "ValuesAsColumns",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t BatchExecutionMode_InitializerValues[] = {
        uint8_t(QSqlQuery::BatchExecutionMode::ValuesAsRows),   //  0x00  0
        uint8_t(QSqlQuery::BatchExecutionMode::ValuesAsColumns) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSqlQuery_TypeF(),
        "2:PySide6.QtSql.QSqlQuery.BatchExecutionMode",
        BatchExecutionMode_Initializer, BatchExecutionMode_InitializerValues);
    SbkPySide6_QtSqlTypeStructs[SBK_QSqlQuery_BatchExecutionMode_IDX].type = EType;
    // Register converter for enum 'QSqlQuery::BatchExecutionMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSqlQuery_BatchExecutionMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QSqlQuery_BatchExecutionMode,
            is_Enum_PythonToCpp_QSqlQuery_BatchExecutionMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QSqlQuery::BatchExecutionMode");
        Shiboken::Conversions::registerConverterAlias(converter, "BatchExecutionMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'BatchExecutionMode' enum.

    qRegisterMetaType< ::QSqlQuery >("QSqlQuery");
    qRegisterMetaType< ::QSqlQuery::BatchExecutionMode >("QSqlQuery::BatchExecutionMode");

    return pyType;
}
