// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtsql_python.h"

// main header
#include "qsqlresult_wrapper.h"

// Extra includes
#include <QSize>
#include <QSqlError>
#include <QSqlQuery>
#include <QSqlRecord>
#include <QStringList>

// Argument includes
#include <QList>
#include <QString>
#include <QStringList>
#include <QtSql/qsqldriver.h>
#include <QtSql/qsqlerror.h>
#include <QtSql/qsqlrecord.h>
#include <QtSql/qsqlresult.h>
#include <QtSql/qtsqlglobal.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QSqlResultWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QSqlResultWrapper::QSqlResultWrapper(const ::QSqlDriver * db) : QSqlResult(db)
{
}

void QSqlResultWrapper::bindValue(const ::QString & placeholder, const ::QVariant & val, ::QFlags<QSql::ParamTypeFlag> type)
{
    if (m_PyMethodCache[0]) {
        return this->::QSqlResult::bindValue(placeholder, val, type);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "bindValue";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QSqlResult::bindValue(placeholder, val, type);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[3] = {
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &placeholder),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &val),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QFlags_QSql_ParamTypeFlag_IDX])))->flagsConverter, &type)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNN)",
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &placeholder),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &val),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QFlags_QSql_ParamTypeFlag_IDX])))->flagsConverter, &type)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 3, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSqlResult", funcName);
        return;
    }
}

void QSqlResultWrapper::bindValue(int pos, const ::QVariant & val, ::QFlags<QSql::ParamTypeFlag> type)
{
    if (m_PyMethodCache[1]) {
        return this->::QSqlResult::bindValue(pos, val, type);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "bindValue";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QSqlResult::bindValue(pos, val, type);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[3] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &pos),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &val),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QFlags_QSql_ParamTypeFlag_IDX])))->flagsConverter, &type)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(iNN)",
        pos,
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &val),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QFlags_QSql_ParamTypeFlag_IDX])))->flagsConverter, &type)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 3, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSqlResult", funcName);
        return;
    }
}

::QVariant QSqlResultWrapper::data(int i)
{
    if (m_PyMethodCache[2]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QSqlResult.data");
        return ::QVariant();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return ::QVariant();
    static PyObject *nameCache[2] = {};
    static const char *funcName = "data";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        Shiboken::Errors::setPureVirtualMethodError("QSqlResult.data");
        return ::QVariant();
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &i)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(i)",
        i
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSqlResult", funcName);
        return ::QVariant();
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSqlResult", funcName, "QVariant", Py_TYPE(pyResult)->tp_name);
        return ::QVariant();
    }
    ::QVariant cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QSqlResultWrapper::detachFromResultSet()
{
    if (m_PyMethodCache[3]) {
        return this->::QSqlResult::detachFromResultSet();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "detachFromResultSet";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QSqlResult::detachFromResultSet();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSqlResult", funcName);
        return;
    }
}

bool QSqlResultWrapper::exec()
{
    if (m_PyMethodCache[4])
        return this->::QSqlResult::exec();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "exec";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QSqlResult::exec();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSqlResult", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSqlResult", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QSqlResultWrapper::execBatch(bool arrayBind)
{
    if (m_PyMethodCache[5])
        return this->::QSqlResult::execBatch(arrayBind);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "execBatch";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QSqlResult::execBatch(arrayBind);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &arrayBind)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &arrayBind)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSqlResult", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSqlResult", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QSqlResultWrapper::fetch(int i)
{
    if (m_PyMethodCache[6]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QSqlResult.fetch");
        return false;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "fetch";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        Shiboken::Errors::setPureVirtualMethodError("QSqlResult.fetch");
        return false;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &i)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(i)",
        i
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSqlResult", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSqlResult", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QSqlResultWrapper::fetchFirst()
{
    if (m_PyMethodCache[7]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QSqlResult.fetchFirst");
        return false;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "fetchFirst";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[7] = true;
        Shiboken::Errors::setPureVirtualMethodError("QSqlResult.fetchFirst");
        return false;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSqlResult", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSqlResult", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QSqlResultWrapper::fetchLast()
{
    if (m_PyMethodCache[8]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QSqlResult.fetchLast");
        return false;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "fetchLast";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[8] = true;
        Shiboken::Errors::setPureVirtualMethodError("QSqlResult.fetchLast");
        return false;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSqlResult", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSqlResult", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QSqlResultWrapper::fetchNext()
{
    if (m_PyMethodCache[9])
        return this->::QSqlResult::fetchNext();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "fetchNext";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[9] = true;
        gil.release();
        return this->::QSqlResult::fetchNext();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSqlResult", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSqlResult", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QSqlResultWrapper::fetchPrevious()
{
    if (m_PyMethodCache[10])
        return this->::QSqlResult::fetchPrevious();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "fetchPrevious";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[10] = true;
        gil.release();
        return this->::QSqlResult::fetchPrevious();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSqlResult", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSqlResult", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QVariant QSqlResultWrapper::handle() const
{
    if (m_PyMethodCache[11])
        return this->::QSqlResult::handle();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return ::QVariant();
    static PyObject *nameCache[2] = {};
    static const char *funcName = "handle";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[11] = true;
        gil.release();
        return this->::QSqlResult::handle();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSqlResult", funcName);
        return ::QVariant();
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSqlResult", funcName, "QVariant", Py_TYPE(pyResult)->tp_name);
        return ::QVariant();
    }
    ::QVariant cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QSqlResultWrapper::isNull(int i)
{
    if (m_PyMethodCache[12]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QSqlResult.isNull");
        return false;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "isNull";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[12] = true;
        Shiboken::Errors::setPureVirtualMethodError("QSqlResult.isNull");
        return false;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &i)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(i)",
        i
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSqlResult", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSqlResult", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QVariant QSqlResultWrapper::lastInsertId() const
{
    if (m_PyMethodCache[13])
        return this->::QSqlResult::lastInsertId();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return ::QVariant();
    static PyObject *nameCache[2] = {};
    static const char *funcName = "lastInsertId";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[13] = true;
        gil.release();
        return this->::QSqlResult::lastInsertId();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSqlResult", funcName);
        return ::QVariant();
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSqlResult", funcName, "QVariant", Py_TYPE(pyResult)->tp_name);
        return ::QVariant();
    }
    ::QVariant cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QSqlResultWrapper::nextResult()
{
    if (m_PyMethodCache[14])
        return this->::QSqlResult::nextResult();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "nextResult";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[14] = true;
        gil.release();
        return this->::QSqlResult::nextResult();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSqlResult", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSqlResult", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

int QSqlResultWrapper::numRowsAffected()
{
    if (m_PyMethodCache[15]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QSqlResult.numRowsAffected");
        return 0;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return 0;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "numRowsAffected";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[15] = true;
        Shiboken::Errors::setPureVirtualMethodError("QSqlResult.numRowsAffected");
        return 0;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSqlResult", funcName);
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSqlResult", funcName, "int", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    int cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QSqlResultWrapper::prepare(const ::QString & query)
{
    if (m_PyMethodCache[16])
        return this->::QSqlResult::prepare(query);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "prepare";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[16] = true;
        gil.release();
        return this->::QSqlResult::prepare(query);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &query)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &query)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSqlResult", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSqlResult", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QSqlRecord QSqlResultWrapper::record() const
{
    if (m_PyMethodCache[17])
        return this->::QSqlResult::record();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return {};
    static PyObject *nameCache[2] = {};
    static const char *funcName = "record";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[17] = true;
        gil.release();
        return this->::QSqlResult::record();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSqlResult", funcName);
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlRecord_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSqlResult", funcName, Shiboken::SbkType< QSqlRecord >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QSqlRecord cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QSqlResultWrapper::reset(const ::QString & sqlquery)
{
    if (m_PyMethodCache[18]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QSqlResult.reset");
        return false;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "reset";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[18] = true;
        Shiboken::Errors::setPureVirtualMethodError("QSqlResult.reset");
        return false;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &sqlquery)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &sqlquery)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSqlResult", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSqlResult", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QSqlResultWrapper::savePrepare(const ::QString & sqlquery)
{
    if (m_PyMethodCache[19])
        return this->::QSqlResult::savePrepare(sqlquery);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "savePrepare";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[19] = true;
        gil.release();
        return this->::QSqlResult::savePrepare(sqlquery);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &sqlquery)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &sqlquery)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSqlResult", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSqlResult", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QSqlResultWrapper::setActive(bool a)
{
    if (m_PyMethodCache[20]) {
        return this->::QSqlResult::setActive(a);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setActive";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[20] = true;
        gil.release();
        return this->::QSqlResult::setActive(a);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &a)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &a)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSqlResult", funcName);
        return;
    }
}

void QSqlResultWrapper::setAt(int at)
{
    if (m_PyMethodCache[21]) {
        return this->::QSqlResult::setAt(at);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setAt";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[21] = true;
        gil.release();
        return this->::QSqlResult::setAt(at);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &at)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(i)",
        at
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSqlResult", funcName);
        return;
    }
}

void QSqlResultWrapper::setForwardOnly(bool forward)
{
    if (m_PyMethodCache[22]) {
        return this->::QSqlResult::setForwardOnly(forward);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setForwardOnly";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[22] = true;
        gil.release();
        return this->::QSqlResult::setForwardOnly(forward);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &forward)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &forward)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSqlResult", funcName);
        return;
    }
}

void QSqlResultWrapper::setLastError(const ::QSqlError & e)
{
    if (m_PyMethodCache[23]) {
        return this->::QSqlResult::setLastError(e);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setLastError";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[23] = true;
        gil.release();
        return this->::QSqlResult::setLastError(e);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_IDX]), &e)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_IDX]), &e)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSqlResult", funcName);
        return;
    }
}

void QSqlResultWrapper::setNumericalPrecisionPolicy(::QSql::NumericalPrecisionPolicy policy)
{
    if (m_PyMethodCache[24]) {
        return this->::QSqlResult::setNumericalPrecisionPolicy(policy);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setNumericalPrecisionPolicy";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[24] = true;
        gil.release();
        return this->::QSqlResult::setNumericalPrecisionPolicy(policy);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSql_NumericalPrecisionPolicy_IDX])))->converter, &policy)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSql_NumericalPrecisionPolicy_IDX])))->converter, &policy)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSqlResult", funcName);
        return;
    }
}

void QSqlResultWrapper::setQuery(const ::QString & query)
{
    if (m_PyMethodCache[25]) {
        return this->::QSqlResult::setQuery(query);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setQuery";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[25] = true;
        gil.release();
        return this->::QSqlResult::setQuery(query);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &query)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &query)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSqlResult", funcName);
        return;
    }
}

void QSqlResultWrapper::setSelect(bool s)
{
    if (m_PyMethodCache[26]) {
        return this->::QSqlResult::setSelect(s);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setSelect";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[26] = true;
        gil.release();
        return this->::QSqlResult::setSelect(s);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &s)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &s)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSqlResult", funcName);
        return;
    }
}

int QSqlResultWrapper::size()
{
    if (m_PyMethodCache[27]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QSqlResult.size");
        return 0;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return 0;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "size";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[27] = true;
        Shiboken::Errors::setPureVirtualMethodError("QSqlResult.size");
        return 0;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSqlResult", funcName);
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSqlResult", funcName, "int", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    int cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QSqlResultWrapper::~QSqlResultWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSqlResult_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QSqlResult");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSqlResult >()))
        return -1;

    QSqlResultWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QSqlResult", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QSqlResult::QSqlResult(const QSqlDriver*)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QSqlResult(const QSqlDriver*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QSqlDriver *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QSqlResult(const QSqlDriver*)
            cptr = new QSqlResultWrapper(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QSqlResult >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSqlResultFunc_addBindValue(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "addBindValue", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSqlResult::addBindValue(QVariant,QFlags<QSql::ParamTypeFlag>)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QFlags_QSql_ParamTypeFlag_IDX])))->flagsConverter, (pyArgs[1])))) {
        overloadId = 0; // addBindValue(QVariant,QFlags<QSql::ParamTypeFlag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addBindValue", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]);

    // Call function/method
    {
        ::QVariant cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<QSql::ParamTypeFlag> cppArg1 = QFlags<QSql::ParamTypeFlag>(0);
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addBindValue(QVariant,QFlags<QSql::ParamTypeFlag>)
            cppSelf->addBindValue(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlResultFunc_at(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // at()const
        int cppResult = const_cast<const ::QSqlResult *>(cppSelf)->at();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlResultFunc_bindValue(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "bindValue", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSqlResult::bindValue(int,QVariant,QFlags<QSql::ParamTypeFlag>)
    // 1: QSqlResult::bindValue(QString,QVariant,QFlags<QSql::ParamTypeFlag>)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QFlags_QSql_ParamTypeFlag_IDX])))->flagsConverter, (pyArgs[2])))) {
        overloadId = 1; // bindValue(QString,QVariant,QFlags<QSql::ParamTypeFlag>)
    } else if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QFlags_QSql_ParamTypeFlag_IDX])))->flagsConverter, (pyArgs[2])))) {
        overloadId = 0; // bindValue(int,QVariant,QFlags<QSql::ParamTypeFlag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "bindValue", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // bindValue(int pos, const QVariant &val, QFlags<QSql::ParamTypeFlag> type)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QVariant cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<QSql::ParamTypeFlag> cppArg2 = QFlags<QSql::ParamTypeFlag>(0);
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // bindValue(int,QVariant,QFlags<QSql::ParamTypeFlag>)
                Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                    ? cppSelf->::QSqlResult::bindValue(cppArg0, cppArg1, cppArg2)
                    : cppSelf->bindValue(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
        case 1: // bindValue(const QString &placeholder, const QVariant &val, QFlags<QSql::ParamTypeFlag> type)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QVariant cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<QSql::ParamTypeFlag> cppArg2 = QFlags<QSql::ParamTypeFlag>(0);
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // bindValue(QString,QVariant,QFlags<QSql::ParamTypeFlag>)
                Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                    ? cppSelf->::QSqlResult::bindValue(cppArg0, cppArg1, cppArg2)
                    : cppSelf->bindValue(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlResultFunc_bindValueType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlResult::bindValueType(QString)const->QFlags<QSql::ParamTypeFlag>
    // 1: QSqlResult::bindValueType(int)const->QFlags<QSql::ParamTypeFlag>
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 1; // bindValueType(int)const
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // bindValueType(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "bindValueType", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // bindValueType(const QString &placeholder) const
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // bindValueType(QString)const
                QFlags<QSql::ParamTypeFlag> cppResult = const_cast<const ::QSqlResult *>(cppSelf)->bindValueType(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QFlags_QSql_ParamTypeFlag_IDX])))->flagsConverter, &cppResult);
            }
            break;
        }
        case 1: // bindValueType(int pos) const
        {
            int cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // bindValueType(int)const
                QFlags<QSql::ParamTypeFlag> cppResult = const_cast<const ::QSqlResult *>(cppSelf)->bindValueType(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QFlags_QSql_ParamTypeFlag_IDX])))->flagsConverter, &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlResultFunc_bindingSyntax(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // bindingSyntax()const
        QSqlResult::BindingSyntax cppResult = const_cast<const ::QSqlResult *>(cppSelf)->bindingSyntax();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_BindingSyntax_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlResultFunc_boundValue(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlResult::boundValue(QString)const->QVariant
    // 1: QSqlResult::boundValue(int)const->QVariant
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 1; // boundValue(int)const
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // boundValue(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "boundValue", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // boundValue(const QString &placeholder) const
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // boundValue(QString)const
                QVariant cppResult = const_cast<const ::QSqlResult *>(cppSelf)->boundValue(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
            }
            break;
        }
        case 1: // boundValue(int pos) const
        {
            int cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // boundValue(int)const
                QVariant cppResult = const_cast<const ::QSqlResult *>(cppSelf)->boundValue(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlResultFunc_boundValueCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // boundValueCount()const
        int cppResult = const_cast<const ::QSqlResult *>(cppSelf)->boundValueCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlResultFunc_boundValueName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlResult::boundValueName(int)const->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // boundValueName(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "boundValueName", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // boundValueName(int)const
            QString cppResult = const_cast<const ::QSqlResult *>(cppSelf)->boundValueName(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlResultFunc_boundValueNames(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // boundValueNames()const
        QStringList cppResult = const_cast<const ::QSqlResult *>(cppSelf)->boundValueNames();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlResultFunc_boundValues(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // boundValues()
        QList<QVariant> & cppResult = cppSelf->boundValues();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtSqlTypeConverters[SBK_QtSql_QList_QVariant_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlResultFunc_clear(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clear()
        cppSelf->clear();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlResultFunc_data(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlResult::data(int)->QVariant
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // data(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "data", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // data(int)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QSqlResult.data");
                return {};
            }
            QVariant cppResult = cppSelf->data(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlResultFunc_detachFromResultSet(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // detachFromResultSet()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QSqlResult::detachFromResultSet()
            : cppSelf->detachFromResultSet();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlResultFunc_driver(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // driver()const
        const QSqlDriver * cppResult = const_cast<const ::QSqlResult *>(cppSelf)->driver();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDriver_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlResultFunc_exec(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;
    pcm.setBlocking();

    // Call function/method
    {

        // exec()
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QSqlResult::exec()
            : cppSelf->exec();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlResultFunc_execBatch(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "execBatch", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]);

    if (PyArg_ParseTuple(args, "|O:execBatch", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSqlResult::execBatch(bool=)->bool
    if (numArgs == 0) {
        overloadId = 0; // execBatch(bool)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))) {
        overloadId = 0; // execBatch(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "execBatch", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_arrayBind = Shiboken::String::createStaticString("arrayBind");
            if (PyDict_Contains(kwds, key_arrayBind) != 0) {
                value = PyDict_GetItem(kwds, key_arrayBind);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_arrayBind);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "execBatch", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "execBatch", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_arrayBind);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "execBatch", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]);
            }
        }
        bool cppArg0 = false;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // execBatch(bool)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSqlResult::execBatch(cppArg0)
                : cppSelf->execBatch(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlResultFunc_exec_(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;
    pcm.setBlocking();

    // Call function/method
    {

        // exec_()
        // Begin code injection
        // ========================================================================
        // START of custom code block [file: ../glue/qtsql.cpp (qsqlresult-exec)]
        if (PyErr_WarnEx(PyExc_DeprecationWarning,
                         "'exec_' will be removed in the future. "
                         "Use 'exec' instead.",
                         1)) {
            return nullptr;
        }
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
#ifndef AVOID_PROTECTED_HACK
        bool cppResult = cppSelf->exec();
#else
        bool cppResult = static_cast<::QSqlResultWrapper *>(cppSelf)->QSqlResultWrapper::exec_protected();
#endif
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        // END of custom code block [file: ../glue/qtsql.cpp (qsqlresult-exec)]
        // ========================================================================
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlResultFunc_executedQuery(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // executedQuery()const
        QString cppResult = const_cast<const ::QSqlResult *>(cppSelf)->executedQuery();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlResultFunc_fetch(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlResult::fetch(int)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // fetch(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fetch", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fetch(int)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QSqlResult.fetch");
                return {};
            }
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = cppSelf->fetch(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlResultFunc_fetchFirst(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // fetchFirst()
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QSqlResult.fetchFirst");
            return {};
        }
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        bool cppResult = cppSelf->fetchFirst();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlResultFunc_fetchLast(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // fetchLast()
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QSqlResult.fetchLast");
            return {};
        }
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        bool cppResult = cppSelf->fetchLast();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlResultFunc_fetchNext(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // fetchNext()
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QSqlResult::fetchNext()
            : cppSelf->fetchNext();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlResultFunc_fetchPrevious(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // fetchPrevious()
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QSqlResult::fetchPrevious()
            : cppSelf->fetchPrevious();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlResultFunc_handle(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // handle()const
        QVariant cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QSqlResult *>(cppSelf)->::QSqlResult::handle()
            : const_cast<const ::QSqlResult *>(cppSelf)->handle();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlResultFunc_hasOutValues(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hasOutValues()const
        bool cppResult = const_cast<const ::QSqlResult *>(cppSelf)->hasOutValues();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlResultFunc_isActive(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isActive()const
        bool cppResult = const_cast<const ::QSqlResult *>(cppSelf)->isActive();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlResultFunc_isForwardOnly(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isForwardOnly()const
        bool cppResult = const_cast<const ::QSqlResult *>(cppSelf)->isForwardOnly();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlResultFunc_isNull(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlResult::isNull(int)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // isNull(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isNull", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isNull(int)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QSqlResult.isNull");
                return {};
            }
            bool cppResult = cppSelf->isNull(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlResultFunc_isPositionalBindingEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isPositionalBindingEnabled()const
        bool cppResult = const_cast<const ::QSqlResult *>(cppSelf)->isPositionalBindingEnabled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlResultFunc_isSelect(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isSelect()const
        bool cppResult = const_cast<const ::QSqlResult *>(cppSelf)->isSelect();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlResultFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QSqlResult *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlResultFunc_lastError(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lastError()const
        QSqlError cppResult = const_cast<const ::QSqlResult *>(cppSelf)->lastError();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlResultFunc_lastInsertId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lastInsertId()const
        QVariant cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QSqlResult *>(cppSelf)->::QSqlResult::lastInsertId()
            : const_cast<const ::QSqlResult *>(cppSelf)->lastInsertId();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlResultFunc_lastQuery(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lastQuery()const
        QString cppResult = const_cast<const ::QSqlResult *>(cppSelf)->lastQuery();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlResultFunc_nextResult(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // nextResult()
        bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QSqlResult::nextResult()
            : cppSelf->nextResult();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlResultFunc_numRowsAffected(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // numRowsAffected()
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QSqlResult.numRowsAffected");
            return {};
        }
        int cppResult = cppSelf->numRowsAffected();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlResultFunc_numericalPrecisionPolicy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // numericalPrecisionPolicy()const
        QSql::NumericalPrecisionPolicy cppResult = const_cast<const ::QSqlResult *>(cppSelf)->numericalPrecisionPolicy();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSql_NumericalPrecisionPolicy_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlResultFunc_prepare(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlResult::prepare(QString)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // prepare(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "prepare", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // prepare(QString)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSqlResult::prepare(cppArg0)
                : cppSelf->prepare(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlResultFunc_record(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // record()const
        QSqlRecord cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QSqlResult *>(cppSelf)->::QSqlResult::record()
            : const_cast<const ::QSqlResult *>(cppSelf)->record();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlRecord_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlResultFunc_reset(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlResult::reset(QString)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // reset(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "reset", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // reset(QString)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QSqlResult.reset");
                return {};
            }
            bool cppResult = cppSelf->reset(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlResultFunc_resetBindCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // resetBindCount()
        cppSelf->resetBindCount();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlResultFunc_savePrepare(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlResult::savePrepare(QString)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // savePrepare(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "savePrepare", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // savePrepare(QString)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSqlResult::savePrepare(cppArg0)
                : cppSelf->savePrepare(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSqlResultFunc_setActive(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlResult::setActive(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setActive(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setActive", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setActive(bool)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSqlResult::setActive(cppArg0)
                : cppSelf->setActive(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlResultFunc_setAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlResult::setAt(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setAt(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAt", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAt(int)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSqlResult::setAt(cppArg0)
                : cppSelf->setAt(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlResultFunc_setForwardOnly(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlResult::setForwardOnly(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setForwardOnly(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setForwardOnly", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setForwardOnly(bool)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSqlResult::setForwardOnly(cppArg0)
                : cppSelf->setForwardOnly(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlResultFunc_setLastError(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlResult::setLastError(QSqlError)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlError_IDX]), (pyArg)))) {
        overloadId = 0; // setLastError(QSqlError)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLastError", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSqlError cppArg0_local;
        ::QSqlError *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setLastError(QSqlError)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSqlResult::setLastError(*cppArg0)
                : cppSelf->setLastError(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlResultFunc_setNumericalPrecisionPolicy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlResult::setNumericalPrecisionPolicy(QSql::NumericalPrecisionPolicy)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSql_NumericalPrecisionPolicy_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setNumericalPrecisionPolicy(QSql::NumericalPrecisionPolicy)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setNumericalPrecisionPolicy", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]);

    // Call function/method
    {
        ::QSql::NumericalPrecisionPolicy cppArg0{QSql::HighPrecision};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setNumericalPrecisionPolicy(QSql::NumericalPrecisionPolicy)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSqlResult::setNumericalPrecisionPolicy(cppArg0)
                : cppSelf->setNumericalPrecisionPolicy(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlResultFunc_setPositionalBindingEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlResult::setPositionalBindingEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setPositionalBindingEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPositionalBindingEnabled", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPositionalBindingEnabled(bool)
            cppSelf->setPositionalBindingEnabled(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlResultFunc_setQuery(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlResult::setQuery(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setQuery(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setQuery", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setQuery(QString)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSqlResult::setQuery(cppArg0)
                : cppSelf->setQuery(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlResultFunc_setSelect(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlResult::setSelect(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setSelect(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSelect", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSelect(bool)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSqlResult::setSelect(cppArg0)
                : cppSelf->setSelect(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSqlResultFunc_size(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // size()
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QSqlResult.size");
            return {};
        }
        int cppResult = cppSelf->size();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QSqlResult_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QSqlResult_EnumFlagInfo[] = {
    "BindingSyntax:Enum",
    "VirtualHookOperation:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSqlResult_methods[] = {
    {"addBindValue", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_addBindValue), METH_VARARGS, nullptr},
    {"at", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_at), METH_NOARGS, nullptr},
    {"bindValue", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_bindValue), METH_VARARGS, nullptr},
    {"bindValueType", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_bindValueType), METH_O, nullptr},
    {"bindingSyntax", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_bindingSyntax), METH_NOARGS, nullptr},
    {"boundValue", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_boundValue), METH_O, nullptr},
    {"boundValueCount", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_boundValueCount), METH_NOARGS, nullptr},
    {"boundValueName", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_boundValueName), METH_O, nullptr},
    {"boundValueNames", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_boundValueNames), METH_NOARGS, nullptr},
    {"boundValues", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_boundValues), METH_NOARGS, nullptr},
    {"clear", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_clear), METH_NOARGS, nullptr},
    {"data", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_data), METH_O, nullptr},
    {"detachFromResultSet", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_detachFromResultSet), METH_NOARGS, nullptr},
    {"driver", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_driver), METH_NOARGS, nullptr},
    {"exec", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_exec), METH_NOARGS, nullptr},
    {"execBatch", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_execBatch), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"exec_", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_exec_), METH_NOARGS, nullptr},
    {"executedQuery", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_executedQuery), METH_NOARGS, nullptr},
    {"fetch", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_fetch), METH_O, nullptr},
    {"fetchFirst", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_fetchFirst), METH_NOARGS, nullptr},
    {"fetchLast", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_fetchLast), METH_NOARGS, nullptr},
    {"fetchNext", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_fetchNext), METH_NOARGS, nullptr},
    {"fetchPrevious", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_fetchPrevious), METH_NOARGS, nullptr},
    {"handle", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_handle), METH_NOARGS, nullptr},
    {"hasOutValues", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_hasOutValues), METH_NOARGS, nullptr},
    {"isActive", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_isActive), METH_NOARGS, nullptr},
    {"isForwardOnly", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_isForwardOnly), METH_NOARGS, nullptr},
    {"isNull", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_isNull), METH_O, nullptr},
    {"isPositionalBindingEnabled", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_isPositionalBindingEnabled), METH_NOARGS, nullptr},
    {"isSelect", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_isSelect), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_isValid), METH_NOARGS, nullptr},
    {"lastError", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_lastError), METH_NOARGS, nullptr},
    {"lastInsertId", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_lastInsertId), METH_NOARGS, nullptr},
    {"lastQuery", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_lastQuery), METH_NOARGS, nullptr},
    {"nextResult", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_nextResult), METH_NOARGS, nullptr},
    {"numRowsAffected", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_numRowsAffected), METH_NOARGS, nullptr},
    {"numericalPrecisionPolicy", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_numericalPrecisionPolicy), METH_NOARGS, nullptr},
    {"prepare", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_prepare), METH_O, nullptr},
    {"record", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_record), METH_NOARGS, nullptr},
    {"reset", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_reset), METH_O, nullptr},
    {"resetBindCount", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_resetBindCount), METH_NOARGS, nullptr},
    {"savePrepare", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_savePrepare), METH_O, nullptr},
    {"setActive", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_setActive), METH_O, nullptr},
    {"setAt", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_setAt), METH_O, nullptr},
    {"setForwardOnly", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_setForwardOnly), METH_O, nullptr},
    {"setLastError", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_setLastError), METH_O, nullptr},
    {"setNumericalPrecisionPolicy", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_setNumericalPrecisionPolicy), METH_O, nullptr},
    {"setPositionalBindingEnabled", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_setPositionalBindingEnabled), METH_O, nullptr},
    {"setQuery", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_setQuery), METH_O, nullptr},
    {"setSelect", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_setSelect), METH_O, nullptr},
    {"size", reinterpret_cast<PyCFunction>(Sbk_QSqlResultFunc_size), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QSqlResult_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QSqlResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QSqlResultWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QSqlResult_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSqlResult_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSqlResult_Type = nullptr;
static PyTypeObject *Sbk_QSqlResult_TypeF(void)
{
    return _Sbk_QSqlResult_Type;
}

static PyType_Slot Sbk_QSqlResult_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QSqlResult_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSqlResult_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSqlResult_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSqlResult_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSqlResult_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSqlResult_spec = {
    "2:PySide6.QtSql.QSqlResult",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSqlResult_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QSqlResult_BindingSyntax(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSqlResult::BindingSyntax>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSqlResult::BindingSyntax *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QSqlResult_BindingSyntax_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_BindingSyntax_IDX])))
        return Enum_PythonToCpp_QSqlResult_BindingSyntax;
    return {};
}

static PyObject *QSqlResult_BindingSyntax_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QSqlResult::BindingSyntax>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QSqlResult::BindingSyntax *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_BindingSyntax_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QSqlResult_VirtualHookOperation(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSqlResult::VirtualHookOperation>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSqlResult::VirtualHookOperation *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QSqlResult_VirtualHookOperation_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_VirtualHookOperation_IDX])))
        return Enum_PythonToCpp_QSqlResult_VirtualHookOperation;
    return {};
}

static PyObject *QSqlResult_VirtualHookOperation_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QSqlResult::VirtualHookOperation>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QSqlResult::VirtualHookOperation *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_VirtualHookOperation_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSqlResult_PythonToCpp_QSqlResult_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSqlResult_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSqlResult_PythonToCpp_QSqlResult_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSqlResult_TypeF()))
        return QSqlResult_PythonToCpp_QSqlResult_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSqlResult_PTR_CppToPython_QSqlResult(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QSqlResult *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QSqlResult_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSqlResult_SignatureStrings[] = {
    "PySide6.QtSql.QSqlResult(self,db:PySide6.QtSql.QSqlDriver)",
    "PySide6.QtSql.QSqlResult.addBindValue(self,val:QVariant,type:PySide6.QtSql.QSql.ParamTypeFlag)",
    "PySide6.QtSql.QSqlResult.at(self)->int",
    "1:PySide6.QtSql.QSqlResult.bindValue(self,pos:int,val:QVariant,type:PySide6.QtSql.QSql.ParamTypeFlag)",
    "0:PySide6.QtSql.QSqlResult.bindValue(self,placeholder:QString,val:QVariant,type:PySide6.QtSql.QSql.ParamTypeFlag)",
    "1:PySide6.QtSql.QSqlResult.bindValueType(self,placeholder:QString)->PySide6.QtSql.QSql.ParamTypeFlag",
    "0:PySide6.QtSql.QSqlResult.bindValueType(self,pos:int)->PySide6.QtSql.QSql.ParamTypeFlag",
    "PySide6.QtSql.QSqlResult.bindingSyntax(self)->PySide6.QtSql.QSqlResult.BindingSyntax",
    "1:PySide6.QtSql.QSqlResult.boundValue(self,placeholder:QString)->QVariant",
    "0:PySide6.QtSql.QSqlResult.boundValue(self,pos:int)->QVariant",
    "PySide6.QtSql.QSqlResult.boundValueCount(self)->int",
    "PySide6.QtSql.QSqlResult.boundValueName(self,pos:int)->QString",
    "PySide6.QtSql.QSqlResult.boundValueNames(self)->QStringList",
    "PySide6.QtSql.QSqlResult.boundValues(self)->QList[QVariant]",
    "PySide6.QtSql.QSqlResult.clear(self)",
    "PySide6.QtSql.QSqlResult.data(self,i:int)->QVariant",
    "PySide6.QtSql.QSqlResult.detachFromResultSet(self)",
    "PySide6.QtSql.QSqlResult.driver(self)->PySide6.QtSql.QSqlDriver",
    "PySide6.QtSql.QSqlResult.exec(self)->bool",
    "PySide6.QtSql.QSqlResult.execBatch(self,arrayBind:bool=false)->bool",
    "PySide6.QtSql.QSqlResult.exec_(self)->bool",
    "PySide6.QtSql.QSqlResult.executedQuery(self)->QString",
    "PySide6.QtSql.QSqlResult.fetch(self,i:int)->bool",
    "PySide6.QtSql.QSqlResult.fetchFirst(self)->bool",
    "PySide6.QtSql.QSqlResult.fetchLast(self)->bool",
    "PySide6.QtSql.QSqlResult.fetchNext(self)->bool",
    "PySide6.QtSql.QSqlResult.fetchPrevious(self)->bool",
    "PySide6.QtSql.QSqlResult.handle(self)->QVariant",
    "PySide6.QtSql.QSqlResult.hasOutValues(self)->bool",
    "PySide6.QtSql.QSqlResult.isActive(self)->bool",
    "PySide6.QtSql.QSqlResult.isForwardOnly(self)->bool",
    "PySide6.QtSql.QSqlResult.isNull(self,i:int)->bool",
    "PySide6.QtSql.QSqlResult.isPositionalBindingEnabled(self)->bool",
    "PySide6.QtSql.QSqlResult.isSelect(self)->bool",
    "PySide6.QtSql.QSqlResult.isValid(self)->bool",
    "PySide6.QtSql.QSqlResult.lastError(self)->PySide6.QtSql.QSqlError",
    "PySide6.QtSql.QSqlResult.lastInsertId(self)->QVariant",
    "PySide6.QtSql.QSqlResult.lastQuery(self)->QString",
    "PySide6.QtSql.QSqlResult.nextResult(self)->bool",
    "PySide6.QtSql.QSqlResult.numRowsAffected(self)->int",
    "PySide6.QtSql.QSqlResult.numericalPrecisionPolicy(self)->PySide6.QtSql.QSql.NumericalPrecisionPolicy",
    "PySide6.QtSql.QSqlResult.prepare(self,query:QString)->bool",
    "PySide6.QtSql.QSqlResult.record(self)->PySide6.QtSql.QSqlRecord",
    "PySide6.QtSql.QSqlResult.reset(self,sqlquery:QString)->bool",
    "PySide6.QtSql.QSqlResult.resetBindCount(self)",
    "PySide6.QtSql.QSqlResult.savePrepare(self,sqlquery:QString)->bool",
    "PySide6.QtSql.QSqlResult.setActive(self,a:bool)",
    "PySide6.QtSql.QSqlResult.setAt(self,at:int)",
    "PySide6.QtSql.QSqlResult.setForwardOnly(self,forward:bool)",
    "PySide6.QtSql.QSqlResult.setLastError(self,e:PySide6.QtSql.QSqlError)",
    "PySide6.QtSql.QSqlResult.setNumericalPrecisionPolicy(self,policy:PySide6.QtSql.QSql.NumericalPrecisionPolicy)",
    "PySide6.QtSql.QSqlResult.setPositionalBindingEnabled(self,enable:bool)",
    "PySide6.QtSql.QSqlResult.setQuery(self,query:QString)",
    "PySide6.QtSql.QSqlResult.setSelect(self,s:bool)",
    "PySide6.QtSql.QSqlResult.size(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t QSqlResult_SignatureByteSize = 623;
static constexpr uint8_t QSqlResult_SignatureBytes[623] = {
    0x78, 0xda, 0x9d, 0x56, 0x5d, 0x6f, 0xda, 0x30, 0x14, 0x7d, 0xef, 0x2f, 0x19, 0x52, 0x86, 0xb6,
    0x97, 0x3d, 0x44, 0xda, 0xa4, 0xb2, 0x16, 0xa9, 0x12, 0xa2, 0xa1, 0x99, 0xfa, 0x32, 0x4d, 0xd3,
    0x25, 0xbe, 0x69, 0x2c, 0x19, 0x1b, 0xae, 0x1d, 0x4a, 0xf6, 0xeb, 0xe7, 0x24, 0x04, 0x02, 0xad,
    0x1d, 0xa7, 0x2f, 0x28, 0xc4, 0xe7, 0xdc, 0x73, 0xbf, 0x9d, 0xa4, 0x4a, 0x39, 0xc3, 0x6f, 0xd3,
    0x95, 0x49, 0x77, 0x62, 0xba, 0xb2, 0x3f, 0x4f, 0xa8, 0x4b, 0x61, 0x3e, 0x69, 0x14, 0x79, 0xc4,
    0xd6, 0x71, 0xf2, 0x06, 0x70, 0x47, 0x7c, 0x8f, 0x34, 0xb9, 0x49, 0x1c, 0xd4, 0x29, 0x30, 0x36,
    0xe3, 0x92, 0x3d, 0x83, 0x28, 0xb1, 0xb5, 0xb3, 0x07, 0x11, 0xaf, 0x9e, 0x81, 0x38, 0x48, 0x13,
    0x99, 0x6a, 0x8b, 0xef, 0x98, 0x9d, 0x26, 0x40, 0xb0, 0xf9, 0x65, 0x0f, 0xe7, 0x02, 0x5e, 0x7c,
    0xe6, 0x5b, 0xe7, 0x26, 0x9f, 0x7f, 0x70, 0x69, 0x6e, 0xbe, 0xc6, 0x4e, 0xe0, 0xfa, 0xd2, 0x89,
    0xad, 0xd2, 0xb1, 0x65, 0x7c, 0xc8, 0x99, 0x2f, 0xe1, 0x2a, 0x02, 0x32, 0x2c, 0x94, 0x60, 0x48,
    0xf1, 0x2a, 0x35, 0xc4, 0xe5, 0xcb, 0x87, 0x14, 0x43, 0xe2, 0xaa, 0xd1, 0x4e, 0x55, 0x9b, 0x9f,
    0x21, 0x95, 0xa0, 0xb0, 0x7a, 0x22, 0x6d, 0x02, 0x43, 0x0c, 0x7b, 0xcd, 0x5a, 0xe7, 0xd2, 0x4a,
    0x1a, 0x38, 0x74, 0x75, 0x74, 0xa2, 0x67, 0x7d, 0xb4, 0x37, 0x25, 0xaa, 0x1c, 0xaa, 0x82, 0xd5,
    0xe9, 0x6a, 0xe0, 0x8d, 0xfb, 0xda, 0xd2, 0x29, 0xe8, 0x13, 0x3b, 0x80, 0xfb, 0xd3, 0x3e, 0x5d,
    0xb4, 0x69, 0x00, 0x67, 0x09, 0x9b, 0xb7, 0x9a, 0xad, 0xef, 0xa1, 0x74, 0xdd, 0x49, 0x1e, 0x79,
    0x0b, 0xae, 0x83, 0xa4, 0xcf, 0xbc, 0x9a, 0xf1, 0xbb, 0x8b, 0xf4, 0x8f, 0x9b, 0x9b, 0x09, 0x04,
    0x6a, 0x59, 0x6e, 0x10, 0x03, 0x03, 0x6d, 0x44, 0x3c, 0x38, 0x87, 0x0c, 0x0d, 0x64, 0xc5, 0x9c,
    0xd4, 0xa6, 0x7d, 0x91, 0xa2, 0x19, 0x94, 0x69, 0x16, 0x92, 0xbb, 0x99, 0xda, 0x85, 0xe5, 0xe6,
    0xe3, 0x01, 0xb3, 0x8e, 0xbd, 0x56, 0x4a, 0xf8, 0x91, 0x33, 0x30, 0x59, 0xd1, 0x46, 0x05, 0x44,
    0x50, 0xd5, 0x3d, 0x1a, 0xd7, 0xb4, 0xef, 0x39, 0x08, 0x8d, 0x41, 0x36, 0xfe, 0x86, 0xcb, 0x95,
    0x06, 0xd9, 0xaa, 0x44, 0xaa, 0xae, 0x4a, 0xeb, 0x66, 0xe5, 0x78, 0x72, 0xb0, 0x4b, 0xbb, 0x5f,
    0xa6, 0x21, 0xcc, 0x39, 0x69, 0x13, 0xe6, 0x56, 0x83, 0x5f, 0xc0, 0x28, 0xf8, 0x12, 0x0f, 0x63,
    0xe0, 0x09, 0xe1, 0x9e, 0xab, 0x52, 0x87, 0x51, 0x0a, 0x90, 0x4c, 0xe0, 0x29, 0x41, 0x83, 0x3d,
    0x56, 0x80, 0x7e, 0x2c, 0xcd, 0x65, 0xe7, 0xfb, 0x15, 0xb8, 0xbe, 0xcd, 0x8c, 0xed, 0xa2, 0x50,
    0xf4, 0x5c, 0xd1, 0x2b, 0x10, 0x7b, 0x94, 0xa2, 0x0a, 0xa5, 0x2c, 0x4b, 0x21, 0xc6, 0x54, 0x8d,
    0xeb, 0x44, 0x69, 0x6e, 0xb8, 0x92, 0x20, 0x8e, 0x7b, 0xf2, 0x5e, 0xc2, 0x5a, 0x20, 0x0b, 0x55,
    0x4c, 0x51, 0x60, 0x66, 0x42, 0xd1, 0x36, 0x5d, 0x3c, 0xd0, 0xb4, 0xb0, 0xbd, 0x71, 0x4f, 0xa4,
    0x3c, 0x33, 0xd9, 0x1c, 0xfb, 0x2d, 0x3c, 0x48, 0x8d, 0x64, 0x1e, 0x58, 0x78, 0x5d, 0x6b, 0xd6,
    0xb8, 0x59, 0x91, 0xb6, 0x2d, 0x7b, 0x1f, 0x3c, 0x83, 0x91, 0xc9, 0x72, 0xf3, 0xa4, 0x5e, 0xf5,
    0x6d, 0x9e, 0xdb, 0xcc, 0x9d, 0x33, 0xed, 0xdd, 0xf0, 0x96, 0x83, 0xc4, 0x33, 0x10, 0xb6, 0xa9,
    0x33, 0xae, 0x6d, 0xc1, 0x12, 0x25, 0x78, 0x56, 0xb9, 0x93, 0x33, 0x5d, 0x3a, 0x28, 0x6e, 0x91,
    0x2d, 0xe1, 0x16, 0xe8, 0x78, 0x7f, 0xec, 0xea, 0x1c, 0xf4, 0xee, 0x3d, 0x7f, 0x4c, 0x56, 0x42,
    0x11, 0xf3, 0xdd, 0xc5, 0xf5, 0xb9, 0x8f, 0xaf, 0x8f, 0x3b, 0x3a, 0xd2, 0x3b, 0x31, 0x56, 0xdb,
    0x72, 0xeb, 0xee, 0xed, 0x5d, 0x98, 0x6e, 0xb4, 0x86, 0x3d, 0x26, 0xfd, 0x40, 0x47, 0xeb, 0x59,
    0xb5, 0xde, 0x20, 0x47, 0xd0, 0x2c, 0xee, 0x89, 0x1f, 0x7f, 0x8c, 0x0d, 0x4c, 0x33, 0x96, 0x5e,
    0xec, 0xf5, 0xd8, 0x47, 0x79, 0xfb, 0x22, 0x40, 0x66, 0x71, 0x31, 0x33, 0xd1, 0x7b, 0x9f, 0x88,
    0xcd, 0xb1, 0xdf, 0xca, 0xd2, 0xd7, 0x6b, 0xf6, 0xbb, 0xa2, 0x7e, 0x8e, 0x47, 0x34, 0x9c, 0x5f,
    0xcd, 0xbb, 0x80, 0x22, 0x6c, 0xfe, 0x04, 0x84, 0x7e, 0x1e, 0xd9, 0xab, 0xce, 0xf5, 0xb2, 0x7a,
    0xdb, 0x2b, 0xd2, 0x83, 0x2a, 0xfc, 0x1f, 0xf6, 0x87, 0xf5, 0x3f, 0xb3, 0x5f, 0xad, 0x50
};
#endif

PyTypeObject *init_QSqlResult(PyObject *module)
{
    if (SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX].type != nullptr)
        return SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX].type;

    Shiboken::AutoDecRef Sbk_QSqlResult_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QSqlResult_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSqlResult",
        "QSqlResult*",
        &Sbk_QSqlResult_spec,
        &Shiboken::callCppDestructor< QSqlResult >,
        Sbk_QSqlResult_Type_bases.object(),
        0);
    auto *pyType = Sbk_QSqlResult_TypeF(); // references _Sbk_QSqlResult_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSqlResult_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSqlResult_SignatureBytes, QSqlResult_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSqlResult_PropertyStrings);
    SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSqlResult_PythonToCpp_QSqlResult_PTR,
        is_QSqlResult_PythonToCpp_QSqlResult_PTR_Convertible,
        QSqlResult_PTR_CppToPython_QSqlResult);

    Shiboken::Conversions::registerConverterName(converter, "QSqlResult");
    Shiboken::Conversions::registerConverterName(converter, "QSqlResult*");
    Shiboken::Conversions::registerConverterName(converter, "QSqlResult&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSqlResult).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QSqlResultWrapper).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QSqlResult_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'BindingSyntax'.
    const char *BindingSyntax_Initializer[] = {
        "PositionalBinding",
        "NamedBinding",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t BindingSyntax_InitializerValues[] = {
        uint8_t(QSqlResult::BindingSyntax::PositionalBinding), //  0x00  0
        uint8_t(QSqlResult::BindingSyntax::NamedBinding)       //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSqlResult_TypeF(),
        "2:PySide6.QtSql.QSqlResult.BindingSyntax",
        BindingSyntax_Initializer, BindingSyntax_InitializerValues);
    SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_BindingSyntax_IDX].type = EType;
    // Register converter for enum 'QSqlResult::BindingSyntax'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSqlResult_BindingSyntax_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QSqlResult_BindingSyntax,
            is_Enum_PythonToCpp_QSqlResult_BindingSyntax_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QSqlResult::BindingSyntax");
        Shiboken::Conversions::registerConverterAlias(converter, "BindingSyntax");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'BindingSyntax' enum.

    // Initialization of enum 'VirtualHookOperation'.
    const char *VirtualHookOperation_Initializer[] = {
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    const uint8_t *VirtualHookOperation_InitializerValues{};
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSqlResult_TypeF(),
        "2:PySide6.QtSql.QSqlResult.VirtualHookOperation",
        VirtualHookOperation_Initializer, VirtualHookOperation_InitializerValues);
    SbkPySide6_QtSqlTypeStructs[SBK_QSqlResult_VirtualHookOperation_IDX].type = EType;
    // Register converter for enum 'QSqlResult::VirtualHookOperation'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSqlResult_VirtualHookOperation_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QSqlResult_VirtualHookOperation,
            is_Enum_PythonToCpp_QSqlResult_VirtualHookOperation_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QSqlResult::VirtualHookOperation");
        Shiboken::Conversions::registerConverterAlias(converter, "VirtualHookOperation");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'VirtualHookOperation' enum.

    qRegisterMetaType< ::QSqlResult *>();
    qRegisterMetaType< ::QSqlResult::BindingSyntax >("QSqlResult::BindingSyntax");
    qRegisterMetaType< ::QSqlResult::VirtualHookOperation >("QSqlResult::VirtualHookOperation");

    return pyType;
}
