// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtstatemachine_python.h"

// main header
#include "qstatemachine_wrappedevent_wrapper.h"

// Argument includes
#include <qcoreevent.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void WrappedEventWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

WrappedEventWrapper::WrappedEventWrapper(::QObject * object, ::QEvent * event) : QStateMachine::WrappedEvent(object, event)
{
}

::QEvent * WrappedEventWrapper::clone() const
{
    if (m_PyMethodCache[0])
        return this->::QEvent::clone();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "clone";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QEvent::clone();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("WrappedEvent", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("WrappedEvent", funcName, Shiboken::SbkType< QEvent >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QEvent *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void WrappedEventWrapper::setAccepted(bool accepted)
{
    if (m_PyMethodCache[1]) {
        return this->::QEvent::setAccepted(accepted);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setAccepted";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QEvent::setAccepted(accepted);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &accepted)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &accepted)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("WrappedEvent", funcName);
        return;
    }
}

WrappedEventWrapper::~WrappedEventWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStateMachine_WrappedEvent_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QStateMachine::WrappedEvent >()))
        return -1;

    WrappedEventWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "WrappedEvent", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: WrappedEvent::WrappedEvent(QObject*,QEvent*)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArgs[1])))) {
        overloadId = 0; // WrappedEvent(QObject*,QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_WrappedEvent_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_WrappedEvent_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return -1;
        ::QEvent *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // WrappedEvent(QObject*,QEvent*)
            cptr = new WrappedEventWrapper(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QStateMachine::WrappedEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_WrappedEvent_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QStateMachine_WrappedEventFunc_event(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStateMachine::WrappedEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_WrappedEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // event()const
        QEvent * cppResult = const_cast<const ::QStateMachine::WrappedEvent *>(cppSelf)->event();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStateMachine_WrappedEventFunc_object(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStateMachine::WrappedEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_WrappedEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // object()const
        QObject * cppResult = const_cast<const ::QStateMachine::WrappedEvent *>(cppSelf)->object();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QStateMachine_WrappedEvent_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QStateMachine_WrappedEvent_methods[] = {
    {"event", reinterpret_cast<PyCFunction>(Sbk_QStateMachine_WrappedEventFunc_event), METH_NOARGS, nullptr},
    {"object", reinterpret_cast<PyCFunction>(Sbk_QStateMachine_WrappedEventFunc_object), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QStateMachine_WrappedEvent_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QStateMachine::WrappedEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_WrappedEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<WrappedEventWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QStateMachine_WrappedEvent_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QStateMachine_WrappedEvent_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QStateMachine_WrappedEvent_Type = nullptr;
static PyTypeObject *Sbk_QStateMachine_WrappedEvent_TypeF(void)
{
    return _Sbk_QStateMachine_WrappedEvent_Type;
}

static PyType_Slot Sbk_QStateMachine_WrappedEvent_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QStateMachine_WrappedEvent_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QStateMachine_WrappedEvent_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QStateMachine_WrappedEvent_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QStateMachine_WrappedEvent_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QStateMachine_WrappedEvent_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QStateMachine_WrappedEvent_spec = {
    "2:PySide6.QtStateMachine.QStateMachine.WrappedEvent",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QStateMachine_WrappedEvent_slots
};

} //extern "C"

static void *Sbk_QStateMachine_WrappedEvent_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QEvent >())
        return dynamic_cast< ::QStateMachine::WrappedEvent *>(reinterpret_cast< ::QEvent *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void WrappedEvent_PythonToCpp_WrappedEvent_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QStateMachine_WrappedEvent_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_WrappedEvent_PythonToCpp_WrappedEvent_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QStateMachine_WrappedEvent_TypeF()))
        return WrappedEvent_PythonToCpp_WrappedEvent_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *WrappedEvent_PTR_CppToPython_WrappedEvent(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QStateMachine::WrappedEvent *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QStateMachine_WrappedEvent_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QStateMachine_WrappedEvent_SignatureStrings[] = {
    "PySide6.QtStateMachine.QStateMachine.WrappedEvent(self,object:PySide6.QtCore.QObject,event:PySide6.QtCore.QEvent)",
    "PySide6.QtStateMachine.QStateMachine.WrappedEvent.event(self)->PySide6.QtCore.QEvent",
    "PySide6.QtStateMachine.QStateMachine.WrappedEvent.object(self)->PySide6.QtCore.QObject",
    nullptr}; // Sentinel
#else
static constexpr size_t QStateMachine_WrappedEvent_SignatureByteSize = 103;
static constexpr uint8_t QStateMachine_WrappedEvent_SignatureBytes[103] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x09, 0x2e, 0x49, 0x2c,
    0x49, 0xf5, 0x4d, 0x4c, 0xce, 0xc8, 0xcc, 0x4b, 0xd5, 0x0b, 0x44, 0xe1, 0x85, 0x17, 0x25, 0x16,
    0x14, 0xa4, 0xa6, 0xb8, 0x96, 0xa5, 0xe6, 0x95, 0x68, 0x14, 0xa7, 0xe6, 0xa4, 0xe9, 0xe4, 0x27,
    0x65, 0xa5, 0x26, 0x97, 0x58, 0x05, 0xc0, 0x75, 0x3b, 0xe7, 0x17, 0x01, 0x75, 0xf9, 0x83, 0x85,
    0x75, 0x52, 0x41, 0x0a, 0x31, 0x24, 0xc1, 0xda, 0x35, 0xb9, 0x02, 0x48, 0xb5, 0x51, 0x2f, 0x15,
    0x6e, 0xaf, 0xa6, 0xae, 0x1d, 0x56, 0x53, 0xc9, 0x30, 0x14, 0xe2, 0x03, 0x5c, 0xa6, 0x42, 0x3c,
    0xc2, 0x05, 0x00, 0x38, 0x7e, 0x67, 0x1d
};
#endif

PyTypeObject *init_QStateMachine_WrappedEvent(PyObject *enclosingClass)
{
    if (SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_WrappedEvent_IDX].type != nullptr)
        return SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_WrappedEvent_IDX].type;

    Shiboken::AutoDecRef Sbk_QStateMachine_WrappedEvent_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]))));

    _Sbk_QStateMachine_WrappedEvent_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "WrappedEvent",
        "QStateMachine::WrappedEvent*",
        &Sbk_QStateMachine_WrappedEvent_spec,
        &Shiboken::callCppDestructor< QStateMachine::WrappedEvent >,
        Sbk_QStateMachine_WrappedEvent_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
    auto *pyType = Sbk_QStateMachine_WrappedEvent_TypeF(); // references _Sbk_QStateMachine_WrappedEvent_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QStateMachine_WrappedEvent_SignatureStrings);
#else
    InitSignatureBytes(pyType, QStateMachine_WrappedEvent_SignatureBytes, QStateMachine_WrappedEvent_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QStateMachine_WrappedEvent_PropertyStrings);
    SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_WrappedEvent_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        WrappedEvent_PythonToCpp_WrappedEvent_PTR,
        is_WrappedEvent_PythonToCpp_WrappedEvent_PTR_Convertible,
        WrappedEvent_PTR_CppToPython_WrappedEvent);

    Shiboken::Conversions::registerConverterName(converter, "QStateMachine::WrappedEvent");
    Shiboken::Conversions::registerConverterName(converter, "QStateMachine::WrappedEvent*");
    Shiboken::Conversions::registerConverterName(converter, "QStateMachine::WrappedEvent&");
    Shiboken::Conversions::registerConverterAlias(converter, "WrappedEvent");
    Shiboken::Conversions::registerConverterAlias(converter, "WrappedEvent*");
    Shiboken::Conversions::registerConverterAlias(converter, "WrappedEvent&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QStateMachine::WrappedEvent).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(WrappedEventWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QStateMachine_WrappedEvent_TypeF(), &Sbk_QStateMachine_WrappedEvent_typeDiscovery);


    return pyType;
}
