// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtstatemachine_python.h"

// main header
#include "qstatemachine_wrapper.h"

// inner classes
#include "qstatemachine_wrappedevent_wrapper.h"
#include "qstatemachine_signalevent_wrapper.h"

// Argument includes
#include <QList>
#include <QSet>
#include <QString>
#include <QtStateMachine/qabstractstate.h>
#include <QtStateMachine/qabstracttransition.h>
#include <QtStateMachine/qsignaltransition.h>
#include <QtStateMachine/qstate.h>
#include <QtStateMachine/qstatemachine.h>
#include <qabstractanimation.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QStateMachineWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QStateMachineWrapper::QStateMachineWrapper(::QObject * parent) : QStateMachine(parent)
{
}

QStateMachineWrapper::QStateMachineWrapper(::QState::ChildMode childMode, ::QObject * parent) : QStateMachine(childMode, parent)
{
}

void QStateMachineWrapper::beginMicrostep(::QEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QStateMachine::beginMicrostep(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "beginMicrostep";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QStateMachine::beginMicrostep(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QStateMachine", funcName);
        return;
    }
}

void QStateMachineWrapper::beginSelectTransitions(::QEvent * event)
{
    if (m_PyMethodCache[1]) {
        return this->::QStateMachine::beginSelectTransitions(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "beginSelectTransitions";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QStateMachine::beginSelectTransitions(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QStateMachine", funcName);
        return;
    }
}

void QStateMachineWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QStateMachine", funcName);
        return;
    }
}

void QStateMachineWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QStateMachine", funcName);
        return;
    }
}

void QStateMachineWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[4]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QStateMachine", funcName);
        return;
    }
}

void QStateMachineWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[5]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QStateMachine", funcName);
        return;
    }
}

void QStateMachineWrapper::endMicrostep(::QEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QStateMachine::endMicrostep(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "endMicrostep";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QStateMachine::endMicrostep(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QStateMachine", funcName);
        return;
    }
}

void QStateMachineWrapper::endSelectTransitions(::QEvent * event)
{
    if (m_PyMethodCache[7]) {
        return this->::QStateMachine::endSelectTransitions(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "endSelectTransitions";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[7] = true;
        gil.release();
        return this->::QStateMachine::endSelectTransitions(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QStateMachine", funcName);
        return;
    }
}

bool QStateMachineWrapper::event(::QEvent * e)
{
    if (m_PyMethodCache[8])
        return this->::QStateMachine::event(e);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[8] = true;
        gil.release();
        return this->::QStateMachine::event(e);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), e)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), e)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QStateMachine", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QStateMachine", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QStateMachineWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[9])
        return this->::QStateMachine::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[9] = true;
        gil.release();
        return this->::QStateMachine::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QStateMachine", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QStateMachine", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QStateMachineWrapper::onEntry(::QEvent * event)
{
    if (m_PyMethodCache[10]) {
        return this->::QStateMachine::onEntry(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "onEntry";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[10] = true;
        gil.release();
        return this->::QStateMachine::onEntry(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QStateMachine", funcName);
        return;
    }
}

void QStateMachineWrapper::onExit(::QEvent * event)
{
    if (m_PyMethodCache[11]) {
        return this->::QStateMachine::onExit(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "onExit";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[11] = true;
        gil.release();
        return this->::QStateMachine::onExit(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QStateMachine", funcName);
        return;
    }
}

void QStateMachineWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[12]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[12] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QStateMachine", funcName);
        return;
    }
}

const QMetaObject *QStateMachineWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QStateMachine::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QStateMachineWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QStateMachine::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QStateMachineWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QStateMachineWrapper *>(this));
    return QStateMachine::qt_metacast(_clname);
}

QStateMachineWrapper::~QStateMachineWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStateMachine_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QStateMachine >()))
        return -1;

    QStateMachineWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:QStateMachine", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QStateMachine::QStateMachine(QObject*=)
    // 1: QStateMachine::QStateMachine(QState::ChildMode,QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QStateMachine(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QState_ChildMode_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QStateMachine(QState::ChildMode,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 1; // QStateMachine(QState::ChildMode,QObject*)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QStateMachine(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QStateMachine(QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0 = nullptr;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QStateMachine(QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QStateMachineWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QStateMachineWrapper(cppArg0);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
        case 1: // QStateMachine(QState::ChildMode childMode, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            ::QState::ChildMode cppArg0{QState::ExclusiveStates};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QObject *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QStateMachine(QState::ChildMode,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QStateMachineWrapper(cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QStateMachineWrapper(cppArg0, cppArg1);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QStateMachine >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QStateMachineFunc_addDefaultAnimation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QStateMachine::addDefaultAnimation(QAbstractAnimation*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractAnimation_IDX]), (pyArg)))) {
        overloadId = 0; // addDefaultAnimation(QAbstractAnimation*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addDefaultAnimation", errInfo, SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAbstractAnimation *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addDefaultAnimation(QAbstractAnimation*)
            cppSelf->addDefaultAnimation(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStateMachineFunc_addState(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QStateMachine::addState(QAbstractState*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QAbstractState_IDX]), (pyArg)))) {
        overloadId = 0; // addState(QAbstractState*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addState", errInfo, SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAbstractState *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addState(QAbstractState*)
            cppSelf->addState(cppArg0);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArg);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStateMachineFunc_beginMicrostep(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QStateMachine::beginMicrostep(QEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // beginMicrostep(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "beginMicrostep", errInfo, SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // beginMicrostep(QEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QStateMachine::beginMicrostep(cppArg0)
                : cppSelf->beginMicrostep(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStateMachineFunc_beginSelectTransitions(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QStateMachine::beginSelectTransitions(QEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // beginSelectTransitions(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "beginSelectTransitions", errInfo, SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // beginSelectTransitions(QEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QStateMachine::beginSelectTransitions(cppArg0)
                : cppSelf->beginSelectTransitions(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStateMachineFunc_cancelDelayedEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QStateMachine::cancelDelayedEvent(int)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // cancelDelayedEvent(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "cancelDelayedEvent", errInfo, SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // cancelDelayedEvent(int)
            bool cppResult = cppSelf->cancelDelayedEvent(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStateMachineFunc_clearError(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clearError()
        cppSelf->clearError();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStateMachineFunc_configuration(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // configuration()
        // Begin code injection
        // ========================================================================
        // START of custom code block [file: ../glue/qtstatemachine.cpp (qstatemachine-configuration)]
        pyResult = PySet_New(0);
        for (auto *abs_state : cppSelf->configuration()) {
                Shiboken::AutoDecRef obj(Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QAbstractState_IDX]), abs_state));
                Shiboken::Object::setParent(self, obj);
                PySet_Add(pyResult, obj);
        }
        // END of custom code block [file: ../glue/qtstatemachine.cpp (qstatemachine-configuration)]
        // ========================================================================
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStateMachineFunc_defaultAnimations(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // defaultAnimations()
        // Begin code injection
        // ========================================================================
        // START of custom code block [file: ../glue/qtstatemachine.cpp (qstatemachine-defaultanimations)]
        pyResult = PyList_New(0);
        for (auto *abs_anim : cppSelf->defaultAnimations()) {
                Shiboken::AutoDecRef obj(Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractAnimation_IDX]), abs_anim));
                Shiboken::Object::setParent(self, obj);
                PyList_Append(pyResult, obj);
        }
        // END of custom code block [file: ../glue/qtstatemachine.cpp (qstatemachine-defaultanimations)]
        // ========================================================================
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStateMachineFunc_endMicrostep(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QStateMachine::endMicrostep(QEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // endMicrostep(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "endMicrostep", errInfo, SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // endMicrostep(QEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QStateMachine::endMicrostep(cppArg0)
                : cppSelf->endMicrostep(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStateMachineFunc_endSelectTransitions(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QStateMachine::endSelectTransitions(QEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // endSelectTransitions(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "endSelectTransitions", errInfo, SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // endSelectTransitions(QEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QStateMachine::endSelectTransitions(cppArg0)
                : cppSelf->endSelectTransitions(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStateMachineFunc_error(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // error()const
        QStateMachine::Error cppResult = const_cast<const ::QStateMachine *>(cppSelf)->error();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_Error_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStateMachineFunc_errorString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // errorString()const
        QString cppResult = const_cast<const ::QStateMachine *>(cppSelf)->errorString();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStateMachineFunc_event(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::event(QEvent*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "event", errInfo, SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // event(QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QStateMachine::event(cppArg0)
                : cppSelf->event(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStateMachineFunc_eventFilter(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "eventFilter", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QObject::eventFilter(QObject*,QEvent*)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArgs[1])))) {
        overloadId = 0; // eventFilter(QObject*,QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "eventFilter", errInfo, SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QObject *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QEvent *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // eventFilter(QObject*,QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QStateMachine::eventFilter(cppArg0, cppArg1)
                : cppSelf->eventFilter(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStateMachineFunc_globalRestorePolicy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // globalRestorePolicy()const
        QState::RestorePolicy cppResult = const_cast<const ::QStateMachine *>(cppSelf)->globalRestorePolicy();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QState_RestorePolicy_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStateMachineFunc_isAnimated(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isAnimated()const
        bool cppResult = const_cast<const ::QStateMachine *>(cppSelf)->isAnimated();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStateMachineFunc_isRunning(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isRunning()const
        bool cppResult = const_cast<const ::QStateMachine *>(cppSelf)->isRunning();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStateMachineFunc_onEntry(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractState::onEntry(QEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // onEntry(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "onEntry", errInfo, SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // onEntry(QEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QStateMachine::onEntry(cppArg0)
                : cppSelf->onEntry(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStateMachineFunc_onExit(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractState::onExit(QEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // onExit(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "onExit", errInfo, SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // onExit(QEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QStateMachine::onExit(cppArg0)
                : cppSelf->onExit(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStateMachineFunc_postDelayedEvent(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "postDelayedEvent", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QStateMachine::postDelayedEvent(QEvent*,int)->int
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // postDelayedEvent(QEvent*,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "postDelayedEvent", errInfo, SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // postDelayedEvent(QEvent*,int)
            int cppResult = cppSelf->postDelayedEvent(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);

            // Ownership transferences.
            Shiboken::Object::releaseOwnership(pyArgs[0]);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStateMachineFunc_postEvent(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "postEvent", errInfo, SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]);

    if (PyArg_ParseTuple(args, "|OO:postEvent", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QStateMachine::postEvent(QEvent*,QStateMachine::EventPriority=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // postEvent(QEvent*,QStateMachine::EventPriority)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_EventPriority_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // postEvent(QEvent*,QStateMachine::EventPriority)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "postEvent", errInfo, SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_priority = Shiboken::String::createStaticString("priority");
            if (PyDict_Contains(kwds, key_priority) != 0) {
                value = PyDict_GetItem(kwds, key_priority);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_priority);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "postEvent", errInfo, SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_EventPriority_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "postEvent", errInfo, SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_priority);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "postEvent", errInfo, SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QStateMachine::EventPriority cppArg1(QStateMachine::EventPriority::NormalPriority);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // postEvent(QEvent*,QStateMachine::EventPriority)
            cppSelf->postEvent(cppArg0, cppArg1);

            // Ownership transferences.
            Shiboken::Object::releaseOwnership(pyArgs[0]);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStateMachineFunc_removeDefaultAnimation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QStateMachine::removeDefaultAnimation(QAbstractAnimation*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractAnimation_IDX]), (pyArg)))) {
        overloadId = 0; // removeDefaultAnimation(QAbstractAnimation*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeDefaultAnimation", errInfo, SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAbstractAnimation *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeDefaultAnimation(QAbstractAnimation*)
            cppSelf->removeDefaultAnimation(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStateMachineFunc_removeState(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QStateMachine::removeState(QAbstractState*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QAbstractState_IDX]), (pyArg)))) {
        overloadId = 0; // removeState(QAbstractState*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeState", errInfo, SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAbstractState *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeState(QAbstractState*)
            cppSelf->removeState(cppArg0);
            // Ownership transferences.
            Shiboken::Object::setParent(Py_None, pyArg);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStateMachineFunc_setAnimated(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QStateMachine::setAnimated(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAnimated(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAnimated", errInfo, SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAnimated(bool)
            cppSelf->setAnimated(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStateMachineFunc_setGlobalRestorePolicy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QStateMachine::setGlobalRestorePolicy(QState::RestorePolicy)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QState_RestorePolicy_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setGlobalRestorePolicy(QState::RestorePolicy)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setGlobalRestorePolicy", errInfo, SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]);

    // Call function/method
    {
        ::QState::RestorePolicy cppArg0{QState::DontRestoreProperties};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setGlobalRestorePolicy(QState::RestorePolicy)
            cppSelf->setGlobalRestorePolicy(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStateMachineFunc_setRunning(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QStateMachine::setRunning(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setRunning(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRunning", errInfo, SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRunning(bool)
            cppSelf->setRunning(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStateMachineFunc_start(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // start()
        cppSelf->start();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStateMachineFunc_stop(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // stop()
        cppSelf->stop();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QStateMachine_PropertyStrings[] = {
    "animated:isAnimated:",
    "errorString:",
    "globalRestorePolicy::",
    "running:isRunning:",
    nullptr // Sentinel
};

static const char *Sbk_QStateMachine_EnumFlagInfo[] = {
    "Error:Enum",
    "EventPriority:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QStateMachine_methods[] = {
    {"addDefaultAnimation", reinterpret_cast<PyCFunction>(Sbk_QStateMachineFunc_addDefaultAnimation), METH_O, nullptr},
    {"addState", reinterpret_cast<PyCFunction>(Sbk_QStateMachineFunc_addState), METH_O, nullptr},
    {"beginMicrostep", reinterpret_cast<PyCFunction>(Sbk_QStateMachineFunc_beginMicrostep), METH_O, nullptr},
    {"beginSelectTransitions", reinterpret_cast<PyCFunction>(Sbk_QStateMachineFunc_beginSelectTransitions), METH_O, nullptr},
    {"cancelDelayedEvent", reinterpret_cast<PyCFunction>(Sbk_QStateMachineFunc_cancelDelayedEvent), METH_O, nullptr},
    {"clearError", reinterpret_cast<PyCFunction>(Sbk_QStateMachineFunc_clearError), METH_NOARGS, nullptr},
    {"configuration", reinterpret_cast<PyCFunction>(Sbk_QStateMachineFunc_configuration), METH_NOARGS, nullptr},
    {"defaultAnimations", reinterpret_cast<PyCFunction>(Sbk_QStateMachineFunc_defaultAnimations), METH_NOARGS, nullptr},
    {"endMicrostep", reinterpret_cast<PyCFunction>(Sbk_QStateMachineFunc_endMicrostep), METH_O, nullptr},
    {"endSelectTransitions", reinterpret_cast<PyCFunction>(Sbk_QStateMachineFunc_endSelectTransitions), METH_O, nullptr},
    {"error", reinterpret_cast<PyCFunction>(Sbk_QStateMachineFunc_error), METH_NOARGS, nullptr},
    {"errorString", reinterpret_cast<PyCFunction>(Sbk_QStateMachineFunc_errorString), METH_NOARGS, nullptr},
    {"event", reinterpret_cast<PyCFunction>(Sbk_QStateMachineFunc_event), METH_O, nullptr},
    {"eventFilter", reinterpret_cast<PyCFunction>(Sbk_QStateMachineFunc_eventFilter), METH_VARARGS, nullptr},
    {"globalRestorePolicy", reinterpret_cast<PyCFunction>(Sbk_QStateMachineFunc_globalRestorePolicy), METH_NOARGS, nullptr},
    {"isAnimated", reinterpret_cast<PyCFunction>(Sbk_QStateMachineFunc_isAnimated), METH_NOARGS, nullptr},
    {"isRunning", reinterpret_cast<PyCFunction>(Sbk_QStateMachineFunc_isRunning), METH_NOARGS, nullptr},
    {"onEntry", reinterpret_cast<PyCFunction>(Sbk_QStateMachineFunc_onEntry), METH_O, nullptr},
    {"onExit", reinterpret_cast<PyCFunction>(Sbk_QStateMachineFunc_onExit), METH_O, nullptr},
    {"postDelayedEvent", reinterpret_cast<PyCFunction>(Sbk_QStateMachineFunc_postDelayedEvent), METH_VARARGS, nullptr},
    {"postEvent", reinterpret_cast<PyCFunction>(Sbk_QStateMachineFunc_postEvent), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"removeDefaultAnimation", reinterpret_cast<PyCFunction>(Sbk_QStateMachineFunc_removeDefaultAnimation), METH_O, nullptr},
    {"removeState", reinterpret_cast<PyCFunction>(Sbk_QStateMachineFunc_removeState), METH_O, nullptr},
    {"setAnimated", reinterpret_cast<PyCFunction>(Sbk_QStateMachineFunc_setAnimated), METH_O, nullptr},
    {"setGlobalRestorePolicy", reinterpret_cast<PyCFunction>(Sbk_QStateMachineFunc_setGlobalRestorePolicy), METH_O, nullptr},
    {"setRunning", reinterpret_cast<PyCFunction>(Sbk_QStateMachineFunc_setRunning), METH_O, nullptr},
    {"start", reinterpret_cast<PyCFunction>(Sbk_QStateMachineFunc_start), METH_NOARGS, nullptr},
    {"stop", reinterpret_cast<PyCFunction>(Sbk_QStateMachineFunc_stop), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QStateMachine_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QStateMachine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QStateMachineWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QStateMachine_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QStateMachine_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QStateMachine_Type = nullptr;
static PyTypeObject *Sbk_QStateMachine_TypeF(void)
{
    return _Sbk_QStateMachine_Type;
}

static PyType_Slot Sbk_QStateMachine_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QStateMachine_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QStateMachine_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QStateMachine_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QStateMachine_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QStateMachine_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QStateMachine_spec = {
    "2:PySide6.QtStateMachine.QStateMachine",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QStateMachine_slots
};

} //extern "C"

static void *Sbk_QStateMachine_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QStateMachine *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QStateMachine_EventPriority(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStateMachine::EventPriority>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStateMachine::EventPriority *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QStateMachine_EventPriority_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_EventPriority_IDX])))
        return Enum_PythonToCpp_QStateMachine_EventPriority;
    return {};
}

static PyObject *QStateMachine_EventPriority_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QStateMachine::EventPriority>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QStateMachine::EventPriority *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_EventPriority_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QStateMachine_Error(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStateMachine::Error>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStateMachine::Error *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QStateMachine_Error_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_Error_IDX])))
        return Enum_PythonToCpp_QStateMachine_Error;
    return {};
}

static PyObject *QStateMachine_Error_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QStateMachine::Error>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QStateMachine::Error *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_Error_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QStateMachine_PythonToCpp_QStateMachine_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QStateMachine_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QStateMachine_PythonToCpp_QStateMachine_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QStateMachine_TypeF()))
        return QStateMachine_PythonToCpp_QStateMachine_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QStateMachine_PTR_CppToPython_QStateMachine(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QStateMachine *>(const_cast<void *>(cppIn)), Sbk_QStateMachine_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QStateMachine_SignatureStrings[] = {
    "1:PySide6.QtStateMachine.QStateMachine(self,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,errorString:QString=None,globalRestorePolicy:QState.RestorePolicy=None,running:bool=None,animated:bool=None)",
    "0:PySide6.QtStateMachine.QStateMachine(self,childMode:PySide6.QtStateMachine.QState.ChildMode,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,errorString:QString=None,globalRestorePolicy:QState.RestorePolicy=None,running:bool=None,animated:bool=None)",
    "PySide6.QtStateMachine.QStateMachine.addDefaultAnimation(self,animation:PySide6.QtCore.QAbstractAnimation)",
    "PySide6.QtStateMachine.QStateMachine.addState(self,state:PySide6.QtStateMachine.QAbstractState)",
    "PySide6.QtStateMachine.QStateMachine.beginMicrostep(self,event:PySide6.QtCore.QEvent)",
    "PySide6.QtStateMachine.QStateMachine.beginSelectTransitions(self,event:PySide6.QtCore.QEvent)",
    "PySide6.QtStateMachine.QStateMachine.cancelDelayedEvent(self,id:int)->bool",
    "PySide6.QtStateMachine.QStateMachine.clearError(self)",
    "PySide6.QtStateMachine.QStateMachine.configuration(self)->QSet[PySide6.QtStateMachine.QAbstractState]",
    "PySide6.QtStateMachine.QStateMachine.defaultAnimations(self)->QList[PySide6.QtCore.QAbstractAnimation]",
    "PySide6.QtStateMachine.QStateMachine.endMicrostep(self,event:PySide6.QtCore.QEvent)",
    "PySide6.QtStateMachine.QStateMachine.endSelectTransitions(self,event:PySide6.QtCore.QEvent)",
    "PySide6.QtStateMachine.QStateMachine.error(self)->PySide6.QtStateMachine.QStateMachine.Error",
    "PySide6.QtStateMachine.QStateMachine.errorString(self)->QString",
    "PySide6.QtStateMachine.QStateMachine.event(self,e:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtStateMachine.QStateMachine.eventFilter(self,watched:PySide6.QtCore.QObject,event:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtStateMachine.QStateMachine.globalRestorePolicy(self)->PySide6.QtStateMachine.QState.RestorePolicy",
    "PySide6.QtStateMachine.QStateMachine.isAnimated(self)->bool",
    "PySide6.QtStateMachine.QStateMachine.isRunning(self)->bool",
    "PySide6.QtStateMachine.QStateMachine.onEntry(self,event:PySide6.QtCore.QEvent)",
    "PySide6.QtStateMachine.QStateMachine.onExit(self,event:PySide6.QtCore.QEvent)",
    "PySide6.QtStateMachine.QStateMachine.postDelayedEvent(self,event:PySide6.QtCore.QEvent,delay:int)->int",
    "PySide6.QtStateMachine.QStateMachine.postEvent(self,event:PySide6.QtCore.QEvent,priority:PySide6.QtStateMachine.QStateMachine.EventPriority=QStateMachine.EventPriority.NormalPriority)",
    "PySide6.QtStateMachine.QStateMachine.removeDefaultAnimation(self,animation:PySide6.QtCore.QAbstractAnimation)",
    "PySide6.QtStateMachine.QStateMachine.removeState(self,state:PySide6.QtStateMachine.QAbstractState)",
    "PySide6.QtStateMachine.QStateMachine.setAnimated(self,enabled:bool)",
    "PySide6.QtStateMachine.QStateMachine.setGlobalRestorePolicy(self,restorePolicy:PySide6.QtStateMachine.QState.RestorePolicy)",
    "PySide6.QtStateMachine.QStateMachine.setRunning(self,running:bool)",
    "PySide6.QtStateMachine.QStateMachine.start(self)",
    "PySide6.QtStateMachine.QStateMachine.stop(self)",
    nullptr}; // Sentinel
#else
static constexpr size_t QStateMachine_SignatureByteSize = 519;
static constexpr uint8_t QStateMachine_SignatureBytes[519] = {
    0x78, 0xda, 0xd5, 0x56, 0x4d, 0x6f, 0xdb, 0x30, 0x0c, 0xbd, 0xef, 0x97, 0x6c, 0x83, 0x6b, 0x6c,
    0x97, 0x1d, 0x0c, 0xa4, 0x40, 0xd0, 0xa6, 0x3b, 0x6c, 0x69, 0x93, 0x7a, 0xb7, 0x61, 0x07, 0xd9,
    0x62, 0x52, 0x0e, 0x8a, 0x64, 0x50, 0x4c, 0x3b, 0xff, 0xfb, 0xc9, 0x56, 0x3c, 0xc7, 0x6d, 0x12,
    0xd0, 0x40, 0x3a, 0xa0, 0x17, 0xdb, 0xa2, 0xc9, 0xf7, 0xc4, 0x4f, 0xe9, 0x73, 0xb6, 0xa8, 0x73,
    0xd4, 0xf0, 0x25, 0x5d, 0x72, 0xce, 0x8a, 0x61, 0xae, 0xca, 0x07, 0xb4, 0x90, 0x2e, 0xf7, 0x57,
    0xef, 0x3d, 0x98, 0x55, 0x52, 0x29, 0x02, 0xcb, 0x7b, 0x06, 0x57, 0x8e, 0x82, 0xe2, 0x5d, 0xf1,
    0x1b, 0x4a, 0x9e, 0xd8, 0xad, 0x31, 0x15, 0x53, 0xf2, 0x31, 0xfb, 0x06, 0xf5, 0x93, 0x23, 0x7d,
    0x67, 0x4d, 0x3d, 0xb9, 0x75, 0x16, 0x12, 0x20, 0x72, 0x94, 0x33, 0xa1, 0x5d, 0x67, 0xcb, 0xf8,
    0x8e, 0x3f, 0xd6, 0xc6, 0x15, 0xca, 0xdc, 0x83, 0xe7, 0x80, 0xb4, 0x70, 0x06, 0xcb, 0x3a, 0x8b,
    0xc4, 0xe9, 0x40, 0x18, 0xb5, 0x69, 0x6b, 0x6d, 0x03, 0x51, 0x38, 0x67, 0xa2, 0x44, 0x59, 0xdc,
    0x04, 0x65, 0xdd, 0x8b, 0x3e, 0xbc, 0xfb, 0x34, 0xc2, 0xa3, 0xf0, 0x69, 0xf4, 0xdc, 0x69, 0x38,
    0x6d, 0x93, 0x5e, 0x75, 0x7a, 0x6f, 0x24, 0x06, 0x92, 0x08, 0xa4, 0x4a, 0xeb, 0x6b, 0x58, 0xa9,
    0xad, 0xe1, 0x69, 0x0b, 0x81, 0xce, 0xc6, 0xa8, 0xa8, 0x6e, 0xf9, 0xc2, 0xcd, 0x69, 0xe1, 0x99,
    0x54, 0xd9, 0x1b, 0xc8, 0xa9, 0xda, 0x75, 0xc4, 0xf7, 0xcd, 0xe7, 0xd1, 0x88, 0x77, 0x1c, 0xad,
    0x54, 0x88, 0x5f, 0xc0, 0x1a, 0xed, 0x1c, 0x4b, 0x72, 0x9e, 0xa1, 0x8a, 0x2c, 0xf0, 0x78, 0x28,
    0x51, 0xb3, 0x46, 0x3a, 0x06, 0x35, 0x07, 0x13, 0x32, 0xfb, 0x83, 0x94, 0xf5, 0xd8, 0x78, 0xec,
    0xcf, 0x85, 0x5e, 0x2a, 0x5b, 0x82, 0xb9, 0x06, 0xa3, 0x6a, 0xd0, 0xad, 0x61, 0x44, 0x46, 0x9d,
    0x61, 0x00, 0xb9, 0xb8, 0x6c, 0xf2, 0x29, 0x84, 0x32, 0xa0, 0x68, 0xd6, 0x14, 0x58, 0x0b, 0x21,
    0xdd, 0x80, 0xb3, 0x2b, 0x5c, 0x6f, 0xa9, 0xcf, 0x7c, 0x20, 0x5d, 0xe6, 0xc0, 0x3f, 0x45, 0xa9,
    0xf9, 0x25, 0x63, 0xd1, 0xcf, 0x4a, 0xcc, 0xff, 0x63, 0xfa, 0x8e, 0x7e, 0x9f, 0xea, 0x48, 0x85,
    0x09, 0x69, 0xc0, 0xea, 0xb3, 0xe7, 0x3f, 0x60, 0xbe, 0x5a, 0xf6, 0xa1, 0xcf, 0xd6, 0xc5, 0xa5,
    0xc8, 0xa2, 0xcd, 0xef, 0x08, 0xf0, 0x38, 0x63, 0xfa, 0xbc, 0xb6, 0x4b, 0xa1, 0x7d, 0x5f, 0x8d,
    0x70, 0xc4, 0xcb, 0x31, 0xe5, 0xd9, 0xc2, 0xdd, 0xa0, 0x61, 0x88, 0x1e, 0x27, 0x4f, 0x8a, 0xcb,
    0x87, 0x30, 0xb1, 0x0e, 0x4f, 0xd1, 0x93, 0xd1, 0x1d, 0xc3, 0x7b, 0x60, 0xb2, 0x8a, 0x22, 0x3e,
    0x9c, 0xbb, 0x32, 0x2e, 0xf4, 0xd3, 0xdd, 0x1c, 0xee, 0x28, 0xe4, 0xfb, 0x44, 0x7f, 0x1f, 0xa7,
    0xfa, 0x78, 0x53, 0x67, 0x67, 0x96, 0xa9, 0x3e, 0x57, 0x55, 0x06, 0xb8, 0x3f, 0xc8, 0xe7, 0x42,
    0xab, 0x42, 0x37, 0xbe, 0x9c, 0x6f, 0x27, 0x70, 0x13, 0xdd, 0x68, 0xef, 0xc6, 0x5f, 0x78, 0xca,
    0x69, 0x84, 0xf8, 0x15, 0xa1, 0x23, 0xe4, 0x3a, 0x93, 0x75, 0x5c, 0x63, 0xb3, 0xd8, 0x99, 0x4c,
    0x4e, 0xfc, 0x4b, 0x6f, 0x1d, 0x6d, 0x94, 0xe9, 0x96, 0xc2, 0xf0, 0x10, 0x6c, 0xdc, 0x23, 0xfc,
    0xaf, 0x23, 0x38, 0xb2, 0xbd, 0xea, 0x29, 0xec, 0x81, 0x07, 0x4d, 0x90, 0x80, 0x55, 0x85, 0xd9,
    0xdd, 0x4c, 0xe4, 0x18, 0x5f, 0x8f, 0xb4, 0x6d, 0x42, 0x83, 0x3b, 0xd2, 0x88, 0x16, 0x96, 0x73,
    0xef, 0x37, 0xe2, 0xe0, 0xae, 0x25, 0x85, 0x60, 0x45, 0x3c, 0xe6, 0x10, 0x0e, 0xbb, 0xac, 0x76,
    0xfa, 0x7f, 0x01, 0x02, 0xf7, 0x3e, 0x3f
};
#endif

PyTypeObject *init_QStateMachine(PyObject *module)
{
    if (SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX].type != nullptr)
        return SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX].type;

    Shiboken::AutoDecRef Sbk_QStateMachine_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtStateMachineTypeStructs[SBK_QState_IDX]))));

    _Sbk_QStateMachine_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QStateMachine",
        "QStateMachine*",
        &Sbk_QStateMachine_spec,
        &Shiboken::callCppDestructor< QStateMachine >,
        Sbk_QStateMachine_Type_bases.object(),
        0);
    auto *pyType = Sbk_QStateMachine_TypeF(); // references _Sbk_QStateMachine_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QStateMachine_SignatureStrings);
#else
    InitSignatureBytes(pyType, QStateMachine_SignatureBytes, QStateMachine_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QStateMachine_PropertyStrings);
    SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QStateMachine_PythonToCpp_QStateMachine_PTR,
        is_QStateMachine_PythonToCpp_QStateMachine_PTR_Convertible,
        QStateMachine_PTR_CppToPython_QStateMachine);

    Shiboken::Conversions::registerConverterName(converter, "QStateMachine");
    Shiboken::Conversions::registerConverterName(converter, "QStateMachine*");
    Shiboken::Conversions::registerConverterName(converter, "QStateMachine&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QStateMachine).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QStateMachineWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QStateMachine_TypeF(), &Sbk_QStateMachine_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QStateMachine_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'EventPriority'.
    const char *EventPriority_Initializer[] = {
        "NormalPriority",
        "HighPriority",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t EventPriority_InitializerValues[] = {
        uint8_t(QStateMachine::EventPriority::NormalPriority), //  0x00  0
        uint8_t(QStateMachine::EventPriority::HighPriority)    //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStateMachine_TypeF(),
        "2:PySide6.QtStateMachine.QStateMachine.EventPriority",
        EventPriority_Initializer, EventPriority_InitializerValues);
    SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_EventPriority_IDX].type = EType;
    // Register converter for enum 'QStateMachine::EventPriority'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStateMachine_EventPriority_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QStateMachine_EventPriority,
            is_Enum_PythonToCpp_QStateMachine_EventPriority_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QStateMachine::EventPriority");
        Shiboken::Conversions::registerConverterAlias(converter, "EventPriority");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'EventPriority' enum.

    // Initialization of enum 'Error'.
    const char *Error_Initializer[] = {
        "NoError",
        "NoInitialStateError",
        "NoDefaultStateInHistoryStateError",
        "NoCommonAncestorForTransitionError",
        "StateMachineChildModeSetToParallelError",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Error_InitializerValues[] = {
        uint8_t(QStateMachine::Error::NoError),                                //  0x00  0
        uint8_t(QStateMachine::Error::NoInitialStateError),                    //  0x01  1
        uint8_t(QStateMachine::Error::NoDefaultStateInHistoryStateError),      //  0x02  2
        uint8_t(QStateMachine::Error::NoCommonAncestorForTransitionError),     //  0x03  3
        uint8_t(QStateMachine::Error::StateMachineChildModeSetToParallelError) //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStateMachine_TypeF(),
        "2:PySide6.QtStateMachine.QStateMachine.Error",
        Error_Initializer, Error_InitializerValues);
    SbkPySide6_QtStateMachineTypeStructs[SBK_QStateMachine_Error_IDX].type = EType;
    // Register converter for enum 'QStateMachine::Error'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStateMachine_Error_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QStateMachine_Error,
            is_Enum_PythonToCpp_QStateMachine_Error_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QStateMachine::Error");
        Shiboken::Conversions::registerConverterAlias(converter, "Error");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Error' enum.

    PySide::Signal::registerSignals(pyType, &::QStateMachine::staticMetaObject);
    qRegisterMetaType< ::QStateMachine::EventPriority >("QStateMachine::EventPriority");
    qRegisterMetaType< ::QStateMachine::Error >("QStateMachine::Error");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QStateMachine::staticMetaObject, sizeof(QStateMachineWrapper));

    return pyType;
}
