// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtsvg_python.h"

// main header
#include "qsvggenerator_wrapper.h"

// Argument includes
#include <QString>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtSvg/qsvggenerator.h>
#include <qiodevice.h>
#include <qpoint.h>
#include <qrect.h>
#include <qsize.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QSvgGeneratorWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QSvgGeneratorWrapper::QSvgGeneratorWrapper()
{
}

QSvgGeneratorWrapper::QSvgGeneratorWrapper(::QSvgGenerator::SvgVersion version) : QSvgGenerator(version)
{
}

int QSvgGeneratorWrapper::devType() const
{
    if (m_PyMethodCache[0])
        return this->::QPaintDevice::devType();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return 0;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "devType";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QPaintDevice::devType();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSvgGenerator", funcName);
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSvgGenerator", funcName, "int", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    int cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QSvgGeneratorWrapper::initPainter(::QPainter * painter) const
{
    if (m_PyMethodCache[1]) {
        return this->::QPaintDevice::initPainter(painter);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "initPainter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QPaintDevice::initPainter(painter);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), painter)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), painter)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSvgGenerator", funcName);
        return;
    }
}

int QSvgGeneratorWrapper::metric(::QPaintDevice::PaintDeviceMetric metric) const
{
    if (m_PyMethodCache[2])
        return this->::QSvgGenerator::metric(metric);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return 0;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "metric";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QSvgGenerator::metric(metric);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_PaintDeviceMetric_IDX])))->converter, &metric)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_PaintDeviceMetric_IDX])))->converter, &metric)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSvgGenerator", funcName);
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSvgGenerator", funcName, "int", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    int cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QPaintEngine * QSvgGeneratorWrapper::paintEngine() const
{
    if (m_PyMethodCache[3])
        return this->::QSvgGenerator::paintEngine();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "paintEngine";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QSvgGenerator::paintEngine();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSvgGenerator", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSvgGenerator", funcName, Shiboken::SbkType< QPaintEngine >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QPaintEngine *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QPaintDevice * QSvgGeneratorWrapper::redirected(::QPoint * offset) const
{
    if (m_PyMethodCache[4])
        return this->::QPaintDevice::redirected(offset);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "redirected";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QPaintDevice::redirected(offset);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), offset)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), offset)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSvgGenerator", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSvgGenerator", funcName, Shiboken::SbkType< QPaintDevice >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QPaintDevice *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QPainter * QSvgGeneratorWrapper::sharedPainter() const
{
    if (m_PyMethodCache[5])
        return this->::QPaintDevice::sharedPainter();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "sharedPainter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QPaintDevice::sharedPainter();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSvgGenerator", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSvgGenerator", funcName, Shiboken::SbkType< QPainter >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QPainter *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QSvgGeneratorWrapper::~QSvgGeneratorWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSvgGenerator_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSvgGenerator >()))
        return -1;

    QSvgGeneratorWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QSvgGenerator", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QSvgGenerator::QSvgGenerator()
    // 1: QSvgGenerator::QSvgGenerator(QSvgGenerator::SvgVersion)
    if (numArgs == 0) {
        overloadId = 0; // QSvgGenerator()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QSvgGenerator_SvgVersion_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 1; // QSvgGenerator(QSvgGenerator::SvgVersion)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSvgTypeStructs[SBK_QSvgGenerator_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtSvgTypeStructs[SBK_QSvgGenerator_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QSvgGenerator()
        {

            // QSvgGenerator()
            cptr = new QSvgGeneratorWrapper();
            break;
        }
        case 1: // QSvgGenerator(QSvgGenerator::SvgVersion version)
        {
            ::QSvgGenerator::SvgVersion cppArg0{QSvgGenerator::SvgVersion::SvgTiny12};
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QSvgGenerator(QSvgGenerator::SvgVersion)
                cptr = new QSvgGeneratorWrapper(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QSvgGenerator >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSvgTypeStructs[SBK_QSvgGenerator_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSvgGeneratorFunc_description(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSvgGenerator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QSvgGenerator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // description()const
        QString cppResult = const_cast<const ::QSvgGenerator *>(cppSelf)->description();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSvgGeneratorFunc_fileName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSvgGenerator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QSvgGenerator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // fileName()const
        QString cppResult = const_cast<const ::QSvgGenerator *>(cppSelf)->fileName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSvgGeneratorFunc_metric(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSvgGenerator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QSvgGenerator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPaintDevice::metric(QPaintDevice::PaintDeviceMetric)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_PaintDeviceMetric_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // metric(QPaintDevice::PaintDeviceMetric)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "metric", errInfo, SbkPySide6_QtSvgTypeStructs[SBK_QSvgGenerator_IDX]);

    // Call function/method
    {
        ::QPaintDevice::PaintDeviceMetric cppArg0 = static_cast< ::QPaintDevice::PaintDeviceMetric>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // metric(QPaintDevice::PaintDeviceMetric)const
            int cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QSvgGenerator *>(cppSelf)->::QSvgGenerator::metric(cppArg0)
                : const_cast<const ::QSvgGenerator *>(cppSelf)->metric(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSvgGeneratorFunc_outputDevice(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSvgGenerator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QSvgGenerator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // outputDevice()const
        QIODevice * cppResult = const_cast<const ::QSvgGenerator *>(cppSelf)->outputDevice();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), cppResult);

        // Ownership transferences.
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSvgGeneratorFunc_paintEngine(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSvgGenerator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QSvgGenerator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // paintEngine()const
        QPaintEngine * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QSvgGenerator *>(cppSelf)->::QSvgGenerator::paintEngine()
            : const_cast<const ::QSvgGenerator *>(cppSelf)->paintEngine();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSvgGeneratorFunc_resolution(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSvgGenerator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QSvgGenerator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // resolution()const
        int cppResult = const_cast<const ::QSvgGenerator *>(cppSelf)->resolution();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSvgGeneratorFunc_setDescription(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSvgGenerator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QSvgGenerator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSvgGenerator::setDescription(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setDescription(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDescription", errInfo, SbkPySide6_QtSvgTypeStructs[SBK_QSvgGenerator_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDescription(QString)
            cppSelf->setDescription(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSvgGeneratorFunc_setFileName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSvgGenerator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QSvgGenerator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSvgGenerator::setFileName(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setFileName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFileName", errInfo, SbkPySide6_QtSvgTypeStructs[SBK_QSvgGenerator_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFileName(QString)
            cppSelf->setFileName(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSvgGeneratorFunc_setOutputDevice(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSvgGenerator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QSvgGenerator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSvgGenerator::setOutputDevice(QIODevice*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), (pyArg)))) {
        overloadId = 0; // setOutputDevice(QIODevice*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOutputDevice", errInfo, SbkPySide6_QtSvgTypeStructs[SBK_QSvgGenerator_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QIODevice *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOutputDevice(QIODevice*)
            cppSelf->setOutputDevice(cppArg0);
            Shiboken::Object::keepReference(reinterpret_cast<SbkObject *>(self), "setOutputDevice(QIODevice*)1", pyArg);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSvgGeneratorFunc_setResolution(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSvgGenerator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QSvgGenerator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSvgGenerator::setResolution(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setResolution(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setResolution", errInfo, SbkPySide6_QtSvgTypeStructs[SBK_QSvgGenerator_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setResolution(int)
            cppSelf->setResolution(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSvgGeneratorFunc_setSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSvgGenerator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QSvgGenerator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSvgGenerator::setSize(QSize)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArg)))) {
        overloadId = 0; // setSize(QSize)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSize", errInfo, SbkPySide6_QtSvgTypeStructs[SBK_QSvgGenerator_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSize cppArg0_local;
        ::QSize *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setSize(QSize)
            cppSelf->setSize(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSvgGeneratorFunc_setTitle(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSvgGenerator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QSvgGenerator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSvgGenerator::setTitle(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setTitle(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTitle", errInfo, SbkPySide6_QtSvgTypeStructs[SBK_QSvgGenerator_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTitle(QString)
            cppSelf->setTitle(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSvgGeneratorFunc_setViewBox(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSvgGenerator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QSvgGenerator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSvgGenerator::setViewBox(QRect)
    // 1: QSvgGenerator::setViewBox(QRectF)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArg)))) {
        overloadId = 0; // setViewBox(QRect)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArg)))) {
        overloadId = 1; // setViewBox(QRectF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setViewBox", errInfo, SbkPySide6_QtSvgTypeStructs[SBK_QSvgGenerator_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setViewBox(const QRect &viewBox)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QRect cppArg0_local;
            ::QRect *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setViewBox(QRect)
                cppSelf->setViewBox(*cppArg0);
            }
            break;
        }
        case 1: // setViewBox(const QRectF &viewBox)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QRectF cppArg0_local;
            ::QRectF *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setViewBox(QRectF)
                cppSelf->setViewBox(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSvgGeneratorFunc_size(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSvgGenerator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QSvgGenerator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // size()const
        QSize cppResult = const_cast<const ::QSvgGenerator *>(cppSelf)->size();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSvgGeneratorFunc_svgVersion(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSvgGenerator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QSvgGenerator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // svgVersion()const
        QSvgGenerator::SvgVersion cppResult = const_cast<const ::QSvgGenerator *>(cppSelf)->svgVersion();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QSvgGenerator_SvgVersion_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSvgGeneratorFunc_title(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSvgGenerator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QSvgGenerator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // title()const
        QString cppResult = const_cast<const ::QSvgGenerator *>(cppSelf)->title();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSvgGeneratorFunc_viewBox(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSvgGenerator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QSvgGenerator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // viewBox()const
        QRect cppResult = const_cast<const ::QSvgGenerator *>(cppSelf)->viewBox();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSvgGeneratorFunc_viewBoxF(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSvgGenerator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QSvgGenerator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // viewBoxF()const
        QRectF cppResult = const_cast<const ::QSvgGenerator *>(cppSelf)->viewBoxF();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QSvgGenerator_PropertyStrings[] = {
    "description::",
    "fileName::",
    "outputDevice::",
    "resolution::",
    "size::",
    "title::",
    "viewBox:viewBoxF:",
    nullptr // Sentinel
};

static const char *Sbk_QSvgGenerator_EnumFlagInfo[] = {
    "SvgVersion:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSvgGenerator_methods[] = {
    {"description", reinterpret_cast<PyCFunction>(Sbk_QSvgGeneratorFunc_description), METH_NOARGS, nullptr},
    {"fileName", reinterpret_cast<PyCFunction>(Sbk_QSvgGeneratorFunc_fileName), METH_NOARGS, nullptr},
    {"metric", reinterpret_cast<PyCFunction>(Sbk_QSvgGeneratorFunc_metric), METH_O, nullptr},
    {"outputDevice", reinterpret_cast<PyCFunction>(Sbk_QSvgGeneratorFunc_outputDevice), METH_NOARGS, nullptr},
    {"paintEngine", reinterpret_cast<PyCFunction>(Sbk_QSvgGeneratorFunc_paintEngine), METH_NOARGS, nullptr},
    {"resolution", reinterpret_cast<PyCFunction>(Sbk_QSvgGeneratorFunc_resolution), METH_NOARGS, nullptr},
    {"setDescription", reinterpret_cast<PyCFunction>(Sbk_QSvgGeneratorFunc_setDescription), METH_O, nullptr},
    {"setFileName", reinterpret_cast<PyCFunction>(Sbk_QSvgGeneratorFunc_setFileName), METH_O, nullptr},
    {"setOutputDevice", reinterpret_cast<PyCFunction>(Sbk_QSvgGeneratorFunc_setOutputDevice), METH_O, nullptr},
    {"setResolution", reinterpret_cast<PyCFunction>(Sbk_QSvgGeneratorFunc_setResolution), METH_O, nullptr},
    {"setSize", reinterpret_cast<PyCFunction>(Sbk_QSvgGeneratorFunc_setSize), METH_O, nullptr},
    {"setTitle", reinterpret_cast<PyCFunction>(Sbk_QSvgGeneratorFunc_setTitle), METH_O, nullptr},
    {"setViewBox", reinterpret_cast<PyCFunction>(Sbk_QSvgGeneratorFunc_setViewBox), METH_O, nullptr},
    {"size", reinterpret_cast<PyCFunction>(Sbk_QSvgGeneratorFunc_size), METH_NOARGS, nullptr},
    {"svgVersion", reinterpret_cast<PyCFunction>(Sbk_QSvgGeneratorFunc_svgVersion), METH_NOARGS, nullptr},
    {"title", reinterpret_cast<PyCFunction>(Sbk_QSvgGeneratorFunc_title), METH_NOARGS, nullptr},
    {"viewBox", reinterpret_cast<PyCFunction>(Sbk_QSvgGeneratorFunc_viewBox), METH_NOARGS, nullptr},
    {"viewBoxF", reinterpret_cast<PyCFunction>(Sbk_QSvgGeneratorFunc_viewBoxF), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QSvgGenerator_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QSvgGenerator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QSvgGenerator_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QSvgGeneratorWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QSvgGenerator_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSvgGenerator_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSvgGenerator_Type = nullptr;
static PyTypeObject *Sbk_QSvgGenerator_TypeF(void)
{
    return _Sbk_QSvgGenerator_Type;
}

static PyType_Slot Sbk_QSvgGenerator_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QSvgGenerator_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSvgGenerator_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSvgGenerator_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSvgGenerator_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSvgGenerator_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSvgGenerator_spec = {
    "2:PySide6.QtSvg.QSvgGenerator",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSvgGenerator_slots
};

} //extern "C"

static void *Sbk_QSvgGenerator_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QPaintDevice >())
        return dynamic_cast< ::QSvgGenerator *>(reinterpret_cast< ::QPaintDevice *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QSvgGenerator_SvgVersion(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSvgGenerator::SvgVersion>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSvgGenerator::SvgVersion *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QSvgGenerator_SvgVersion_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QSvgGenerator_SvgVersion_IDX])))
        return Enum_PythonToCpp_QSvgGenerator_SvgVersion;
    return {};
}

static PyObject *QSvgGenerator_SvgVersion_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QSvgGenerator::SvgVersion>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QSvgGenerator::SvgVersion *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QSvgGenerator_SvgVersion_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSvgGenerator_PythonToCpp_QSvgGenerator_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSvgGenerator_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSvgGenerator_PythonToCpp_QSvgGenerator_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSvgGenerator_TypeF()))
        return QSvgGenerator_PythonToCpp_QSvgGenerator_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSvgGenerator_PTR_CppToPython_QSvgGenerator(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QSvgGenerator *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QSvgGenerator_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSvgGenerator_SignatureStrings[] = {
    "1:PySide6.QtSvg.QSvgGenerator(self,*:KeywordOnly=None,size:QSize=None,viewBox:QRectF=None,title:QString=None,description:QString=None,fileName:QString=None,outputDevice:QIODevice=None,resolution:int=None)",
    "0:PySide6.QtSvg.QSvgGenerator(self,version:PySide6.QtSvg.QSvgGenerator.SvgVersion,*:KeywordOnly=None,size:QSize=None,viewBox:QRectF=None,title:QString=None,description:QString=None,fileName:QString=None,outputDevice:QIODevice=None,resolution:int=None)",
    "PySide6.QtSvg.QSvgGenerator.description(self)->QString",
    "PySide6.QtSvg.QSvgGenerator.fileName(self)->QString",
    "PySide6.QtSvg.QSvgGenerator.metric(self,metric:PySide6.QtGui.QPaintDevice.PaintDeviceMetric)->int",
    "PySide6.QtSvg.QSvgGenerator.outputDevice(self)->PySide6.QtCore.QIODevice",
    "PySide6.QtSvg.QSvgGenerator.paintEngine(self)->PySide6.QtGui.QPaintEngine",
    "PySide6.QtSvg.QSvgGenerator.resolution(self)->int",
    "PySide6.QtSvg.QSvgGenerator.setDescription(self,description:QString)",
    "PySide6.QtSvg.QSvgGenerator.setFileName(self,fileName:QString)",
    "PySide6.QtSvg.QSvgGenerator.setOutputDevice(self,outputDevice:PySide6.QtCore.QIODevice)",
    "PySide6.QtSvg.QSvgGenerator.setResolution(self,dpi:int)",
    "PySide6.QtSvg.QSvgGenerator.setSize(self,size:PySide6.QtCore.QSize)",
    "PySide6.QtSvg.QSvgGenerator.setTitle(self,title:QString)",
    "1:PySide6.QtSvg.QSvgGenerator.setViewBox(self,viewBox:PySide6.QtCore.QRect)",
    "0:PySide6.QtSvg.QSvgGenerator.setViewBox(self,viewBox:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect])",
    "PySide6.QtSvg.QSvgGenerator.size(self)->PySide6.QtCore.QSize",
    "PySide6.QtSvg.QSvgGenerator.svgVersion(self)->PySide6.QtSvg.QSvgGenerator.SvgVersion",
    "PySide6.QtSvg.QSvgGenerator.title(self)->QString",
    "PySide6.QtSvg.QSvgGenerator.viewBox(self)->PySide6.QtCore.QRect",
    "PySide6.QtSvg.QSvgGenerator.viewBoxF(self)->PySide6.QtCore.QRectF",
    nullptr}; // Sentinel
#else
static constexpr size_t QSvgGenerator_SignatureByteSize = 399;
static constexpr uint8_t QSvgGenerator_SignatureBytes[399] = {
    0x78, 0xda, 0xd5, 0x54, 0x3d, 0x6f, 0x83, 0x30, 0x10, 0xdd, 0xf3, 0x2b, 0x3a, 0x96, 0x8a, 0x5a,
    0xcd, 0xd2, 0x01, 0xa9, 0x1d, 0xfa, 0x41, 0x54, 0x55, 0x0d, 0x21, 0x69, 0xb3, 0x54, 0x1d, 0x10,
    0x5c, 0x22, 0x4b, 0xc4, 0x46, 0xc6, 0x90, 0xd2, 0x5f, 0x5f, 0x9b, 0x0b, 0x09, 0x10, 0x62, 0xa7,
    0x63, 0x17, 0xcb, 0x3e, 0xdf, 0x7b, 0x77, 0xf7, 0xec, 0xbb, 0xb1, 0x37, 0xab, 0x16, 0x34, 0x81,
    0x5b, 0x12, 0xca, 0x45, 0xb9, 0x26, 0xa1, 0x5a, 0x26, 0xc0, 0x40, 0x44, 0x92, 0x8b, 0xcb, 0x1c,
    0xd2, 0x95, 0x7b, 0xe5, 0xbd, 0x42, 0xb5, 0xe5, 0x22, 0x09, 0x58, 0x5a, 0xdd, 0x4d, 0x39, 0x03,
    0x37, 0xa7, 0x3f, 0xe0, 0x85, 0x0b, 0xb5, 0xe2, 0xb9, 0xa4, 0xb0, 0x7d, 0xe0, 0xdf, 0x5e, 0x38,
    0x87, 0x58, 0xfa, 0x68, 0x93, 0x54, 0xa6, 0xda, 0x49, 0x0a, 0xca, 0xd6, 0x68, 0x4a, 0x20, 0x8f,
    0x05, 0xcd, 0x24, 0xe5, 0xac, 0x7b, 0xb1, 0xa2, 0x29, 0x4c, 0xa3, 0x4d, 0xcf, 0x9d, 0x17, 0x32,
    0x2b, 0xe4, 0x13, 0x94, 0x34, 0x56, 0x37, 0x2f, 0x01, 0xee, 0xf0, 0x4e, 0x40, 0xce, 0xd3, 0xa2,
    0x66, 0xa2, 0x4c, 0xd6, 0x36, 0x67, 0x74, 0x63, 0x2f, 0xa6, 0x04, 0x91, 0x6b, 0x90, 0xc1, 0x91,
    0xa8, 0xc3, 0x12, 0xdd, 0xfe, 0x51, 0xed, 0xa6, 0x82, 0x5a, 0xb1, 0x6b, 0x15, 0x9c, 0xeb, 0xfb,
    0x5d, 0x30, 0x23, 0xac, 0xc9, 0xec, 0x2f, 0x98, 0x0d, 0x28, 0x9f, 0x18, 0xb5, 0xc6, 0x7d, 0x4b,
    0xea, 0x49, 0x41, 0x49, 0x38, 0x8b, 0x54, 0xd2, 0x58, 0x0e, 0x69, 0xed, 0xdf, 0x6a, 0x67, 0x15,
    0x45, 0x59, 0x8c, 0x11, 0xda, 0xca, 0x34, 0x99, 0x1d, 0xfc, 0x1f, 0xb9, 0x00, 0xb2, 0xd7, 0xcb,
    0x48, 0x94, 0xe9, 0xe0, 0xcf, 0x6c, 0x4d, 0xd9, 0x00, 0xcf, 0x21, 0x55, 0xf4, 0x30, 0x32, 0x1d,
    0x1e, 0xa4, 0x21, 0xb2, 0x15, 0x91, 0x83, 0xaa, 0xa0, 0xfb, 0x28, 0x43, 0x3f, 0xc4, 0xb1, 0x91,
    0xf8, 0xed, 0x27, 0x3a, 0xfa, 0x4a, 0x56, 0x78, 0xd0, 0xd7, 0xb2, 0xfb, 0xef, 0x4e, 0xc9, 0x6a,
    0xe5, 0x9d, 0x77, 0x05, 0x71, 0x93, 0x8c, 0xea, 0xaf, 0x6a, 0xc5, 0xe9, 0xae, 0x42, 0x44, 0xdd,
    0x65, 0xfd, 0xf8, 0xfa, 0xda, 0xca, 0xf1, 0xae, 0x7b, 0x0f, 0x49, 0x3a, 0x6d, 0xe8, 0x8c, 0xc6,
    0x9e, 0x05, 0xba, 0xc4, 0x56, 0xde, 0x4d, 0x8a, 0x5d, 0x5f, 0xf7, 0x93, 0xd0, 0x6d, 0x6e, 0x19,
    0x35, 0x27, 0xb9, 0x64, 0x95, 0xa9, 0x4c, 0xc8, 0x07, 0x53, 0xca, 0x7c, 0x0e, 0x11, 0xfb, 0xee,
    0xc5, 0x90, 0xf9, 0xcb, 0x52, 0x75, 0x23, 0xdb, 0x40, 0x2b, 0x68, 0xcd, 0xcc, 0xe0, 0xfd, 0xb4,
    0x3b, 0xa6, 0x30, 0xcd, 0x46, 0x23, 0xa9, 0xdc, 0x3f, 0xc2, 0x99, 0x73, 0xa3, 0x6c, 0xc9, 0x35,
    0x50, 0x85, 0x16, 0xe1, 0x1c, 0xbc, 0x6f, 0x22, 0xf0, 0x47, 0xbf, 0x2a, 0xd9, 0x83, 0x00
};
#endif

PyTypeObject *init_QSvgGenerator(PyObject *module)
{
    if (SbkPySide6_QtSvgTypeStructs[SBK_QSvgGenerator_IDX].type != nullptr)
        return SbkPySide6_QtSvgTypeStructs[SBK_QSvgGenerator_IDX].type;

    Shiboken::AutoDecRef Sbk_QSvgGenerator_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]))));

    _Sbk_QSvgGenerator_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSvgGenerator",
        "QSvgGenerator*",
        &Sbk_QSvgGenerator_spec,
        &Shiboken::callCppDestructor< QSvgGenerator >,
        Sbk_QSvgGenerator_Type_bases.object(),
        0);
    auto *pyType = Sbk_QSvgGenerator_TypeF(); // references _Sbk_QSvgGenerator_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSvgGenerator_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSvgGenerator_SignatureBytes, QSvgGenerator_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSvgGenerator_PropertyStrings);
    SbkPySide6_QtSvgTypeStructs[SBK_QSvgGenerator_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSvgGenerator_PythonToCpp_QSvgGenerator_PTR,
        is_QSvgGenerator_PythonToCpp_QSvgGenerator_PTR_Convertible,
        QSvgGenerator_PTR_CppToPython_QSvgGenerator);

    Shiboken::Conversions::registerConverterName(converter, "QSvgGenerator");
    Shiboken::Conversions::registerConverterName(converter, "QSvgGenerator*");
    Shiboken::Conversions::registerConverterName(converter, "QSvgGenerator&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSvgGenerator).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QSvgGeneratorWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QSvgGenerator_TypeF(), &Sbk_QSvgGenerator_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QSvgGenerator_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'SvgVersion'.
    const char *SvgVersion_Initializer[] = {
        "SvgTiny12",
        "Svg11",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t SvgVersion_InitializerValues[] = {
        int8_t(QSvgGenerator::SvgVersion::SvgTiny12), //  0x00  0
        int8_t(QSvgGenerator::SvgVersion::Svg11)      //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSvgGenerator_TypeF(),
        "2:PySide6.QtSvg.QSvgGenerator.SvgVersion",
        SvgVersion_Initializer, SvgVersion_InitializerValues);
    SbkPySide6_QtSvgTypeStructs[SBK_QSvgGenerator_SvgVersion_IDX].type = EType;
    // Register converter for enum 'QSvgGenerator::SvgVersion'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSvgGenerator_SvgVersion_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QSvgGenerator_SvgVersion,
            is_Enum_PythonToCpp_QSvgGenerator_SvgVersion_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QSvgGenerator::SvgVersion");
        Shiboken::Conversions::registerConverterAlias(converter, "SvgVersion");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'SvgVersion' enum.

    qRegisterMetaType< ::QSvgGenerator *>();
    qRegisterMetaType< ::QSvgGenerator::SvgVersion >("QSvgGenerator::SvgVersion");

    return pyType;
}
