// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtsvg_python.h"

// main header
#include "qsvgrenderer_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QtGui/qpainter.h>
#include <QtGui/qtransform.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qrect.h>
#include <qsize.h>
#include <qthread.h>
#include <qvariant.h>
#include <qxmlstream.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QSvgRendererWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QSvgRendererWrapper::QSvgRendererWrapper(::QObject * parent) : QSvgRenderer(parent)
{
}

QSvgRendererWrapper::QSvgRendererWrapper(::QXmlStreamReader * contents, ::QObject * parent) : QSvgRenderer(contents, parent)
{
}

QSvgRendererWrapper::QSvgRendererWrapper(const ::QByteArray & contents, ::QObject * parent) : QSvgRenderer(contents, parent)
{
}

QSvgRendererWrapper::QSvgRendererWrapper(const ::QString & filename, ::QObject * parent) : QSvgRenderer(filename, parent)
{
}

void QSvgRendererWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSvgRenderer", funcName);
        return;
    }
}

void QSvgRendererWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSvgRenderer", funcName);
        return;
    }
}

void QSvgRendererWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSvgRenderer", funcName);
        return;
    }
}

void QSvgRendererWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSvgRenderer", funcName);
        return;
    }
}

bool QSvgRendererWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSvgRenderer", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSvgRenderer", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QSvgRendererWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSvgRenderer", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSvgRenderer", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QSvgRendererWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSvgRenderer", funcName);
        return;
    }
}

const QMetaObject *QSvgRendererWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QSvgRenderer::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QSvgRendererWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QSvgRenderer::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QSvgRendererWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QSvgRendererWrapper *>(this));
    return QSvgRenderer::qt_metacast(_clname);
}

QSvgRendererWrapper::~QSvgRendererWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSvgRenderer_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSvgRenderer >()))
        return -1;

    QSvgRendererWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:QSvgRenderer", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QSvgRenderer::QSvgRenderer(QObject*=)
    // 1: QSvgRenderer::QSvgRenderer(QXmlStreamReader*,QObject*=)
    // 2: QSvgRenderer::QSvgRenderer(QByteArray,QObject*=)
    // 3: QSvgRenderer::QSvgRenderer(QString,QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QSvgRenderer(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QSvgRenderer(QXmlStreamReader*,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 1; // QSvgRenderer(QXmlStreamReader*,QObject*)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QSvgRenderer(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 3; // QSvgRenderer(QString,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 3; // QSvgRenderer(QString,QObject*)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 2; // QSvgRenderer(QByteArray,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 2; // QSvgRenderer(QByteArray,QObject*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QSvgRenderer(QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0 = nullptr;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QSvgRenderer(QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QSvgRendererWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QSvgRendererWrapper(cppArg0);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
        case 1: // QSvgRenderer(QXmlStreamReader *contents, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QXmlStreamReader *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QObject *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QSvgRenderer(QXmlStreamReader*,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QSvgRendererWrapper(cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QSvgRendererWrapper(cppArg0, cppArg1);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
        case 2: // QSvgRenderer(const QByteArray &contents, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QObject *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QSvgRenderer(QByteArray,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QSvgRendererWrapper(*cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QSvgRendererWrapper(*cppArg0, cppArg1);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
        case 3: // QSvgRenderer(const QString &filename, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QObject *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QSvgRenderer(QString,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QSvgRendererWrapper(cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QSvgRendererWrapper(cppArg0, cppArg1);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QSvgRenderer >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QSvgRendererFunc_animated(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSvgRenderer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // animated()const
        bool cppResult = const_cast<const ::QSvgRenderer *>(cppSelf)->animated();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSvgRendererFunc_animationDuration(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSvgRenderer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // animationDuration()const
        int cppResult = const_cast<const ::QSvgRenderer *>(cppSelf)->animationDuration();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSvgRendererFunc_aspectRatioMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSvgRenderer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // aspectRatioMode()const
        Qt::AspectRatioMode cppResult = const_cast<const ::QSvgRenderer *>(cppSelf)->aspectRatioMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_AspectRatioMode_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSvgRendererFunc_boundsOnElement(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSvgRenderer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSvgRenderer::boundsOnElement(QString)const->QRectF
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // boundsOnElement(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "boundsOnElement", errInfo, SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // boundsOnElement(QString)const
            QRectF cppResult = const_cast<const ::QSvgRenderer *>(cppSelf)->boundsOnElement(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSvgRendererFunc_currentFrame(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSvgRenderer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // currentFrame()const
        int cppResult = const_cast<const ::QSvgRenderer *>(cppSelf)->currentFrame();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSvgRendererFunc_defaultSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSvgRenderer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // defaultSize()const
        QSize cppResult = const_cast<const ::QSvgRenderer *>(cppSelf)->defaultSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSvgRendererFunc_elementExists(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSvgRenderer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSvgRenderer::elementExists(QString)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // elementExists(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "elementExists", errInfo, SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // elementExists(QString)const
            bool cppResult = const_cast<const ::QSvgRenderer *>(cppSelf)->elementExists(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSvgRendererFunc_framesPerSecond(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSvgRenderer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // framesPerSecond()const
        int cppResult = const_cast<const ::QSvgRenderer *>(cppSelf)->framesPerSecond();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSvgRendererFunc_isAnimationEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSvgRenderer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isAnimationEnabled()const
        bool cppResult = const_cast<const ::QSvgRenderer *>(cppSelf)->isAnimationEnabled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSvgRendererFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSvgRenderer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QSvgRenderer *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSvgRendererFunc_load(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSvgRenderer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSvgRenderer::load(QXmlStreamReader*)->bool
    // 1: QSvgRenderer::load(QByteArray)->bool
    // 2: QSvgRenderer::load(QString)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), (pyArg)))) {
        overloadId = 0; // load(QXmlStreamReader*)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 2; // load(QString)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 1; // load(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "load", errInfo, SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // load(QXmlStreamReader *contents)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QXmlStreamReader *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // load(QXmlStreamReader*)
                bool cppResult = cppSelf->load(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // load(const QByteArray &contents)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // load(QByteArray)
                bool cppResult = cppSelf->load(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 2: // load(const QString &filename)
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // load(QString)
                bool cppResult = cppSelf->load(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSvgRendererFunc_options(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSvgRenderer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // options()const
        QFlags<QtSvg::Option> cppResult = const_cast<const ::QSvgRenderer *>(cppSelf)->options();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QFlags_QtSvg_Option_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSvgRendererFunc_render(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSvgRenderer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "render", errInfo, SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:render", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSvgRenderer::render(QPainter*)
    // 1: QSvgRenderer::render(QPainter*,QRectF)
    // 2: QSvgRenderer::render(QPainter*,QString,const QRectF&=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // render(QPainter*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 2; // render(QPainter*,QString,QRectF)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[2])))) {
                overloadId = 2; // render(QPainter*,QString,QRectF)
            }
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[1])))) {
            overloadId = 1; // render(QPainter*,QRectF)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "render", errInfo, SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // render(QPainter *p)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "render", errInfo, SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPainter *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // render(QPainter*)
                cppSelf->render(cppArg0);
            }
            break;
        }
        case 1: // render(QPainter *p, const QRectF &bounds)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "render", errInfo, SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPainter *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QRectF cppArg1_local;
            ::QRectF *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // render(QPainter*,QRectF)
                cppSelf->render(cppArg0, *cppArg1);
            }
            break;
        }
        case 2: // render(QPainter *p, const QString &elementId, const QRectF &bounds)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_bounds = Shiboken::String::createStaticString("bounds");
                if (PyDict_Contains(kwds, key_bounds) != 0) {
                    value = PyDict_GetItem(kwds, key_bounds);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_bounds);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "render", errInfo, SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "render", errInfo, SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_bounds);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "render", errInfo, SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPainter *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QRectF cppArg2_local = QRectF();
            ::QRectF *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2]) {
                if (pythonToCpp[2].isValue())
                    pythonToCpp[2](pyArgs[2], &cppArg2_local);
                else
                    pythonToCpp[2](pyArgs[2], &cppArg2);
                }

            if (Shiboken::Errors::occurred() == nullptr) {
                // render(QPainter*,QString,QRectF)
                cppSelf->render(cppArg0, cppArg1, *cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSvgRendererFunc_setAnimationEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSvgRenderer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSvgRenderer::setAnimationEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAnimationEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAnimationEnabled", errInfo, SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAnimationEnabled(bool)
            cppSelf->setAnimationEnabled(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSvgRendererFunc_setAspectRatioMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSvgRenderer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSvgRenderer::setAspectRatioMode(Qt::AspectRatioMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_AspectRatioMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setAspectRatioMode(Qt::AspectRatioMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAspectRatioMode", errInfo, SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]);

    // Call function/method
    {
        ::Qt::AspectRatioMode cppArg0{Qt::IgnoreAspectRatio};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAspectRatioMode(Qt::AspectRatioMode)
            cppSelf->setAspectRatioMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSvgRendererFunc_setCurrentFrame(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSvgRenderer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSvgRenderer::setCurrentFrame(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setCurrentFrame(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCurrentFrame", errInfo, SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCurrentFrame(int)
            cppSelf->setCurrentFrame(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSvgRendererFunc_setDefaultOptions(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QSvgRenderer::setDefaultOptions(QFlags<QtSvg::Option>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QFlags_QtSvg_Option_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setDefaultOptions(QFlags<QtSvg::Option>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDefaultOptions", errInfo, SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]);

    // Call function/method
    {
        ::QFlags<QtSvg::Option> cppArg0 = QFlags<QtSvg::Option>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDefaultOptions(QFlags<QtSvg::Option>)
            ::QSvgRenderer::setDefaultOptions(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSvgRendererFunc_setFramesPerSecond(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSvgRenderer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSvgRenderer::setFramesPerSecond(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setFramesPerSecond(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFramesPerSecond", errInfo, SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFramesPerSecond(int)
            cppSelf->setFramesPerSecond(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSvgRendererFunc_setOptions(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSvgRenderer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSvgRenderer::setOptions(QFlags<QtSvg::Option>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QFlags_QtSvg_Option_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setOptions(QFlags<QtSvg::Option>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOptions", errInfo, SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]);

    // Call function/method
    {
        ::QFlags<QtSvg::Option> cppArg0 = QFlags<QtSvg::Option>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOptions(QFlags<QtSvg::Option>)
            cppSelf->setOptions(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSvgRendererFunc_setViewBox(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSvgRenderer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSvgRenderer::setViewBox(QRect)
    // 1: QSvgRenderer::setViewBox(QRectF)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArg)))) {
        overloadId = 0; // setViewBox(QRect)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArg)))) {
        overloadId = 1; // setViewBox(QRectF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setViewBox", errInfo, SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setViewBox(const QRect &viewbox)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QRect cppArg0_local;
            ::QRect *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setViewBox(QRect)
                cppSelf->setViewBox(*cppArg0);
            }
            break;
        }
        case 1: // setViewBox(const QRectF &viewbox)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QRectF cppArg0_local;
            ::QRectF *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setViewBox(QRectF)
                cppSelf->setViewBox(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSvgRendererFunc_transformForElement(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSvgRenderer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSvgRenderer::transformForElement(QString)const->QTransform
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // transformForElement(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "transformForElement", errInfo, SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // transformForElement(QString)const
            QTransform cppResult = const_cast<const ::QSvgRenderer *>(cppSelf)->transformForElement(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSvgRendererFunc_viewBox(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSvgRenderer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // viewBox()const
        QRect cppResult = const_cast<const ::QSvgRenderer *>(cppSelf)->viewBox();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSvgRendererFunc_viewBoxF(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSvgRenderer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // viewBoxF()const
        QRectF cppResult = const_cast<const ::QSvgRenderer *>(cppSelf)->viewBoxF();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QSvgRenderer_PropertyStrings[] = {
    "animationEnabled:isAnimationEnabled:",
    "aspectRatioMode::",
    "currentFrame::",
    "framesPerSecond::",
    "options::",
    "viewBox:viewBoxF:",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSvgRenderer_methods[] = {
    {"animated", reinterpret_cast<PyCFunction>(Sbk_QSvgRendererFunc_animated), METH_NOARGS, nullptr},
    {"animationDuration", reinterpret_cast<PyCFunction>(Sbk_QSvgRendererFunc_animationDuration), METH_NOARGS, nullptr},
    {"aspectRatioMode", reinterpret_cast<PyCFunction>(Sbk_QSvgRendererFunc_aspectRatioMode), METH_NOARGS, nullptr},
    {"boundsOnElement", reinterpret_cast<PyCFunction>(Sbk_QSvgRendererFunc_boundsOnElement), METH_O, nullptr},
    {"currentFrame", reinterpret_cast<PyCFunction>(Sbk_QSvgRendererFunc_currentFrame), METH_NOARGS, nullptr},
    {"defaultSize", reinterpret_cast<PyCFunction>(Sbk_QSvgRendererFunc_defaultSize), METH_NOARGS, nullptr},
    {"elementExists", reinterpret_cast<PyCFunction>(Sbk_QSvgRendererFunc_elementExists), METH_O, nullptr},
    {"framesPerSecond", reinterpret_cast<PyCFunction>(Sbk_QSvgRendererFunc_framesPerSecond), METH_NOARGS, nullptr},
    {"isAnimationEnabled", reinterpret_cast<PyCFunction>(Sbk_QSvgRendererFunc_isAnimationEnabled), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QSvgRendererFunc_isValid), METH_NOARGS, nullptr},
    {"load", reinterpret_cast<PyCFunction>(Sbk_QSvgRendererFunc_load), METH_O, nullptr},
    {"options", reinterpret_cast<PyCFunction>(Sbk_QSvgRendererFunc_options), METH_NOARGS, nullptr},
    {"render", reinterpret_cast<PyCFunction>(Sbk_QSvgRendererFunc_render), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setAnimationEnabled", reinterpret_cast<PyCFunction>(Sbk_QSvgRendererFunc_setAnimationEnabled), METH_O, nullptr},
    {"setAspectRatioMode", reinterpret_cast<PyCFunction>(Sbk_QSvgRendererFunc_setAspectRatioMode), METH_O, nullptr},
    {"setCurrentFrame", reinterpret_cast<PyCFunction>(Sbk_QSvgRendererFunc_setCurrentFrame), METH_O, nullptr},
    {"setDefaultOptions", reinterpret_cast<PyCFunction>(Sbk_QSvgRendererFunc_setDefaultOptions), METH_O|METH_STATIC, nullptr},
    {"setFramesPerSecond", reinterpret_cast<PyCFunction>(Sbk_QSvgRendererFunc_setFramesPerSecond), METH_O, nullptr},
    {"setOptions", reinterpret_cast<PyCFunction>(Sbk_QSvgRendererFunc_setOptions), METH_O, nullptr},
    {"setViewBox", reinterpret_cast<PyCFunction>(Sbk_QSvgRendererFunc_setViewBox), METH_O, nullptr},
    {"transformForElement", reinterpret_cast<PyCFunction>(Sbk_QSvgRendererFunc_transformForElement), METH_O, nullptr},
    {"viewBox", reinterpret_cast<PyCFunction>(Sbk_QSvgRendererFunc_viewBox), METH_NOARGS, nullptr},
    {"viewBoxF", reinterpret_cast<PyCFunction>(Sbk_QSvgRendererFunc_viewBoxF), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QSvgRenderer_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QSvgRenderer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QSvgRendererWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QSvgRenderer_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSvgRenderer_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSvgRenderer_Type = nullptr;
static PyTypeObject *Sbk_QSvgRenderer_TypeF(void)
{
    return _Sbk_QSvgRenderer_Type;
}

static PyType_Slot Sbk_QSvgRenderer_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QSvgRenderer_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSvgRenderer_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSvgRenderer_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSvgRenderer_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSvgRenderer_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSvgRenderer_spec = {
    "2:PySide6.QtSvg.QSvgRenderer",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSvgRenderer_slots
};

} //extern "C"

static void *Sbk_QSvgRenderer_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QSvgRenderer *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSvgRenderer_PythonToCpp_QSvgRenderer_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSvgRenderer_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSvgRenderer_PythonToCpp_QSvgRenderer_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSvgRenderer_TypeF()))
        return QSvgRenderer_PythonToCpp_QSvgRenderer_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSvgRenderer_PTR_CppToPython_QSvgRenderer(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QSvgRenderer *>(const_cast<void *>(cppIn)), Sbk_QSvgRenderer_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSvgRenderer_SignatureStrings[] = {
    "3:PySide6.QtSvg.QSvgRenderer(self,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,viewBox:QRectF=None,framesPerSecond:int=None,currentFrame:int=None,aspectRatioMode:Qt.AspectRatioMode=None,options:PySide6.QtSvg.QtSvg.Option=None,animationEnabled:bool=None)",
    "2:PySide6.QtSvg.QSvgRenderer(self,contents:PySide6.QtCore.QXmlStreamReader,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,viewBox:QRectF=None,framesPerSecond:int=None,currentFrame:int=None,aspectRatioMode:Qt.AspectRatioMode=None,options:PySide6.QtSvg.QtSvg.Option=None,animationEnabled:bool=None)",
    "1:PySide6.QtSvg.QSvgRenderer(self,contents:typing.Union[PySide6.QtCore.QByteArray, char*],parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,viewBox:QRectF=None,framesPerSecond:int=None,currentFrame:int=None,aspectRatioMode:Qt.AspectRatioMode=None,options:PySide6.QtSvg.QtSvg.Option=None,animationEnabled:bool=None)",
    "0:PySide6.QtSvg.QSvgRenderer(self,filename:QString,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,viewBox:QRectF=None,framesPerSecond:int=None,currentFrame:int=None,aspectRatioMode:Qt.AspectRatioMode=None,options:PySide6.QtSvg.QtSvg.Option=None,animationEnabled:bool=None)",
    "PySide6.QtSvg.QSvgRenderer.animated(self)->bool",
    "PySide6.QtSvg.QSvgRenderer.animationDuration(self)->int",
    "PySide6.QtSvg.QSvgRenderer.aspectRatioMode(self)->PySide6.QtCore.Qt.AspectRatioMode",
    "PySide6.QtSvg.QSvgRenderer.boundsOnElement(self,id:QString)->PySide6.QtCore.QRectF",
    "PySide6.QtSvg.QSvgRenderer.currentFrame(self)->int",
    "PySide6.QtSvg.QSvgRenderer.defaultSize(self)->PySide6.QtCore.QSize",
    "PySide6.QtSvg.QSvgRenderer.elementExists(self,id:QString)->bool",
    "PySide6.QtSvg.QSvgRenderer.framesPerSecond(self)->int",
    "PySide6.QtSvg.QSvgRenderer.isAnimationEnabled(self)->bool",
    "PySide6.QtSvg.QSvgRenderer.isValid(self)->bool",
    "2:PySide6.QtSvg.QSvgRenderer.load(self,contents:PySide6.QtCore.QXmlStreamReader)->bool",
    "1:PySide6.QtSvg.QSvgRenderer.load(self,contents:typing.Union[PySide6.QtCore.QByteArray, char*])->bool",
    "0:PySide6.QtSvg.QSvgRenderer.load(self,filename:QString)->bool",
    "PySide6.QtSvg.QSvgRenderer.options(self)->PySide6.QtSvg.QtSvg.Option",
    "2:PySide6.QtSvg.QSvgRenderer.render(self,p:PySide6.QtGui.QPainter)",
    "1:PySide6.QtSvg.QSvgRenderer.render(self,p:PySide6.QtGui.QPainter,bounds:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect])",
    "0:PySide6.QtSvg.QSvgRenderer.render(self,p:PySide6.QtGui.QPainter,elementId:QString,bounds:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect]=QRectF())",
    "PySide6.QtSvg.QSvgRenderer.setAnimationEnabled(self,enable:bool)",
    "PySide6.QtSvg.QSvgRenderer.setAspectRatioMode(self,mode:PySide6.QtCore.Qt.AspectRatioMode)",
    "PySide6.QtSvg.QSvgRenderer.setCurrentFrame(self,arg__1:int)",
    "PySide6.QtSvg.QSvgRenderer.setDefaultOptions(flags:PySide6.QtSvg.QtSvg.Option)",
    "PySide6.QtSvg.QSvgRenderer.setFramesPerSecond(self,num:int)",
    "PySide6.QtSvg.QSvgRenderer.setOptions(self,flags:PySide6.QtSvg.QtSvg.Option)",
    "1:PySide6.QtSvg.QSvgRenderer.setViewBox(self,viewbox:PySide6.QtCore.QRect)",
    "0:PySide6.QtSvg.QSvgRenderer.setViewBox(self,viewbox:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect])",
    "PySide6.QtSvg.QSvgRenderer.transformForElement(self,id:QString)->PySide6.QtGui.QTransform",
    "PySide6.QtSvg.QSvgRenderer.viewBox(self)->PySide6.QtCore.QRect",
    "PySide6.QtSvg.QSvgRenderer.viewBoxF(self)->PySide6.QtCore.QRectF",
    nullptr}; // Sentinel
#else
static constexpr size_t QSvgRenderer_SignatureByteSize = 591;
static constexpr uint8_t QSvgRenderer_SignatureBytes[591] = {
    0x78, 0xda, 0xe5, 0x56, 0x51, 0x6f, 0xda, 0x30, 0x10, 0x7e, 0xef, 0xaf, 0xe8, 0x63, 0xa9, 0xbc,
    0xa8, 0x6c, 0xd2, 0x1e, 0x22, 0x31, 0x89, 0xb6, 0x64, 0x9a, 0xa6, 0x2d, 0x04, 0xb6, 0x6a, 0xd2,
    0x54, 0x55, 0x06, 0x5f, 0x98, 0x27, 0xc7, 0x46, 0xb6, 0x43, 0x9b, 0xfd, 0xfa, 0x39, 0x31, 0xd9,
    0x20, 0x04, 0xdb, 0xa8, 0x8f, 0xbc, 0x04, 0x62, 0xdf, 0x7d, 0xbe, 0xfb, 0x7c, 0xf7, 0x5d, 0xde,
    0xc5, 0xd3, 0x6a, 0x4e, 0x09, 0xbc, 0x8f, 0x32, 0x3d, 0xdf, 0xac, 0xa2, 0xcc, 0x3c, 0x66, 0xc0,
    0x09, 0x48, 0x90, 0x57, 0x0a, 0x58, 0x8e, 0xd6, 0x58, 0x02, 0xd7, 0x3b, 0x66, 0x77, 0x42, 0x42,
    0x94, 0xa5, 0x8b, 0xdf, 0xb0, 0xd4, 0x23, 0x5e, 0x32, 0xb6, 0xd6, 0x12, 0x5d, 0xc7, 0x9f, 0xa1,
    0x7a, 0x16, 0x92, 0xa4, 0x9c, 0x55, 0xa3, 0xaf, 0x82, 0x03, 0xda, 0x50, 0x78, 0xbe, 0x15, 0x2f,
    0x71, 0x36, 0x33, 0x86, 0x89, 0x5d, 0xcb, 0x25, 0x2e, 0x40, 0x4d, 0x41, 0xce, 0x61, 0x29, 0x38,
    0x89, 0x29, 0xd7, 0x76, 0x63, 0x59, 0xca, 0xfa, 0x98, 0xa4, 0xde, 0xff, 0xbf, 0x8a, 0xd5, 0xda,
    0xf8, 0xce, 0xb0, 0xa6, 0xe2, 0x8b, 0x20, 0x10, 0x67, 0x3a, 0x1a, 0xef, 0x2f, 0x59, 0x3b, 0xb1,
    0x36, 0xaf, 0x5c, 0x75, 0x73, 0x69, 0x9e, 0x69, 0xb3, 0xb7, 0xc5, 0xe3, 0xb4, 0xa8, 0x3d, 0xf9,
    0x84, 0xe3, 0x05, 0x03, 0x12, 0x2f, 0x84, 0x60, 0xcd, 0xd6, 0xe0, 0xe2, 0xad, 0x97, 0x09, 0x13,
    0xb1, 0x36, 0x31, 0xaa, 0x03, 0x2e, 0x7e, 0x14, 0x6c, 0xae, 0x25, 0xe0, 0x62, 0x06, 0xd8, 0xd8,
    0x9f, 0x0d, 0x65, 0xc3, 0x70, 0xca, 0x74, 0xb5, 0xa6, 0x7c, 0x15, 0x7d, 0xe7, 0x06, 0xe9, 0x67,
    0x97, 0x98, 0xdb, 0x4a, 0xc3, 0x58, 0x4a, 0x5c, 0xa1, 0xcb, 0xe5, 0x2f, 0x2c, 0xaf, 0x1f, 0xcf,
    0x86, 0xc1, 0x1b, 0x2f, 0x83, 0x39, 0x65, 0xc0, 0xeb, 0xf8, 0x32, 0x53, 0x62, 0x86, 0xc2, 0xb3,
    0xa1, 0xe6, 0x38, 0x31, 0x91, 0x75, 0x03, 0xd2, 0x30, 0x34, 0x78, 0xf3, 0xa1, 0xf6, 0xf2, 0xdb,
    0x9b, 0x63, 0xee, 0x4b, 0xd9, 0xfc, 0xb6, 0x8e, 0x26, 0x31, 0xa7, 0xdf, 0x7e, 0x6e, 0xad, 0x57,
    0x97, 0xfa, 0x03, 0x12, 0x5c, 0x98, 0x0b, 0x51, 0x72, 0xa2, 0x52, 0x3e, 0x61, 0x50, 0x18, 0x82,
    0xed, 0x25, 0x53, 0xd2, 0x5e, 0x6f, 0x0f, 0x7c, 0x73, 0x5d, 0x2e, 0xc8, 0xdd, 0xbb, 0x0a, 0xcc,
    0x8c, 0x40, 0x8e, 0x4b, 0xa6, 0xe7, 0xf4, 0xcf, 0xd1, 0xac, 0xea, 0x3d, 0x17, 0x04, 0xd8, 0x04,
    0x26, 0x2f, 0x54, 0x69, 0xd5, 0x93, 0x86, 0xef, 0x52, 0x3a, 0xa5, 0x17, 0x18, 0x38, 0x55, 0xe3,
    0x4e, 0xcd, 0x84, 0x16, 0x01, 0x55, 0x0f, 0x98, 0xd1, 0x7d, 0x73, 0x97, 0xe6, 0x47, 0x4c, 0x60,
    0x72, 0x9a, 0xf0, 0xb7, 0xb0, 0xc3, 0x13, 0x61, 0x4f, 0x13, 0xc7, 0xf6, 0x94, 0x9b, 0xb0, 0x53,
    0xba, 0x02, 0x12, 0x40, 0xd5, 0xb6, 0x7d, 0x0f, 0x2b, 0xa3, 0xdb, 0xc5, 0x6e, 0x02, 0x65, 0xf3,
    0x67, 0xfb, 0x15, 0xb1, 0x63, 0xf8, 0xb1, 0xa4, 0x51, 0x36, 0xc5, 0xe6, 0xa6, 0x0d, 0x65, 0x6e,
    0xb2, 0x42, 0x20, 0x90, 0x6d, 0x29, 0x37, 0x8b, 0x4d, 0x13, 0xa1, 0xcb, 0xbe, 0xe5, 0x47, 0xb7,
    0x0c, 0x87, 0xc5, 0xb0, 0xed, 0x86, 0x4f, 0xff, 0x3a, 0xe0, 0xd5, 0x51, 0x8d, 0xec, 0xee, 0xd5,
    0xc0, 0x29, 0x85, 0x0a, 0x74, 0x6f, 0x43, 0x20, 0x68, 0x5e, 0x1a, 0x41, 0xf5, 0x02, 0xf4, 0xc8,
    0x1c, 0x2a, 0x6a, 0x7d, 0xf7, 0x2a, 0x9d, 0x0f, 0xfa, 0xae, 0x2b, 0x4d, 0x08, 0xcb, 0xd5, 0xd3,
    0xd3, 0xb0, 0x1e, 0x29, 0x3e, 0xdf, 0x7b, 0xab, 0x51, 0xe9, 0xb6, 0x18, 0x73, 0x86, 0x57, 0xae,
    0x89, 0xe2, 0x83, 0x4b, 0x7a, 0xf4, 0x06, 0xf1, 0xb2, 0x08, 0x09, 0x25, 0xdd, 0x69, 0x08, 0xe4,
    0x0f, 0xc4, 0x59, 0xd2, 0x06, 0xee, 0xc1, 0x4e, 0x62, 0x0b, 0x57, 0x8f, 0xe5, 0x85, 0x19, 0xcb,
    0x7d, 0x45, 0xe0, 0xa9, 0xcc, 0x63, 0x50, 0xaf, 0xe8, 0x04, 0xc7, 0x69, 0x5a, 0x62, 0xae, 0x72,
    0x21, 0x8b, 0x44, 0xc8, 0x90, 0xe9, 0xd5, 0xf4, 0xc7, 0xb7, 0xd6, 0xc9, 0x85, 0xbc, 0xd9, 0x49,
    0xe2, 0xc8, 0x00, 0x0c, 0x70, 0x4f, 0x5c, 0xfe, 0xc9, 0xc5, 0x5f, 0x4b, 0xcc, 0xac, 0xa1
};
#endif

PyTypeObject *init_QSvgRenderer(PyObject *module)
{
    if (SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX].type != nullptr)
        return SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX].type;

    Shiboken::AutoDecRef Sbk_QSvgRenderer_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QSvgRenderer_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSvgRenderer",
        "QSvgRenderer*",
        &Sbk_QSvgRenderer_spec,
        &Shiboken::callCppDestructor< QSvgRenderer >,
        Sbk_QSvgRenderer_Type_bases.object(),
        0);
    auto *pyType = Sbk_QSvgRenderer_TypeF(); // references _Sbk_QSvgRenderer_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSvgRenderer_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSvgRenderer_SignatureBytes, QSvgRenderer_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSvgRenderer_PropertyStrings);
    SbkPySide6_QtSvgTypeStructs[SBK_QSvgRenderer_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSvgRenderer_PythonToCpp_QSvgRenderer_PTR,
        is_QSvgRenderer_PythonToCpp_QSvgRenderer_PTR_Convertible,
        QSvgRenderer_PTR_CppToPython_QSvgRenderer);

    Shiboken::Conversions::registerConverterName(converter, "QSvgRenderer");
    Shiboken::Conversions::registerConverterName(converter, "QSvgRenderer*");
    Shiboken::Conversions::registerConverterName(converter, "QSvgRenderer&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSvgRenderer).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QSvgRendererWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QSvgRenderer_TypeF(), &Sbk_QSvgRenderer_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::QSvgRenderer::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QSvgRenderer::staticMetaObject, sizeof(QSvgRendererWrapper));

    return pyType;
}
