// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qttest_python.h"

// main header
#include "qsignalspy_wrapper.h"

// Extra includes
#include <pysidesignal.h>

// Argument includes
#include <QList>
#include <qbytearray.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSignalSpy_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSignalSpy >()))
        return -1;

    ::QSignalSpy *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QSignalSpy", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QSignalSpy::QSignalSpy(PySideSignalInstance)
    // 1: QSignalSpy::QSignalSpy(const QObject*,QMetaMethod)
    // 2: QSignalSpy::QSignalSpy(const QObject*,const char*)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        if (numArgs == 2
            && Shiboken::String::check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[1])))) {
            overloadId = 2; // QSignalSpy(const QObject*,const char*)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), (pyArgs[1])))) {
            overloadId = 1; // QSignalSpy(const QObject*,QMetaMethod)
        }
    } else if (numArgs == 1
        && PySide::Signal::checkInstanceType(pyArgs[0])) {
        overloadId = 0; // QSignalSpy(PySideSignalInstance)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QSignalSpy_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtTestTypeStructs[SBK_QSignalSpy_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QSignalSpy(PySideSignalInstance signal)
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QSignalSpy(PySideSignalInstance)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qttest.cpp (qsignalspy-signal)]
                auto *signalInst = reinterpret_cast<PySideSignalInstance *>(pyArgs[1-1]);
                PyObject *emitterPyObject = PySide::Signal::getObject(signalInst);
                ::QObject* emitter{nullptr};
                Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), emitterPyObject, &(emitter));
                QByteArray signature = PySide::Signal::getSignature(signalInst);
                if (!signature.isEmpty())
                    signature.prepend('2'); // SIGNAL() macro

                if (emitter == nullptr || signature.isEmpty()) {
                    QByteArray error = QByteArrayLiteral("Wrong parameter (")
                        + (pyArgs[1-1])->ob_type->tp_name
                        + QByteArrayLiteral(") passed, QSignalSpy requires a signal.");
                    PyErr_SetString(PyExc_ValueError, error.constData());
                    return -1;
                }
                cptr = new QSignalSpy(emitter, signature.constData());
                // END of custom code block [file: ../glue/qttest.cpp (qsignalspy-signal)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 1: // QSignalSpy(const QObject *obj, QMetaMethod signal)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QMetaMethod cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QSignalSpy(const QObject*,QMetaMethod)
                cptr = new ::QSignalSpy(cppArg0, cppArg1);
            }
            break;
        }
        case 2: // QSignalSpy(const QObject *obj, const char *aSignal)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            const char* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QSignalSpy(const QObject*,const char*)
                cptr = new ::QSignalSpy(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QSignalSpy >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QSignalSpy_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSignalSpyFunc_at(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSignalSpy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtTestTypeStructs[SBK_QSignalSpy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSignalSpy::at(qsizetype)const->QList<QVariant>
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // at(qsizetype)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "at", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QSignalSpy_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // at(qsizetype)const
            QList<QVariant> cppResult = const_cast<const ::QSignalSpy *>(cppSelf)->at(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtTestTypeConverters[SBK_QtTest_QList_QVariant_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSignalSpyFunc_count(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSignalSpy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtTestTypeStructs[SBK_QSignalSpy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // count()const
        qsizetype cppResult = const_cast<const ::QSignalSpy *>(cppSelf)->count();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSignalSpyFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSignalSpy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtTestTypeStructs[SBK_QSignalSpy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QSignalSpy *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSignalSpyFunc_signal(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSignalSpy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtTestTypeStructs[SBK_QSignalSpy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // signal()const
        QByteArray cppResult = const_cast<const ::QSignalSpy *>(cppSelf)->signal();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSignalSpyFunc_size(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSignalSpy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtTestTypeStructs[SBK_QSignalSpy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // size()const
        qsizetype cppResult = const_cast<const ::QSignalSpy *>(cppSelf)->size();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSignalSpyFunc_wait(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSignalSpy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtTestTypeStructs[SBK_QSignalSpy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSignalSpy::wait(int)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // wait(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "wait", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QSignalSpy_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // wait(int)
            bool cppResult = cppSelf->wait(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QSignalSpy_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSignalSpy_methods[] = {
    {"at", reinterpret_cast<PyCFunction>(Sbk_QSignalSpyFunc_at), METH_O, nullptr},
    {"count", reinterpret_cast<PyCFunction>(Sbk_QSignalSpyFunc_count), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QSignalSpyFunc_isValid), METH_NOARGS, nullptr},
    {"signal", reinterpret_cast<PyCFunction>(Sbk_QSignalSpyFunc_signal), METH_NOARGS, nullptr},
    {"size", reinterpret_cast<PyCFunction>(Sbk_QSignalSpyFunc_size), METH_NOARGS, nullptr},
    {"wait", reinterpret_cast<PyCFunction>(Sbk_QSignalSpyFunc_wait), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QSignalSpy_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSignalSpy_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSignalSpy_Type = nullptr;
static PyTypeObject *Sbk_QSignalSpy_TypeF(void)
{
    return _Sbk_QSignalSpy_Type;
}

static PyType_Slot Sbk_QSignalSpy_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSignalSpy_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSignalSpy_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSignalSpy_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSignalSpy_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSignalSpy_spec = {
    "2:PySide6.QtTest.QSignalSpy",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSignalSpy_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSignalSpy_PythonToCpp_QSignalSpy_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSignalSpy_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSignalSpy_PythonToCpp_QSignalSpy_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSignalSpy_TypeF()))
        return QSignalSpy_PythonToCpp_QSignalSpy_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSignalSpy_PTR_CppToPython_QSignalSpy(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QSignalSpy_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSignalSpy_SignatureStrings[] = {
    "2:PySide6.QtTest.QSignalSpy(self,signal:PySideSignalInstance)",
    "1:PySide6.QtTest.QSignalSpy(self,obj:PySide6.QtCore.QObject,signal:PySide6.QtCore.QMetaMethod)",
    "0:PySide6.QtTest.QSignalSpy(self,obj:PySide6.QtCore.QObject,aSignal:char*)",
    "PySide6.QtTest.QSignalSpy.at(self,arg__1:qsizetype)->QList[QVariant]",
    "PySide6.QtTest.QSignalSpy.count(self)->qsizetype",
    "PySide6.QtTest.QSignalSpy.isValid(self)->bool",
    "PySide6.QtTest.QSignalSpy.signal(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtTest.QSignalSpy.size(self)->qsizetype",
    "PySide6.QtTest.QSignalSpy.wait(self,timeout:int)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QSignalSpy_SignatureByteSize = 208;
static constexpr uint8_t QSignalSpy_SignatureBytes[208] = {
    0x78, 0xda, 0xa5, 0x90, 0x3d, 0x0b, 0xc2, 0x40, 0x0c, 0x86, 0xf7, 0xfe, 0x12, 0x2b, 0x5a, 0xd4,
    0xc1, 0xa1, 0x83, 0xa0, 0x4e, 0x82, 0xa2, 0x47, 0xc5, 0x45, 0x44, 0xd2, 0x36, 0xd6, 0x48, 0xbd,
    0xd3, 0xbb, 0x88, 0x9c, 0xbf, 0x5e, 0xf1, 0xac, 0x5f, 0x60, 0x45, 0x1c, 0x32, 0x84, 0x3c, 0xef,
    0x43, 0x92, 0x56, 0x38, 0xb1, 0x11, 0xa5, 0xd8, 0x0e, 0x04, 0x4f, 0xd1, 0x70, 0x20, 0x22, 0xca,
    0x24, 0xe4, 0xd1, 0xce, 0x56, 0x0c, 0xe6, 0xab, 0x9a, 0xb9, 0xb6, 0x37, 0xca, 0xcd, 0x06, 0xd2,
    0x30, 0xc8, 0x04, 0x7d, 0xaf, 0xf9, 0x2d, 0xad, 0xe2, 0xcd, 0x13, 0xd2, 0x57, 0x1a, 0x03, 0x31,
    0x8e, 0x37, 0x98, 0xf0, 0xab, 0xf8, 0x31, 0x1d, 0x21, 0xc3, 0xa5, 0xd6, 0x2a, 0xf5, 0xbd, 0xc6,
    0x1f, 0x7a, 0x70, 0x68, 0x98, 0xac, 0x41, 0x57, 0x7d, 0xef, 0xa3, 0x28, 0x00, 0x76, 0x2e, 0xd0,
    0xd9, 0x72, 0xd9, 0x0c, 0xf7, 0x86, 0x4e, 0xc8, 0x76, 0x87, 0x7e, 0xbd, 0x23, 0x86, 0x64, 0x78,
    0x2e, 0x66, 0xa0, 0x09, 0x24, 0x2f, 0x4a, 0x24, 0x89, 0x3a, 0x48, 0xe7, 0xb9, 0xc4, 0xee, 0x8a,
    0x92, 0x00, 0x99, 0x19, 0xe4, 0x94, 0x16, 0x91, 0x58, 0xa9, 0xbc, 0x84, 0x76, 0xbf, 0x2a, 0xe0,
    0xf7, 0x8b, 0x7b, 0x96, 0xb1, 0xab, 0x35, 0xd8, 0x52, 0xc3, 0x09, 0x7f, 0xd9, 0xef, 0x08, 0x74,
    0xfb, 0x0b, 0xd3, 0x16, 0xd5, 0x81, 0x43, 0x92, 0x5c, 0x2c, 0x7a, 0x06, 0x41, 0x4c, 0xc9, 0x9e
};
#endif

PyTypeObject *init_QSignalSpy(PyObject *module)
{
    if (SbkPySide6_QtTestTypeStructs[SBK_QSignalSpy_IDX].type != nullptr)
        return SbkPySide6_QtTestTypeStructs[SBK_QSignalSpy_IDX].type;

    Shiboken::AutoDecRef Sbk_QSignalSpy_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QSignalSpy_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSignalSpy",
        "QSignalSpy*",
        &Sbk_QSignalSpy_spec,
        &Shiboken::callCppDestructor< ::QSignalSpy >,
        Sbk_QSignalSpy_Type_bases.object(),
        0);
    auto *pyType = Sbk_QSignalSpy_TypeF(); // references _Sbk_QSignalSpy_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSignalSpy_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSignalSpy_SignatureBytes, QSignalSpy_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSignalSpy_PropertyStrings);
    SbkPySide6_QtTestTypeStructs[SBK_QSignalSpy_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSignalSpy_PythonToCpp_QSignalSpy_PTR,
        is_QSignalSpy_PythonToCpp_QSignalSpy_PTR_Convertible,
        QSignalSpy_PTR_CppToPython_QSignalSpy);

    Shiboken::Conversions::registerConverterName(converter, "QSignalSpy");
    Shiboken::Conversions::registerConverterName(converter, "QSignalSpy*");
    Shiboken::Conversions::registerConverterName(converter, "QSignalSpy&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSignalSpy).name());

    qRegisterMetaType< ::QSignalSpy *>();

    return pyType;
}
