// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qttexttospeech_python.h"

// main header
#include "qvoice_wrapper.h"

// Argument includes
#include <QString>
#include <QtTextToSpeech/qvoice.h>
#include <qdatastream.h>
#include <qlocale.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QVoice_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QVoice >()))
        return -1;

    ::QVoice *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QVoice", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QVoice::QVoice()
    // 1: QVoice::QVoice(QVoice)
    if (numArgs == 0) {
        overloadId = 0; // QVoice()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtTextToSpeechTypeStructs[SBK_QVoice_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QVoice(QVoice)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtTextToSpeechTypeStructs[SBK_QVoice_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtTextToSpeechTypeStructs[SBK_QVoice_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QVoice()
        {

            // QVoice()
            cptr = new ::QVoice();
            break;
        }
        case 1: // QVoice(const QVoice &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QVoice cppArg0_local;
            ::QVoice *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QVoice(QVoice)
                cptr = new ::QVoice(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QVoice >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtTextToSpeechTypeStructs[SBK_QVoice_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QVoiceFunc_age(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVoice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtTextToSpeechTypeStructs[SBK_QVoice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // age()const
        QVoice::Age cppResult = const_cast<const ::QVoice *>(cppSelf)->age();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtTextToSpeechTypeStructs[SBK_QVoice_Age_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVoiceFunc_ageName(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QVoice::ageName(QVoice::Age)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtTextToSpeechTypeStructs[SBK_QVoice_Age_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // ageName(QVoice::Age)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "ageName", errInfo, SbkPySide6_QtTextToSpeechTypeStructs[SBK_QVoice_IDX]);

    // Call function/method
    {
        ::QVoice::Age cppArg0{QVoice::Child};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // ageName(QVoice::Age)
            QString cppResult = ::QVoice::ageName(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVoiceFunc_gender(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVoice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtTextToSpeechTypeStructs[SBK_QVoice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // gender()const
        QVoice::Gender cppResult = const_cast<const ::QVoice *>(cppSelf)->gender();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtTextToSpeechTypeStructs[SBK_QVoice_Gender_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVoiceFunc_genderName(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QVoice::genderName(QVoice::Gender)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtTextToSpeechTypeStructs[SBK_QVoice_Gender_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // genderName(QVoice::Gender)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "genderName", errInfo, SbkPySide6_QtTextToSpeechTypeStructs[SBK_QVoice_IDX]);

    // Call function/method
    {
        ::QVoice::Gender cppArg0{QVoice::Male};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // genderName(QVoice::Gender)
            QString cppResult = ::QVoice::genderName(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVoiceFunc_language(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVoice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtTextToSpeechTypeStructs[SBK_QVoice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // language()const
        QLocale::Language cppResult = const_cast<const ::QVoice *>(cppSelf)->language();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Language_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVoiceFunc_locale(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVoice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtTextToSpeechTypeStructs[SBK_QVoice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // locale()const
        QLocale cppResult = const_cast<const ::QVoice *>(cppSelf)->locale();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVoiceFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVoice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtTextToSpeechTypeStructs[SBK_QVoice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // name()const
        QString cppResult = const_cast<const ::QVoice *>(cppSelf)->name();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVoiceFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVoice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtTextToSpeechTypeStructs[SBK_QVoice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QVoice::swap(QVoice&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtTextToSpeechTypeStructs[SBK_QVoice_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QVoice&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtTextToSpeechTypeStructs[SBK_QVoice_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QVoice cppArg0_local;
        ::QVoice *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QVoice&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QVoice__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QVoice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtTextToSpeechTypeStructs[SBK_QVoice_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtTextToSpeechTypeStructs[SBK_QVoice_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QVoice_PropertyStrings[] = {
    "age:",
    "gender:",
    "language:",
    "locale:",
    "name:",
    nullptr // Sentinel
};

static const char *Sbk_QVoice_EnumFlagInfo[] = {
    "Age:Enum",
    "Gender:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QVoice_methods[] = {
    {"age", reinterpret_cast<PyCFunction>(Sbk_QVoiceFunc_age), METH_NOARGS, nullptr},
    {"ageName", reinterpret_cast<PyCFunction>(Sbk_QVoiceFunc_ageName), METH_O|METH_STATIC, nullptr},
    {"gender", reinterpret_cast<PyCFunction>(Sbk_QVoiceFunc_gender), METH_NOARGS, nullptr},
    {"genderName", reinterpret_cast<PyCFunction>(Sbk_QVoiceFunc_genderName), METH_O|METH_STATIC, nullptr},
    {"language", reinterpret_cast<PyCFunction>(Sbk_QVoiceFunc_language), METH_NOARGS, nullptr},
    {"locale", reinterpret_cast<PyCFunction>(Sbk_QVoiceFunc_locale), METH_NOARGS, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_QVoiceFunc_name), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QVoiceFunc_swap), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QVoice__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QVoiceFunc___lshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtTextToSpeechTypeStructs[SBK_QVoice_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtTextToSpeechTypeStructs[SBK_QVoice_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVoice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtTextToSpeechTypeStructs[SBK_QVoice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rlshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QVoice::operator<<(QDataStream&)->QDataStream&
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // operator<<(QDataStream&,QVoice)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator<<", errInfo, SbkPySide6_QtTextToSpeechTypeStructs[SBK_QVoice_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator<<(QDataStream&,QVoice) [reverse operator]
                QDataStream & cppResult = (*cppArg0) << (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVoiceFunc___rshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtTextToSpeechTypeStructs[SBK_QVoice_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtTextToSpeechTypeStructs[SBK_QVoice_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVoice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtTextToSpeechTypeStructs[SBK_QVoice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rrshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QVoice::operator>>(QDataStream&)->QDataStream&
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // operator>>(QDataStream&,QVoice&)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator>>", errInfo, SbkPySide6_QtTextToSpeechTypeStructs[SBK_QVoice_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator>>(QDataStream&,QVoice&) [reverse operator]
                QDataStream & cppResult = (*cppArg0) >> (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

// Rich comparison
static PyObject * Sbk_QVoice_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QVoice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtTextToSpeechTypeStructs[SBK_QVoice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtTextToSpeechTypeStructs[SBK_QVoice_IDX]), (pyArg)))) {
                // operator!=(const QVoice &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QVoice cppArg0_local;
                ::QVoice *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtTextToSpeechTypeStructs[SBK_QVoice_IDX]), (pyArg)))) {
                // operator==(const QVoice &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QVoice cppArg0_local;
                ::QVoice *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QVoice_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QVoice_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QVoice__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVoice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtTextToSpeechTypeStructs[SBK_QVoice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QVoice_Type = nullptr;
static PyTypeObject *Sbk_QVoice_TypeF(void)
{
    return _Sbk_QVoice_Type;
}

static PyType_Slot Sbk_QVoice_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QVoice__repr__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QVoice_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QVoice_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QVoice_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QVoice_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QVoice_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_lshift,      reinterpret_cast<void *>(Sbk_QVoiceFunc___lshift__)},
    {Py_nb_rshift,      reinterpret_cast<void *>(Sbk_QVoiceFunc___rshift__)},
    {0, nullptr}
};
static PyType_Spec Sbk_QVoice_spec = {
    "2:PySide6.QtTextToSpeech.QVoice",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QVoice_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QVoice_Gender(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QVoice::Gender>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QVoice::Gender *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QVoice_Gender_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtTextToSpeechTypeStructs[SBK_QVoice_Gender_IDX])))
        return Enum_PythonToCpp_QVoice_Gender;
    return {};
}

static PyObject *QVoice_Gender_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QVoice::Gender>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QVoice::Gender *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtTextToSpeechTypeStructs[SBK_QVoice_Gender_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QVoice_Age(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QVoice::Age>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QVoice::Age *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QVoice_Age_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtTextToSpeechTypeStructs[SBK_QVoice_Age_IDX])))
        return Enum_PythonToCpp_QVoice_Age;
    return {};
}

static PyObject *QVoice_Age_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QVoice::Age>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QVoice::Age *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtTextToSpeechTypeStructs[SBK_QVoice_Age_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QVoice_PythonToCpp_QVoice_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QVoice_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QVoice_PythonToCpp_QVoice_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QVoice_TypeF()))
        return QVoice_PythonToCpp_QVoice_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QVoice_PTR_CppToPython_QVoice(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QVoice_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QVoice_COPY_CppToPython_QVoice(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QVoice *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QVoice_TypeF(), new ::QVoice(*source), true, true);
}

// Python to C++ copy conversion.
static void QVoice_PythonToCpp_QVoice_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QVoice *>(cppOut) = *reinterpret_cast< ::QVoice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtTextToSpeechTypeStructs[SBK_QVoice_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QVoice_PythonToCpp_QVoice_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QVoice_TypeF()))
        return QVoice_PythonToCpp_QVoice_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QVoice_SignatureStrings[] = {
    "1:PySide6.QtTextToSpeech.QVoice(self,*:KeywordOnly=None,name:QString=None,gender:QVoice.Gender=None,age:QVoice.Age=None,locale:QLocale=None,language:QLocale.Language=None)",
    "0:PySide6.QtTextToSpeech.QVoice(self,other:PySide6.QtTextToSpeech.QVoice,*:KeywordOnly=None,name:QString=None,gender:QVoice.Gender=None,age:QVoice.Age=None,locale:QLocale=None,language:QLocale.Language=None)",
    "PySide6.QtTextToSpeech.QVoice.age(self)->PySide6.QtTextToSpeech.QVoice.Age",
    "PySide6.QtTextToSpeech.QVoice.ageName(age:PySide6.QtTextToSpeech.QVoice.Age)->QString",
    "PySide6.QtTextToSpeech.QVoice.gender(self)->PySide6.QtTextToSpeech.QVoice.Gender",
    "PySide6.QtTextToSpeech.QVoice.genderName(gender:PySide6.QtTextToSpeech.QVoice.Gender)->QString",
    "PySide6.QtTextToSpeech.QVoice.language(self)->PySide6.QtCore.QLocale.Language",
    "PySide6.QtTextToSpeech.QVoice.locale(self)->PySide6.QtCore.QLocale",
    "PySide6.QtTextToSpeech.QVoice.name(self)->QString",
    "PySide6.QtTextToSpeech.QVoice.swap(self,other:PySide6.QtTextToSpeech.QVoice)",
    "PySide6.QtTextToSpeech.QVoice.__copy__(self)->typing.Self",
    "PySide6.QtTextToSpeech.QVoice.__lshift__(self,str:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "PySide6.QtTextToSpeech.QVoice.__rshift__(self,str:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "PySide6.QtTextToSpeech.QVoice.__ne__(self,rhs:PySide6.QtTextToSpeech.QVoice)->bool",
    "PySide6.QtTextToSpeech.QVoice.__eq__(self,rhs:PySide6.QtTextToSpeech.QVoice)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QVoice_SignatureByteSize = 295;
static constexpr uint8_t QVoice_SignatureBytes[295] = {
    0x78, 0xda, 0xcd, 0x92, 0x4f, 0x4b, 0x03, 0x31, 0x10, 0xc5, 0xef, 0x7e, 0x92, 0x56, 0xb6, 0xc1,
    0x5e, 0x3c, 0x2c, 0x58, 0x10, 0x05, 0x0f, 0x2d, 0xd5, 0x65, 0x8b, 0xd7, 0x25, 0xee, 0x4e, 0xb3,
    0x0b, 0x69, 0xb2, 0x26, 0x91, 0x9a, 0x6f, 0x6f, 0x9a, 0x3f, 0x28, 0x2a, 0x3b, 0xe9, 0x45, 0x3c,
    0x85, 0xbc, 0x4c, 0xde, 0xfc, 0xe6, 0x25, 0xcb, 0xf2, 0xc9, 0xd6, 0x43, 0x07, 0xd7, 0xa4, 0x32,
    0x3b, 0x78, 0x37, 0x3b, 0x59, 0x8f, 0x00, 0x6d, 0x4f, 0xaa, 0x67, 0x39, 0xb4, 0x30, 0xd3, 0xc0,
    0xf7, 0xc5, 0x65, 0xb9, 0x06, 0x7b, 0x94, 0xaa, 0x7b, 0x14, 0xdc, 0xde, 0x6c, 0xa5, 0x80, 0x42,
    0xd0, 0x03, 0x94, 0x55, 0x6d, 0xd4, 0x20, 0x58, 0x50, 0x18, 0x88, 0x0e, 0x54, 0x19, 0xee, 0x91,
    0x07, 0xbf, 0x0b, 0x27, 0x94, 0x41, 0x92, 0x6f, 0x19, 0x04, 0x8d, 0xcb, 0x96, 0x72, 0x27, 0x6f,
    0xfc, 0x1a, 0x35, 0x2a, 0xd8, 0x9b, 0x2f, 0x0e, 0x2a, 0xd9, 0x44, 0xc1, 0x1f, 0xcf, 0x2f, 0xae,
    0x72, 0x58, 0xa5, 0xe9, 0x1d, 0xc5, 0x64, 0xe1, 0x7f, 0x99, 0x67, 0x12, 0x92, 0xb8, 0x3a, 0x3f,
    0xd1, 0x7c, 0xb1, 0x9a, 0x2e, 0x74, 0x0c, 0xb8, 0xd5, 0xd6, 0xcd, 0x37, 0x3b, 0xb1, 0xa0, 0x5e,
    0xae, 0x5f, 0xcc, 0x01, 0x71, 0x0d, 0x01, 0xe5, 0x31, 0x86, 0xf8, 0xb2, 0x0c, 0x3d, 0x69, 0x0c,
    0x3f, 0xc7, 0x34, 0x9b, 0x37, 0x3d, 0xc7, 0x4f, 0xe2, 0x3b, 0xa9, 0x80, 0x7c, 0x7f, 0x24, 0xcc,
    0xcd, 0x57, 0x4f, 0x7b, 0x21, 0x16, 0xa7, 0x3f, 0x97, 0x0c, 0xf2, 0x46, 0xd0, 0x47, 0x3a, 0x66,
    0x7f, 0x73, 0xec, 0x83, 0x35, 0x4d, 0x2b, 0x47, 0xdb, 0x34, 0x09, 0xc1, 0xd8, 0xd1, 0x11, 0x90,
    0xda, 0xed, 0xd0, 0x9b, 0x5c, 0xf7, 0xc3, 0xde, 0xc4, 0xbb, 0x85, 0x36, 0x5f, 0x51, 0x42, 0x02,
    0xf7, 0xd4, 0x50, 0x37, 0x13, 0xd0, 0xc3, 0x2f, 0xf1, 0x7c, 0x1e, 0xa2, 0x9d, 0xd4, 0x9f, 0x75,
    0x12, 0x90, 0xba, 0xa8, 0x5e, 0x23, 0xd1, 0x2e, 0x56, 0x2f, 0x52, 0x72, 0xd4, 0x12, 0x5e, 0xcf,
    0xb6, 0xfc, 0x00, 0x63, 0xa6, 0xfc, 0xfb
};
#endif

PyTypeObject *init_QVoice(PyObject *module)
{
    if (SbkPySide6_QtTextToSpeechTypeStructs[SBK_QVoice_IDX].type != nullptr)
        return SbkPySide6_QtTextToSpeechTypeStructs[SBK_QVoice_IDX].type;

    Shiboken::AutoDecRef Sbk_QVoice_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QVoice_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QVoice",
        "QVoice",
        &Sbk_QVoice_spec,
        &Shiboken::callCppDestructor< ::QVoice >,
        Sbk_QVoice_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QVoice_TypeF(); // references _Sbk_QVoice_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QVoice_SignatureStrings);
#else
    InitSignatureBytes(pyType, QVoice_SignatureBytes, QVoice_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QVoice_PropertyStrings);
    SbkPySide6_QtTextToSpeechTypeStructs[SBK_QVoice_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QVoice_PythonToCpp_QVoice_PTR,
        is_QVoice_PythonToCpp_QVoice_PTR_Convertible,
        QVoice_PTR_CppToPython_QVoice,
        QVoice_COPY_CppToPython_QVoice);

    Shiboken::Conversions::registerConverterName(converter, "QVoice");
    Shiboken::Conversions::registerConverterName(converter, "QVoice*");
    Shiboken::Conversions::registerConverterName(converter, "QVoice&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QVoice).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QVoice_PythonToCpp_QVoice_COPY,
        is_QVoice_PythonToCpp_QVoice_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QVoice_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Gender'.
    const char *Gender_Initializer[] = {
        "Male",
        "Female",
        "Unknown",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Gender_InitializerValues[] = {
        uint8_t(QVoice::Gender::Male),   //  0x00  0
        uint8_t(QVoice::Gender::Female), //  0x01  1
        uint8_t(QVoice::Gender::Unknown) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QVoice_TypeF(),
        "2:PySide6.QtTextToSpeech.QVoice.Gender",
        Gender_Initializer, Gender_InitializerValues);
    SbkPySide6_QtTextToSpeechTypeStructs[SBK_QVoice_Gender_IDX].type = EType;
    // Register converter for enum 'QVoice::Gender'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QVoice_Gender_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QVoice_Gender,
            is_Enum_PythonToCpp_QVoice_Gender_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QVoice::Gender");
        Shiboken::Conversions::registerConverterAlias(converter, "Gender");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Gender' enum.

    // Initialization of enum 'Age'.
    const char *Age_Initializer[] = {
        "Child",
        "Teenager",
        "Adult",
        "Senior",
        "Other",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Age_InitializerValues[] = {
        uint8_t(QVoice::Age::Child),    //  0x00  0
        uint8_t(QVoice::Age::Teenager), //  0x01  1
        uint8_t(QVoice::Age::Adult),    //  0x02  2
        uint8_t(QVoice::Age::Senior),   //  0x03  3
        uint8_t(QVoice::Age::Other)     //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QVoice_TypeF(),
        "2:PySide6.QtTextToSpeech.QVoice.Age",
        Age_Initializer, Age_InitializerValues);
    SbkPySide6_QtTextToSpeechTypeStructs[SBK_QVoice_Age_IDX].type = EType;
    // Register converter for enum 'QVoice::Age'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QVoice_Age_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QVoice_Age,
            is_Enum_PythonToCpp_QVoice_Age_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QVoice::Age");
        Shiboken::Conversions::registerConverterAlias(converter, "Age");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Age' enum.

    qRegisterMetaType< ::QVoice::Gender >("QVoice::Gender");
    qRegisterMetaType< ::QVoice::Age >("QVoice::Age");

    return pyType;
}
