// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwebenginecore_python.h"

// main header
#include "qwebengineclientcertificateselection_wrapper.h"

// Argument includes
#include <QList>
#include <QtNetwork/qsslcertificate.h>
#include <QtWebEngineCore/qwebengineclientcertificateselection.h>
#include <qurl.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QWebEngineClientCertificateSelection_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QWebEngineClientCertificateSelection >()))
        return -1;

    ::QWebEngineClientCertificateSelection *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QWebEngineClientCertificateSelection", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QWebEngineClientCertificateSelection::QWebEngineClientCertificateSelection(QWebEngineClientCertificateSelection)
    if (numArgs == 1
        && (pyArgs[0] != Py_None && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineClientCertificateSelection_IDX]), (pyArgs[0]))))) {
        overloadId = 0; // QWebEngineClientCertificateSelection(QWebEngineClientCertificateSelection)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineClientCertificateSelection_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineClientCertificateSelection_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QWebEngineClientCertificateSelection *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QWebEngineClientCertificateSelection(QWebEngineClientCertificateSelection)
            cptr = new ::QWebEngineClientCertificateSelection(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QWebEngineClientCertificateSelection >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineClientCertificateSelection_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QWebEngineClientCertificateSelectionFunc_certificates(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineClientCertificateSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineClientCertificateSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // certificates()const
        QList<QSslCertificate> cppResult = const_cast<const ::QWebEngineClientCertificateSelection *>(cppSelf)->certificates();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtWebEngineCoreTypeConverters[SBK_QtWebEngineCore_QList_QSslCertificate_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineClientCertificateSelectionFunc_host(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineClientCertificateSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineClientCertificateSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // host()const
        QUrl cppResult = const_cast<const ::QWebEngineClientCertificateSelection *>(cppSelf)->host();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineClientCertificateSelectionFunc_select(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineClientCertificateSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineClientCertificateSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineClientCertificateSelection::select(QSslCertificate)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslCertificate_IDX]), (pyArg)))) {
        overloadId = 0; // select(QSslCertificate)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "select", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineClientCertificateSelection_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSslCertificate cppArg0_local;
        ::QSslCertificate *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // select(QSslCertificate)
            cppSelf->select(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineClientCertificateSelectionFunc_selectNone(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineClientCertificateSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineClientCertificateSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // selectNone()
        cppSelf->selectNone();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineClientCertificateSelection__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QWebEngineClientCertificateSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineClientCertificateSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineClientCertificateSelection_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QWebEngineClientCertificateSelection_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QWebEngineClientCertificateSelection_methods[] = {
    {"certificates", reinterpret_cast<PyCFunction>(Sbk_QWebEngineClientCertificateSelectionFunc_certificates), METH_NOARGS, nullptr},
    {"host", reinterpret_cast<PyCFunction>(Sbk_QWebEngineClientCertificateSelectionFunc_host), METH_NOARGS, nullptr},
    {"select", reinterpret_cast<PyCFunction>(Sbk_QWebEngineClientCertificateSelectionFunc_select), METH_O, nullptr},
    {"selectNone", reinterpret_cast<PyCFunction>(Sbk_QWebEngineClientCertificateSelectionFunc_selectNone), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QWebEngineClientCertificateSelection__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QWebEngineClientCertificateSelection_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QWebEngineClientCertificateSelection_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QWebEngineClientCertificateSelection_Type = nullptr;
static PyTypeObject *Sbk_QWebEngineClientCertificateSelection_TypeF(void)
{
    return _Sbk_QWebEngineClientCertificateSelection_Type;
}

static PyType_Slot Sbk_QWebEngineClientCertificateSelection_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QWebEngineClientCertificateSelection_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QWebEngineClientCertificateSelection_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QWebEngineClientCertificateSelection_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QWebEngineClientCertificateSelection_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QWebEngineClientCertificateSelection_spec = {
    "2:PySide6.QtWebEngineCore.QWebEngineClientCertificateSelection",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QWebEngineClientCertificateSelection_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QWebEngineClientCertificateSelection_PythonToCpp_QWebEngineClientCertificateSelection_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QWebEngineClientCertificateSelection_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QWebEngineClientCertificateSelection_PythonToCpp_QWebEngineClientCertificateSelection_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QWebEngineClientCertificateSelection_TypeF()))
        return QWebEngineClientCertificateSelection_PythonToCpp_QWebEngineClientCertificateSelection_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QWebEngineClientCertificateSelection_PTR_CppToPython_QWebEngineClientCertificateSelection(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QWebEngineClientCertificateSelection_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QWebEngineClientCertificateSelection_COPY_CppToPython_QWebEngineClientCertificateSelection(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QWebEngineClientCertificateSelection *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QWebEngineClientCertificateSelection_TypeF(), new ::QWebEngineClientCertificateSelection(*source), true, true);
}

// Python to C++ copy conversion.
static void QWebEngineClientCertificateSelection_PythonToCpp_QWebEngineClientCertificateSelection_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QWebEngineClientCertificateSelection *>(cppOut) = *reinterpret_cast< ::QWebEngineClientCertificateSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineClientCertificateSelection_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QWebEngineClientCertificateSelection_PythonToCpp_QWebEngineClientCertificateSelection_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QWebEngineClientCertificateSelection_TypeF()))
        return QWebEngineClientCertificateSelection_PythonToCpp_QWebEngineClientCertificateSelection_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QWebEngineClientCertificateSelection_SignatureStrings[] = {
    "PySide6.QtWebEngineCore.QWebEngineClientCertificateSelection(self,arg__1:PySide6.QtWebEngineCore.QWebEngineClientCertificateSelection)",
    "PySide6.QtWebEngineCore.QWebEngineClientCertificateSelection.certificates(self)->QList[PySide6.QtNetwork.QSslCertificate]",
    "PySide6.QtWebEngineCore.QWebEngineClientCertificateSelection.host(self)->PySide6.QtCore.QUrl",
    "PySide6.QtWebEngineCore.QWebEngineClientCertificateSelection.select(self,certificate:typing.Union[PySide6.QtNetwork.QSslCertificate, PySide6.QtCore.QIODevice])",
    "PySide6.QtWebEngineCore.QWebEngineClientCertificateSelection.selectNone(self)",
    "PySide6.QtWebEngineCore.QWebEngineClientCertificateSelection.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QWebEngineClientCertificateSelection_SignatureByteSize = 192;
static constexpr uint8_t QWebEngineClientCertificateSelection_SignatureBytes[192] = {
    0x78, 0xda, 0xad, 0x90, 0x41, 0x0b, 0x82, 0x40, 0x10, 0x85, 0xef, 0xfe, 0x8a, 0x8e, 0x09, 0xb6,
    0xd0, 0xa5, 0x83, 0x87, 0x2e, 0xd6, 0x21, 0x08, 0x53, 0x44, 0x3a, 0x84, 0x2c, 0xb6, 0x8d, 0x36,
    0xb4, 0xec, 0xca, 0xee, 0x50, 0xf8, 0xef, 0x13, 0x4d, 0x94, 0x2e, 0x1d, 0xb6, 0xdb, 0xcc, 0x30,
    0xf3, 0xcd, 0x7b, 0x2f, 0x69, 0x33, 0xbc, 0xc1, 0x86, 0xa5, 0x74, 0x86, 0xeb, 0x5e, 0xd5, 0xa8,
    0x20, 0xd2, 0x06, 0x58, 0x3a, 0xb5, 0x12, 0x41, 0x51, 0x04, 0x86, 0xb0, 0x42, 0x51, 0x12, 0x64,
    0x20, 0x41, 0x10, 0x6a, 0xb5, 0xb4, 0x20, 0xab, 0xa0, 0x34, 0x35, 0xe7, 0xeb, 0x30, 0x71, 0x00,
    0xf9, 0x9e, 0xcb, 0x35, 0x13, 0xd3, 0xd0, 0xf6, 0x9a, 0xfc, 0xd5, 0x36, 0x3d, 0xa2, 0xa5, 0xcb,
    0x84, 0x8d, 0x81, 0x5e, 0xda, 0x3c, 0x58, 0x9a, 0x59, 0x39, 0x83, 0x14, 0x6e, 0x9f, 0xef, 0xda,
    0xd2, 0xf8, 0x71, 0x02, 0x0d, 0xf7, 0xb9, 0x91, 0x6e, 0x70, 0xdb, 0x57, 0x43, 0xc8, 0x33, 0x8b,
    0x21, 0xb5, 0x0d, 0xaa, 0x9a, 0xe5, 0xaa, 0x5b, 0xfa, 0xed, 0x30, 0x58, 0x7c, 0x0b, 0x3b, 0x9c,
    0x76, 0xf0, 0x44, 0x01, 0x85, 0xff, 0x0f, 0x7d, 0xb1, 0x56, 0x30, 0x44, 0xe0, 0x46, 0xe3, 0x5c,
    0xe8, 0xa6, 0xe5, 0x7c, 0x8c, 0xf3, 0xe3, 0xb2, 0x5b, 0xa8, 0xbc, 0x37, 0xbe, 0x56, 0xfa, 0xb3
};
#endif

PyTypeObject *init_QWebEngineClientCertificateSelection(PyObject *module)
{
    if (SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineClientCertificateSelection_IDX].type != nullptr)
        return SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineClientCertificateSelection_IDX].type;

    Shiboken::AutoDecRef Sbk_QWebEngineClientCertificateSelection_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QWebEngineClientCertificateSelection_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QWebEngineClientCertificateSelection",
        "QWebEngineClientCertificateSelection",
        &Sbk_QWebEngineClientCertificateSelection_spec,
        &Shiboken::callCppDestructor< ::QWebEngineClientCertificateSelection >,
        Sbk_QWebEngineClientCertificateSelection_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QWebEngineClientCertificateSelection_TypeF(); // references _Sbk_QWebEngineClientCertificateSelection_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QWebEngineClientCertificateSelection_SignatureStrings);
#else
    InitSignatureBytes(pyType, QWebEngineClientCertificateSelection_SignatureBytes, QWebEngineClientCertificateSelection_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QWebEngineClientCertificateSelection_PropertyStrings);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineClientCertificateSelection_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QWebEngineClientCertificateSelection_PythonToCpp_QWebEngineClientCertificateSelection_PTR,
        is_QWebEngineClientCertificateSelection_PythonToCpp_QWebEngineClientCertificateSelection_PTR_Convertible,
        QWebEngineClientCertificateSelection_PTR_CppToPython_QWebEngineClientCertificateSelection,
        QWebEngineClientCertificateSelection_COPY_CppToPython_QWebEngineClientCertificateSelection);

    Shiboken::Conversions::registerConverterName(converter, "QWebEngineClientCertificateSelection");
    Shiboken::Conversions::registerConverterName(converter, "QWebEngineClientCertificateSelection*");
    Shiboken::Conversions::registerConverterName(converter, "QWebEngineClientCertificateSelection&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QWebEngineClientCertificateSelection).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QWebEngineClientCertificateSelection_PythonToCpp_QWebEngineClientCertificateSelection_COPY,
        is_QWebEngineClientCertificateSelection_PythonToCpp_QWebEngineClientCertificateSelection_COPY_Convertible);

    qRegisterMetaType< ::QWebEngineClientCertificateSelection >("QWebEngineClientCertificateSelection");

    return pyType;
}
