// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwebenginecore_python.h"

// main header
#include "qwebengineclientcertificatestore_wrapper.h"

// Argument includes
#include <QList>
#include <QtNetwork/qsslcertificate.h>
#include <QtNetwork/qsslkey.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QWebEngineClientCertificateStoreFunc_add(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineClientCertificateStore *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineClientCertificateStore_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "add", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QWebEngineClientCertificateStore::add(QSslCertificate,QSslKey)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslCertificate_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslKey_IDX]), (pyArgs[1])))) {
        overloadId = 0; // add(QSslCertificate,QSslKey)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "add", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineClientCertificateStore_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QSslCertificate cppArg0_local;
        ::QSslCertificate *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QSslKey cppArg1_local;
        ::QSslKey *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // add(QSslCertificate,QSslKey)
            cppSelf->add(*cppArg0, *cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineClientCertificateStoreFunc_certificates(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineClientCertificateStore *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineClientCertificateStore_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // certificates()const
        QList<QSslCertificate> cppResult = const_cast<const ::QWebEngineClientCertificateStore *>(cppSelf)->certificates();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtWebEngineCoreTypeConverters[SBK_QtWebEngineCore_QList_QSslCertificate_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineClientCertificateStoreFunc_clear(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineClientCertificateStore *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineClientCertificateStore_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clear()
        cppSelf->clear();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineClientCertificateStoreFunc_remove(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineClientCertificateStore *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineClientCertificateStore_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineClientCertificateStore::remove(QSslCertificate)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslCertificate_IDX]), (pyArg)))) {
        overloadId = 0; // remove(QSslCertificate)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "remove", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineClientCertificateStore_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSslCertificate cppArg0_local;
        ::QSslCertificate *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // remove(QSslCertificate)
            cppSelf->remove(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QWebEngineClientCertificateStore_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QWebEngineClientCertificateStore_methods[] = {
    {"add", reinterpret_cast<PyCFunction>(Sbk_QWebEngineClientCertificateStoreFunc_add), METH_VARARGS, nullptr},
    {"certificates", reinterpret_cast<PyCFunction>(Sbk_QWebEngineClientCertificateStoreFunc_certificates), METH_NOARGS, nullptr},
    {"clear", reinterpret_cast<PyCFunction>(Sbk_QWebEngineClientCertificateStoreFunc_clear), METH_NOARGS, nullptr},
    {"remove", reinterpret_cast<PyCFunction>(Sbk_QWebEngineClientCertificateStoreFunc_remove), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QWebEngineClientCertificateStore_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QWebEngineClientCertificateStore_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QWebEngineClientCertificateStore_Type = nullptr;
static PyTypeObject *Sbk_QWebEngineClientCertificateStore_TypeF(void)
{
    return _Sbk_QWebEngineClientCertificateStore_Type;
}

static PyType_Slot Sbk_QWebEngineClientCertificateStore_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(SbkDeallocWrapperWithPrivateDtor)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QWebEngineClientCertificateStore_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QWebEngineClientCertificateStore_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QWebEngineClientCertificateStore_methods)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QWebEngineClientCertificateStore_spec = {
    "2:PySide6.QtWebEngineCore.QWebEngineClientCertificateStore",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QWebEngineClientCertificateStore_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QWebEngineClientCertificateStore_PythonToCpp_QWebEngineClientCertificateStore_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QWebEngineClientCertificateStore_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QWebEngineClientCertificateStore_PythonToCpp_QWebEngineClientCertificateStore_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QWebEngineClientCertificateStore_TypeF()))
        return QWebEngineClientCertificateStore_PythonToCpp_QWebEngineClientCertificateStore_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QWebEngineClientCertificateStore_PTR_CppToPython_QWebEngineClientCertificateStore(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QWebEngineClientCertificateStore_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QWebEngineClientCertificateStore_SignatureStrings[] = {
    "PySide6.QtWebEngineCore.QWebEngineClientCertificateStore.add(self,certificate:typing.Union[PySide6.QtNetwork.QSslCertificate, PySide6.QtCore.QIODevice],privateKey:typing.Union[PySide6.QtNetwork.QSslKey, Qt.HANDLE])",
    "PySide6.QtWebEngineCore.QWebEngineClientCertificateStore.certificates(self)->QList[PySide6.QtNetwork.QSslCertificate]",
    "PySide6.QtWebEngineCore.QWebEngineClientCertificateStore.clear(self)",
    "PySide6.QtWebEngineCore.QWebEngineClientCertificateStore.remove(self,certificate:typing.Union[PySide6.QtNetwork.QSslCertificate, PySide6.QtCore.QIODevice])",
    nullptr}; // Sentinel
#else
static constexpr size_t QWebEngineClientCertificateStore_SignatureByteSize = 180;
static constexpr uint8_t QWebEngineClientCertificateStore_SignatureBytes[180] = {
    0x78, 0xda, 0xb5, 0x91, 0x41, 0x0b, 0x82, 0x40, 0x10, 0x46, 0xef, 0xfd, 0x0a, 0x8f, 0x09, 0xdb,
    0x1e, 0x3b, 0x74, 0x08, 0x42, 0x85, 0x22, 0x31, 0x17, 0x89, 0x0e, 0xe1, 0xc1, 0x74, 0x94, 0xa1,
    0x6d, 0x57, 0x76, 0x07, 0xc3, 0x7f, 0x9f, 0x25, 0xa4, 0xb7, 0xc2, 0xe8, 0xb8, 0xcc, 0xe3, 0x7d,
    0x3c, 0x36, 0x6e, 0x13, 0x2c, 0x60, 0xc9, 0x05, 0x9d, 0xe0, 0x12, 0xa8, 0x0a, 0x15, 0x78, 0xda,
    0x00, 0x17, 0xc3, 0x53, 0x22, 0x28, 0xf2, 0xc0, 0x10, 0x96, 0x98, 0x67, 0x04, 0x09, 0x3d, 0x81,
    0xac, 0x28, 0xe6, 0x16, 0x64, 0xc9, 0xf2, 0xe1, 0xb2, 0xa2, 0xb6, 0x46, 0x55, 0xf1, 0xa3, 0x42,
    0xad, 0xce, 0xf1, 0x5b, 0x1d, 0x01, 0xdd, 0xb5, 0xb9, 0x72, 0x91, 0x58, 0x39, 0x12, 0x31, 0x67,
    0x40, 0xfa, 0xd1, 0xdd, 0xc1, 0x87, 0x06, 0x73, 0x48, 0x59, 0x6d, 0xb0, 0xe9, 0x90, 0x3d, 0xb4,
    0xdf, 0x48, 0x3b, 0x8c, 0x39, 0x82, 0xf8, 0x76, 0x13, 0xf9, 0x61, 0x90, 0xba, 0xb3, 0x78, 0x6a,
    0xd6, 0xa8, 0xc6, 0xbe, 0xfa, 0xdc, 0xc5, 0x5a, 0x84, 0x68, 0xe9, 0x73, 0x4e, 0xfa, 0xc3, 0xaa,
    0x84, 0xcc, 0xf4, 0x73, 0xd3, 0x25, 0x06, 0x6e, 0xba, 0x81, 0x3f, 0x7e, 0x8a, 0x3b, 0x7b, 0x00,
    0xac, 0x4a, 0xcd, 0x4e
};
#endif

PyTypeObject *init_QWebEngineClientCertificateStore(PyObject *module)
{
    if (SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineClientCertificateStore_IDX].type != nullptr)
        return SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineClientCertificateStore_IDX].type;

    Shiboken::AutoDecRef Sbk_QWebEngineClientCertificateStore_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QWebEngineClientCertificateStore_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QWebEngineClientCertificateStore",
        "QWebEngineClientCertificateStore*",
        &Sbk_QWebEngineClientCertificateStore_spec,
        nullptr,
        Sbk_QWebEngineClientCertificateStore_Type_bases.object(),
        0);
    auto *pyType = Sbk_QWebEngineClientCertificateStore_TypeF(); // references _Sbk_QWebEngineClientCertificateStore_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QWebEngineClientCertificateStore_SignatureStrings);
#else
    InitSignatureBytes(pyType, QWebEngineClientCertificateStore_SignatureBytes, QWebEngineClientCertificateStore_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QWebEngineClientCertificateStore_PropertyStrings);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineClientCertificateStore_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QWebEngineClientCertificateStore_PythonToCpp_QWebEngineClientCertificateStore_PTR,
        is_QWebEngineClientCertificateStore_PythonToCpp_QWebEngineClientCertificateStore_PTR_Convertible,
        QWebEngineClientCertificateStore_PTR_CppToPython_QWebEngineClientCertificateStore);

    Shiboken::Conversions::registerConverterName(converter, "QWebEngineClientCertificateStore");
    Shiboken::Conversions::registerConverterName(converter, "QWebEngineClientCertificateStore*");
    Shiboken::Conversions::registerConverterName(converter, "QWebEngineClientCertificateStore&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QWebEngineClientCertificateStore).name());

    qRegisterMetaType< ::QWebEngineClientCertificateStore *>();

    return pyType;
}
