// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwebenginecore_python.h"

// main header
#include "qwebenginedownloadrequest_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QtWebEngineCore/qwebenginedownloadrequest.h>
#include <QtWebEngineCore/qwebenginepage.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qurl.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QWebEngineDownloadRequestWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

void QWebEngineDownloadRequestWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWebEngineDownloadRequest", funcName);
        return;
    }
}

void QWebEngineDownloadRequestWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWebEngineDownloadRequest", funcName);
        return;
    }
}

void QWebEngineDownloadRequestWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWebEngineDownloadRequest", funcName);
        return;
    }
}

void QWebEngineDownloadRequestWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWebEngineDownloadRequest", funcName);
        return;
    }
}

bool QWebEngineDownloadRequestWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWebEngineDownloadRequest", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QWebEngineDownloadRequest", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QWebEngineDownloadRequestWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWebEngineDownloadRequest", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QWebEngineDownloadRequest", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QWebEngineDownloadRequestWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWebEngineDownloadRequest", funcName);
        return;
    }
}

const QMetaObject *QWebEngineDownloadRequestWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QWebEngineDownloadRequest::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QWebEngineDownloadRequestWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QWebEngineDownloadRequest::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QWebEngineDownloadRequestWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QWebEngineDownloadRequestWrapper *>(this));
    return QWebEngineDownloadRequest::qt_metacast(_clname);
}

QWebEngineDownloadRequestWrapper::~QWebEngineDownloadRequestWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QWebEngineDownloadRequestFunc_accept(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineDownloadRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // accept()
        cppSelf->accept();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineDownloadRequestFunc_cancel(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineDownloadRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cancel()
        cppSelf->cancel();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineDownloadRequestFunc_downloadDirectory(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineDownloadRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // downloadDirectory()const
        QString cppResult = const_cast<const ::QWebEngineDownloadRequest *>(cppSelf)->downloadDirectory();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineDownloadRequestFunc_downloadFileName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineDownloadRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // downloadFileName()const
        QString cppResult = const_cast<const ::QWebEngineDownloadRequest *>(cppSelf)->downloadFileName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineDownloadRequestFunc_id(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineDownloadRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // id()const
        quint32 cppResult = const_cast<const ::QWebEngineDownloadRequest *>(cppSelf)->id();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineDownloadRequestFunc_interruptReason(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineDownloadRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // interruptReason()const
        QWebEngineDownloadRequest::DownloadInterruptReason cppResult = const_cast<const ::QWebEngineDownloadRequest *>(cppSelf)->interruptReason();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_DownloadInterruptReason_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineDownloadRequestFunc_interruptReasonString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineDownloadRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // interruptReasonString()const
        QString cppResult = const_cast<const ::QWebEngineDownloadRequest *>(cppSelf)->interruptReasonString();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineDownloadRequestFunc_isFinished(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineDownloadRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isFinished()const
        bool cppResult = const_cast<const ::QWebEngineDownloadRequest *>(cppSelf)->isFinished();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineDownloadRequestFunc_isPaused(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineDownloadRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isPaused()const
        bool cppResult = const_cast<const ::QWebEngineDownloadRequest *>(cppSelf)->isPaused();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineDownloadRequestFunc_isSavePageDownload(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineDownloadRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isSavePageDownload()const
        bool cppResult = const_cast<const ::QWebEngineDownloadRequest *>(cppSelf)->isSavePageDownload();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineDownloadRequestFunc_mimeType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineDownloadRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // mimeType()const
        QString cppResult = const_cast<const ::QWebEngineDownloadRequest *>(cppSelf)->mimeType();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineDownloadRequestFunc_page(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineDownloadRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // page()const
        QWebEnginePage * cppResult = const_cast<const ::QWebEngineDownloadRequest *>(cppSelf)->page();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineDownloadRequestFunc_pause(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineDownloadRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pause()
        cppSelf->pause();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineDownloadRequestFunc_receivedBytes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineDownloadRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // receivedBytes()const
        qint64 cppResult = const_cast<const ::QWebEngineDownloadRequest *>(cppSelf)->receivedBytes();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineDownloadRequestFunc_resume(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineDownloadRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // resume()
        cppSelf->resume();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineDownloadRequestFunc_savePageFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineDownloadRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // savePageFormat()const
        QWebEngineDownloadRequest::SavePageFormat cppResult = const_cast<const ::QWebEngineDownloadRequest *>(cppSelf)->savePageFormat();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_SavePageFormat_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineDownloadRequestFunc_setDownloadDirectory(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineDownloadRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineDownloadRequest::setDownloadDirectory(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setDownloadDirectory(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDownloadDirectory", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDownloadDirectory(QString)
            cppSelf->setDownloadDirectory(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineDownloadRequestFunc_setDownloadFileName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineDownloadRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineDownloadRequest::setDownloadFileName(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setDownloadFileName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDownloadFileName", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDownloadFileName(QString)
            cppSelf->setDownloadFileName(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineDownloadRequestFunc_setSavePageFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineDownloadRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineDownloadRequest::setSavePageFormat(QWebEngineDownloadRequest::SavePageFormat)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_SavePageFormat_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setSavePageFormat(QWebEngineDownloadRequest::SavePageFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSavePageFormat", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_IDX]);

    // Call function/method
    {
        ::QWebEngineDownloadRequest::SavePageFormat cppArg0{QWebEngineDownloadRequest::SingleHtmlSaveFormat};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSavePageFormat(QWebEngineDownloadRequest::SavePageFormat)
            cppSelf->setSavePageFormat(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineDownloadRequestFunc_state(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineDownloadRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // state()const
        QWebEngineDownloadRequest::DownloadState cppResult = const_cast<const ::QWebEngineDownloadRequest *>(cppSelf)->state();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_DownloadState_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineDownloadRequestFunc_suggestedFileName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineDownloadRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // suggestedFileName()const
        QString cppResult = const_cast<const ::QWebEngineDownloadRequest *>(cppSelf)->suggestedFileName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineDownloadRequestFunc_totalBytes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineDownloadRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // totalBytes()const
        qint64 cppResult = const_cast<const ::QWebEngineDownloadRequest *>(cppSelf)->totalBytes();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineDownloadRequestFunc_url(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineDownloadRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // url()const
        QUrl cppResult = const_cast<const ::QWebEngineDownloadRequest *>(cppSelf)->url();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QWebEngineDownloadRequest_PropertyStrings[] = {
    "downloadDirectory::",
    "downloadFileName::",
    "id:",
    "interruptReason:",
    "interruptReasonString:",
    "isFinished:",
    "isPaused:",
    "isSavePageDownload:",
    "mimeType:",
    "receivedBytes:",
    "savePageFormat::",
    "state:",
    "suggestedFileName:",
    "totalBytes:",
    "url:",
    nullptr // Sentinel
};

static const char *Sbk_QWebEngineDownloadRequest_EnumFlagInfo[] = {
    "DownloadInterruptReason:Enum",
    "DownloadState:Enum",
    "SavePageFormat:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QWebEngineDownloadRequest_methods[] = {
    {"accept", reinterpret_cast<PyCFunction>(Sbk_QWebEngineDownloadRequestFunc_accept), METH_NOARGS, nullptr},
    {"cancel", reinterpret_cast<PyCFunction>(Sbk_QWebEngineDownloadRequestFunc_cancel), METH_NOARGS, nullptr},
    {"downloadDirectory", reinterpret_cast<PyCFunction>(Sbk_QWebEngineDownloadRequestFunc_downloadDirectory), METH_NOARGS, nullptr},
    {"downloadFileName", reinterpret_cast<PyCFunction>(Sbk_QWebEngineDownloadRequestFunc_downloadFileName), METH_NOARGS, nullptr},
    {"id", reinterpret_cast<PyCFunction>(Sbk_QWebEngineDownloadRequestFunc_id), METH_NOARGS, nullptr},
    {"interruptReason", reinterpret_cast<PyCFunction>(Sbk_QWebEngineDownloadRequestFunc_interruptReason), METH_NOARGS, nullptr},
    {"interruptReasonString", reinterpret_cast<PyCFunction>(Sbk_QWebEngineDownloadRequestFunc_interruptReasonString), METH_NOARGS, nullptr},
    {"isFinished", reinterpret_cast<PyCFunction>(Sbk_QWebEngineDownloadRequestFunc_isFinished), METH_NOARGS, nullptr},
    {"isPaused", reinterpret_cast<PyCFunction>(Sbk_QWebEngineDownloadRequestFunc_isPaused), METH_NOARGS, nullptr},
    {"isSavePageDownload", reinterpret_cast<PyCFunction>(Sbk_QWebEngineDownloadRequestFunc_isSavePageDownload), METH_NOARGS, nullptr},
    {"mimeType", reinterpret_cast<PyCFunction>(Sbk_QWebEngineDownloadRequestFunc_mimeType), METH_NOARGS, nullptr},
    {"page", reinterpret_cast<PyCFunction>(Sbk_QWebEngineDownloadRequestFunc_page), METH_NOARGS, nullptr},
    {"pause", reinterpret_cast<PyCFunction>(Sbk_QWebEngineDownloadRequestFunc_pause), METH_NOARGS, nullptr},
    {"receivedBytes", reinterpret_cast<PyCFunction>(Sbk_QWebEngineDownloadRequestFunc_receivedBytes), METH_NOARGS, nullptr},
    {"resume", reinterpret_cast<PyCFunction>(Sbk_QWebEngineDownloadRequestFunc_resume), METH_NOARGS, nullptr},
    {"savePageFormat", reinterpret_cast<PyCFunction>(Sbk_QWebEngineDownloadRequestFunc_savePageFormat), METH_NOARGS, nullptr},
    {"setDownloadDirectory", reinterpret_cast<PyCFunction>(Sbk_QWebEngineDownloadRequestFunc_setDownloadDirectory), METH_O, nullptr},
    {"setDownloadFileName", reinterpret_cast<PyCFunction>(Sbk_QWebEngineDownloadRequestFunc_setDownloadFileName), METH_O, nullptr},
    {"setSavePageFormat", reinterpret_cast<PyCFunction>(Sbk_QWebEngineDownloadRequestFunc_setSavePageFormat), METH_O, nullptr},
    {"state", reinterpret_cast<PyCFunction>(Sbk_QWebEngineDownloadRequestFunc_state), METH_NOARGS, nullptr},
    {"suggestedFileName", reinterpret_cast<PyCFunction>(Sbk_QWebEngineDownloadRequestFunc_suggestedFileName), METH_NOARGS, nullptr},
    {"totalBytes", reinterpret_cast<PyCFunction>(Sbk_QWebEngineDownloadRequestFunc_totalBytes), METH_NOARGS, nullptr},
    {"url", reinterpret_cast<PyCFunction>(Sbk_QWebEngineDownloadRequestFunc_url), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QWebEngineDownloadRequest_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QWebEngineDownloadRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QWebEngineDownloadRequestWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QWebEngineDownloadRequest_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QWebEngineDownloadRequest_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QWebEngineDownloadRequest_Type = nullptr;
static PyTypeObject *Sbk_QWebEngineDownloadRequest_TypeF(void)
{
    return _Sbk_QWebEngineDownloadRequest_Type;
}

static PyType_Slot Sbk_QWebEngineDownloadRequest_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QWebEngineDownloadRequest_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QWebEngineDownloadRequest_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QWebEngineDownloadRequest_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QWebEngineDownloadRequest_methods)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QWebEngineDownloadRequest_spec = {
    "2:PySide6.QtWebEngineCore.QWebEngineDownloadRequest",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QWebEngineDownloadRequest_slots
};

} //extern "C"

static void *Sbk_QWebEngineDownloadRequest_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QWebEngineDownloadRequest *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QWebEngineDownloadRequest_DownloadState(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWebEngineDownloadRequest::DownloadState>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QWebEngineDownloadRequest::DownloadState *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QWebEngineDownloadRequest_DownloadState_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_DownloadState_IDX])))
        return Enum_PythonToCpp_QWebEngineDownloadRequest_DownloadState;
    return {};
}

static PyObject *QWebEngineDownloadRequest_DownloadState_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QWebEngineDownloadRequest::DownloadState>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QWebEngineDownloadRequest::DownloadState *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_DownloadState_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QWebEngineDownloadRequest_SavePageFormat(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWebEngineDownloadRequest::SavePageFormat>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QWebEngineDownloadRequest::SavePageFormat *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QWebEngineDownloadRequest_SavePageFormat_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_SavePageFormat_IDX])))
        return Enum_PythonToCpp_QWebEngineDownloadRequest_SavePageFormat;
    return {};
}

static PyObject *QWebEngineDownloadRequest_SavePageFormat_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QWebEngineDownloadRequest::SavePageFormat>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QWebEngineDownloadRequest::SavePageFormat *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_SavePageFormat_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QWebEngineDownloadRequest_DownloadInterruptReason(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWebEngineDownloadRequest::DownloadInterruptReason>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QWebEngineDownloadRequest::DownloadInterruptReason *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QWebEngineDownloadRequest_DownloadInterruptReason_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_DownloadInterruptReason_IDX])))
        return Enum_PythonToCpp_QWebEngineDownloadRequest_DownloadInterruptReason;
    return {};
}

static PyObject *QWebEngineDownloadRequest_DownloadInterruptReason_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QWebEngineDownloadRequest::DownloadInterruptReason>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QWebEngineDownloadRequest::DownloadInterruptReason *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_DownloadInterruptReason_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QWebEngineDownloadRequest_PythonToCpp_QWebEngineDownloadRequest_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QWebEngineDownloadRequest_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QWebEngineDownloadRequest_PythonToCpp_QWebEngineDownloadRequest_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QWebEngineDownloadRequest_TypeF()))
        return QWebEngineDownloadRequest_PythonToCpp_QWebEngineDownloadRequest_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QWebEngineDownloadRequest_PTR_CppToPython_QWebEngineDownloadRequest(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QWebEngineDownloadRequest *>(const_cast<void *>(cppIn)), Sbk_QWebEngineDownloadRequest_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QWebEngineDownloadRequest_SignatureStrings[] = {
    "PySide6.QtWebEngineCore.QWebEngineDownloadRequest.accept(self)",
    "PySide6.QtWebEngineCore.QWebEngineDownloadRequest.cancel(self)",
    "PySide6.QtWebEngineCore.QWebEngineDownloadRequest.downloadDirectory(self)->QString",
    "PySide6.QtWebEngineCore.QWebEngineDownloadRequest.downloadFileName(self)->QString",
    "PySide6.QtWebEngineCore.QWebEngineDownloadRequest.id(self)->quint32",
    "PySide6.QtWebEngineCore.QWebEngineDownloadRequest.interruptReason(self)->PySide6.QtWebEngineCore.QWebEngineDownloadRequest.DownloadInterruptReason",
    "PySide6.QtWebEngineCore.QWebEngineDownloadRequest.interruptReasonString(self)->QString",
    "PySide6.QtWebEngineCore.QWebEngineDownloadRequest.isFinished(self)->bool",
    "PySide6.QtWebEngineCore.QWebEngineDownloadRequest.isPaused(self)->bool",
    "PySide6.QtWebEngineCore.QWebEngineDownloadRequest.isSavePageDownload(self)->bool",
    "PySide6.QtWebEngineCore.QWebEngineDownloadRequest.mimeType(self)->QString",
    "PySide6.QtWebEngineCore.QWebEngineDownloadRequest.page(self)->PySide6.QtWebEngineCore.QWebEnginePage",
    "PySide6.QtWebEngineCore.QWebEngineDownloadRequest.pause(self)",
    "PySide6.QtWebEngineCore.QWebEngineDownloadRequest.receivedBytes(self)->qint64",
    "PySide6.QtWebEngineCore.QWebEngineDownloadRequest.resume(self)",
    "PySide6.QtWebEngineCore.QWebEngineDownloadRequest.savePageFormat(self)->PySide6.QtWebEngineCore.QWebEngineDownloadRequest.SavePageFormat",
    "PySide6.QtWebEngineCore.QWebEngineDownloadRequest.setDownloadDirectory(self,directory:QString)",
    "PySide6.QtWebEngineCore.QWebEngineDownloadRequest.setDownloadFileName(self,fileName:QString)",
    "PySide6.QtWebEngineCore.QWebEngineDownloadRequest.setSavePageFormat(self,format:PySide6.QtWebEngineCore.QWebEngineDownloadRequest.SavePageFormat)",
    "PySide6.QtWebEngineCore.QWebEngineDownloadRequest.state(self)->PySide6.QtWebEngineCore.QWebEngineDownloadRequest.DownloadState",
    "PySide6.QtWebEngineCore.QWebEngineDownloadRequest.suggestedFileName(self)->QString",
    "PySide6.QtWebEngineCore.QWebEngineDownloadRequest.totalBytes(self)->qint64",
    "PySide6.QtWebEngineCore.QWebEngineDownloadRequest.url(self)->PySide6.QtCore.QUrl",
    nullptr}; // Sentinel
#else
static constexpr size_t QWebEngineDownloadRequest_SignatureByteSize = 310;
static constexpr uint8_t QWebEngineDownloadRequest_SignatureBytes[310] = {
    0x78, 0xda, 0xad, 0x95, 0x3f, 0x6f, 0x83, 0x30, 0x10, 0xc5, 0xf7, 0x7c, 0x92, 0x46, 0xa2, 0x0c,
    0x6d, 0x95, 0x21, 0x43, 0x87, 0x36, 0x45, 0xea, 0x52, 0x41, 0x68, 0xd5, 0xd9, 0xc1, 0x0f, 0x6a,
    0xc9, 0xd8, 0xc4, 0x3e, 0xa7, 0xe2, 0xdb, 0x97, 0x94, 0x3f, 0x12, 0x4a, 0x87, 0xc6, 0x66, 0x82,
    0x27, 0x74, 0x3f, 0x1f, 0x8f, 0x7b, 0x47, 0xda, 0xe6, 0x82, 0x63, 0x13, 0x67, 0xf4, 0x89, 0xc3,
    0x8b, 0xaa, 0x84, 0xc2, 0xb3, 0x36, 0x88, 0xb3, 0x49, 0xee, 0xf4, 0xb7, 0x92, 0x9a, 0xf1, 0x3d,
    0x8e, 0x0e, 0x96, 0x62, 0x56, 0x14, 0x68, 0xe8, 0xc6, 0x42, 0x96, 0xeb, 0x55, 0x7a, 0x75, 0x79,
    0xc1, 0x54, 0x01, 0xe9, 0x5d, 0xce, 0x07, 0xbd, 0x13, 0x06, 0x05, 0x69, 0xd3, 0xf6, 0xa4, 0xdb,
    0xc7, 0x2c, 0x27, 0x23, 0x54, 0x15, 0x80, 0x4c, 0x84, 0xc4, 0x1b, 0xab, 0x11, 0x4e, 0x14, 0x7c,
    0x64, 0x1c, 0x9d, 0x50, 0x74, 0x7f, 0xe7, 0xc3, 0x50, 0x04, 0x63, 0x5c, 0x43, 0x7b, 0x30, 0xab,
    0xd5, 0x08, 0xbc, 0x1e, 0x34, 0xea, 0xd7, 0x39, 0x30, 0xbc, 0xa5, 0xde, 0x9e, 0x05, 0xdc, 0xb2,
    0x89, 0x50, 0xc2, 0x7e, 0x61, 0x72, 0xed, 0xa0, 0xb5, 0xf4, 0x02, 0xa5, 0xcc, 0xd9, 0x05, 0x30,
    0x39, 0x3b, 0x21, 0x65, 0xd5, 0xf4, 0x24, 0x10, 0x58, 0x8b, 0x1a, 0xef, 0x6d, 0xb3, 0xc0, 0x60,
    0x35, 0x5d, 0x53, 0xff, 0x9f, 0x84, 0xf3, 0x2b, 0x78, 0x1d, 0xd2, 0x99, 0xe8, 0x1d, 0xd0, 0x2e,
    0x96, 0x10, 0x27, 0xf0, 0xa7, 0x96, 0x60, 0xa7, 0x18, 0x74, 0xa3, 0xb3, 0x79, 0xf0, 0xa2, 0x59,
    0x57, 0xfb, 0x37, 0x63, 0x87, 0x0f, 0x99, 0x68, 0x53, 0x33, 0xf2, 0xcf, 0x50, 0x3e, 0xe3, 0xf8,
    0x34, 0x02, 0xda, 0xfd, 0xb9, 0xb9, 0x22, 0x3e, 0xca, 0xed, 0x30, 0x16, 0xeb, 0x30, 0xfc, 0x6c,
    0x8b, 0x45, 0xe5, 0xa0, 0x02, 0xe1, 0xf9, 0xa5, 0x8f, 0x51, 0xf9, 0x7b, 0xbf, 0x0d, 0x35, 0xd3,
    0xab, 0x23, 0x62, 0x84, 0xf0, 0x8d, 0x98, 0x9f, 0x31, 0x3e, 0xc7, 0xbb, 0xaa, 0xea, 0xae, 0x58,
    0xf0, 0x8f, 0x41, 0x9a, 0x98, 0x5c, 0x26, 0x32, 0xce, 0xc8, 0x4b, 0x6b, 0xfa, 0x9a, 0x0f, 0x23,
    0x57, 0x3f, 0xc3, 0x06, 0xf0, 0x9a
};
#endif

PyTypeObject *init_QWebEngineDownloadRequest(PyObject *module)
{
    if (SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_IDX].type != nullptr)
        return SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_IDX].type;

    Shiboken::AutoDecRef Sbk_QWebEngineDownloadRequest_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QWebEngineDownloadRequest_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QWebEngineDownloadRequest",
        "QWebEngineDownloadRequest*",
        &Sbk_QWebEngineDownloadRequest_spec,
        &Shiboken::callCppDestructor< QWebEngineDownloadRequest >,
        Sbk_QWebEngineDownloadRequest_Type_bases.object(),
        0);
    auto *pyType = Sbk_QWebEngineDownloadRequest_TypeF(); // references _Sbk_QWebEngineDownloadRequest_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QWebEngineDownloadRequest_SignatureStrings);
#else
    InitSignatureBytes(pyType, QWebEngineDownloadRequest_SignatureBytes, QWebEngineDownloadRequest_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QWebEngineDownloadRequest_PropertyStrings);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QWebEngineDownloadRequest_PythonToCpp_QWebEngineDownloadRequest_PTR,
        is_QWebEngineDownloadRequest_PythonToCpp_QWebEngineDownloadRequest_PTR_Convertible,
        QWebEngineDownloadRequest_PTR_CppToPython_QWebEngineDownloadRequest);

    Shiboken::Conversions::registerConverterName(converter, "QWebEngineDownloadRequest");
    Shiboken::Conversions::registerConverterName(converter, "QWebEngineDownloadRequest*");
    Shiboken::Conversions::registerConverterName(converter, "QWebEngineDownloadRequest&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QWebEngineDownloadRequest).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QWebEngineDownloadRequestWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QWebEngineDownloadRequest_TypeF(), &Sbk_QWebEngineDownloadRequest_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QWebEngineDownloadRequest_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'DownloadState'.
    const char *DownloadState_Initializer[] = {
        "DownloadRequested",
        "DownloadInProgress",
        "DownloadCompleted",
        "DownloadCancelled",
        "DownloadInterrupted",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t DownloadState_InitializerValues[] = {
        uint8_t(QWebEngineDownloadRequest::DownloadState::DownloadRequested),  //  0x00  0
        uint8_t(QWebEngineDownloadRequest::DownloadState::DownloadInProgress), //  0x01  1
        uint8_t(QWebEngineDownloadRequest::DownloadState::DownloadCompleted),  //  0x02  2
        uint8_t(QWebEngineDownloadRequest::DownloadState::DownloadCancelled),  //  0x03  3
        uint8_t(QWebEngineDownloadRequest::DownloadState::DownloadInterrupted) //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWebEngineDownloadRequest_TypeF(),
        "2:PySide6.QtWebEngineCore.QWebEngineDownloadRequest.DownloadState",
        DownloadState_Initializer, DownloadState_InitializerValues);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_DownloadState_IDX].type = EType;
    // Register converter for enum 'QWebEngineDownloadRequest::DownloadState'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWebEngineDownloadRequest_DownloadState_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QWebEngineDownloadRequest_DownloadState,
            is_Enum_PythonToCpp_QWebEngineDownloadRequest_DownloadState_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QWebEngineDownloadRequest::DownloadState");
        Shiboken::Conversions::registerConverterAlias(converter, "DownloadState");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'DownloadState' enum.

    // Initialization of enum 'SavePageFormat'.
    const char *SavePageFormat_Initializer[] = {
        "UnknownSaveFormat",
        "SingleHtmlSaveFormat",
        "CompleteHtmlSaveFormat",
        "MimeHtmlSaveFormat",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t SavePageFormat_InitializerValues[] = {
        int8_t(QWebEngineDownloadRequest::SavePageFormat::UnknownSaveFormat),      // -0x01 -1
        int8_t(QWebEngineDownloadRequest::SavePageFormat::SingleHtmlSaveFormat),   //  0x00  0
        int8_t(QWebEngineDownloadRequest::SavePageFormat::CompleteHtmlSaveFormat), //  0x01  1
        int8_t(QWebEngineDownloadRequest::SavePageFormat::MimeHtmlSaveFormat)      //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWebEngineDownloadRequest_TypeF(),
        "2:PySide6.QtWebEngineCore.QWebEngineDownloadRequest.SavePageFormat",
        SavePageFormat_Initializer, SavePageFormat_InitializerValues);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_SavePageFormat_IDX].type = EType;
    // Register converter for enum 'QWebEngineDownloadRequest::SavePageFormat'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWebEngineDownloadRequest_SavePageFormat_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QWebEngineDownloadRequest_SavePageFormat,
            is_Enum_PythonToCpp_QWebEngineDownloadRequest_SavePageFormat_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QWebEngineDownloadRequest::SavePageFormat");
        Shiboken::Conversions::registerConverterAlias(converter, "SavePageFormat");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'SavePageFormat' enum.

    // Initialization of enum 'DownloadInterruptReason'.
    const char *DownloadInterruptReason_Initializer[] = {
        "NoReason",
        "FileFailed",
        "FileAccessDenied",
        "FileNoSpace",
        "FileNameTooLong",
        "FileTooLarge",
        "FileVirusInfected",
        "FileTransientError",
        "FileBlocked",
        "FileSecurityCheckFailed",
        "FileTooShort",
        "FileHashMismatch",
        "NetworkFailed",
        "NetworkTimeout",
        "NetworkDisconnected",
        "NetworkServerDown",
        "NetworkInvalidRequest",
        "ServerFailed",
        "ServerBadContent",
        "ServerUnauthorized",
        "ServerCertProblem",
        "ServerForbidden",
        "ServerUnreachable",
        "UserCanceled",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t DownloadInterruptReason_InitializerValues[] = {
        uint8_t(QWebEngineDownloadRequest::DownloadInterruptReason::NoReason),                //  0x00  0
        uint8_t(QWebEngineDownloadRequest::DownloadInterruptReason::FileFailed),              //  0x01  1
        uint8_t(QWebEngineDownloadRequest::DownloadInterruptReason::FileAccessDenied),        //  0x02  2
        uint8_t(QWebEngineDownloadRequest::DownloadInterruptReason::FileNoSpace),             //  0x03  3
        uint8_t(QWebEngineDownloadRequest::DownloadInterruptReason::FileNameTooLong),         //  0x05  5
        uint8_t(QWebEngineDownloadRequest::DownloadInterruptReason::FileTooLarge),            //  0x06  6
        uint8_t(QWebEngineDownloadRequest::DownloadInterruptReason::FileVirusInfected),       //  0x07  7
        uint8_t(QWebEngineDownloadRequest::DownloadInterruptReason::FileTransientError),      //  0x0a  10
        uint8_t(QWebEngineDownloadRequest::DownloadInterruptReason::FileBlocked),             //  0x0b  11
        uint8_t(QWebEngineDownloadRequest::DownloadInterruptReason::FileSecurityCheckFailed), //  0x0c  12
        uint8_t(QWebEngineDownloadRequest::DownloadInterruptReason::FileTooShort),            //  0x0d  13
        uint8_t(QWebEngineDownloadRequest::DownloadInterruptReason::FileHashMismatch),        //  0x0e  14
        uint8_t(QWebEngineDownloadRequest::DownloadInterruptReason::NetworkFailed),           //  0x14  20
        uint8_t(QWebEngineDownloadRequest::DownloadInterruptReason::NetworkTimeout),          //  0x15  21
        uint8_t(QWebEngineDownloadRequest::DownloadInterruptReason::NetworkDisconnected),     //  0x16  22
        uint8_t(QWebEngineDownloadRequest::DownloadInterruptReason::NetworkServerDown),       //  0x17  23
        uint8_t(QWebEngineDownloadRequest::DownloadInterruptReason::NetworkInvalidRequest),   //  0x18  24
        uint8_t(QWebEngineDownloadRequest::DownloadInterruptReason::ServerFailed),            //  0x1e  30
        uint8_t(QWebEngineDownloadRequest::DownloadInterruptReason::ServerBadContent),        //  0x21  33
        uint8_t(QWebEngineDownloadRequest::DownloadInterruptReason::ServerUnauthorized),      //  0x22  34
        uint8_t(QWebEngineDownloadRequest::DownloadInterruptReason::ServerCertProblem),       //  0x23  35
        uint8_t(QWebEngineDownloadRequest::DownloadInterruptReason::ServerForbidden),         //  0x24  36
        uint8_t(QWebEngineDownloadRequest::DownloadInterruptReason::ServerUnreachable),       //  0x25  37
        uint8_t(QWebEngineDownloadRequest::DownloadInterruptReason::UserCanceled)             //  0x28  40
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWebEngineDownloadRequest_TypeF(),
        "2:PySide6.QtWebEngineCore.QWebEngineDownloadRequest.DownloadInterruptReason",
        DownloadInterruptReason_Initializer, DownloadInterruptReason_InitializerValues);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_DownloadInterruptReason_IDX].type = EType;
    // Register converter for enum 'QWebEngineDownloadRequest::DownloadInterruptReason'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWebEngineDownloadRequest_DownloadInterruptReason_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QWebEngineDownloadRequest_DownloadInterruptReason,
            is_Enum_PythonToCpp_QWebEngineDownloadRequest_DownloadInterruptReason_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QWebEngineDownloadRequest::DownloadInterruptReason");
        Shiboken::Conversions::registerConverterAlias(converter, "DownloadInterruptReason");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'DownloadInterruptReason' enum.

    PySide::Signal::registerSignals(pyType, &::QWebEngineDownloadRequest::staticMetaObject);
    qRegisterMetaType< ::QWebEngineDownloadRequest::DownloadState >("QWebEngineDownloadRequest::DownloadState");
    qRegisterMetaType< ::QWebEngineDownloadRequest::SavePageFormat >("QWebEngineDownloadRequest::SavePageFormat");
    qRegisterMetaType< ::QWebEngineDownloadRequest::DownloadInterruptReason >("QWebEngineDownloadRequest::DownloadInterruptReason");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QWebEngineDownloadRequest::staticMetaObject, sizeof(QWebEngineDownloadRequestWrapper));

    return pyType;
}
