// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwebenginecore_python.h"

// main header
#include "qwebenginefilesystemaccessrequest_wrapper.h"

// Argument includes
#include <QtWebEngineCore/qwebenginefilesystemaccessrequest.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qurl.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QWebEngineFileSystemAccessRequest_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QWebEngineFileSystemAccessRequest >()))
        return -1;

    ::QWebEngineFileSystemAccessRequest *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QWebEngineFileSystemAccessRequest", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QWebEngineFileSystemAccessRequest::QWebEngineFileSystemAccessRequest(QWebEngineFileSystemAccessRequest)
    if (numArgs == 1
        && (pyArgs[0] != Py_None && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFileSystemAccessRequest_IDX]), (pyArgs[0]))))) {
        overloadId = 0; // QWebEngineFileSystemAccessRequest(QWebEngineFileSystemAccessRequest)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFileSystemAccessRequest_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFileSystemAccessRequest_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QWebEngineFileSystemAccessRequest *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QWebEngineFileSystemAccessRequest(QWebEngineFileSystemAccessRequest)
            cptr = new ::QWebEngineFileSystemAccessRequest(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QWebEngineFileSystemAccessRequest >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFileSystemAccessRequest_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QWebEngineFileSystemAccessRequestFunc_accept(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineFileSystemAccessRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFileSystemAccessRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // accept()
        cppSelf->accept();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineFileSystemAccessRequestFunc_accessFlags(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineFileSystemAccessRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFileSystemAccessRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // accessFlags()const
        QFlags<QWebEngineFileSystemAccessRequest::AccessFlag> cppResult = const_cast<const ::QWebEngineFileSystemAccessRequest *>(cppSelf)->accessFlags();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QFlags_QWebEngineFileSystemAccessRequest_AccessFlag_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineFileSystemAccessRequestFunc_filePath(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineFileSystemAccessRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFileSystemAccessRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // filePath()const
        QUrl cppResult = const_cast<const ::QWebEngineFileSystemAccessRequest *>(cppSelf)->filePath();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineFileSystemAccessRequestFunc_handleType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineFileSystemAccessRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFileSystemAccessRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // handleType()const
        QWebEngineFileSystemAccessRequest::HandleType cppResult = const_cast<const ::QWebEngineFileSystemAccessRequest *>(cppSelf)->handleType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFileSystemAccessRequest_HandleType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineFileSystemAccessRequestFunc_origin(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineFileSystemAccessRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFileSystemAccessRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // origin()const
        QUrl cppResult = const_cast<const ::QWebEngineFileSystemAccessRequest *>(cppSelf)->origin();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineFileSystemAccessRequestFunc_reject(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineFileSystemAccessRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFileSystemAccessRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // reject()
        cppSelf->reject();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineFileSystemAccessRequest__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QWebEngineFileSystemAccessRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFileSystemAccessRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFileSystemAccessRequest_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QWebEngineFileSystemAccessRequest_PropertyStrings[] = {
    "accessFlags:",
    "filePath:",
    "handleType:",
    "origin:",
    nullptr // Sentinel
};

static const char *Sbk_QWebEngineFileSystemAccessRequest_EnumFlagInfo[] = {
    "AccessFlag:Flag:AccessFlags",
    "HandleType:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QWebEngineFileSystemAccessRequest_methods[] = {
    {"accept", reinterpret_cast<PyCFunction>(Sbk_QWebEngineFileSystemAccessRequestFunc_accept), METH_NOARGS, nullptr},
    {"accessFlags", reinterpret_cast<PyCFunction>(Sbk_QWebEngineFileSystemAccessRequestFunc_accessFlags), METH_NOARGS, nullptr},
    {"filePath", reinterpret_cast<PyCFunction>(Sbk_QWebEngineFileSystemAccessRequestFunc_filePath), METH_NOARGS, nullptr},
    {"handleType", reinterpret_cast<PyCFunction>(Sbk_QWebEngineFileSystemAccessRequestFunc_handleType), METH_NOARGS, nullptr},
    {"origin", reinterpret_cast<PyCFunction>(Sbk_QWebEngineFileSystemAccessRequestFunc_origin), METH_NOARGS, nullptr},
    {"reject", reinterpret_cast<PyCFunction>(Sbk_QWebEngineFileSystemAccessRequestFunc_reject), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QWebEngineFileSystemAccessRequest__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QWebEngineFileSystemAccessRequest_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QWebEngineFileSystemAccessRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFileSystemAccessRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFileSystemAccessRequest_IDX]), (pyArg)))) {
                // operator!=(const QWebEngineFileSystemAccessRequest &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QWebEngineFileSystemAccessRequest *cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFileSystemAccessRequest_IDX]), (pyArg)))) {
                // operator==(const QWebEngineFileSystemAccessRequest &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QWebEngineFileSystemAccessRequest *cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QWebEngineFileSystemAccessRequest_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QWebEngineFileSystemAccessRequest_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QWebEngineFileSystemAccessRequest_Type = nullptr;
static PyTypeObject *Sbk_QWebEngineFileSystemAccessRequest_TypeF(void)
{
    return _Sbk_QWebEngineFileSystemAccessRequest_Type;
}

static PyType_Slot Sbk_QWebEngineFileSystemAccessRequest_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QWebEngineFileSystemAccessRequest_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QWebEngineFileSystemAccessRequest_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QWebEngineFileSystemAccessRequest_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QWebEngineFileSystemAccessRequest_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QWebEngineFileSystemAccessRequest_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QWebEngineFileSystemAccessRequest_spec = {
    "2:PySide6.QtWebEngineCore.QWebEngineFileSystemAccessRequest",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QWebEngineFileSystemAccessRequest_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QWebEngineFileSystemAccessRequest_HandleType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWebEngineFileSystemAccessRequest::HandleType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QWebEngineFileSystemAccessRequest::HandleType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QWebEngineFileSystemAccessRequest_HandleType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFileSystemAccessRequest_HandleType_IDX])))
        return Enum_PythonToCpp_QWebEngineFileSystemAccessRequest_HandleType;
    return {};
}

static PyObject *QWebEngineFileSystemAccessRequest_HandleType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QWebEngineFileSystemAccessRequest::HandleType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QWebEngineFileSystemAccessRequest::HandleType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFileSystemAccessRequest_HandleType_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QWebEngineFileSystemAccessRequest_AccessFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWebEngineFileSystemAccessRequest::AccessFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QWebEngineFileSystemAccessRequest::AccessFlag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QWebEngineFileSystemAccessRequest_AccessFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFileSystemAccessRequest_AccessFlag_IDX])))
        return Enum_PythonToCpp_QWebEngineFileSystemAccessRequest_AccessFlag;
    return {};
}

static PyObject *QWebEngineFileSystemAccessRequest_AccessFlag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QWebEngineFileSystemAccessRequest::AccessFlag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QWebEngineFileSystemAccessRequest::AccessFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFileSystemAccessRequest_AccessFlag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QWebEngineFileSystemAccessRequest_AccessFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QWebEngineFileSystemAccessRequest::AccessFlag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QWebEngineFileSystemAccessRequest::AccessFlag> *>(cppOut) = value;

}

static PyObject *QWebEngineFileSystemAccessRequest_AccessFlag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QWebEngineFileSystemAccessRequest::AccessFlag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFileSystemAccessRequest_AccessFlag_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QWebEngineFileSystemAccessRequest_PythonToCpp_QWebEngineFileSystemAccessRequest_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QWebEngineFileSystemAccessRequest_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QWebEngineFileSystemAccessRequest_PythonToCpp_QWebEngineFileSystemAccessRequest_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QWebEngineFileSystemAccessRequest_TypeF()))
        return QWebEngineFileSystemAccessRequest_PythonToCpp_QWebEngineFileSystemAccessRequest_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QWebEngineFileSystemAccessRequest_PTR_CppToPython_QWebEngineFileSystemAccessRequest(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QWebEngineFileSystemAccessRequest_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QWebEngineFileSystemAccessRequest_COPY_CppToPython_QWebEngineFileSystemAccessRequest(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QWebEngineFileSystemAccessRequest *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QWebEngineFileSystemAccessRequest_TypeF(), new ::QWebEngineFileSystemAccessRequest(*source), true, true);
}

// Python to C++ copy conversion.
static void QWebEngineFileSystemAccessRequest_PythonToCpp_QWebEngineFileSystemAccessRequest_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QWebEngineFileSystemAccessRequest *>(cppOut) = *reinterpret_cast< ::QWebEngineFileSystemAccessRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFileSystemAccessRequest_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QWebEngineFileSystemAccessRequest_PythonToCpp_QWebEngineFileSystemAccessRequest_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QWebEngineFileSystemAccessRequest_TypeF()))
        return QWebEngineFileSystemAccessRequest_PythonToCpp_QWebEngineFileSystemAccessRequest_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QWebEngineFileSystemAccessRequest_SignatureStrings[] = {
    "PySide6.QtWebEngineCore.QWebEngineFileSystemAccessRequest(self,other:PySide6.QtWebEngineCore.QWebEngineFileSystemAccessRequest,*:KeywordOnly=None,origin:QUrl=None,filePath:QUrl=None,handleType:QWebEngineFileSystemAccessRequest.HandleType=None,accessFlags:PySide6.QtWebEngineCore.QWebEngineFileSystemAccessRequest.AccessFlag=None)",
    "PySide6.QtWebEngineCore.QWebEngineFileSystemAccessRequest.accept(self)",
    "PySide6.QtWebEngineCore.QWebEngineFileSystemAccessRequest.accessFlags(self)->PySide6.QtWebEngineCore.QWebEngineFileSystemAccessRequest.AccessFlag",
    "PySide6.QtWebEngineCore.QWebEngineFileSystemAccessRequest.filePath(self)->PySide6.QtCore.QUrl",
    "PySide6.QtWebEngineCore.QWebEngineFileSystemAccessRequest.handleType(self)->PySide6.QtWebEngineCore.QWebEngineFileSystemAccessRequest.HandleType",
    "PySide6.QtWebEngineCore.QWebEngineFileSystemAccessRequest.origin(self)->PySide6.QtCore.QUrl",
    "PySide6.QtWebEngineCore.QWebEngineFileSystemAccessRequest.reject(self)",
    "PySide6.QtWebEngineCore.QWebEngineFileSystemAccessRequest.__copy__(self)->typing.Self",
    "PySide6.QtWebEngineCore.QWebEngineFileSystemAccessRequest.__ne__(self,rhs:PySide6.QtWebEngineCore.QWebEngineFileSystemAccessRequest)->bool",
    "PySide6.QtWebEngineCore.QWebEngineFileSystemAccessRequest.__eq__(self,rhs:PySide6.QtWebEngineCore.QWebEngineFileSystemAccessRequest)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QWebEngineFileSystemAccessRequest_SignatureByteSize = 244;
static constexpr uint8_t QWebEngineFileSystemAccessRequest_SignatureBytes[244] = {
    0x78, 0xda, 0xb5, 0x93, 0x51, 0x6b, 0xc2, 0x30, 0x10, 0xc7, 0xdf, 0xf7, 0x49, 0x36, 0xa9, 0x79,
    0xf4, 0xa1, 0xe0, 0xa0, 0xc8, 0x64, 0x20, 0xcc, 0xd6, 0x4e, 0xf6, 0x58, 0x6a, 0xfb, 0xb7, 0xcd,
    0x88, 0x49, 0x4d, 0x22, 0x23, 0xdf, 0xde, 0xac, 0xd1, 0x3a, 0xd8, 0xc3, 0xa0, 0xe7, 0x1e, 0x73,
    0xc9, 0xfd, 0xf2, 0xbb, 0xdc, 0x25, 0x75, 0x39, 0xaf, 0x31, 0x63, 0x99, 0xfd, 0xc0, 0xee, 0x45,
    0x36, 0x5c, 0x62, 0xa1, 0x34, 0x58, 0x36, 0x2c, 0x97, 0x5c, 0x20, 0x77, 0xc6, 0xe2, 0x90, 0x54,
    0x15, 0x8c, 0xd9, 0xe0, 0x78, 0x82, 0xb1, 0x8f, 0x06, 0x62, 0x1f, 0x29, 0xdb, 0x42, 0xc7, 0xe9,
    0x58, 0x48, 0x34, 0x89, 0x57, 0x70, 0x5f, 0x4a, 0xd7, 0x6b, 0x29, 0xdc, 0xfc, 0x4d, 0x49, 0x44,
    0x4a, 0x73, 0x9f, 0x11, 0x67, 0x5b, 0x2d, 0x42, 0x60, 0xef, 0x73, 0xd3, 0xd2, 0xb6, 0x3f, 0x42,
    0x6d, 0x29, 0x6b, 0x81, 0x77, 0xd7, 0x21, 0xfe, 0xf3, 0x0e, 0xf6, 0x3a, 0x1c, 0x0e, 0xc9, 0x65,
    0xbf, 0xbb, 0x14, 0x65, 0x63, 0xc6, 0x9b, 0xb3, 0x64, 0xa0, 0xf4, 0xd4, 0xa7, 0x87, 0xf1, 0xa8,
    0x6f, 0xa1, 0x2e, 0x3c, 0x28, 0x15, 0x73, 0xa9, 0x2b, 0xb0, 0xa6, 0xcf, 0xf7, 0x28, 0x8f, 0x60,
    0x74, 0xed, 0xdc, 0x6f, 0x9d, 0x00, 0xf0, 0xfd, 0x24, 0xd0, 0x6f, 0x43, 0x40, 0x2f, 0xf7, 0x36,
    0x23, 0x04, 0xa1, 0x30, 0xb9, 0xff, 0x53, 0xac, 0xc6, 0x27, 0x2a, 0xfa, 0x8c, 0x14, 0x45, 0xa5,
    0x3a, 0x57, 0x14, 0x57, 0x49, 0xeb, 0x3a, 0x2e, 0x1b, 0x96, 0xfb, 0x15, 0x89, 0x2a, 0x71, 0x61,
    0x46, 0xba, 0x25, 0xfc, 0x2a, 0x6f, 0xb4, 0x53, 0x4a, 0x90, 0x54, 0x70, 0xbc, 0xab, 0xca, 0x19,
    0xf1, 0x8b, 0xe7, 0x2c
};
#endif

PyTypeObject *init_QWebEngineFileSystemAccessRequest(PyObject *module)
{
    if (SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFileSystemAccessRequest_IDX].type != nullptr)
        return SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFileSystemAccessRequest_IDX].type;

    Shiboken::AutoDecRef Sbk_QWebEngineFileSystemAccessRequest_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QWebEngineFileSystemAccessRequest_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QWebEngineFileSystemAccessRequest",
        "QWebEngineFileSystemAccessRequest",
        &Sbk_QWebEngineFileSystemAccessRequest_spec,
        &Shiboken::callCppDestructor< ::QWebEngineFileSystemAccessRequest >,
        Sbk_QWebEngineFileSystemAccessRequest_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QWebEngineFileSystemAccessRequest_TypeF(); // references _Sbk_QWebEngineFileSystemAccessRequest_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QWebEngineFileSystemAccessRequest_SignatureStrings);
#else
    InitSignatureBytes(pyType, QWebEngineFileSystemAccessRequest_SignatureBytes, QWebEngineFileSystemAccessRequest_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QWebEngineFileSystemAccessRequest_PropertyStrings);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFileSystemAccessRequest_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QWebEngineFileSystemAccessRequest_PythonToCpp_QWebEngineFileSystemAccessRequest_PTR,
        is_QWebEngineFileSystemAccessRequest_PythonToCpp_QWebEngineFileSystemAccessRequest_PTR_Convertible,
        QWebEngineFileSystemAccessRequest_PTR_CppToPython_QWebEngineFileSystemAccessRequest,
        QWebEngineFileSystemAccessRequest_COPY_CppToPython_QWebEngineFileSystemAccessRequest);

    Shiboken::Conversions::registerConverterName(converter, "QWebEngineFileSystemAccessRequest");
    Shiboken::Conversions::registerConverterName(converter, "QWebEngineFileSystemAccessRequest*");
    Shiboken::Conversions::registerConverterName(converter, "QWebEngineFileSystemAccessRequest&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QWebEngineFileSystemAccessRequest).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QWebEngineFileSystemAccessRequest_PythonToCpp_QWebEngineFileSystemAccessRequest_COPY,
        is_QWebEngineFileSystemAccessRequest_PythonToCpp_QWebEngineFileSystemAccessRequest_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QWebEngineFileSystemAccessRequest_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'HandleType'.
    const char *HandleType_Initializer[] = {
        "File",
        "Directory",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t HandleType_InitializerValues[] = {
        uint8_t(QWebEngineFileSystemAccessRequest::HandleType::File),     //  0x00  0
        uint8_t(QWebEngineFileSystemAccessRequest::HandleType::Directory) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWebEngineFileSystemAccessRequest_TypeF(),
        "2:PySide6.QtWebEngineCore.QWebEngineFileSystemAccessRequest.HandleType",
        HandleType_Initializer, HandleType_InitializerValues);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFileSystemAccessRequest_HandleType_IDX].type = EType;
    // Register converter for enum 'QWebEngineFileSystemAccessRequest::HandleType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWebEngineFileSystemAccessRequest_HandleType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QWebEngineFileSystemAccessRequest_HandleType,
            is_Enum_PythonToCpp_QWebEngineFileSystemAccessRequest_HandleType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QWebEngineFileSystemAccessRequest::HandleType");
        Shiboken::Conversions::registerConverterAlias(converter, "HandleType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'HandleType' enum.

    // Initialization of enum 'AccessFlag'.
    const char *AccessFlag_Initializer[] = {
        "Read",
        "Write",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t AccessFlag_InitializerValues[] = {
        uint8_t(QWebEngineFileSystemAccessRequest::AccessFlag::Read), //  0x01  1
        uint8_t(QWebEngineFileSystemAccessRequest::AccessFlag::Write) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWebEngineFileSystemAccessRequest_TypeF(),
        "2:PySide6.QtWebEngineCore.QWebEngineFileSystemAccessRequest.AccessFlag",
        AccessFlag_Initializer, AccessFlag_InitializerValues);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFileSystemAccessRequest_AccessFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QFlags_QWebEngineFileSystemAccessRequest_AccessFlag_IDX].type =
        EType;
    // Register converter for enum 'QWebEngineFileSystemAccessRequest::AccessFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWebEngineFileSystemAccessRequest_AccessFlag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QWebEngineFileSystemAccessRequest_AccessFlag,
            is_Enum_PythonToCpp_QWebEngineFileSystemAccessRequest_AccessFlag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QWebEngineFileSystemAccessRequest::AccessFlag");
        Shiboken::Conversions::registerConverterAlias(converter, "AccessFlag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QWebEngineFileSystemAccessRequest_AccessFlag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QWebEngineFileSystemAccessRequest_AccessFlag,
            is_Enum_PythonToCpp_QWebEngineFileSystemAccessRequest_AccessFlag_Convertible);
        // Register converter for flag 'QFlags<QWebEngineFileSystemAccessRequest::AccessFlag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QWebEngineFileSystemAccessRequest::AccessFlag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QWebEngineFileSystemAccessRequest::AccessFlags");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'AccessFlag' enum/flags.

    qRegisterMetaType< ::QWebEngineFileSystemAccessRequest >("QWebEngineFileSystemAccessRequest");
    qRegisterMetaType< ::QWebEngineFileSystemAccessRequest::HandleType >("QWebEngineFileSystemAccessRequest::HandleType");
    qRegisterMetaType< ::QWebEngineFileSystemAccessRequest::AccessFlag >("QWebEngineFileSystemAccessRequest::AccessFlag");

    return pyType;
}
