// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwebenginecore_python.h"

// main header
#include "qwebenginefindtextresult_wrapper.h"

// Argument includes
#include <QtWebEngineCore/qwebenginefindtextresult.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QWebEngineFindTextResult_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QWebEngineFindTextResult >()))
        return -1;

    ::QWebEngineFindTextResult *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QWebEngineFindTextResult", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QWebEngineFindTextResult::QWebEngineFindTextResult()
    // 1: QWebEngineFindTextResult::QWebEngineFindTextResult(QWebEngineFindTextResult)
    if (numArgs == 0) {
        overloadId = 0; // QWebEngineFindTextResult()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFindTextResult_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QWebEngineFindTextResult(QWebEngineFindTextResult)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFindTextResult_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFindTextResult_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QWebEngineFindTextResult()
        {

            // QWebEngineFindTextResult()
            cptr = new ::QWebEngineFindTextResult();
            break;
        }
        case 1: // QWebEngineFindTextResult(const QWebEngineFindTextResult &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QWebEngineFindTextResult cppArg0_local;
            ::QWebEngineFindTextResult *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QWebEngineFindTextResult(QWebEngineFindTextResult)
                cptr = new ::QWebEngineFindTextResult(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QWebEngineFindTextResult >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFindTextResult_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QWebEngineFindTextResultFunc_activeMatch(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineFindTextResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFindTextResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // activeMatch()const
        int cppResult = const_cast<const ::QWebEngineFindTextResult *>(cppSelf)->activeMatch();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineFindTextResultFunc_numberOfMatches(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineFindTextResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFindTextResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // numberOfMatches()const
        int cppResult = const_cast<const ::QWebEngineFindTextResult *>(cppSelf)->numberOfMatches();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineFindTextResult__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QWebEngineFindTextResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFindTextResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFindTextResult_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QWebEngineFindTextResult_PropertyStrings[] = {
    "activeMatch:",
    "numberOfMatches:",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QWebEngineFindTextResult_methods[] = {
    {"activeMatch", reinterpret_cast<PyCFunction>(Sbk_QWebEngineFindTextResultFunc_activeMatch), METH_NOARGS, nullptr},
    {"numberOfMatches", reinterpret_cast<PyCFunction>(Sbk_QWebEngineFindTextResultFunc_numberOfMatches), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QWebEngineFindTextResult__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QWebEngineFindTextResult_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QWebEngineFindTextResult_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QWebEngineFindTextResult_Type = nullptr;
static PyTypeObject *Sbk_QWebEngineFindTextResult_TypeF(void)
{
    return _Sbk_QWebEngineFindTextResult_Type;
}

static PyType_Slot Sbk_QWebEngineFindTextResult_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QWebEngineFindTextResult_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QWebEngineFindTextResult_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QWebEngineFindTextResult_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QWebEngineFindTextResult_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QWebEngineFindTextResult_spec = {
    "2:PySide6.QtWebEngineCore.QWebEngineFindTextResult",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QWebEngineFindTextResult_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QWebEngineFindTextResult_PythonToCpp_QWebEngineFindTextResult_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QWebEngineFindTextResult_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QWebEngineFindTextResult_PythonToCpp_QWebEngineFindTextResult_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QWebEngineFindTextResult_TypeF()))
        return QWebEngineFindTextResult_PythonToCpp_QWebEngineFindTextResult_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QWebEngineFindTextResult_PTR_CppToPython_QWebEngineFindTextResult(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QWebEngineFindTextResult_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QWebEngineFindTextResult_COPY_CppToPython_QWebEngineFindTextResult(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QWebEngineFindTextResult *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QWebEngineFindTextResult_TypeF(), new ::QWebEngineFindTextResult(*source), true, true);
}

// Python to C++ copy conversion.
static void QWebEngineFindTextResult_PythonToCpp_QWebEngineFindTextResult_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QWebEngineFindTextResult *>(cppOut) = *reinterpret_cast< ::QWebEngineFindTextResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFindTextResult_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QWebEngineFindTextResult_PythonToCpp_QWebEngineFindTextResult_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QWebEngineFindTextResult_TypeF()))
        return QWebEngineFindTextResult_PythonToCpp_QWebEngineFindTextResult_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QWebEngineFindTextResult_SignatureStrings[] = {
    "1:PySide6.QtWebEngineCore.QWebEngineFindTextResult(self,*:KeywordOnly=None,numberOfMatches:int=None,activeMatch:int=None)",
    "0:PySide6.QtWebEngineCore.QWebEngineFindTextResult(self,other:PySide6.QtWebEngineCore.QWebEngineFindTextResult,*:KeywordOnly=None,numberOfMatches:int=None,activeMatch:int=None)",
    "PySide6.QtWebEngineCore.QWebEngineFindTextResult.activeMatch(self)->int",
    "PySide6.QtWebEngineCore.QWebEngineFindTextResult.numberOfMatches(self)->int",
    "PySide6.QtWebEngineCore.QWebEngineFindTextResult.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QWebEngineFindTextResult_SignatureByteSize = 163;
static constexpr uint8_t QWebEngineFindTextResult_SignatureBytes[163] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x09, 0x4f,
    0x4d, 0x72, 0xcd, 0x4b, 0xcf, 0xcc, 0x4b, 0x75, 0xce, 0x2f, 0x4a, 0xd5, 0x0b, 0x84, 0x73, 0xdd,
    0x32, 0xf3, 0x52, 0x42, 0x52, 0x2b, 0x4a, 0x82, 0x52, 0x8b, 0x4b, 0x73, 0x4a, 0x34, 0x8a, 0x53,
    0x73, 0xd2, 0x74, 0xb4, 0xac, 0xbc, 0x53, 0x2b, 0xcb, 0xf3, 0x8b, 0x52, 0xfc, 0xf3, 0x72, 0x2a,
    0x6d, 0xfd, 0xf2, 0xf3, 0x52, 0x75, 0xf2, 0x4a, 0x73, 0x93, 0x52, 0x8b, 0xfc, 0xd3, 0x7c, 0x13,
    0x4b, 0x92, 0x33, 0x52, 0x8b, 0xad, 0x32, 0xf3, 0x4a, 0x20, 0x12, 0x89, 0xc9, 0x25, 0x99, 0x65,
    0xa9, 0x60, 0x61, 0xb8, 0xa0, 0x26, 0x97, 0x01, 0x99, 0x36, 0xe7, 0x97, 0x64, 0xa4, 0x16, 0x91,
    0xac, 0x97, 0x0a, 0x0e, 0x26, 0xd5, 0x4a, 0x3d, 0x24, 0x63, 0xc0, 0x4e, 0xd7, 0xd4, 0xb5, 0x03,
    0x9a, 0x46, 0xba, 0x39, 0x68, 0xee, 0xa4, 0xc8, 0xac, 0xf8, 0xf8, 0xe4, 0xfc, 0x82, 0xca, 0xf8,
    0x78, 0x98, 0x21, 0x25, 0x95, 0x05, 0x99, 0x79, 0xe9, 0x7a, 0xc1, 0x40, 0x1e, 0x17, 0x00, 0xb2,
    0x14, 0xc0, 0xae
};
#endif

PyTypeObject *init_QWebEngineFindTextResult(PyObject *module)
{
    if (SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFindTextResult_IDX].type != nullptr)
        return SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFindTextResult_IDX].type;

    Shiboken::AutoDecRef Sbk_QWebEngineFindTextResult_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QWebEngineFindTextResult_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QWebEngineFindTextResult",
        "QWebEngineFindTextResult",
        &Sbk_QWebEngineFindTextResult_spec,
        &Shiboken::callCppDestructor< ::QWebEngineFindTextResult >,
        Sbk_QWebEngineFindTextResult_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QWebEngineFindTextResult_TypeF(); // references _Sbk_QWebEngineFindTextResult_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QWebEngineFindTextResult_SignatureStrings);
#else
    InitSignatureBytes(pyType, QWebEngineFindTextResult_SignatureBytes, QWebEngineFindTextResult_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QWebEngineFindTextResult_PropertyStrings);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFindTextResult_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QWebEngineFindTextResult_PythonToCpp_QWebEngineFindTextResult_PTR,
        is_QWebEngineFindTextResult_PythonToCpp_QWebEngineFindTextResult_PTR_Convertible,
        QWebEngineFindTextResult_PTR_CppToPython_QWebEngineFindTextResult,
        QWebEngineFindTextResult_COPY_CppToPython_QWebEngineFindTextResult);

    Shiboken::Conversions::registerConverterName(converter, "QWebEngineFindTextResult");
    Shiboken::Conversions::registerConverterName(converter, "QWebEngineFindTextResult*");
    Shiboken::Conversions::registerConverterName(converter, "QWebEngineFindTextResult&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QWebEngineFindTextResult).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QWebEngineFindTextResult_PythonToCpp_QWebEngineFindTextResult_COPY,
        is_QWebEngineFindTextResult_PythonToCpp_QWebEngineFindTextResult_COPY_Convertible);


    return pyType;
}
