// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwebenginecore_python.h"

// main header
#include "qwebengineglobalsettings_dnsmode_wrapper.h"

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace QWebEngineGlobalSettings;


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QWebEngineGlobalSettings_DnsMode_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QWebEngineGlobalSettings::DnsMode >()))
        return -1;

    ::QWebEngineGlobalSettings::DnsMode *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "DnsMode", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: DnsMode::DnsMode()
    // 1: DnsMode::DnsMode(QWebEngineGlobalSettings::DnsMode)
    if (numArgs == 0) {
        overloadId = 0; // DnsMode()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineGlobalSettings_DnsMode_IDX]), (pyArgs[0])))) {
        overloadId = 1; // DnsMode(QWebEngineGlobalSettings::DnsMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineGlobalSettings_DnsMode_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineGlobalSettings_DnsMode_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // DnsMode()
        {

            // DnsMode()
            cptr = new ::QWebEngineGlobalSettings::DnsMode();
            break;
        }
        case 1: // DnsMode(const QWebEngineGlobalSettings::DnsMode &DnsMode)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QWebEngineGlobalSettings::DnsMode cppArg0_local;
            ::QWebEngineGlobalSettings::DnsMode *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // DnsMode(QWebEngineGlobalSettings::DnsMode)
                cptr = new ::QWebEngineGlobalSettings::DnsMode(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QWebEngineGlobalSettings::DnsMode >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineGlobalSettings_DnsMode_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QWebEngineGlobalSettings_DnsMode__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QWebEngineGlobalSettings::DnsMode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineGlobalSettings_DnsMode_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineGlobalSettings_DnsMode_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QWebEngineGlobalSettings_DnsMode_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QWebEngineGlobalSettings_DnsMode_methods[] = {
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QWebEngineGlobalSettings_DnsMode__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QWebEngineGlobalSettings_DnsMode_get_secureMode(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineGlobalSettings::DnsMode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineGlobalSettings_DnsMode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::QWebEngineGlobalSettings::SecureDnsMode cppOut_local = cppSelf->secureMode;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineGlobalSettings_SecureDnsMode_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QWebEngineGlobalSettings_DnsMode_set_secureMode(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QWebEngineGlobalSettings::DnsMode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineGlobalSettings_DnsMode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("secureMode");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineGlobalSettings_SecureDnsMode_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("secureMode", "SecureDnsMode");
        return -1;
    }

    auto cppOut_local = cppSelf->secureMode;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->secureMode = cppOut_local;

    return 0;
}

static PyObject *Sbk_QWebEngineGlobalSettings_DnsMode_get_serverTemplates(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineGlobalSettings::DnsMode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineGlobalSettings_DnsMode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppSelf->serverTemplates);
    return pyOut;
}
static int Sbk_QWebEngineGlobalSettings_DnsMode_set_serverTemplates(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QWebEngineGlobalSettings::DnsMode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineGlobalSettings_DnsMode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("serverTemplates");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("serverTemplates", "QStringList");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->serverTemplates;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

// Getters and Setters for DnsMode
static PyGetSetDef Sbk_QWebEngineGlobalSettings_DnsMode_getsetlist[] = {
    {const_cast<char *>("secureMode"), Sbk_QWebEngineGlobalSettings_DnsMode_get_secureMode, Sbk_QWebEngineGlobalSettings_DnsMode_set_secureMode, nullptr, nullptr},
    {const_cast<char *>("serverTemplates"), Sbk_QWebEngineGlobalSettings_DnsMode_get_serverTemplates, Sbk_QWebEngineGlobalSettings_DnsMode_set_serverTemplates, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QWebEngineGlobalSettings_DnsMode_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QWebEngineGlobalSettings_DnsMode_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QWebEngineGlobalSettings_DnsMode_Type = nullptr;
static PyTypeObject *Sbk_QWebEngineGlobalSettings_DnsMode_TypeF(void)
{
    return _Sbk_QWebEngineGlobalSettings_DnsMode_Type;
}

static PyType_Slot Sbk_QWebEngineGlobalSettings_DnsMode_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QWebEngineGlobalSettings_DnsMode_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QWebEngineGlobalSettings_DnsMode_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QWebEngineGlobalSettings_DnsMode_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QWebEngineGlobalSettings_DnsMode_getsetlist)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QWebEngineGlobalSettings_DnsMode_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QWebEngineGlobalSettings_DnsMode_spec = {
    "2:PySide6.QtWebEngineCore.QWebEngineGlobalSettings.DnsMode",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QWebEngineGlobalSettings_DnsMode_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void DnsMode_PythonToCpp_DnsMode_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QWebEngineGlobalSettings_DnsMode_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_DnsMode_PythonToCpp_DnsMode_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QWebEngineGlobalSettings_DnsMode_TypeF()))
        return DnsMode_PythonToCpp_DnsMode_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *DnsMode_PTR_CppToPython_DnsMode(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QWebEngineGlobalSettings_DnsMode_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *DnsMode_COPY_CppToPython_DnsMode(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QWebEngineGlobalSettings::DnsMode *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QWebEngineGlobalSettings_DnsMode_TypeF(), new ::QWebEngineGlobalSettings::DnsMode(*source), true, true);
}

// Python to C++ copy conversion.
static void DnsMode_PythonToCpp_DnsMode_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QWebEngineGlobalSettings::DnsMode *>(cppOut) = *reinterpret_cast< ::QWebEngineGlobalSettings::DnsMode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineGlobalSettings_DnsMode_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_DnsMode_PythonToCpp_DnsMode_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QWebEngineGlobalSettings_DnsMode_TypeF()))
        return DnsMode_PythonToCpp_DnsMode_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QWebEngineGlobalSettings_DnsMode_SignatureStrings[] = {
    "1:PySide6.QtWebEngineCore.QWebEngineGlobalSettings.DnsMode(self)",
    "0:PySide6.QtWebEngineCore.QWebEngineGlobalSettings.DnsMode(self,DnsMode:PySide6.QtWebEngineCore.QWebEngineGlobalSettings.DnsMode)",
    "PySide6.QtWebEngineCore.QWebEngineGlobalSettings.DnsMode.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QWebEngineGlobalSettings_DnsMode_SignatureByteSize = 101;
static constexpr uint8_t QWebEngineGlobalSettings_DnsMode_SignatureBytes[101] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x09, 0x4f,
    0x4d, 0x72, 0xcd, 0x4b, 0xcf, 0xcc, 0x4b, 0x75, 0xce, 0x2f, 0x4a, 0xd5, 0x0b, 0x84, 0x73, 0xdd,
    0x73, 0xf2, 0x93, 0x12, 0x73, 0x82, 0x53, 0x4b, 0x4a, 0x32, 0xf3, 0xd2, 0x8b, 0xf5, 0x5c, 0xf2,
    0x8a, 0x7d, 0xf3, 0x53, 0x52, 0x35, 0x8a, 0x53, 0x73, 0xd2, 0x34, 0xb9, 0x0c, 0x28, 0x33, 0x40,
    0x07, 0xca, 0x21, 0xdb, 0x14, 0x4d, 0x2e, 0x72, 0x75, 0xea, 0xc5, 0xc7, 0x27, 0xe7, 0x17, 0x54,
    0xc6, 0xc7, 0x43, 0x7c, 0xa2, 0x6b, 0x57, 0x52, 0x59, 0x00, 0x94, 0xd7, 0x0b, 0x06, 0xf2, 0xb8,
    0x00, 0x98, 0xd3, 0x65, 0x9c
};
#endif

PyTypeObject *init_QWebEngineGlobalSettings_DnsMode(PyObject *enclosingClass)
{
    if (SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineGlobalSettings_DnsMode_IDX].type != nullptr)
        return SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineGlobalSettings_DnsMode_IDX].type;

    Shiboken::AutoDecRef Sbk_QWebEngineGlobalSettings_DnsMode_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QWebEngineGlobalSettings_DnsMode_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "DnsMode",
        "QWebEngineGlobalSettings::DnsMode",
        &Sbk_QWebEngineGlobalSettings_DnsMode_spec,
        &Shiboken::callCppDestructor< ::QWebEngineGlobalSettings::DnsMode >,
        Sbk_QWebEngineGlobalSettings_DnsMode_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass | Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QWebEngineGlobalSettings_DnsMode_TypeF(); // references _Sbk_QWebEngineGlobalSettings_DnsMode_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QWebEngineGlobalSettings_DnsMode_SignatureStrings);
#else
    InitSignatureBytes(pyType, QWebEngineGlobalSettings_DnsMode_SignatureBytes, QWebEngineGlobalSettings_DnsMode_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QWebEngineGlobalSettings_DnsMode_PropertyStrings);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineGlobalSettings_DnsMode_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        DnsMode_PythonToCpp_DnsMode_PTR,
        is_DnsMode_PythonToCpp_DnsMode_PTR_Convertible,
        DnsMode_PTR_CppToPython_DnsMode,
        DnsMode_COPY_CppToPython_DnsMode);

    Shiboken::Conversions::registerConverterName(converter, "QWebEngineGlobalSettings::DnsMode");
    Shiboken::Conversions::registerConverterName(converter, "QWebEngineGlobalSettings::DnsMode*");
    Shiboken::Conversions::registerConverterName(converter, "QWebEngineGlobalSettings::DnsMode&");
    Shiboken::Conversions::registerConverterAlias(converter, "DnsMode");
    Shiboken::Conversions::registerConverterAlias(converter, "DnsMode*");
    Shiboken::Conversions::registerConverterAlias(converter, "DnsMode&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QWebEngineGlobalSettings::DnsMode).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        DnsMode_PythonToCpp_DnsMode_COPY,
        is_DnsMode_PythonToCpp_DnsMode_COPY_Convertible);

    qRegisterMetaType< ::QWebEngineGlobalSettings::DnsMode >("DnsMode");
    qRegisterMetaType< ::QWebEngineGlobalSettings::DnsMode >("QWebEngineGlobalSettings::DnsMode");

    return pyType;
}
