// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwebenginecore_python.h"

// main header
#include "qwebenginehistoryitem_wrapper.h"

// Argument includes
#include <QString>
#include <QtWebEngineCore/qwebenginehistory.h>
#include <qdatetime.h>
#include <qurl.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QWebEngineHistoryItem_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QWebEngineHistoryItem >()))
        return -1;

    ::QWebEngineHistoryItem *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QWebEngineHistoryItem", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QWebEngineHistoryItem::QWebEngineHistoryItem(QWebEngineHistoryItem)
    if (numArgs == 1
        && (pyArgs[0] != Py_None && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineHistoryItem_IDX]), (pyArgs[0]))))) {
        overloadId = 0; // QWebEngineHistoryItem(QWebEngineHistoryItem)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineHistoryItem_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineHistoryItem_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QWebEngineHistoryItem *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QWebEngineHistoryItem(QWebEngineHistoryItem)
            cptr = new ::QWebEngineHistoryItem(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QWebEngineHistoryItem >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineHistoryItem_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QWebEngineHistoryItemFunc_iconUrl(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineHistoryItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineHistoryItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // iconUrl()const
        QUrl cppResult = const_cast<const ::QWebEngineHistoryItem *>(cppSelf)->iconUrl();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineHistoryItemFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineHistoryItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineHistoryItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QWebEngineHistoryItem *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineHistoryItemFunc_lastVisited(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineHistoryItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineHistoryItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lastVisited()const
        QDateTime cppResult = const_cast<const ::QWebEngineHistoryItem *>(cppSelf)->lastVisited();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineHistoryItemFunc_originalUrl(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineHistoryItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineHistoryItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // originalUrl()const
        QUrl cppResult = const_cast<const ::QWebEngineHistoryItem *>(cppSelf)->originalUrl();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineHistoryItemFunc_title(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineHistoryItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineHistoryItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // title()const
        QString cppResult = const_cast<const ::QWebEngineHistoryItem *>(cppSelf)->title();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineHistoryItemFunc_url(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineHistoryItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineHistoryItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // url()const
        QUrl cppResult = const_cast<const ::QWebEngineHistoryItem *>(cppSelf)->url();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineHistoryItem__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QWebEngineHistoryItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineHistoryItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineHistoryItem_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QWebEngineHistoryItem_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QWebEngineHistoryItem_methods[] = {
    {"iconUrl", reinterpret_cast<PyCFunction>(Sbk_QWebEngineHistoryItemFunc_iconUrl), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QWebEngineHistoryItemFunc_isValid), METH_NOARGS, nullptr},
    {"lastVisited", reinterpret_cast<PyCFunction>(Sbk_QWebEngineHistoryItemFunc_lastVisited), METH_NOARGS, nullptr},
    {"originalUrl", reinterpret_cast<PyCFunction>(Sbk_QWebEngineHistoryItemFunc_originalUrl), METH_NOARGS, nullptr},
    {"title", reinterpret_cast<PyCFunction>(Sbk_QWebEngineHistoryItemFunc_title), METH_NOARGS, nullptr},
    {"url", reinterpret_cast<PyCFunction>(Sbk_QWebEngineHistoryItemFunc_url), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QWebEngineHistoryItem__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QWebEngineHistoryItem_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QWebEngineHistoryItem_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QWebEngineHistoryItem_Type = nullptr;
static PyTypeObject *Sbk_QWebEngineHistoryItem_TypeF(void)
{
    return _Sbk_QWebEngineHistoryItem_Type;
}

static PyType_Slot Sbk_QWebEngineHistoryItem_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QWebEngineHistoryItem_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QWebEngineHistoryItem_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QWebEngineHistoryItem_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QWebEngineHistoryItem_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QWebEngineHistoryItem_spec = {
    "2:PySide6.QtWebEngineCore.QWebEngineHistoryItem",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QWebEngineHistoryItem_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QWebEngineHistoryItem_PythonToCpp_QWebEngineHistoryItem_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QWebEngineHistoryItem_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QWebEngineHistoryItem_PythonToCpp_QWebEngineHistoryItem_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QWebEngineHistoryItem_TypeF()))
        return QWebEngineHistoryItem_PythonToCpp_QWebEngineHistoryItem_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QWebEngineHistoryItem_PTR_CppToPython_QWebEngineHistoryItem(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QWebEngineHistoryItem_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QWebEngineHistoryItem_COPY_CppToPython_QWebEngineHistoryItem(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QWebEngineHistoryItem *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QWebEngineHistoryItem_TypeF(), new ::QWebEngineHistoryItem(*source), true, true);
}

// Python to C++ copy conversion.
static void QWebEngineHistoryItem_PythonToCpp_QWebEngineHistoryItem_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QWebEngineHistoryItem *>(cppOut) = *reinterpret_cast< ::QWebEngineHistoryItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineHistoryItem_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QWebEngineHistoryItem_PythonToCpp_QWebEngineHistoryItem_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QWebEngineHistoryItem_TypeF()))
        return QWebEngineHistoryItem_PythonToCpp_QWebEngineHistoryItem_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QWebEngineHistoryItem_SignatureStrings[] = {
    "PySide6.QtWebEngineCore.QWebEngineHistoryItem(self,other:PySide6.QtWebEngineCore.QWebEngineHistoryItem)",
    "PySide6.QtWebEngineCore.QWebEngineHistoryItem.iconUrl(self)->PySide6.QtCore.QUrl",
    "PySide6.QtWebEngineCore.QWebEngineHistoryItem.isValid(self)->bool",
    "PySide6.QtWebEngineCore.QWebEngineHistoryItem.lastVisited(self)->PySide6.QtCore.QDateTime",
    "PySide6.QtWebEngineCore.QWebEngineHistoryItem.originalUrl(self)->PySide6.QtCore.QUrl",
    "PySide6.QtWebEngineCore.QWebEngineHistoryItem.title(self)->QString",
    "PySide6.QtWebEngineCore.QWebEngineHistoryItem.url(self)->PySide6.QtCore.QUrl",
    "PySide6.QtWebEngineCore.QWebEngineHistoryItem.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QWebEngineHistoryItem_SignatureByteSize = 166;
static constexpr uint8_t QWebEngineHistoryItem_SignatureBytes[166] = {
    0x78, 0xda, 0xad, 0x8f, 0xb1, 0x0e, 0xc2, 0x30, 0x0c, 0x44, 0xf7, 0x7e, 0x09, 0x95, 0x20, 0x23,
    0x43, 0x07, 0x16, 0x40, 0x82, 0xad, 0x55, 0xa1, 0x8c, 0x51, 0xda, 0x98, 0x62, 0x29, 0x8d, 0xab,
    0xc4, 0x0c, 0xf9, 0x7b, 0x22, 0x50, 0x60, 0x62, 0x88, 0xd4, 0xf1, 0xec, 0xbb, 0xe7, 0x73, 0x1d,
    0x5a, 0xd4, 0xb0, 0x15, 0x0d, 0xdf, 0xa0, 0x3f, 0xda, 0x11, 0x2d, 0xec, 0xc9, 0x81, 0x68, 0xbe,
    0xf2, 0x84, 0x9e, 0xc9, 0x85, 0x33, 0xc3, 0xb4, 0xf2, 0x60, 0xee, 0x6b, 0xe2, 0x07, 0xb8, 0xaa,
    0xce, 0x09, 0x96, 0x45, 0x96, 0x5d, 0xe0, 0x40, 0xf6, 0xea, 0xcc, 0xfb, 0x5e, 0xb9, 0xd9, 0xfd,
    0xc2, 0x9f, 0x4c, 0x5c, 0xe5, 0x02, 0x7d, 0xa7, 0x0c, 0xea, 0x04, 0xec, 0x89, 0x72, 0x09, 0x46,
    0x79, 0xee, 0xd0, 0x23, 0x83, 0xfe, 0x57, 0xeb, 0xa0, 0x18, 0x2e, 0x38, 0x41, 0x26, 0x99, 0x1c,
    0xc6, 0x91, 0x32, 0x8b, 0x3e, 0xcc, 0xc8, 0x06, 0x12, 0xae, 0x69, 0xd9, 0xa1, 0x1d, 0x33, 0x11,
    0xcf, 0x25, 0xfb, 0x48, 0x39, 0xd0, 0x1c, 0xa4, 0x4c, 0x44, 0x0e, 0x73, 0x6c, 0x24, 0xda, 0xa8,
    0x8a, 0x17, 0xa4, 0xdb, 0xe9, 0xd9
};
#endif

PyTypeObject *init_QWebEngineHistoryItem(PyObject *module)
{
    if (SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineHistoryItem_IDX].type != nullptr)
        return SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineHistoryItem_IDX].type;

    Shiboken::AutoDecRef Sbk_QWebEngineHistoryItem_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QWebEngineHistoryItem_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QWebEngineHistoryItem",
        "QWebEngineHistoryItem",
        &Sbk_QWebEngineHistoryItem_spec,
        &Shiboken::callCppDestructor< ::QWebEngineHistoryItem >,
        Sbk_QWebEngineHistoryItem_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QWebEngineHistoryItem_TypeF(); // references _Sbk_QWebEngineHistoryItem_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QWebEngineHistoryItem_SignatureStrings);
#else
    InitSignatureBytes(pyType, QWebEngineHistoryItem_SignatureBytes, QWebEngineHistoryItem_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QWebEngineHistoryItem_PropertyStrings);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineHistoryItem_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QWebEngineHistoryItem_PythonToCpp_QWebEngineHistoryItem_PTR,
        is_QWebEngineHistoryItem_PythonToCpp_QWebEngineHistoryItem_PTR_Convertible,
        QWebEngineHistoryItem_PTR_CppToPython_QWebEngineHistoryItem,
        QWebEngineHistoryItem_COPY_CppToPython_QWebEngineHistoryItem);

    Shiboken::Conversions::registerConverterName(converter, "QWebEngineHistoryItem");
    Shiboken::Conversions::registerConverterName(converter, "QWebEngineHistoryItem*");
    Shiboken::Conversions::registerConverterName(converter, "QWebEngineHistoryItem&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QWebEngineHistoryItem).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QWebEngineHistoryItem_PythonToCpp_QWebEngineHistoryItem_COPY,
        is_QWebEngineHistoryItem_PythonToCpp_QWebEngineHistoryItem_COPY_Convertible);

    qRegisterMetaType< ::QWebEngineHistoryItem >("QWebEngineHistoryItem");

    return pyType;
}
