// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwebenginecore_python.h"

// main header
#include "qwebenginepermission_wrapper.h"

// Argument includes
#include <QtWebEngineCore/qwebenginepermission.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qurl.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QWebEnginePermission_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QWebEnginePermission >()))
        return -1;

    ::QWebEnginePermission *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QWebEnginePermission", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QWebEnginePermission::QWebEnginePermission()
    // 1: QWebEnginePermission::QWebEnginePermission(QWebEnginePermission)
    if (numArgs == 0) {
        overloadId = 0; // QWebEnginePermission()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePermission_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QWebEnginePermission(QWebEnginePermission)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePermission_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePermission_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QWebEnginePermission()
        {

            // QWebEnginePermission()
            cptr = new ::QWebEnginePermission();
            break;
        }
        case 1: // QWebEnginePermission(const QWebEnginePermission &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QWebEnginePermission cppArg0_local;
            ::QWebEnginePermission *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QWebEnginePermission(QWebEnginePermission)
                cptr = new ::QWebEnginePermission(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QWebEnginePermission >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePermission_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QWebEnginePermissionFunc_deny(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePermission *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePermission_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // deny()const
        const_cast<const ::QWebEnginePermission *>(cppSelf)->deny();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEnginePermissionFunc_grant(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePermission *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePermission_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // grant()const
        const_cast<const ::QWebEnginePermission *>(cppSelf)->grant();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEnginePermissionFunc_isPersistent(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QWebEnginePermission::isPersistent(QWebEnginePermission::PermissionType)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePermission_PermissionType_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // isPersistent(QWebEnginePermission::PermissionType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isPersistent", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePermission_IDX]);

    // Call function/method
    {
        ::QWebEnginePermission::PermissionType cppArg0{QWebEnginePermission::PermissionType::Unsupported};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isPersistent(QWebEnginePermission::PermissionType)
            bool cppResult = ::QWebEnginePermission::isPersistent(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePermissionFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePermission *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePermission_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QWebEnginePermission *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePermissionFunc_origin(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePermission *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePermission_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // origin()const
        QUrl cppResult = const_cast<const ::QWebEnginePermission *>(cppSelf)->origin();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePermissionFunc_permissionType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePermission *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePermission_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // permissionType()const
        QWebEnginePermission::PermissionType cppResult = const_cast<const ::QWebEnginePermission *>(cppSelf)->permissionType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePermission_PermissionType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePermissionFunc_reset(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePermission *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePermission_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // reset()const
        const_cast<const ::QWebEnginePermission *>(cppSelf)->reset();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEnginePermissionFunc_state(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePermission *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePermission_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // state()const
        QWebEnginePermission::State cppResult = const_cast<const ::QWebEnginePermission *>(cppSelf)->state();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePermission_State_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePermissionFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePermission *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePermission_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEnginePermission::swap(QWebEnginePermission&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePermission_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QWebEnginePermission&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePermission_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QWebEnginePermission cppArg0_local;
        ::QWebEnginePermission *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QWebEnginePermission&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEnginePermission__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QWebEnginePermission *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePermission_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePermission_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QWebEnginePermission_PropertyStrings[] = {
    "isValid:",
    "origin:",
    "permissionType:",
    "state:",
    nullptr // Sentinel
};

static const char *Sbk_QWebEnginePermission_EnumFlagInfo[] = {
    "PermissionType:Enum",
    "State:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QWebEnginePermission_methods[] = {
    {"deny", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePermissionFunc_deny), METH_NOARGS, nullptr},
    {"grant", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePermissionFunc_grant), METH_NOARGS, nullptr},
    {"isPersistent", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePermissionFunc_isPersistent), METH_O|METH_STATIC, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePermissionFunc_isValid), METH_NOARGS, nullptr},
    {"origin", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePermissionFunc_origin), METH_NOARGS, nullptr},
    {"permissionType", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePermissionFunc_permissionType), METH_NOARGS, nullptr},
    {"reset", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePermissionFunc_reset), METH_NOARGS, nullptr},
    {"state", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePermissionFunc_state), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePermissionFunc_swap), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePermission__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QWebEnginePermission_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QWebEnginePermission *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePermission_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePermission_IDX]), (pyArg)))) {
                // operator!=(const QWebEnginePermission &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QWebEnginePermission cppArg0_local;
                ::QWebEnginePermission *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePermission_IDX]), (pyArg)))) {
                // operator==(const QWebEnginePermission &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QWebEnginePermission cppArg0_local;
                ::QWebEnginePermission *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QWebEnginePermission_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QWebEnginePermission_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QWebEnginePermission_Type = nullptr;
static PyTypeObject *Sbk_QWebEnginePermission_TypeF(void)
{
    return _Sbk_QWebEnginePermission_Type;
}

static PyType_Slot Sbk_QWebEnginePermission_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QWebEnginePermission_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QWebEnginePermission_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QWebEnginePermission_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QWebEnginePermission_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QWebEnginePermission_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QWebEnginePermission_spec = {
    "2:PySide6.QtWebEngineCore.QWebEnginePermission",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QWebEnginePermission_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QWebEnginePermission_PermissionType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWebEnginePermission::PermissionType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QWebEnginePermission::PermissionType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QWebEnginePermission_PermissionType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePermission_PermissionType_IDX])))
        return Enum_PythonToCpp_QWebEnginePermission_PermissionType;
    return {};
}

static PyObject *QWebEnginePermission_PermissionType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QWebEnginePermission::PermissionType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QWebEnginePermission::PermissionType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePermission_PermissionType_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QWebEnginePermission_State(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWebEnginePermission::State>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QWebEnginePermission::State *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QWebEnginePermission_State_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePermission_State_IDX])))
        return Enum_PythonToCpp_QWebEnginePermission_State;
    return {};
}

static PyObject *QWebEnginePermission_State_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QWebEnginePermission::State>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QWebEnginePermission::State *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePermission_State_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QWebEnginePermission_PythonToCpp_QWebEnginePermission_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QWebEnginePermission_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QWebEnginePermission_PythonToCpp_QWebEnginePermission_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QWebEnginePermission_TypeF()))
        return QWebEnginePermission_PythonToCpp_QWebEnginePermission_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QWebEnginePermission_PTR_CppToPython_QWebEnginePermission(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QWebEnginePermission_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QWebEnginePermission_COPY_CppToPython_QWebEnginePermission(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QWebEnginePermission *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QWebEnginePermission_TypeF(), new ::QWebEnginePermission(*source), true, true);
}

// Python to C++ copy conversion.
static void QWebEnginePermission_PythonToCpp_QWebEnginePermission_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QWebEnginePermission *>(cppOut) = *reinterpret_cast< ::QWebEnginePermission *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePermission_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QWebEnginePermission_PythonToCpp_QWebEnginePermission_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QWebEnginePermission_TypeF()))
        return QWebEnginePermission_PythonToCpp_QWebEnginePermission_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QWebEnginePermission_SignatureStrings[] = {
    "1:PySide6.QtWebEngineCore.QWebEnginePermission(self,*:KeywordOnly=None,origin:QUrl=None,permissionType:QWebEnginePermission.PermissionType=None,state:QWebEnginePermission.State=None,isValid:bool=None)",
    "0:PySide6.QtWebEngineCore.QWebEnginePermission(self,other:PySide6.QtWebEngineCore.QWebEnginePermission,*:KeywordOnly=None,origin:QUrl=None,permissionType:QWebEnginePermission.PermissionType=None,state:QWebEnginePermission.State=None,isValid:bool=None)",
    "PySide6.QtWebEngineCore.QWebEnginePermission.deny(self)",
    "PySide6.QtWebEngineCore.QWebEnginePermission.grant(self)",
    "PySide6.QtWebEngineCore.QWebEnginePermission.isPersistent(permissionType:PySide6.QtWebEngineCore.QWebEnginePermission.PermissionType)->bool",
    "PySide6.QtWebEngineCore.QWebEnginePermission.isValid(self)->bool",
    "PySide6.QtWebEngineCore.QWebEnginePermission.origin(self)->PySide6.QtCore.QUrl",
    "PySide6.QtWebEngineCore.QWebEnginePermission.permissionType(self)->PySide6.QtWebEngineCore.QWebEnginePermission.PermissionType",
    "PySide6.QtWebEngineCore.QWebEnginePermission.reset(self)",
    "PySide6.QtWebEngineCore.QWebEnginePermission.state(self)->PySide6.QtWebEngineCore.QWebEnginePermission.State",
    "PySide6.QtWebEngineCore.QWebEnginePermission.swap(self,other:PySide6.QtWebEngineCore.QWebEnginePermission)",
    "PySide6.QtWebEngineCore.QWebEnginePermission.__copy__(self)->typing.Self",
    "PySide6.QtWebEngineCore.QWebEnginePermission.__ne__(self,rhs:PySide6.QtWebEngineCore.QWebEnginePermission)->bool",
    "PySide6.QtWebEngineCore.QWebEnginePermission.__eq__(self,rhs:PySide6.QtWebEngineCore.QWebEnginePermission)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QWebEnginePermission_SignatureByteSize = 266;
static constexpr uint8_t QWebEnginePermission_SignatureBytes[266] = {
    0x78, 0xda, 0xcd, 0x53, 0xcb, 0x4e, 0xc3, 0x30, 0x10, 0xbc, 0xf3, 0x25, 0x14, 0x05, 0x8b, 0x5e,
    0x38, 0x58, 0x82, 0x0b, 0xe2, 0x84, 0x44, 0x13, 0x85, 0xc7, 0xd1, 0x4a, 0xc9, 0x36, 0x5d, 0x29,
    0x78, 0x8d, 0xd7, 0x52, 0xe5, 0xbf, 0xc7, 0x8d, 0x69, 0x51, 0x78, 0x1c, 0xd6, 0x5c, 0x38, 0xae,
    0x3d, 0x33, 0xbb, 0x33, 0x5e, 0x2f, 0x75, 0x1d, 0x5b, 0xec, 0xe1, 0x52, 0x35, 0xe1, 0x19, 0xd6,
    0xb7, 0x76, 0x40, 0x0b, 0x37, 0xe4, 0x41, 0x35, 0xc7, 0xb2, 0x06, 0xff, 0x8a, 0xcc, 0x48, 0xf6,
    0x94, 0x61, 0xdc, 0x54, 0x67, 0xfa, 0x0e, 0xe2, 0x8e, 0x7c, 0xbf, 0xb2, 0x63, 0xbc, 0xba, 0x27,
    0x0b, 0x15, 0x79, 0x4c, 0x48, 0xdd, 0x3c, 0xfa, 0x31, 0x1f, 0xb8, 0x23, 0xe7, 0x21, 0x3a, 0xd0,
    0x3f, 0x89, 0xa9, 0x7a, 0x86, 0xc9, 0x3c, 0x0e, 0x5d, 0xf8, 0x05, 0xde, 0xee, 0xaf, 0x32, 0x0a,
    0xf9, 0xa9, 0x1b, 0xb1, 0xd7, 0x6b, 0xa2, 0xdc, 0x6f, 0x71, 0x72, 0x51, 0x60, 0x84, 0xc2, 0x16,
    0xbc, 0x88, 0xf7, 0x3f, 0xbd, 0x4b, 0x1c, 0xa8, 0x1e, 0x6c, 0x9c, 0xec, 0x0b, 0x79, 0x83, 0xef,
    0x6c, 0x28, 0x21, 0x22, 0xa7, 0x82, 0x91, 0x03, 0x24, 0xfe, 0x97, 0x6c, 0x44, 0x42, 0xf3, 0xcc,
    0x16, 0xe7, 0xd7, 0xfb, 0x08, 0xa4, 0xb3, 0x4c, 0xe1, 0x65, 0x1b, 0x25, 0x02, 0xf9, 0xb1, 0x0f,
    0xfc, 0x4f, 0x6a, 0x66, 0xa4, 0x15, 0x90, 0xc9, 0xcd, 0xe3, 0xf8, 0x2e, 0x2b, 0x4e, 0x45, 0xd6,
    0xde, 0x03, 0x43, 0xd1, 0x9b, 0x4e, 0xab, 0x5a, 0x34, 0xee, 0xb4, 0xc9, 0xc2, 0x66, 0xbb, 0xce,
    0x95, 0x7e, 0x58, 0xa1, 0x2f, 0x63, 0x5e, 0xc8, 0x45, 0x63, 0x0e, 0xd6, 0x42, 0x74, 0x68, 0x07,
    0xd5, 0xa6, 0x4a, 0x2a, 0x64, 0xe1, 0x43, 0xa6, 0xf2, 0x5b, 0x96, 0xcd, 0x5c, 0xb2, 0x98, 0xc6,
    0xc0, 0xdb, 0x5f, 0x1b, 0xbe, 0x03, 0x18, 0xfd, 0x3d, 0xc8
};
#endif

PyTypeObject *init_QWebEnginePermission(PyObject *module)
{
    if (SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePermission_IDX].type != nullptr)
        return SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePermission_IDX].type;

    Shiboken::AutoDecRef Sbk_QWebEnginePermission_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QWebEnginePermission_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QWebEnginePermission",
        "QWebEnginePermission",
        &Sbk_QWebEnginePermission_spec,
        &Shiboken::callCppDestructor< ::QWebEnginePermission >,
        Sbk_QWebEnginePermission_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QWebEnginePermission_TypeF(); // references _Sbk_QWebEnginePermission_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QWebEnginePermission_SignatureStrings);
#else
    InitSignatureBytes(pyType, QWebEnginePermission_SignatureBytes, QWebEnginePermission_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QWebEnginePermission_PropertyStrings);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePermission_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QWebEnginePermission_PythonToCpp_QWebEnginePermission_PTR,
        is_QWebEnginePermission_PythonToCpp_QWebEnginePermission_PTR_Convertible,
        QWebEnginePermission_PTR_CppToPython_QWebEnginePermission,
        QWebEnginePermission_COPY_CppToPython_QWebEnginePermission);

    Shiboken::Conversions::registerConverterName(converter, "QWebEnginePermission");
    Shiboken::Conversions::registerConverterName(converter, "QWebEnginePermission*");
    Shiboken::Conversions::registerConverterName(converter, "QWebEnginePermission&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QWebEnginePermission).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QWebEnginePermission_PythonToCpp_QWebEnginePermission_COPY,
        is_QWebEnginePermission_PythonToCpp_QWebEnginePermission_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QWebEnginePermission_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'PermissionType'.
    const char *PermissionType_Initializer[] = {
        "Unsupported",
        "MediaAudioCapture",
        "MediaVideoCapture",
        "MediaAudioVideoCapture",
        "DesktopVideoCapture",
        "DesktopAudioVideoCapture",
        "MouseLock",
        "Notifications",
        "Geolocation",
        "ClipboardReadWrite",
        "LocalFontsAccess",
        nullptr};
    // "uint8_t" used instead of "unsigned char"
    constexpr uint8_t PermissionType_InitializerValues[] = {
        uint8_t(QWebEnginePermission::PermissionType::Unsupported),              //  0x00  0
        uint8_t(QWebEnginePermission::PermissionType::MediaAudioCapture),        //  0x01  1
        uint8_t(QWebEnginePermission::PermissionType::MediaVideoCapture),        //  0x02  2
        uint8_t(QWebEnginePermission::PermissionType::MediaAudioVideoCapture),   //  0x03  3
        uint8_t(QWebEnginePermission::PermissionType::DesktopVideoCapture),      //  0x04  4
        uint8_t(QWebEnginePermission::PermissionType::DesktopAudioVideoCapture), //  0x05  5
        uint8_t(QWebEnginePermission::PermissionType::MouseLock),                //  0x06  6
        uint8_t(QWebEnginePermission::PermissionType::Notifications),            //  0x07  7
        uint8_t(QWebEnginePermission::PermissionType::Geolocation),              //  0x08  8
        uint8_t(QWebEnginePermission::PermissionType::ClipboardReadWrite),       //  0x09  9
        uint8_t(QWebEnginePermission::PermissionType::LocalFontsAccess)          //  0x0a  10
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWebEnginePermission_TypeF(),
        "2:PySide6.QtWebEngineCore.QWebEnginePermission.PermissionType",
        PermissionType_Initializer, PermissionType_InitializerValues);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePermission_PermissionType_IDX].type = EType;
    // Register converter for enum 'QWebEnginePermission::PermissionType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWebEnginePermission_PermissionType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QWebEnginePermission_PermissionType,
            is_Enum_PythonToCpp_QWebEnginePermission_PermissionType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QWebEnginePermission::PermissionType");
        Shiboken::Conversions::registerConverterAlias(converter, "PermissionType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'PermissionType' enum.

    // Initialization of enum 'State'.
    const char *State_Initializer[] = {
        "Invalid",
        "Ask",
        "Granted",
        "Denied",
        nullptr};
    // "uint8_t" used instead of "unsigned char"
    constexpr uint8_t State_InitializerValues[] = {
        uint8_t(QWebEnginePermission::State::Invalid), //  0x00  0
        uint8_t(QWebEnginePermission::State::Ask),     //  0x01  1
        uint8_t(QWebEnginePermission::State::Granted), //  0x02  2
        uint8_t(QWebEnginePermission::State::Denied)   //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWebEnginePermission_TypeF(),
        "2:PySide6.QtWebEngineCore.QWebEnginePermission.State",
        State_Initializer, State_InitializerValues);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePermission_State_IDX].type = EType;
    // Register converter for enum 'QWebEnginePermission::State'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWebEnginePermission_State_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QWebEnginePermission_State,
            is_Enum_PythonToCpp_QWebEnginePermission_State_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QWebEnginePermission::State");
        Shiboken::Conversions::registerConverterAlias(converter, "State");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'State' enum.

    qRegisterMetaType< ::QWebEnginePermission >("QWebEnginePermission");
    qRegisterMetaType< ::QWebEnginePermission::PermissionType >("QWebEnginePermission::PermissionType");
    qRegisterMetaType< ::QWebEnginePermission::State >("QWebEnginePermission::State");

    return pyType;
}
