// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwebenginecore_python.h"

// main header
#include "qwebengineprofile_wrapper.h"

// Extra includes
#include <QtWebEngineCore/QWebEngineNotification>

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QStringList>
#include <QtWebEngineCore/qwebengineclientcertificatestore.h>
#include <QtWebEngineCore/qwebengineclienthints.h>
#include <QtWebEngineCore/qwebenginecookiestore.h>
#include <QtWebEngineCore/qwebenginedownloadrequest.h>
#include <QtWebEngineCore/qwebenginepermission.h>
#include <QtWebEngineCore/qwebengineprofile.h>
#include <QtWebEngineCore/qwebenginescriptcollection.h>
#include <QtWebEngineCore/qwebenginesettings.h>
#include <QtWebEngineCore/qwebengineurlrequestinterceptor.h>
#include <QtWebEngineCore/qwebengineurlschemehandler.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qurl.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Begin code injection
// ========================================================================
// START of custom code block [file: ../glue/qtwebenginecore.cpp (qwebengineprofile-functor)]
struct QWebEngineNotificationFunctor : public Shiboken::PyObjectHolder
{
    using Shiboken::PyObjectHolder::PyObjectHolder;

    void operator()(std::unique_ptr<QWebEngineNotification> webEngineNotification);
};

void QWebEngineNotificationFunctor::operator()
    (std::unique_ptr<QWebEngineNotification> webEngineNotification)
{
    Shiboken::GilState state;
    Shiboken::AutoDecRef arglist(PyTuple_New(1));
    auto *notification = webEngineNotification.release();
    PyTuple_SetItem(arglist.object(), 0,
                     Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineNotification_IDX]), notification));
    Shiboken::AutoDecRef ret(PyObject_CallObject(object(), arglist));
};
// END of custom code block [file: ../glue/qtwebenginecore.cpp (qwebengineprofile-functor)]
// ========================================================================
// End of code injection


// Native ---------------------------------------------------------

void QWebEngineProfileWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QWebEngineProfileWrapper::QWebEngineProfileWrapper(::QObject * parent) : QWebEngineProfile(parent)
{
}

QWebEngineProfileWrapper::QWebEngineProfileWrapper(const ::QString & name, ::QObject * parent) : QWebEngineProfile(name, parent)
{
}

void QWebEngineProfileWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWebEngineProfile", funcName);
        return;
    }
}

void QWebEngineProfileWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWebEngineProfile", funcName);
        return;
    }
}

void QWebEngineProfileWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWebEngineProfile", funcName);
        return;
    }
}

void QWebEngineProfileWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWebEngineProfile", funcName);
        return;
    }
}

bool QWebEngineProfileWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWebEngineProfile", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QWebEngineProfile", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QWebEngineProfileWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWebEngineProfile", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QWebEngineProfile", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QWebEngineProfileWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWebEngineProfile", funcName);
        return;
    }
}

const QMetaObject *QWebEngineProfileWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QWebEngineProfile::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QWebEngineProfileWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QWebEngineProfile::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QWebEngineProfileWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QWebEngineProfileWrapper *>(this));
    return QWebEngineProfile::qt_metacast(_clname);
}

QWebEngineProfileWrapper::~QWebEngineProfileWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QWebEngineProfile_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QWebEngineProfile >()))
        return -1;

    QWebEngineProfileWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:QWebEngineProfile", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QWebEngineProfile::QWebEngineProfile(QObject*=)
    // 1: QWebEngineProfile::QWebEngineProfile(QString,QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QWebEngineProfile(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QWebEngineProfile(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QWebEngineProfile(QString,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 1; // QWebEngineProfile(QString,QObject*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QWebEngineProfile(QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0 = nullptr;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QWebEngineProfile(QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QWebEngineProfileWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QWebEngineProfileWrapper(cppArg0);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
        case 1: // QWebEngineProfile(const QString &name, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QObject *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QWebEngineProfile(QString,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QWebEngineProfileWrapper(cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QWebEngineProfileWrapper(cppArg0, cppArg1);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QWebEngineProfile >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QWebEngineProfileFunc_cachePath(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cachePath()const
        QString cppResult = const_cast<const ::QWebEngineProfile *>(cppSelf)->cachePath();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineProfileFunc_clearAllVisitedLinks(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clearAllVisitedLinks()
        cppSelf->clearAllVisitedLinks();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineProfileFunc_clearHttpCache(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clearHttpCache()
        cppSelf->clearHttpCache();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineProfileFunc_clearVisitedLinks(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineProfile::clearVisitedLinks(QList<QUrl>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtWebEngineCoreTypeConverters[SBK_QtWebEngineCore_QList_QUrl_IDX], (pyArg)))) {
        overloadId = 0; // clearVisitedLinks(QList<QUrl>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "clearVisitedLinks", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]);

    // Call function/method
    {
        ::QList<QUrl> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // clearVisitedLinks(QList<QUrl>)
            cppSelf->clearVisitedLinks(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineProfileFunc_clientCertificateStore(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clientCertificateStore()
        QWebEngineClientCertificateStore * cppResult = cppSelf->clientCertificateStore();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineClientCertificateStore_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineProfileFunc_clientHints(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clientHints()const
        QWebEngineClientHints * cppResult = const_cast<const ::QWebEngineProfile *>(cppSelf)->clientHints();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineClientHints_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineProfileFunc_cookieStore(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cookieStore()
        QWebEngineCookieStore * cppResult = cppSelf->cookieStore();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineCookieStore_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineProfileFunc_defaultProfile(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // defaultProfile()
        QWebEngineProfile * cppResult = ::QWebEngineProfile::defaultProfile();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineProfileFunc_downloadPath(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // downloadPath()const
        QString cppResult = const_cast<const ::QWebEngineProfile *>(cppSelf)->downloadPath();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineProfileFunc_httpAcceptLanguage(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // httpAcceptLanguage()const
        QString cppResult = const_cast<const ::QWebEngineProfile *>(cppSelf)->httpAcceptLanguage();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineProfileFunc_httpCacheMaximumSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // httpCacheMaximumSize()const
        int cppResult = const_cast<const ::QWebEngineProfile *>(cppSelf)->httpCacheMaximumSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineProfileFunc_httpCacheType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // httpCacheType()const
        QWebEngineProfile::HttpCacheType cppResult = const_cast<const ::QWebEngineProfile *>(cppSelf)->httpCacheType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_HttpCacheType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineProfileFunc_httpUserAgent(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // httpUserAgent()const
        QString cppResult = const_cast<const ::QWebEngineProfile *>(cppSelf)->httpUserAgent();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineProfileFunc_installUrlSchemeHandler(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "installUrlSchemeHandler", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QWebEngineProfile::installUrlSchemeHandler(QByteArray,QWebEngineUrlSchemeHandler*)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlSchemeHandler_IDX]), (pyArgs[1])))) {
        overloadId = 0; // installUrlSchemeHandler(QByteArray,QWebEngineUrlSchemeHandler*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "installUrlSchemeHandler", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QWebEngineUrlSchemeHandler *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // installUrlSchemeHandler(QByteArray,QWebEngineUrlSchemeHandler*)
            cppSelf->installUrlSchemeHandler(*cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineProfileFunc_isOffTheRecord(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isOffTheRecord()const
        bool cppResult = const_cast<const ::QWebEngineProfile *>(cppSelf)->isOffTheRecord();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineProfileFunc_isPushServiceEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isPushServiceEnabled()const
        bool cppResult = const_cast<const ::QWebEngineProfile *>(cppSelf)->isPushServiceEnabled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineProfileFunc_isSpellCheckEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isSpellCheckEnabled()const
        bool cppResult = const_cast<const ::QWebEngineProfile *>(cppSelf)->isSpellCheckEnabled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineProfileFunc_listAllPermissions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // listAllPermissions()const
        QList<QWebEnginePermission> cppResult = const_cast<const ::QWebEngineProfile *>(cppSelf)->listAllPermissions();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtWebEngineCoreTypeConverters[SBK_QtWebEngineCore_QList_QWebEnginePermission_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineProfileFunc_listPermissionsForOrigin(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineProfile::listPermissionsForOrigin(QUrl)const->QList<QWebEnginePermission>
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // listPermissionsForOrigin(QUrl)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "listPermissionsForOrigin", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // listPermissionsForOrigin(QUrl)const
            QList<QWebEnginePermission> cppResult = const_cast<const ::QWebEngineProfile *>(cppSelf)->listPermissionsForOrigin(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtWebEngineCoreTypeConverters[SBK_QtWebEngineCore_QList_QWebEnginePermission_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineProfileFunc_listPermissionsForPermissionType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineProfile::listPermissionsForPermissionType(QWebEnginePermission::PermissionType)const->QList<QWebEnginePermission>
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePermission_PermissionType_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // listPermissionsForPermissionType(QWebEnginePermission::PermissionType)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "listPermissionsForPermissionType", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]);

    // Call function/method
    {
        ::QWebEnginePermission::PermissionType cppArg0{QWebEnginePermission::PermissionType::Unsupported};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // listPermissionsForPermissionType(QWebEnginePermission::PermissionType)const
            QList<QWebEnginePermission> cppResult = const_cast<const ::QWebEngineProfile *>(cppSelf)->listPermissionsForPermissionType(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtWebEngineCoreTypeConverters[SBK_QtWebEngineCore_QList_QWebEnginePermission_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineProfileFunc_persistentCookiesPolicy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // persistentCookiesPolicy()const
        QWebEngineProfile::PersistentCookiesPolicy cppResult = const_cast<const ::QWebEngineProfile *>(cppSelf)->persistentCookiesPolicy();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_PersistentCookiesPolicy_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineProfileFunc_persistentPermissionsPolicy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // persistentPermissionsPolicy()const
        QWebEngineProfile::PersistentPermissionsPolicy cppResult = const_cast<const ::QWebEngineProfile *>(cppSelf)->persistentPermissionsPolicy();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_PersistentPermissionsPolicy_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineProfileFunc_persistentStoragePath(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // persistentStoragePath()const
        QString cppResult = const_cast<const ::QWebEngineProfile *>(cppSelf)->persistentStoragePath();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineProfileFunc_queryPermission(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "queryPermission", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QWebEngineProfile::queryPermission(QUrl,QWebEnginePermission::PermissionType)const->QWebEnginePermission
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePermission_PermissionType_IDX])))->converter, (pyArgs[1])))) {
        overloadId = 0; // queryPermission(QUrl,QWebEnginePermission::PermissionType)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "queryPermission", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QWebEnginePermission::PermissionType cppArg1{QWebEnginePermission::PermissionType::Unsupported};
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // queryPermission(QUrl,QWebEnginePermission::PermissionType)const
            QWebEnginePermission cppResult = const_cast<const ::QWebEngineProfile *>(cppSelf)->queryPermission(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePermission_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineProfileFunc_removeAllUrlSchemeHandlers(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // removeAllUrlSchemeHandlers()
        cppSelf->removeAllUrlSchemeHandlers();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineProfileFunc_removeUrlScheme(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineProfile::removeUrlScheme(QByteArray)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // removeUrlScheme(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeUrlScheme", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // removeUrlScheme(QByteArray)
            cppSelf->removeUrlScheme(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineProfileFunc_removeUrlSchemeHandler(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineProfile::removeUrlSchemeHandler(QWebEngineUrlSchemeHandler*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlSchemeHandler_IDX]), (pyArg)))) {
        overloadId = 0; // removeUrlSchemeHandler(QWebEngineUrlSchemeHandler*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeUrlSchemeHandler", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QWebEngineUrlSchemeHandler *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeUrlSchemeHandler(QWebEngineUrlSchemeHandler*)
            cppSelf->removeUrlSchemeHandler(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineProfileFunc_scripts(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // scripts()const
        QWebEngineScriptCollection * cppResult = const_cast<const ::QWebEngineProfile *>(cppSelf)->scripts();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineScriptCollection_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineProfileFunc_setCachePath(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineProfile::setCachePath(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setCachePath(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCachePath", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCachePath(QString)
            cppSelf->setCachePath(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineProfileFunc_setDownloadPath(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineProfile::setDownloadPath(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setDownloadPath(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDownloadPath", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDownloadPath(QString)
            cppSelf->setDownloadPath(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineProfileFunc_setHttpAcceptLanguage(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineProfile::setHttpAcceptLanguage(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setHttpAcceptLanguage(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHttpAcceptLanguage", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHttpAcceptLanguage(QString)
            cppSelf->setHttpAcceptLanguage(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineProfileFunc_setHttpCacheMaximumSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineProfile::setHttpCacheMaximumSize(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setHttpCacheMaximumSize(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHttpCacheMaximumSize", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHttpCacheMaximumSize(int)
            cppSelf->setHttpCacheMaximumSize(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineProfileFunc_setHttpCacheType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineProfile::setHttpCacheType(QWebEngineProfile::HttpCacheType)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_HttpCacheType_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setHttpCacheType(QWebEngineProfile::HttpCacheType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHttpCacheType", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]);

    // Call function/method
    {
        ::QWebEngineProfile::HttpCacheType cppArg0{QWebEngineProfile::MemoryHttpCache};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHttpCacheType(QWebEngineProfile::HttpCacheType)
            cppSelf->setHttpCacheType(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineProfileFunc_setHttpUserAgent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineProfile::setHttpUserAgent(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setHttpUserAgent(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHttpUserAgent", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHttpUserAgent(QString)
            cppSelf->setHttpUserAgent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineProfileFunc_setNotificationPresenter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineProfile::setNotificationPresenter(PyCallable*)
    if (PyCallable_Check(pyArg)) {
        overloadId = 0; // setNotificationPresenter(PyCallable*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setNotificationPresenter", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]);

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // setNotificationPresenter(PyCallable*)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtwebenginecore.cpp (qwebengineprofile-setnotificationpresenter)]
            cppSelf->setNotificationPresenter(QWebEngineNotificationFunctor(pyArg));
            // END of custom code block [file: ../glue/qtwebenginecore.cpp (qwebengineprofile-setnotificationpresenter)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineProfileFunc_setPersistentCookiesPolicy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineProfile::setPersistentCookiesPolicy(QWebEngineProfile::PersistentCookiesPolicy)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_PersistentCookiesPolicy_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setPersistentCookiesPolicy(QWebEngineProfile::PersistentCookiesPolicy)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPersistentCookiesPolicy", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]);

    // Call function/method
    {
        ::QWebEngineProfile::PersistentCookiesPolicy cppArg0{QWebEngineProfile::NoPersistentCookies};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPersistentCookiesPolicy(QWebEngineProfile::PersistentCookiesPolicy)
            cppSelf->setPersistentCookiesPolicy(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineProfileFunc_setPersistentPermissionsPolicy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineProfile::setPersistentPermissionsPolicy(QWebEngineProfile::PersistentPermissionsPolicy)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_PersistentPermissionsPolicy_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setPersistentPermissionsPolicy(QWebEngineProfile::PersistentPermissionsPolicy)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPersistentPermissionsPolicy", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]);

    // Call function/method
    {
        ::QWebEngineProfile::PersistentPermissionsPolicy cppArg0{QWebEngineProfile::PersistentPermissionsPolicy::AskEveryTime};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPersistentPermissionsPolicy(QWebEngineProfile::PersistentPermissionsPolicy)
            cppSelf->setPersistentPermissionsPolicy(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineProfileFunc_setPersistentStoragePath(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineProfile::setPersistentStoragePath(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setPersistentStoragePath(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPersistentStoragePath", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPersistentStoragePath(QString)
            cppSelf->setPersistentStoragePath(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineProfileFunc_setPushServiceEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineProfile::setPushServiceEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setPushServiceEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPushServiceEnabled", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPushServiceEnabled(bool)
            cppSelf->setPushServiceEnabled(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineProfileFunc_setSpellCheckEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineProfile::setSpellCheckEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setSpellCheckEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSpellCheckEnabled", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSpellCheckEnabled(bool)
            cppSelf->setSpellCheckEnabled(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineProfileFunc_setSpellCheckLanguages(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineProfile::setSpellCheckLanguages(QStringList)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // setSpellCheckLanguages(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSpellCheckLanguages", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSpellCheckLanguages(QStringList)
            cppSelf->setSpellCheckLanguages(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineProfileFunc_setUrlRequestInterceptor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineProfile::setUrlRequestInterceptor(QWebEngineUrlRequestInterceptor*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlRequestInterceptor_IDX]), (pyArg)))) {
        overloadId = 0; // setUrlRequestInterceptor(QWebEngineUrlRequestInterceptor*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUrlRequestInterceptor", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QWebEngineUrlRequestInterceptor *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setUrlRequestInterceptor(QWebEngineUrlRequestInterceptor*)
            cppSelf->setUrlRequestInterceptor(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineProfileFunc_settings(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // settings()const
        QWebEngineSettings * cppResult = const_cast<const ::QWebEngineProfile *>(cppSelf)->settings();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineProfileFunc_spellCheckLanguages(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // spellCheckLanguages()const
        QStringList cppResult = const_cast<const ::QWebEngineProfile *>(cppSelf)->spellCheckLanguages();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineProfileFunc_storageName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // storageName()const
        QString cppResult = const_cast<const ::QWebEngineProfile *>(cppSelf)->storageName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineProfileFunc_urlSchemeHandler(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineProfile::urlSchemeHandler(QByteArray)const->const QWebEngineUrlSchemeHandler*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // urlSchemeHandler(QByteArray)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "urlSchemeHandler", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // urlSchemeHandler(QByteArray)const
            const QWebEngineUrlSchemeHandler * cppResult = const_cast<const ::QWebEngineProfile *>(cppSelf)->urlSchemeHandler(*cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlSchemeHandler_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineProfileFunc_visitedLinksContainsUrl(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineProfile::visitedLinksContainsUrl(QUrl)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // visitedLinksContainsUrl(QUrl)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "visitedLinksContainsUrl", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // visitedLinksContainsUrl(QUrl)const
            bool cppResult = const_cast<const ::QWebEngineProfile *>(cppSelf)->visitedLinksContainsUrl(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QWebEngineProfile_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QWebEngineProfile_EnumFlagInfo[] = {
    "HttpCacheType:Enum",
    "PersistentCookiesPolicy:Enum",
    "PersistentPermissionsPolicy:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QWebEngineProfile_methods[] = {
    {"cachePath", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_cachePath), METH_NOARGS, nullptr},
    {"clearAllVisitedLinks", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_clearAllVisitedLinks), METH_NOARGS, nullptr},
    {"clearHttpCache", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_clearHttpCache), METH_NOARGS, nullptr},
    {"clearVisitedLinks", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_clearVisitedLinks), METH_O, nullptr},
    {"clientCertificateStore", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_clientCertificateStore), METH_NOARGS, nullptr},
    {"clientHints", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_clientHints), METH_NOARGS, nullptr},
    {"cookieStore", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_cookieStore), METH_NOARGS, nullptr},
    {"defaultProfile", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_defaultProfile), METH_NOARGS|METH_STATIC, nullptr},
    {"downloadPath", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_downloadPath), METH_NOARGS, nullptr},
    {"httpAcceptLanguage", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_httpAcceptLanguage), METH_NOARGS, nullptr},
    {"httpCacheMaximumSize", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_httpCacheMaximumSize), METH_NOARGS, nullptr},
    {"httpCacheType", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_httpCacheType), METH_NOARGS, nullptr},
    {"httpUserAgent", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_httpUserAgent), METH_NOARGS, nullptr},
    {"installUrlSchemeHandler", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_installUrlSchemeHandler), METH_VARARGS, nullptr},
    {"isOffTheRecord", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_isOffTheRecord), METH_NOARGS, nullptr},
    {"isPushServiceEnabled", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_isPushServiceEnabled), METH_NOARGS, nullptr},
    {"isSpellCheckEnabled", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_isSpellCheckEnabled), METH_NOARGS, nullptr},
    {"listAllPermissions", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_listAllPermissions), METH_NOARGS, nullptr},
    {"listPermissionsForOrigin", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_listPermissionsForOrigin), METH_O, nullptr},
    {"listPermissionsForPermissionType", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_listPermissionsForPermissionType), METH_O, nullptr},
    {"persistentCookiesPolicy", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_persistentCookiesPolicy), METH_NOARGS, nullptr},
    {"persistentPermissionsPolicy", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_persistentPermissionsPolicy), METH_NOARGS, nullptr},
    {"persistentStoragePath", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_persistentStoragePath), METH_NOARGS, nullptr},
    {"queryPermission", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_queryPermission), METH_VARARGS, nullptr},
    {"removeAllUrlSchemeHandlers", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_removeAllUrlSchemeHandlers), METH_NOARGS, nullptr},
    {"removeUrlScheme", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_removeUrlScheme), METH_O, nullptr},
    {"removeUrlSchemeHandler", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_removeUrlSchemeHandler), METH_O, nullptr},
    {"scripts", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_scripts), METH_NOARGS, nullptr},
    {"setCachePath", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_setCachePath), METH_O, nullptr},
    {"setDownloadPath", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_setDownloadPath), METH_O, nullptr},
    {"setHttpAcceptLanguage", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_setHttpAcceptLanguage), METH_O, nullptr},
    {"setHttpCacheMaximumSize", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_setHttpCacheMaximumSize), METH_O, nullptr},
    {"setHttpCacheType", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_setHttpCacheType), METH_O, nullptr},
    {"setHttpUserAgent", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_setHttpUserAgent), METH_O, nullptr},
    {"setNotificationPresenter", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_setNotificationPresenter), METH_O, nullptr},
    {"setPersistentCookiesPolicy", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_setPersistentCookiesPolicy), METH_O, nullptr},
    {"setPersistentPermissionsPolicy", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_setPersistentPermissionsPolicy), METH_O, nullptr},
    {"setPersistentStoragePath", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_setPersistentStoragePath), METH_O, nullptr},
    {"setPushServiceEnabled", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_setPushServiceEnabled), METH_O, nullptr},
    {"setSpellCheckEnabled", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_setSpellCheckEnabled), METH_O, nullptr},
    {"setSpellCheckLanguages", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_setSpellCheckLanguages), METH_O, nullptr},
    {"setUrlRequestInterceptor", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_setUrlRequestInterceptor), METH_O, nullptr},
    {"settings", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_settings), METH_NOARGS, nullptr},
    {"spellCheckLanguages", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_spellCheckLanguages), METH_NOARGS, nullptr},
    {"storageName", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_storageName), METH_NOARGS, nullptr},
    {"urlSchemeHandler", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_urlSchemeHandler), METH_O, nullptr},
    {"visitedLinksContainsUrl", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileFunc_visitedLinksContainsUrl), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QWebEngineProfile_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QWebEngineProfileWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QWebEngineProfile_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QWebEngineProfile_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QWebEngineProfile_Type = nullptr;
static PyTypeObject *Sbk_QWebEngineProfile_TypeF(void)
{
    return _Sbk_QWebEngineProfile_Type;
}

static PyType_Slot Sbk_QWebEngineProfile_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QWebEngineProfile_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QWebEngineProfile_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QWebEngineProfile_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QWebEngineProfile_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QWebEngineProfile_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QWebEngineProfile_spec = {
    "2:PySide6.QtWebEngineCore.QWebEngineProfile",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QWebEngineProfile_slots
};

} //extern "C"

static void *Sbk_QWebEngineProfile_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QWebEngineProfile *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QWebEngineProfile_HttpCacheType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWebEngineProfile::HttpCacheType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QWebEngineProfile::HttpCacheType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QWebEngineProfile_HttpCacheType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_HttpCacheType_IDX])))
        return Enum_PythonToCpp_QWebEngineProfile_HttpCacheType;
    return {};
}

static PyObject *QWebEngineProfile_HttpCacheType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QWebEngineProfile::HttpCacheType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QWebEngineProfile::HttpCacheType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_HttpCacheType_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QWebEngineProfile_PersistentCookiesPolicy(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWebEngineProfile::PersistentCookiesPolicy>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QWebEngineProfile::PersistentCookiesPolicy *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QWebEngineProfile_PersistentCookiesPolicy_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_PersistentCookiesPolicy_IDX])))
        return Enum_PythonToCpp_QWebEngineProfile_PersistentCookiesPolicy;
    return {};
}

static PyObject *QWebEngineProfile_PersistentCookiesPolicy_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QWebEngineProfile::PersistentCookiesPolicy>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QWebEngineProfile::PersistentCookiesPolicy *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_PersistentCookiesPolicy_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QWebEngineProfile_PersistentPermissionsPolicy(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWebEngineProfile::PersistentPermissionsPolicy>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QWebEngineProfile::PersistentPermissionsPolicy *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QWebEngineProfile_PersistentPermissionsPolicy_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_PersistentPermissionsPolicy_IDX])))
        return Enum_PythonToCpp_QWebEngineProfile_PersistentPermissionsPolicy;
    return {};
}

static PyObject *QWebEngineProfile_PersistentPermissionsPolicy_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QWebEngineProfile::PersistentPermissionsPolicy>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QWebEngineProfile::PersistentPermissionsPolicy *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_PersistentPermissionsPolicy_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QWebEngineProfile_PythonToCpp_QWebEngineProfile_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QWebEngineProfile_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QWebEngineProfile_PythonToCpp_QWebEngineProfile_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QWebEngineProfile_TypeF()))
        return QWebEngineProfile_PythonToCpp_QWebEngineProfile_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QWebEngineProfile_PTR_CppToPython_QWebEngineProfile(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QWebEngineProfile *>(const_cast<void *>(cppIn)), Sbk_QWebEngineProfile_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QWebEngineProfile_SignatureStrings[] = {
    "1:PySide6.QtWebEngineCore.QWebEngineProfile(self,parent:PySide6.QtCore.QObject=nullptr)",
    "0:PySide6.QtWebEngineCore.QWebEngineProfile(self,name:QString,parent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtWebEngineCore.QWebEngineProfile.cachePath(self)->QString",
    "PySide6.QtWebEngineCore.QWebEngineProfile.clearAllVisitedLinks(self)",
    "PySide6.QtWebEngineCore.QWebEngineProfile.clearHttpCache(self)",
    "PySide6.QtWebEngineCore.QWebEngineProfile.clearVisitedLinks(self,urls:QList[PySide6.QtCore.QUrl])",
    "PySide6.QtWebEngineCore.QWebEngineProfile.clientCertificateStore(self)->PySide6.QtWebEngineCore.QWebEngineClientCertificateStore",
    "PySide6.QtWebEngineCore.QWebEngineProfile.clientHints(self)->PySide6.QtWebEngineCore.QWebEngineClientHints",
    "PySide6.QtWebEngineCore.QWebEngineProfile.cookieStore(self)->PySide6.QtWebEngineCore.QWebEngineCookieStore",
    "PySide6.QtWebEngineCore.QWebEngineProfile.defaultProfile()->PySide6.QtWebEngineCore.QWebEngineProfile",
    "PySide6.QtWebEngineCore.QWebEngineProfile.downloadPath(self)->QString",
    "PySide6.QtWebEngineCore.QWebEngineProfile.httpAcceptLanguage(self)->QString",
    "PySide6.QtWebEngineCore.QWebEngineProfile.httpCacheMaximumSize(self)->int",
    "PySide6.QtWebEngineCore.QWebEngineProfile.httpCacheType(self)->PySide6.QtWebEngineCore.QWebEngineProfile.HttpCacheType",
    "PySide6.QtWebEngineCore.QWebEngineProfile.httpUserAgent(self)->QString",
    "PySide6.QtWebEngineCore.QWebEngineProfile.installUrlSchemeHandler(self,scheme:typing.Union[PySide6.QtCore.QByteArray, char*],arg__2:PySide6.QtWebEngineCore.QWebEngineUrlSchemeHandler)",
    "PySide6.QtWebEngineCore.QWebEngineProfile.isOffTheRecord(self)->bool",
    "PySide6.QtWebEngineCore.QWebEngineProfile.isPushServiceEnabled(self)->bool",
    "PySide6.QtWebEngineCore.QWebEngineProfile.isSpellCheckEnabled(self)->bool",
    "PySide6.QtWebEngineCore.QWebEngineProfile.listAllPermissions(self)->QList[PySide6.QtWebEngineCore.QWebEnginePermission]",
    "PySide6.QtWebEngineCore.QWebEngineProfile.listPermissionsForOrigin(self,securityOrigin:typing.Union[PySide6.QtCore.QUrl, QString])->QList[PySide6.QtWebEngineCore.QWebEnginePermission]",
    "PySide6.QtWebEngineCore.QWebEngineProfile.listPermissionsForPermissionType(self,permissionType:PySide6.QtWebEngineCore.QWebEnginePermission.PermissionType)->QList[PySide6.QtWebEngineCore.QWebEnginePermission]",
    "PySide6.QtWebEngineCore.QWebEngineProfile.persistentCookiesPolicy(self)->PySide6.QtWebEngineCore.QWebEngineProfile.PersistentCookiesPolicy",
    "PySide6.QtWebEngineCore.QWebEngineProfile.persistentPermissionsPolicy(self)->PySide6.QtWebEngineCore.QWebEngineProfile.PersistentPermissionsPolicy",
    "PySide6.QtWebEngineCore.QWebEngineProfile.persistentStoragePath(self)->QString",
    "PySide6.QtWebEngineCore.QWebEngineProfile.queryPermission(self,securityOrigin:typing.Union[PySide6.QtCore.QUrl, QString],permissionType:PySide6.QtWebEngineCore.QWebEnginePermission.PermissionType)->PySide6.QtWebEngineCore.QWebEnginePermission",
    "PySide6.QtWebEngineCore.QWebEngineProfile.removeAllUrlSchemeHandlers(self)",
    "PySide6.QtWebEngineCore.QWebEngineProfile.removeUrlScheme(self,scheme:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "PySide6.QtWebEngineCore.QWebEngineProfile.removeUrlSchemeHandler(self,arg__1:PySide6.QtWebEngineCore.QWebEngineUrlSchemeHandler)",
    "PySide6.QtWebEngineCore.QWebEngineProfile.scripts(self)->PySide6.QtWebEngineCore.QWebEngineScriptCollection",
    "PySide6.QtWebEngineCore.QWebEngineProfile.setCachePath(self,path:QString)",
    "PySide6.QtWebEngineCore.QWebEngineProfile.setDownloadPath(self,path:QString)",
    "PySide6.QtWebEngineCore.QWebEngineProfile.setHttpAcceptLanguage(self,httpAcceptLanguage:QString)",
    "PySide6.QtWebEngineCore.QWebEngineProfile.setHttpCacheMaximumSize(self,maxSize:int)",
    "PySide6.QtWebEngineCore.QWebEngineProfile.setHttpCacheType(self,arg__1:PySide6.QtWebEngineCore.QWebEngineProfile.HttpCacheType)",
    "PySide6.QtWebEngineCore.QWebEngineProfile.setHttpUserAgent(self,userAgent:QString)",
    "PySide6.QtWebEngineCore.QWebEngineProfile.setNotificationPresenter(self,notificationPresenter:PyCallable)",
    "PySide6.QtWebEngineCore.QWebEngineProfile.setPersistentCookiesPolicy(self,arg__1:PySide6.QtWebEngineCore.QWebEngineProfile.PersistentCookiesPolicy)",
    "PySide6.QtWebEngineCore.QWebEngineProfile.setPersistentPermissionsPolicy(self,arg__1:PySide6.QtWebEngineCore.QWebEngineProfile.PersistentPermissionsPolicy)",
    "PySide6.QtWebEngineCore.QWebEngineProfile.setPersistentStoragePath(self,path:QString)",
    "PySide6.QtWebEngineCore.QWebEngineProfile.setPushServiceEnabled(self,enabled:bool)",
    "PySide6.QtWebEngineCore.QWebEngineProfile.setSpellCheckEnabled(self,enabled:bool)",
    "PySide6.QtWebEngineCore.QWebEngineProfile.setSpellCheckLanguages(self,languages:QStringList)",
    "PySide6.QtWebEngineCore.QWebEngineProfile.setUrlRequestInterceptor(self,interceptor:PySide6.QtWebEngineCore.QWebEngineUrlRequestInterceptor)",
    "PySide6.QtWebEngineCore.QWebEngineProfile.settings(self)->PySide6.QtWebEngineCore.QWebEngineSettings",
    "PySide6.QtWebEngineCore.QWebEngineProfile.spellCheckLanguages(self)->QStringList",
    "PySide6.QtWebEngineCore.QWebEngineProfile.storageName(self)->QString",
    "PySide6.QtWebEngineCore.QWebEngineProfile.urlSchemeHandler(self,arg__1:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtWebEngineCore.QWebEngineUrlSchemeHandler",
    "PySide6.QtWebEngineCore.QWebEngineProfile.visitedLinksContainsUrl(self,url:typing.Union[PySide6.QtCore.QUrl, QString])->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QWebEngineProfile_SignatureByteSize = 790;
static constexpr uint8_t QWebEngineProfile_SignatureBytes[790] = {
    0x78, 0xda, 0xc5, 0x58, 0x4d, 0x6f, 0xd3, 0x40, 0x10, 0xbd, 0xf3, 0x2b, 0x7a, 0xa4, 0xc8, 0x44,
    0x94, 0x03, 0x87, 0x48, 0x20, 0x05, 0x53, 0x14, 0xa4, 0xd2, 0x3a, 0x75, 0x03, 0x07, 0x14, 0x55,
    0x1b, 0x67, 0x12, 0x2f, 0x5d, 0xef, 0x9a, 0xdd, 0x75, 0xa9, 0xf9, 0xf5, 0x8c, 0x3f, 0xf3, 0x61,
    0xa7, 0x78, 0xec, 0x56, 0x1c, 0xd7, 0xde, 0x79, 0x6f, 0x76, 0x3c, 0x3b, 0x6f, 0xc6, 0x67, 0x63,
    0x2f, 0xf5, 0xf9, 0x0a, 0xde, 0x8d, 0x66, 0xf6, 0x3b, 0x2c, 0xcf, 0xe5, 0x86, 0x4b, 0x70, 0x95,
    0x86, 0xd1, 0xac, 0x5e, 0x7a, 0x5a, 0xad, 0xb9, 0x80, 0x97, 0x06, 0xc4, 0xda, 0x89, 0x99, 0x06,
    0x69, 0x77, 0xac, 0x8a, 0xcd, 0x57, 0xcb, 0x9f, 0x10, 0xd8, 0xf7, 0x32, 0x11, 0x22, 0xb6, 0xfa,
    0xf4, 0xc5, 0x1b, 0x2a, 0xae, 0x64, 0x11, 0x8c, 0x67, 0xbe, 0xd5, 0x5c, 0x6e, 0xba, 0x92, 0x74,
    0xa6, 0x18, 0x05, 0x2c, 0x08, 0xc1, 0x63, 0x36, 0xcc, 0xc9, 0x4e, 0x5f, 0x7f, 0x28, 0x99, 0x28,
    0x10, 0x02, 0x98, 0x9e, 0x08, 0xf1, 0x8d, 0x1b, 0x6e, 0x61, 0x75, 0xc1, 0xe5, 0x9d, 0x29, 0xd0,
    0xa8, 0x20, 0x53, 0x6b, 0x63, 0x37, 0x73, 0xa8, 0x9f, 0x79, 0xc3, 0x01, 0x27, 0xd1, 0xc2, 0x8c,
    0x67, 0x17, 0xdc, 0xd8, 0x1f, 0x87, 0x21, 0x9b, 0x6b, 0xb1, 0xa0, 0x31, 0x70, 0x8c, 0xbc, 0x0b,
    0xda, 0xf2, 0x35, 0x0f, 0x98, 0x05, 0xdf, 0xe2, 0xc6, 0x2a, 0x6a, 0xff, 0xc6, 0x71, 0x5b, 0xed,
    0xc9, 0x0e, 0x4c, 0xb9, 0xb4, 0x86, 0xca, 0x9a, 0x1b, 0x51, 0xa8, 0x94, 0xba, 0xe3, 0xe4, 0x03,
    0x6e, 0x8d, 0x08, 0x54, 0x2b, 0x58, 0xb3, 0x44, 0xd8, 0x2a, 0xe3, 0x3b, 0x31, 0x95, 0x9b, 0x29,
    0x2c, 0xea, 0xb7, 0x14, 0x8a, 0xad, 0x86, 0x25, 0x7a, 0x88, 0xe9, 0x39, 0x09, 0x02, 0x88, 0xed,
    0x05, 0x93, 0x9b, 0x84, 0x6d, 0x60, 0x18, 0x56, 0x9e, 0xea, 0x5f, 0xd9, 0x03, 0x8f, 0x92, 0xc8,
    0xe7, 0x7f, 0x6a, 0x34, 0xfc, 0x5a, 0x7d, 0x90, 0x6e, 0xd2, 0x98, 0xf0, 0xb9, 0x2a, 0xf3, 0xe9,
    0xae, 0x39, 0x91, 0x76, 0x6e, 0x40, 0x4f, 0x36, 0x98, 0x60, 0xfd, 0xe3, 0xc0, 0xa5, 0xb1, 0x4c,
    0x08, 0xbc, 0x8d, 0x3e, 0xfa, 0x10, 0xc1, 0x94, 0xc9, 0x95, 0x00, 0x5d, 0x5c, 0x5f, 0x93, 0x3f,
    0x1a, 0xdb, 0x34, 0x46, 0xd0, 0xd1, 0x5c, 0x72, 0x25, 0x1b, 0xf7, 0xf8, 0x63, 0x6a, 0x61, 0xa2,
    0x35, 0x4b, 0x9d, 0x93, 0x20, 0x64, 0xfa, 0xd5, 0xc2, 0x61, 0x7a, 0x73, 0x7b, 0xfb, 0xb6, 0x43,
    0x99, 0x3d, 0x24, 0xa5, 0x94, 0x03, 0x6e, 0xae, 0xd6, 0xeb, 0x9b, 0x10, 0xae, 0x21, 0x50, 0x7a,
    0x55, 0x9d, 0x7f, 0xa9, 0x94, 0x20, 0x81, 0x78, 0x89, 0x09, 0x7d, 0xd0, 0xf7, 0x3c, 0x80, 0x73,
    0xc9, 0x96, 0x02, 0xfa, 0x43, 0xf9, 0x31, 0x08, 0xe1, 0x86, 0x10, 0xdc, 0x0d, 0x43, 0x12, 0x58,
    0x2d, 0xb1, 0x9a, 0x7b, 0xa0, 0x23, 0x6e, 0x0c, 0x86, 0xbc, 0x2e, 0x37, 0x87, 0x85, 0xf4, 0x28,
    0x52, 0x6d, 0xba, 0x20, 0xf2, 0xee, 0x90, 0x7e, 0x56, 0xfa, 0x4a, 0x73, 0xdc, 0x50, 0xa6, 0x02,
    0x04, 0x89, 0xe6, 0x36, 0x2d, 0x9e, 0x3d, 0x9e, 0x12, 0xf8, 0x5d, 0x9d, 0x93, 0x32, 0x15, 0x17,
    0xff, 0xc1, 0xef, 0xed, 0xaa, 0xbe, 0x92, 0x4e, 0xbc, 0xf7, 0x6c, 0x4c, 0x71, 0x66, 0xb4, 0x8f,
    0xf7, 0xec, 0x07, 0x42, 0x57, 0x0d, 0xe2, 0x67, 0x6a, 0x95, 0x97, 0x74, 0xe3, 0x29, 0xc1, 0x83,
    0x94, 0x5e, 0x5a, 0xbc, 0x76, 0xa0, 0x5e, 0xae, 0xec, 0x44, 0x78, 0xb8, 0x3b, 0x0d, 0xb0, 0x5e,
    0x2e, 0x65, 0x52, 0x87, 0x1a, 0x30, 0x4c, 0x53, 0x7e, 0x25, 0xa0, 0xd3, 0xad, 0x3f, 0x03, 0x93,
    0xfd, 0x69, 0xd3, 0x8c, 0x62, 0x4d, 0x38, 0xb2, 0x86, 0x48, 0xdd, 0xc3, 0xa4, 0x59, 0xf4, 0xe9,
    0x5d, 0x63, 0x01, 0x55, 0xe3, 0x0c, 0x50, 0x8d, 0x01, 0xac, 0x7b, 0x92, 0x95, 0x8b, 0xcf, 0xd9,
    0x33, 0x8b, 0x8f, 0x09, 0x34, 0x8f, 0x29, 0x6d, 0xa0, 0x9f, 0x1b, 0xb8, 0x4a, 0x08, 0x1c, 0x13,
    0x68, 0x5f, 0xcb, 0x80, 0x75, 0xf7, 0x66, 0x04, 0x9c, 0x41, 0x6c, 0x58, 0x0d, 0x24, 0xa7, 0x34,
    0xa4, 0x4f, 0x87, 0x7d, 0xd8, 0x10, 0xb0, 0x69, 0x7b, 0x3b, 0xe6, 0x34, 0xdb, 0xb4, 0x01, 0x04,
    0xad, 0x3d, 0x9a, 0x13, 0xb1, 0x87, 0x6c, 0x31, 0xc6, 0x4e, 0xad, 0x2f, 0xe6, 0x56, 0x1a, 0x3a,
    0xa7, 0x4c, 0x6b, 0xcb, 0xd6, 0x83, 0x7f, 0xbf, 0x6d, 0x73, 0x92, 0x6a, 0xd9, 0x33, 0x4c, 0x97,
    0xaa, 0x1c, 0x69, 0x30, 0xb1, 0x3c, 0x0d, 0x06, 0x91, 0xaa, 0xdb, 0x20, 0xdb, 0x5e, 0xe1, 0x49,
    0x5d, 0x6c, 0xf9, 0xb2, 0x1e, 0x85, 0xc8, 0xe4, 0x3d, 0xa2, 0x4c, 0xf4, 0x30, 0x1e, 0x41, 0xeb,
    0xed, 0x53, 0xbb, 0x44, 0x0d, 0xf1, 0xab, 0x81, 0xd8, 0xdb, 0xb7, 0x43, 0xad, 0x1a, 0x72, 0xef,
    0x8e, 0xf4, 0xac, 0x0e, 0x14, 0x8b, 0x71, 0xd6, 0x6f, 0x12, 0x21, 0xdb, 0x7b, 0xd7, 0xa7, 0x41,
    0xac, 0x8a, 0x40, 0xf9, 0x4b, 0x40, 0x54, 0xcb, 0xea, 0xf4, 0x59, 0x2f, 0x45, 0x04, 0xc7, 0xda,
    0x7d, 0x0d, 0xa8, 0xdc, 0xc6, 0x7e, 0xc9, 0x12, 0x3a, 0x2b, 0x35, 0xaa, 0xcc, 0x78, 0xbe, 0x7d,
    0xd0, 0x4d, 0x04, 0x9a, 0x40, 0x44, 0x67, 0x2c, 0x9e, 0x81, 0x22, 0x05, 0xa5, 0x05, 0x85, 0xe4,
    0x48, 0x2c, 0xb7, 0x0d, 0x4f, 0x16, 0x43, 0x0a, 0x60, 0x91, 0x8d, 0x97, 0x2c, 0x1a, 0x30, 0x41,
    0x27, 0x8f, 0xe9, 0x2f, 0x51, 0xfc, 0xbb, 0x04, 0xee, 0x50, 0xb0, 0x09, 0xae, 0xde, 0xef, 0xfc,
    0x98, 0x72, 0x95, 0xb4, 0x0c, 0xa7, 0x5e, 0x84, 0xab, 0xff, 0x51, 0xd1, 0xc6, 0x99, 0x7c, 0x9e,
    0xfb, 0x0b, 0x0b, 0x28, 0xa0, 0x5e
};
#endif

PyTypeObject *init_QWebEngineProfile(PyObject *module)
{
    if (SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX].type != nullptr)
        return SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX].type;

    Shiboken::AutoDecRef Sbk_QWebEngineProfile_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QWebEngineProfile_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QWebEngineProfile",
        "QWebEngineProfile*",
        &Sbk_QWebEngineProfile_spec,
        &Shiboken::callCppDestructor< QWebEngineProfile >,
        Sbk_QWebEngineProfile_Type_bases.object(),
        0);
    auto *pyType = Sbk_QWebEngineProfile_TypeF(); // references _Sbk_QWebEngineProfile_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QWebEngineProfile_SignatureStrings);
#else
    InitSignatureBytes(pyType, QWebEngineProfile_SignatureBytes, QWebEngineProfile_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QWebEngineProfile_PropertyStrings);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QWebEngineProfile_PythonToCpp_QWebEngineProfile_PTR,
        is_QWebEngineProfile_PythonToCpp_QWebEngineProfile_PTR_Convertible,
        QWebEngineProfile_PTR_CppToPython_QWebEngineProfile);

    Shiboken::Conversions::registerConverterName(converter, "QWebEngineProfile");
    Shiboken::Conversions::registerConverterName(converter, "QWebEngineProfile*");
    Shiboken::Conversions::registerConverterName(converter, "QWebEngineProfile&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QWebEngineProfile).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QWebEngineProfileWrapper).name());


    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QWebEngineProfile_TypeF(), &Sbk_QWebEngineProfile_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QWebEngineProfile_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'HttpCacheType'.
    const char *HttpCacheType_Initializer[] = {
        "MemoryHttpCache",
        "DiskHttpCache",
        "NoCache",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t HttpCacheType_InitializerValues[] = {
        uint8_t(QWebEngineProfile::HttpCacheType::MemoryHttpCache), //  0x00  0
        uint8_t(QWebEngineProfile::HttpCacheType::DiskHttpCache),   //  0x01  1
        uint8_t(QWebEngineProfile::HttpCacheType::NoCache)          //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWebEngineProfile_TypeF(),
        "2:PySide6.QtWebEngineCore.QWebEngineProfile.HttpCacheType",
        HttpCacheType_Initializer, HttpCacheType_InitializerValues);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_HttpCacheType_IDX].type = EType;
    // Register converter for enum 'QWebEngineProfile::HttpCacheType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWebEngineProfile_HttpCacheType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QWebEngineProfile_HttpCacheType,
            is_Enum_PythonToCpp_QWebEngineProfile_HttpCacheType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QWebEngineProfile::HttpCacheType");
        Shiboken::Conversions::registerConverterAlias(converter, "HttpCacheType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'HttpCacheType' enum.

    // Initialization of enum 'PersistentCookiesPolicy'.
    const char *PersistentCookiesPolicy_Initializer[] = {
        "NoPersistentCookies",
        "AllowPersistentCookies",
        "ForcePersistentCookies",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t PersistentCookiesPolicy_InitializerValues[] = {
        uint8_t(QWebEngineProfile::PersistentCookiesPolicy::NoPersistentCookies),    //  0x00  0
        uint8_t(QWebEngineProfile::PersistentCookiesPolicy::AllowPersistentCookies), //  0x01  1
        uint8_t(QWebEngineProfile::PersistentCookiesPolicy::ForcePersistentCookies)  //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWebEngineProfile_TypeF(),
        "2:PySide6.QtWebEngineCore.QWebEngineProfile.PersistentCookiesPolicy",
        PersistentCookiesPolicy_Initializer, PersistentCookiesPolicy_InitializerValues);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_PersistentCookiesPolicy_IDX].type = EType;
    // Register converter for enum 'QWebEngineProfile::PersistentCookiesPolicy'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWebEngineProfile_PersistentCookiesPolicy_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QWebEngineProfile_PersistentCookiesPolicy,
            is_Enum_PythonToCpp_QWebEngineProfile_PersistentCookiesPolicy_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QWebEngineProfile::PersistentCookiesPolicy");
        Shiboken::Conversions::registerConverterAlias(converter, "PersistentCookiesPolicy");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'PersistentCookiesPolicy' enum.

    // Initialization of enum 'PersistentPermissionsPolicy'.
    const char *PersistentPermissionsPolicy_Initializer[] = {
        "AskEveryTime",
        "StoreInMemory",
        "StoreOnDisk",
        nullptr};
    // "uint8_t" used instead of "unsigned char"
    constexpr uint8_t PersistentPermissionsPolicy_InitializerValues[] = {
        uint8_t(QWebEngineProfile::PersistentPermissionsPolicy::AskEveryTime),  //  0x00  0
        uint8_t(QWebEngineProfile::PersistentPermissionsPolicy::StoreInMemory), //  0x01  1
        uint8_t(QWebEngineProfile::PersistentPermissionsPolicy::StoreOnDisk)    //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWebEngineProfile_TypeF(),
        "2:PySide6.QtWebEngineCore.QWebEngineProfile.PersistentPermissionsPolicy",
        PersistentPermissionsPolicy_Initializer, PersistentPermissionsPolicy_InitializerValues);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_PersistentPermissionsPolicy_IDX].type = EType;
    // Register converter for enum 'QWebEngineProfile::PersistentPermissionsPolicy'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWebEngineProfile_PersistentPermissionsPolicy_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QWebEngineProfile_PersistentPermissionsPolicy,
            is_Enum_PythonToCpp_QWebEngineProfile_PersistentPermissionsPolicy_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QWebEngineProfile::PersistentPermissionsPolicy");
        Shiboken::Conversions::registerConverterAlias(converter, "PersistentPermissionsPolicy");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'PersistentPermissionsPolicy' enum.

    PySide::Signal::registerSignals(pyType, &::QWebEngineProfile::staticMetaObject);

    qRegisterMetaType< ::QWebEngineProfile::HttpCacheType >("QWebEngineProfile::HttpCacheType");
    qRegisterMetaType< ::QWebEngineProfile::PersistentCookiesPolicy >("QWebEngineProfile::PersistentCookiesPolicy");
    qRegisterMetaType< ::QWebEngineProfile::PersistentPermissionsPolicy >("QWebEngineProfile::PersistentPermissionsPolicy");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QWebEngineProfile::staticMetaObject, sizeof(QWebEngineProfileWrapper));

    return pyType;
}

