// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwebenginecore_python.h"

// main header
#include "qwebenginequotarequest_wrapper.h"

// Argument includes
#include <QtWebEngineCore/qwebenginequotarequest.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qurl.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QWebEngineQuotaRequest_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QWebEngineQuotaRequest >()))
        return -1;

    ::QWebEngineQuotaRequest *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineQuotaRequest_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QWebEngineQuotaRequest", "QWebEngineQuotaRequest()");
        if (Shiboken::Errors::occurred() != nullptr)
            return -1;

        // QWebEngineQuotaRequest()
        cptr = new ::QWebEngineQuotaRequest();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QWebEngineQuotaRequest >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QWebEngineQuotaRequestFunc_accept(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineQuotaRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineQuotaRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // accept()
        cppSelf->accept();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineQuotaRequestFunc_origin(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineQuotaRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineQuotaRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // origin()const
        QUrl cppResult = const_cast<const ::QWebEngineQuotaRequest *>(cppSelf)->origin();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineQuotaRequestFunc_reject(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineQuotaRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineQuotaRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // reject()
        cppSelf->reject();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineQuotaRequestFunc_requestedSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineQuotaRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineQuotaRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // requestedSize()const
        qint64 cppResult = const_cast<const ::QWebEngineQuotaRequest *>(cppSelf)->requestedSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QWebEngineQuotaRequest_PropertyStrings[] = {
    "origin:",
    "requestedSize:",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QWebEngineQuotaRequest_methods[] = {
    {"accept", reinterpret_cast<PyCFunction>(Sbk_QWebEngineQuotaRequestFunc_accept), METH_NOARGS, nullptr},
    {"origin", reinterpret_cast<PyCFunction>(Sbk_QWebEngineQuotaRequestFunc_origin), METH_NOARGS, nullptr},
    {"reject", reinterpret_cast<PyCFunction>(Sbk_QWebEngineQuotaRequestFunc_reject), METH_NOARGS, nullptr},
    {"requestedSize", reinterpret_cast<PyCFunction>(Sbk_QWebEngineQuotaRequestFunc_requestedSize), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QWebEngineQuotaRequest_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QWebEngineQuotaRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineQuotaRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineQuotaRequest_IDX]), (pyArg)))) {
                // operator!=(const QWebEngineQuotaRequest &arg__1) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QWebEngineQuotaRequest *cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineQuotaRequest_IDX]), (pyArg)))) {
                // operator==(const QWebEngineQuotaRequest &arg__1) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QWebEngineQuotaRequest *cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QWebEngineQuotaRequest_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QWebEngineQuotaRequest_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QWebEngineQuotaRequest_Type = nullptr;
static PyTypeObject *Sbk_QWebEngineQuotaRequest_TypeF(void)
{
    return _Sbk_QWebEngineQuotaRequest_Type;
}

static PyType_Slot Sbk_QWebEngineQuotaRequest_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QWebEngineQuotaRequest_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QWebEngineQuotaRequest_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QWebEngineQuotaRequest_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QWebEngineQuotaRequest_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QWebEngineQuotaRequest_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QWebEngineQuotaRequest_spec = {
    "2:PySide6.QtWebEngineCore.QWebEngineQuotaRequest",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QWebEngineQuotaRequest_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QWebEngineQuotaRequest_PythonToCpp_QWebEngineQuotaRequest_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QWebEngineQuotaRequest_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QWebEngineQuotaRequest_PythonToCpp_QWebEngineQuotaRequest_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QWebEngineQuotaRequest_TypeF()))
        return QWebEngineQuotaRequest_PythonToCpp_QWebEngineQuotaRequest_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QWebEngineQuotaRequest_PTR_CppToPython_QWebEngineQuotaRequest(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QWebEngineQuotaRequest_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QWebEngineQuotaRequest_SignatureStrings[] = {
    "PySide6.QtWebEngineCore.QWebEngineQuotaRequest(self,*:KeywordOnly=None,origin:QUrl=None,requestedSize:qint64=None)",
    "PySide6.QtWebEngineCore.QWebEngineQuotaRequest.accept(self)",
    "PySide6.QtWebEngineCore.QWebEngineQuotaRequest.origin(self)->PySide6.QtCore.QUrl",
    "PySide6.QtWebEngineCore.QWebEngineQuotaRequest.reject(self)",
    "PySide6.QtWebEngineCore.QWebEngineQuotaRequest.requestedSize(self)->qint64",
    "PySide6.QtWebEngineCore.QWebEngineQuotaRequest.__ne__(self,arg__1:PySide6.QtWebEngineCore.QWebEngineQuotaRequest)->bool",
    "PySide6.QtWebEngineCore.QWebEngineQuotaRequest.__eq__(self,arg__1:PySide6.QtWebEngineCore.QWebEngineQuotaRequest)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QWebEngineQuotaRequest_SignatureByteSize = 176;
static constexpr uint8_t QWebEngineQuotaRequest_SignatureBytes[176] = {
    0x78, 0xda, 0xad, 0x91, 0xcb, 0x0a, 0xc2, 0x30, 0x10, 0x45, 0xf7, 0x7e, 0x89, 0x4a, 0x2d, 0x08,
    0xd2, 0x45, 0x40, 0x37, 0xe2, 0x4a, 0xd0, 0xc6, 0x22, 0x2e, 0x43, 0x1f, 0xd7, 0x12, 0x09, 0x89,
    0x9d, 0xa6, 0x48, 0xfd, 0x7a, 0x8b, 0x83, 0x8a, 0xcb, 0x88, 0xcb, 0x24, 0x73, 0xee, 0xb9, 0x4c,
    0xd2, 0x3e, 0xd3, 0x15, 0x92, 0x58, 0xfa, 0x13, 0x8a, 0x8d, 0xad, 0xb5, 0xc5, 0xda, 0x11, 0x62,
    0xf9, 0x3e, 0xca, 0xce, 0xf9, 0xfc, 0x80, 0xa6, 0x43, 0xeb, 0xc7, 0x2d, 0xcc, 0x39, 0x9a, 0x8a,
    0x2d, 0xfa, 0x9b, 0xa3, 0x6a, 0x6f, 0x4d, 0xbf, 0xdc, 0x39, 0x8b, 0xc8, 0x91, 0x1e, 0x66, 0x85,
    0x3c, 0x92, 0xe1, 0x0b, 0x62, 0x00, 0x55, 0xa6, 0xef, 0x10, 0x8d, 0xb6, 0x3e, 0x59, 0x3c, 0x5f,
    0x26, 0xa3, 0x34, 0x48, 0x19, 0xe7, 0x65, 0x89, 0x2b, 0x9b, 0x83, 0x59, 0xae, 0xc5, 0xec, 0x6c,
    0xf5, 0x81, 0x99, 0x19, 0xca, 0x86, 0x06, 0x12, 0x2e, 0x28, 0x7f, 0x2c, 0xf3, 0xb5, 0x92, 0x57,
    0x27, 0xde, 0x4c, 0x68, 0x94, 0x52, 0x16, 0x4a, 0xf1, 0x6f, 0xe4, 0x54, 0x2b, 0x35, 0x17, 0x61,
    0x09, 0x83, 0xb9, 0x70, 0xce, 0x84, 0x7b, 0xd1, 0xfc, 0xc5, 0xfb, 0x00, 0x63, 0x58, 0xe6, 0xc8
};
#endif

PyTypeObject *init_QWebEngineQuotaRequest(PyObject *module)
{
    if (SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineQuotaRequest_IDX].type != nullptr)
        return SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineQuotaRequest_IDX].type;

    Shiboken::AutoDecRef Sbk_QWebEngineQuotaRequest_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QWebEngineQuotaRequest_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QWebEngineQuotaRequest",
        "QWebEngineQuotaRequest*",
        &Sbk_QWebEngineQuotaRequest_spec,
        &Shiboken::callCppDestructor< ::QWebEngineQuotaRequest >,
        Sbk_QWebEngineQuotaRequest_Type_bases.object(),
        0);
    auto *pyType = Sbk_QWebEngineQuotaRequest_TypeF(); // references _Sbk_QWebEngineQuotaRequest_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QWebEngineQuotaRequest_SignatureStrings);
#else
    InitSignatureBytes(pyType, QWebEngineQuotaRequest_SignatureBytes, QWebEngineQuotaRequest_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QWebEngineQuotaRequest_PropertyStrings);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineQuotaRequest_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QWebEngineQuotaRequest_PythonToCpp_QWebEngineQuotaRequest_PTR,
        is_QWebEngineQuotaRequest_PythonToCpp_QWebEngineQuotaRequest_PTR_Convertible,
        QWebEngineQuotaRequest_PTR_CppToPython_QWebEngineQuotaRequest);

    Shiboken::Conversions::registerConverterName(converter, "QWebEngineQuotaRequest");
    Shiboken::Conversions::registerConverterName(converter, "QWebEngineQuotaRequest*");
    Shiboken::Conversions::registerConverterName(converter, "QWebEngineQuotaRequest&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QWebEngineQuotaRequest).name());

    qRegisterMetaType< ::QWebEngineQuotaRequest *>();

    return pyType;
}
