// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwebenginecore_python.h"

// main header
#include "qwebenginescript_wrapper.h"

// Argument includes
#include <QString>
#include <QtWebEngineCore/qwebenginescript.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qurl.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QWebEngineScript_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QWebEngineScript >()))
        return -1;

    ::QWebEngineScript *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QWebEngineScript", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QWebEngineScript::QWebEngineScript()
    // 1: QWebEngineScript::QWebEngineScript(QWebEngineScript)
    if (numArgs == 0) {
        overloadId = 0; // QWebEngineScript()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineScript_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QWebEngineScript(QWebEngineScript)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineScript_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineScript_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QWebEngineScript()
        {

            // QWebEngineScript()
            cptr = new ::QWebEngineScript();
            break;
        }
        case 1: // QWebEngineScript(const QWebEngineScript &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QWebEngineScript cppArg0_local;
            ::QWebEngineScript *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QWebEngineScript(QWebEngineScript)
                cptr = new ::QWebEngineScript(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QWebEngineScript >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineScript_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QWebEngineScriptFunc_injectionPoint(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineScript *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineScript_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // injectionPoint()const
        QWebEngineScript::InjectionPoint cppResult = const_cast<const ::QWebEngineScript *>(cppSelf)->injectionPoint();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineScript_InjectionPoint_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineScriptFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineScript *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineScript_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // name()const
        QString cppResult = const_cast<const ::QWebEngineScript *>(cppSelf)->name();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineScriptFunc_runsOnSubFrames(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineScript *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineScript_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // runsOnSubFrames()const
        bool cppResult = const_cast<const ::QWebEngineScript *>(cppSelf)->runsOnSubFrames();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineScriptFunc_setInjectionPoint(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineScript *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineScript_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineScript::setInjectionPoint(QWebEngineScript::InjectionPoint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineScript_InjectionPoint_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setInjectionPoint(QWebEngineScript::InjectionPoint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setInjectionPoint", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineScript_IDX]);

    // Call function/method
    {
        ::QWebEngineScript::InjectionPoint cppArg0{QWebEngineScript::Deferred};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setInjectionPoint(QWebEngineScript::InjectionPoint)
            cppSelf->setInjectionPoint(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineScriptFunc_setName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineScript *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineScript_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineScript::setName(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setName", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineScript_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setName(QString)
            cppSelf->setName(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineScriptFunc_setRunsOnSubFrames(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineScript *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineScript_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineScript::setRunsOnSubFrames(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setRunsOnSubFrames(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRunsOnSubFrames", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineScript_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRunsOnSubFrames(bool)
            cppSelf->setRunsOnSubFrames(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineScriptFunc_setSourceCode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineScript *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineScript_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineScript::setSourceCode(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setSourceCode(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSourceCode", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineScript_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSourceCode(QString)
            cppSelf->setSourceCode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineScriptFunc_setSourceUrl(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineScript *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineScript_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineScript::setSourceUrl(QUrl)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // setSourceUrl(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSourceUrl", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineScript_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setSourceUrl(QUrl)
            cppSelf->setSourceUrl(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineScriptFunc_setWorldId(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineScript *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineScript_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineScript::setWorldId(quint32)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArg)))) {
        overloadId = 0; // setWorldId(quint32)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setWorldId", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineScript_IDX]);

    // Call function/method
    {
        quint32 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setWorldId(quint32)
            cppSelf->setWorldId(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineScriptFunc_sourceCode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineScript *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineScript_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sourceCode()const
        QString cppResult = const_cast<const ::QWebEngineScript *>(cppSelf)->sourceCode();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineScriptFunc_sourceUrl(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineScript *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineScript_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sourceUrl()const
        QUrl cppResult = const_cast<const ::QWebEngineScript *>(cppSelf)->sourceUrl();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineScriptFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineScript *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineScript_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineScript::swap(QWebEngineScript&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineScript_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QWebEngineScript&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineScript_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QWebEngineScript cppArg0_local;
        ::QWebEngineScript *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QWebEngineScript&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineScriptFunc_worldId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineScript *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineScript_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // worldId()const
        quint32 cppResult = const_cast<const ::QWebEngineScript *>(cppSelf)->worldId();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineScript__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QWebEngineScript *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineScript_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineScript_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QWebEngineScript_PropertyStrings[] = {
    "injectionPoint::",
    "name::",
    "runsOnSubFrames::",
    "sourceCode::",
    "sourceUrl::",
    "worldId::",
    nullptr // Sentinel
};

static const char *Sbk_QWebEngineScript_EnumFlagInfo[] = {
    "InjectionPoint:Enum",
    "ScriptWorldId:IntEnum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QWebEngineScript_methods[] = {
    {"injectionPoint", reinterpret_cast<PyCFunction>(Sbk_QWebEngineScriptFunc_injectionPoint), METH_NOARGS, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_QWebEngineScriptFunc_name), METH_NOARGS, nullptr},
    {"runsOnSubFrames", reinterpret_cast<PyCFunction>(Sbk_QWebEngineScriptFunc_runsOnSubFrames), METH_NOARGS, nullptr},
    {"setInjectionPoint", reinterpret_cast<PyCFunction>(Sbk_QWebEngineScriptFunc_setInjectionPoint), METH_O, nullptr},
    {"setName", reinterpret_cast<PyCFunction>(Sbk_QWebEngineScriptFunc_setName), METH_O, nullptr},
    {"setRunsOnSubFrames", reinterpret_cast<PyCFunction>(Sbk_QWebEngineScriptFunc_setRunsOnSubFrames), METH_O, nullptr},
    {"setSourceCode", reinterpret_cast<PyCFunction>(Sbk_QWebEngineScriptFunc_setSourceCode), METH_O, nullptr},
    {"setSourceUrl", reinterpret_cast<PyCFunction>(Sbk_QWebEngineScriptFunc_setSourceUrl), METH_O, nullptr},
    {"setWorldId", reinterpret_cast<PyCFunction>(Sbk_QWebEngineScriptFunc_setWorldId), METH_O, nullptr},
    {"sourceCode", reinterpret_cast<PyCFunction>(Sbk_QWebEngineScriptFunc_sourceCode), METH_NOARGS, nullptr},
    {"sourceUrl", reinterpret_cast<PyCFunction>(Sbk_QWebEngineScriptFunc_sourceUrl), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QWebEngineScriptFunc_swap), METH_O, nullptr},
    {"worldId", reinterpret_cast<PyCFunction>(Sbk_QWebEngineScriptFunc_worldId), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QWebEngineScript__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QWebEngineScript_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QWebEngineScript *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineScript_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineScript_IDX]), (pyArg)))) {
                // operator!=(const QWebEngineScript &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QWebEngineScript cppArg0_local;
                ::QWebEngineScript *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineScript_IDX]), (pyArg)))) {
                // operator==(const QWebEngineScript &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QWebEngineScript cppArg0_local;
                ::QWebEngineScript *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QWebEngineScript_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QWebEngineScript_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QWebEngineScript__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineScript *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineScript_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QWebEngineScript_Type = nullptr;
static PyTypeObject *Sbk_QWebEngineScript_TypeF(void)
{
    return _Sbk_QWebEngineScript_Type;
}

static PyType_Slot Sbk_QWebEngineScript_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QWebEngineScript__repr__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QWebEngineScript_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QWebEngineScript_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QWebEngineScript_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QWebEngineScript_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QWebEngineScript_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QWebEngineScript_spec = {
    "2:PySide6.QtWebEngineCore.QWebEngineScript",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QWebEngineScript_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QWebEngineScript_InjectionPoint(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWebEngineScript::InjectionPoint>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QWebEngineScript::InjectionPoint *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QWebEngineScript_InjectionPoint_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineScript_InjectionPoint_IDX])))
        return Enum_PythonToCpp_QWebEngineScript_InjectionPoint;
    return {};
}

static PyObject *QWebEngineScript_InjectionPoint_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QWebEngineScript::InjectionPoint>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QWebEngineScript::InjectionPoint *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineScript_InjectionPoint_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QWebEngineScript_ScriptWorldId(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWebEngineScript::ScriptWorldId>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QWebEngineScript::ScriptWorldId *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QWebEngineScript_ScriptWorldId_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineScript_ScriptWorldId_IDX])))
        return Enum_PythonToCpp_QWebEngineScript_ScriptWorldId;
    return {};
}

static PyObject *QWebEngineScript_ScriptWorldId_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QWebEngineScript::ScriptWorldId>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QWebEngineScript::ScriptWorldId *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineScript_ScriptWorldId_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QWebEngineScript_PythonToCpp_QWebEngineScript_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QWebEngineScript_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QWebEngineScript_PythonToCpp_QWebEngineScript_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QWebEngineScript_TypeF()))
        return QWebEngineScript_PythonToCpp_QWebEngineScript_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QWebEngineScript_PTR_CppToPython_QWebEngineScript(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QWebEngineScript_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QWebEngineScript_COPY_CppToPython_QWebEngineScript(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QWebEngineScript *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QWebEngineScript_TypeF(), new ::QWebEngineScript(*source), true, true);
}

// Python to C++ copy conversion.
static void QWebEngineScript_PythonToCpp_QWebEngineScript_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QWebEngineScript *>(cppOut) = *reinterpret_cast< ::QWebEngineScript *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineScript_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QWebEngineScript_PythonToCpp_QWebEngineScript_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QWebEngineScript_TypeF()))
        return QWebEngineScript_PythonToCpp_QWebEngineScript_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QWebEngineScript_SignatureStrings[] = {
    "1:PySide6.QtWebEngineCore.QWebEngineScript(self,*:KeywordOnly=None,name:QString=None,sourceUrl:QUrl=None,sourceCode:QString=None,injectionPoint:QWebEngineScript.InjectionPoint=None,worldId:quint32=None,runsOnSubFrames:bool=None)",
    "0:PySide6.QtWebEngineCore.QWebEngineScript(self,other:PySide6.QtWebEngineCore.QWebEngineScript,*:KeywordOnly=None,name:QString=None,sourceUrl:QUrl=None,sourceCode:QString=None,injectionPoint:QWebEngineScript.InjectionPoint=None,worldId:quint32=None,runsOnSubFrames:bool=None)",
    "PySide6.QtWebEngineCore.QWebEngineScript.injectionPoint(self)->PySide6.QtWebEngineCore.QWebEngineScript.InjectionPoint",
    "PySide6.QtWebEngineCore.QWebEngineScript.name(self)->QString",
    "PySide6.QtWebEngineCore.QWebEngineScript.runsOnSubFrames(self)->bool",
    "PySide6.QtWebEngineCore.QWebEngineScript.setInjectionPoint(self,arg__1:PySide6.QtWebEngineCore.QWebEngineScript.InjectionPoint)",
    "PySide6.QtWebEngineCore.QWebEngineScript.setName(self,arg__1:QString)",
    "PySide6.QtWebEngineCore.QWebEngineScript.setRunsOnSubFrames(self,on:bool)",
    "PySide6.QtWebEngineCore.QWebEngineScript.setSourceCode(self,arg__1:QString)",
    "PySide6.QtWebEngineCore.QWebEngineScript.setSourceUrl(self,url:typing.Union[PySide6.QtCore.QUrl, QString])",
    "PySide6.QtWebEngineCore.QWebEngineScript.setWorldId(self,arg__1:quint32)",
    "PySide6.QtWebEngineCore.QWebEngineScript.sourceCode(self)->QString",
    "PySide6.QtWebEngineCore.QWebEngineScript.sourceUrl(self)->PySide6.QtCore.QUrl",
    "PySide6.QtWebEngineCore.QWebEngineScript.swap(self,other:PySide6.QtWebEngineCore.QWebEngineScript)",
    "PySide6.QtWebEngineCore.QWebEngineScript.worldId(self)->quint32",
    "PySide6.QtWebEngineCore.QWebEngineScript.__copy__(self)->typing.Self",
    "PySide6.QtWebEngineCore.QWebEngineScript.__ne__(self,other:PySide6.QtWebEngineCore.QWebEngineScript)->bool",
    "PySide6.QtWebEngineCore.QWebEngineScript.__eq__(self,other:PySide6.QtWebEngineCore.QWebEngineScript)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QWebEngineScript_SignatureByteSize = 349;
static constexpr uint8_t QWebEngineScript_SignatureBytes[349] = {
    0x78, 0xda, 0xd5, 0x54, 0x4f, 0x4b, 0xc3, 0x30, 0x14, 0xbf, 0xfb, 0x29, 0x3c, 0x3a, 0xa9, 0xc5,
    0x29, 0x78, 0x08, 0xe8, 0x65, 0x28, 0x0c, 0x61, 0x5b, 0x0d, 0x63, 0x07, 0x91, 0xb0, 0xb6, 0xcf,
    0x19, 0xa9, 0x2f, 0x5d, 0x9a, 0x52, 0xfa, 0xed, 0xcd, 0x96, 0x74, 0x2e, 0xd5, 0x43, 0xd2, 0x9d,
    0xbc, 0x14, 0xf2, 0x9a, 0xf7, 0xfb, 0xd7, 0xf7, 0x3a, 0x26, 0x8b, 0x96, 0xf2, 0x1c, 0xee, 0xe2,
    0x44, 0xad, 0x20, 0x7d, 0xc4, 0x0d, 0x47, 0x98, 0x08, 0x09, 0x71, 0x72, 0x38, 0xd2, 0x4c, 0xf2,
    0x52, 0x5d, 0x54, 0x50, 0xbc, 0x47, 0x97, 0xe4, 0x19, 0xda, 0x46, 0xc8, 0x7c, 0x8e, 0x45, 0x7b,
    0x3f, 0x13, 0x08, 0x11, 0xae, 0xbf, 0x80, 0x24, 0x54, 0x49, 0x8e, 0x1b, 0x53, 0xa9, 0x44, 0x2d,
    0x33, 0x58, 0xca, 0x82, 0x24, 0xfa, 0x71, 0x5c, 0x9b, 0x88, 0xbc, 0x77, 0x97, 0xe3, 0x27, 0x64,
    0x8a, 0x0b, 0x5c, 0x08, 0x8e, 0x8a, 0xf4, 0x59, 0xe3, 0xa9, 0xf3, 0xde, 0xf4, 0x68, 0xfe, 0x22,
    0x9f, 0xe6, 0x64, 0x5b, 0xeb, 0xd2, 0xed, 0x8d, 0x29, 0xca, 0x1a, 0xab, 0x39, 0xd2, 0x3a, 0x7d,
    0x92, 0x5a, 0x50, 0x45, 0x52, 0x21, 0x0c, 0xf5, 0xe8, 0xec, 0x3a, 0xd0, 0xa4, 0x50, 0x1f, 0x20,
    0xbd, 0x7b, 0xfe, 0x67, 0x26, 0xbe, 0xee, 0x62, 0x57, 0xcc, 0x3e, 0xa0, 0xd1, 0xd5, 0x83, 0x77,
    0xbb, 0xab, 0xd5, 0x9f, 0x76, 0x97, 0x60, 0x47, 0x66, 0xc3, 0xf1, 0x6f, 0xee, 0xf9, 0xee, 0x70,
    0x76, 0xf6, 0xfd, 0x41, 0x2a, 0x50, 0xd3, 0xdf, 0xde, 0xa3, 0xb5, 0xdc, 0x30, 0x36, 0x26, 0x03,
    0x03, 0x18, 0x05, 0xf1, 0xcf, 0xba, 0x10, 0x3a, 0x56, 0x9b, 0x44, 0x18, 0xca, 0xcb, 0x1f, 0x69,
    0x44, 0x02, 0xf7, 0xd3, 0x10, 0x86, 0x44, 0x0f, 0x03, 0x7b, 0xba, 0x2a, 0xda, 0x2d, 0x84, 0x81,
    0xaa, 0xf5, 0x66, 0xa8, 0xb6, 0xd4, 0x30, 0xf1, 0x12, 0x75, 0x5a, 0xaf, 0x3f, 0x58, 0x06, 0x42,
    0xdf, 0x8c, 0xce, 0x2d, 0xd3, 0x5b, 0x18, 0xd5, 0xca, 0xec, 0x86, 0xa3, 0xd9, 0xee, 0x49, 0x08,
    0x90, 0x6b, 0x7e, 0xc8, 0x5c, 0x56, 0x8e, 0x67, 0x67, 0x8d, 0x0e, 0x26, 0x03, 0xd0, 0x9a, 0x75,
    0x39, 0xe4, 0x87, 0x15, 0xe0, 0xb9, 0x39, 0x4a, 0x4e, 0xcb, 0xb5, 0xa1, 0xf9, 0xf7, 0x33, 0x96,
    0x89, 0xb2, 0x65, 0xac, 0x03, 0xb0, 0x5f, 0x98, 0xea, 0x53, 0x08, 0x08, 0x82, 0x85, 0x08, 0x75,
    0x1a, 0xba, 0xf3, 0x8c, 0xc1, 0xf6, 0x34, 0xaa, 0x6f, 0xcb, 0x31, 0xad, 0x0d
};
#endif

PyTypeObject *init_QWebEngineScript(PyObject *module)
{
    if (SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineScript_IDX].type != nullptr)
        return SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineScript_IDX].type;

    Shiboken::AutoDecRef Sbk_QWebEngineScript_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QWebEngineScript_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QWebEngineScript",
        "QWebEngineScript",
        &Sbk_QWebEngineScript_spec,
        &Shiboken::callCppDestructor< ::QWebEngineScript >,
        Sbk_QWebEngineScript_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QWebEngineScript_TypeF(); // references _Sbk_QWebEngineScript_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QWebEngineScript_SignatureStrings);
#else
    InitSignatureBytes(pyType, QWebEngineScript_SignatureBytes, QWebEngineScript_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QWebEngineScript_PropertyStrings);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineScript_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QWebEngineScript_PythonToCpp_QWebEngineScript_PTR,
        is_QWebEngineScript_PythonToCpp_QWebEngineScript_PTR_Convertible,
        QWebEngineScript_PTR_CppToPython_QWebEngineScript,
        QWebEngineScript_COPY_CppToPython_QWebEngineScript);

    Shiboken::Conversions::registerConverterName(converter, "QWebEngineScript");
    Shiboken::Conversions::registerConverterName(converter, "QWebEngineScript*");
    Shiboken::Conversions::registerConverterName(converter, "QWebEngineScript&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QWebEngineScript).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QWebEngineScript_PythonToCpp_QWebEngineScript_COPY,
        is_QWebEngineScript_PythonToCpp_QWebEngineScript_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QWebEngineScript_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'InjectionPoint'.
    const char *InjectionPoint_Initializer[] = {
        "Deferred",
        "DocumentReady",
        "DocumentCreation",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t InjectionPoint_InitializerValues[] = {
        uint8_t(QWebEngineScript::InjectionPoint::Deferred),        //  0x00  0
        uint8_t(QWebEngineScript::InjectionPoint::DocumentReady),   //  0x01  1
        uint8_t(QWebEngineScript::InjectionPoint::DocumentCreation) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWebEngineScript_TypeF(),
        "2:PySide6.QtWebEngineCore.QWebEngineScript.InjectionPoint",
        InjectionPoint_Initializer, InjectionPoint_InitializerValues);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineScript_InjectionPoint_IDX].type = EType;
    // Register converter for enum 'QWebEngineScript::InjectionPoint'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWebEngineScript_InjectionPoint_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QWebEngineScript_InjectionPoint,
            is_Enum_PythonToCpp_QWebEngineScript_InjectionPoint_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QWebEngineScript::InjectionPoint");
        Shiboken::Conversions::registerConverterAlias(converter, "InjectionPoint");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'InjectionPoint' enum.

    // Initialization of enum 'ScriptWorldId'.
    const char *ScriptWorldId_Initializer[] = {
        "MainWorld",
        "ApplicationWorld",
        "UserWorld",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ScriptWorldId_InitializerValues[] = {
        uint8_t(QWebEngineScript::ScriptWorldId::MainWorld),        //  0x00  0
        uint8_t(QWebEngineScript::ScriptWorldId::ApplicationWorld), //  0x01  1
        uint8_t(QWebEngineScript::ScriptWorldId::UserWorld)         //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWebEngineScript_TypeF(),
        "2:PySide6.QtWebEngineCore.QWebEngineScript.ScriptWorldId",
        ScriptWorldId_Initializer, ScriptWorldId_InitializerValues);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineScript_ScriptWorldId_IDX].type = EType;
    // Register converter for enum 'QWebEngineScript::ScriptWorldId'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWebEngineScript_ScriptWorldId_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QWebEngineScript_ScriptWorldId,
            is_Enum_PythonToCpp_QWebEngineScript_ScriptWorldId_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QWebEngineScript::ScriptWorldId");
        Shiboken::Conversions::registerConverterAlias(converter, "ScriptWorldId");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ScriptWorldId' enum.

    qRegisterMetaType< ::QWebEngineScript >("QWebEngineScript");
    qRegisterMetaType< ::QWebEngineScript::InjectionPoint >("QWebEngineScript::InjectionPoint");
    qRegisterMetaType< ::QWebEngineScript::ScriptWorldId >("QWebEngineScript::ScriptWorldId");

    return pyType;
}
