// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwebenginecore_python.h"

// main header
#include "qwebenginesettings_wrapper.h"

// Argument includes
#include <QString>
#include <QtWebEngineCore/qwebenginesettings.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QWebEngineSettingsFunc_defaultTextEncoding(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineSettings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // defaultTextEncoding()const
        QString cppResult = const_cast<const ::QWebEngineSettings *>(cppSelf)->defaultTextEncoding();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineSettingsFunc_fontFamily(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineSettings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineSettings::fontFamily(QWebEngineSettings::FontFamily)const->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_FontFamily_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // fontFamily(QWebEngineSettings::FontFamily)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fontFamily", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_IDX]);

    // Call function/method
    {
        ::QWebEngineSettings::FontFamily cppArg0{QWebEngineSettings::StandardFont};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fontFamily(QWebEngineSettings::FontFamily)const
            QString cppResult = const_cast<const ::QWebEngineSettings *>(cppSelf)->fontFamily(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineSettingsFunc_fontSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineSettings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineSettings::fontSize(QWebEngineSettings::FontSize)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_FontSize_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // fontSize(QWebEngineSettings::FontSize)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fontSize", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_IDX]);

    // Call function/method
    {
        ::QWebEngineSettings::FontSize cppArg0{QWebEngineSettings::MinimumFontSize};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fontSize(QWebEngineSettings::FontSize)const
            int cppResult = const_cast<const ::QWebEngineSettings *>(cppSelf)->fontSize(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineSettingsFunc_imageAnimationPolicy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineSettings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // imageAnimationPolicy()const
        QWebEngineSettings::ImageAnimationPolicy cppResult = const_cast<const ::QWebEngineSettings *>(cppSelf)->imageAnimationPolicy();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_ImageAnimationPolicy_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineSettingsFunc_resetAttribute(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineSettings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineSettings::resetAttribute(QWebEngineSettings::WebAttribute)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_WebAttribute_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // resetAttribute(QWebEngineSettings::WebAttribute)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "resetAttribute", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_IDX]);

    // Call function/method
    {
        ::QWebEngineSettings::WebAttribute cppArg0{QWebEngineSettings::AutoLoadImages};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // resetAttribute(QWebEngineSettings::WebAttribute)
            cppSelf->resetAttribute(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineSettingsFunc_resetFontFamily(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineSettings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineSettings::resetFontFamily(QWebEngineSettings::FontFamily)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_FontFamily_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // resetFontFamily(QWebEngineSettings::FontFamily)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "resetFontFamily", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_IDX]);

    // Call function/method
    {
        ::QWebEngineSettings::FontFamily cppArg0{QWebEngineSettings::StandardFont};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // resetFontFamily(QWebEngineSettings::FontFamily)
            cppSelf->resetFontFamily(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineSettingsFunc_resetFontSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineSettings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineSettings::resetFontSize(QWebEngineSettings::FontSize)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_FontSize_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // resetFontSize(QWebEngineSettings::FontSize)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "resetFontSize", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_IDX]);

    // Call function/method
    {
        ::QWebEngineSettings::FontSize cppArg0{QWebEngineSettings::MinimumFontSize};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // resetFontSize(QWebEngineSettings::FontSize)
            cppSelf->resetFontSize(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineSettingsFunc_resetImageAnimationPolicy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineSettings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // resetImageAnimationPolicy()
        cppSelf->resetImageAnimationPolicy();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineSettingsFunc_resetUnknownUrlSchemePolicy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineSettings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // resetUnknownUrlSchemePolicy()
        cppSelf->resetUnknownUrlSchemePolicy();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineSettingsFunc_setAttribute(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineSettings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setAttribute", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QWebEngineSettings::setAttribute(QWebEngineSettings::WebAttribute,bool)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_WebAttribute_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
        overloadId = 0; // setAttribute(QWebEngineSettings::WebAttribute,bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setAttribute", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_IDX]);

    // Call function/method
    {
        ::QWebEngineSettings::WebAttribute cppArg0{QWebEngineSettings::AutoLoadImages};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        bool cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAttribute(QWebEngineSettings::WebAttribute,bool)
            cppSelf->setAttribute(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineSettingsFunc_setDefaultTextEncoding(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineSettings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineSettings::setDefaultTextEncoding(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setDefaultTextEncoding(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDefaultTextEncoding", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDefaultTextEncoding(QString)
            cppSelf->setDefaultTextEncoding(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineSettingsFunc_setFontFamily(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineSettings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setFontFamily", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QWebEngineSettings::setFontFamily(QWebEngineSettings::FontFamily,QString)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_FontFamily_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // setFontFamily(QWebEngineSettings::FontFamily,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setFontFamily", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_IDX]);

    // Call function/method
    {
        ::QWebEngineSettings::FontFamily cppArg0{QWebEngineSettings::StandardFont};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFontFamily(QWebEngineSettings::FontFamily,QString)
            cppSelf->setFontFamily(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineSettingsFunc_setFontSize(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineSettings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setFontSize", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QWebEngineSettings::setFontSize(QWebEngineSettings::FontSize,int)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_FontSize_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // setFontSize(QWebEngineSettings::FontSize,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setFontSize", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_IDX]);

    // Call function/method
    {
        ::QWebEngineSettings::FontSize cppArg0{QWebEngineSettings::MinimumFontSize};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFontSize(QWebEngineSettings::FontSize,int)
            cppSelf->setFontSize(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineSettingsFunc_setImageAnimationPolicy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineSettings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineSettings::setImageAnimationPolicy(QWebEngineSettings::ImageAnimationPolicy)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_ImageAnimationPolicy_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setImageAnimationPolicy(QWebEngineSettings::ImageAnimationPolicy)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setImageAnimationPolicy", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_IDX]);

    // Call function/method
    {
        ::QWebEngineSettings::ImageAnimationPolicy cppArg0{QWebEngineSettings::ImageAnimationPolicy::Inherited};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setImageAnimationPolicy(QWebEngineSettings::ImageAnimationPolicy)
            cppSelf->setImageAnimationPolicy(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineSettingsFunc_setUnknownUrlSchemePolicy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineSettings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineSettings::setUnknownUrlSchemePolicy(QWebEngineSettings::UnknownUrlSchemePolicy)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_UnknownUrlSchemePolicy_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setUnknownUrlSchemePolicy(QWebEngineSettings::UnknownUrlSchemePolicy)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUnknownUrlSchemePolicy", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_IDX]);

    // Call function/method
    {
        ::QWebEngineSettings::UnknownUrlSchemePolicy cppArg0{QWebEngineSettings::InheritedUnknownUrlSchemePolicy};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setUnknownUrlSchemePolicy(QWebEngineSettings::UnknownUrlSchemePolicy)
            cppSelf->setUnknownUrlSchemePolicy(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineSettingsFunc_testAttribute(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineSettings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineSettings::testAttribute(QWebEngineSettings::WebAttribute)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_WebAttribute_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // testAttribute(QWebEngineSettings::WebAttribute)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "testAttribute", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_IDX]);

    // Call function/method
    {
        ::QWebEngineSettings::WebAttribute cppArg0{QWebEngineSettings::AutoLoadImages};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // testAttribute(QWebEngineSettings::WebAttribute)const
            bool cppResult = const_cast<const ::QWebEngineSettings *>(cppSelf)->testAttribute(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineSettingsFunc_unknownUrlSchemePolicy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineSettings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // unknownUrlSchemePolicy()const
        QWebEngineSettings::UnknownUrlSchemePolicy cppResult = const_cast<const ::QWebEngineSettings *>(cppSelf)->unknownUrlSchemePolicy();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_UnknownUrlSchemePolicy_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QWebEngineSettings_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QWebEngineSettings_EnumFlagInfo[] = {
    "FontFamily:Enum",
    "FontSize:Enum",
    "ImageAnimationPolicy:Enum",
    "UnknownUrlSchemePolicy:Enum",
    "WebAttribute:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QWebEngineSettings_methods[] = {
    {"defaultTextEncoding", reinterpret_cast<PyCFunction>(Sbk_QWebEngineSettingsFunc_defaultTextEncoding), METH_NOARGS, nullptr},
    {"fontFamily", reinterpret_cast<PyCFunction>(Sbk_QWebEngineSettingsFunc_fontFamily), METH_O, nullptr},
    {"fontSize", reinterpret_cast<PyCFunction>(Sbk_QWebEngineSettingsFunc_fontSize), METH_O, nullptr},
    {"imageAnimationPolicy", reinterpret_cast<PyCFunction>(Sbk_QWebEngineSettingsFunc_imageAnimationPolicy), METH_NOARGS, nullptr},
    {"resetAttribute", reinterpret_cast<PyCFunction>(Sbk_QWebEngineSettingsFunc_resetAttribute), METH_O, nullptr},
    {"resetFontFamily", reinterpret_cast<PyCFunction>(Sbk_QWebEngineSettingsFunc_resetFontFamily), METH_O, nullptr},
    {"resetFontSize", reinterpret_cast<PyCFunction>(Sbk_QWebEngineSettingsFunc_resetFontSize), METH_O, nullptr},
    {"resetImageAnimationPolicy", reinterpret_cast<PyCFunction>(Sbk_QWebEngineSettingsFunc_resetImageAnimationPolicy), METH_NOARGS, nullptr},
    {"resetUnknownUrlSchemePolicy", reinterpret_cast<PyCFunction>(Sbk_QWebEngineSettingsFunc_resetUnknownUrlSchemePolicy), METH_NOARGS, nullptr},
    {"setAttribute", reinterpret_cast<PyCFunction>(Sbk_QWebEngineSettingsFunc_setAttribute), METH_VARARGS, nullptr},
    {"setDefaultTextEncoding", reinterpret_cast<PyCFunction>(Sbk_QWebEngineSettingsFunc_setDefaultTextEncoding), METH_O, nullptr},
    {"setFontFamily", reinterpret_cast<PyCFunction>(Sbk_QWebEngineSettingsFunc_setFontFamily), METH_VARARGS, nullptr},
    {"setFontSize", reinterpret_cast<PyCFunction>(Sbk_QWebEngineSettingsFunc_setFontSize), METH_VARARGS, nullptr},
    {"setImageAnimationPolicy", reinterpret_cast<PyCFunction>(Sbk_QWebEngineSettingsFunc_setImageAnimationPolicy), METH_O, nullptr},
    {"setUnknownUrlSchemePolicy", reinterpret_cast<PyCFunction>(Sbk_QWebEngineSettingsFunc_setUnknownUrlSchemePolicy), METH_O, nullptr},
    {"testAttribute", reinterpret_cast<PyCFunction>(Sbk_QWebEngineSettingsFunc_testAttribute), METH_O, nullptr},
    {"unknownUrlSchemePolicy", reinterpret_cast<PyCFunction>(Sbk_QWebEngineSettingsFunc_unknownUrlSchemePolicy), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QWebEngineSettings_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QWebEngineSettings_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QWebEngineSettings_Type = nullptr;
static PyTypeObject *Sbk_QWebEngineSettings_TypeF(void)
{
    return _Sbk_QWebEngineSettings_Type;
}

static PyType_Slot Sbk_QWebEngineSettings_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QWebEngineSettings_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QWebEngineSettings_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QWebEngineSettings_methods)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QWebEngineSettings_spec = {
    "2:PySide6.QtWebEngineCore.QWebEngineSettings",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QWebEngineSettings_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QWebEngineSettings_FontFamily(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWebEngineSettings::FontFamily>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QWebEngineSettings::FontFamily *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QWebEngineSettings_FontFamily_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_FontFamily_IDX])))
        return Enum_PythonToCpp_QWebEngineSettings_FontFamily;
    return {};
}

static PyObject *QWebEngineSettings_FontFamily_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QWebEngineSettings::FontFamily>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QWebEngineSettings::FontFamily *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_FontFamily_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QWebEngineSettings_WebAttribute(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWebEngineSettings::WebAttribute>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QWebEngineSettings::WebAttribute *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QWebEngineSettings_WebAttribute_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_WebAttribute_IDX])))
        return Enum_PythonToCpp_QWebEngineSettings_WebAttribute;
    return {};
}

static PyObject *QWebEngineSettings_WebAttribute_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QWebEngineSettings::WebAttribute>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QWebEngineSettings::WebAttribute *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_WebAttribute_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QWebEngineSettings_FontSize(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWebEngineSettings::FontSize>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QWebEngineSettings::FontSize *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QWebEngineSettings_FontSize_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_FontSize_IDX])))
        return Enum_PythonToCpp_QWebEngineSettings_FontSize;
    return {};
}

static PyObject *QWebEngineSettings_FontSize_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QWebEngineSettings::FontSize>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QWebEngineSettings::FontSize *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_FontSize_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QWebEngineSettings_UnknownUrlSchemePolicy(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWebEngineSettings::UnknownUrlSchemePolicy>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QWebEngineSettings::UnknownUrlSchemePolicy *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QWebEngineSettings_UnknownUrlSchemePolicy_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_UnknownUrlSchemePolicy_IDX])))
        return Enum_PythonToCpp_QWebEngineSettings_UnknownUrlSchemePolicy;
    return {};
}

static PyObject *QWebEngineSettings_UnknownUrlSchemePolicy_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QWebEngineSettings::UnknownUrlSchemePolicy>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QWebEngineSettings::UnknownUrlSchemePolicy *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_UnknownUrlSchemePolicy_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QWebEngineSettings_ImageAnimationPolicy(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWebEngineSettings::ImageAnimationPolicy>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QWebEngineSettings::ImageAnimationPolicy *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QWebEngineSettings_ImageAnimationPolicy_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_ImageAnimationPolicy_IDX])))
        return Enum_PythonToCpp_QWebEngineSettings_ImageAnimationPolicy;
    return {};
}

static PyObject *QWebEngineSettings_ImageAnimationPolicy_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QWebEngineSettings::ImageAnimationPolicy>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QWebEngineSettings::ImageAnimationPolicy *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_ImageAnimationPolicy_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QWebEngineSettings_PythonToCpp_QWebEngineSettings_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QWebEngineSettings_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QWebEngineSettings_PythonToCpp_QWebEngineSettings_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QWebEngineSettings_TypeF()))
        return QWebEngineSettings_PythonToCpp_QWebEngineSettings_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QWebEngineSettings_PTR_CppToPython_QWebEngineSettings(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QWebEngineSettings_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QWebEngineSettings_SignatureStrings[] = {
    "PySide6.QtWebEngineCore.QWebEngineSettings.defaultTextEncoding(self)->QString",
    "PySide6.QtWebEngineCore.QWebEngineSettings.fontFamily(self,which:PySide6.QtWebEngineCore.QWebEngineSettings.FontFamily)->QString",
    "PySide6.QtWebEngineCore.QWebEngineSettings.fontSize(self,type:PySide6.QtWebEngineCore.QWebEngineSettings.FontSize)->int",
    "PySide6.QtWebEngineCore.QWebEngineSettings.imageAnimationPolicy(self)->PySide6.QtWebEngineCore.QWebEngineSettings.ImageAnimationPolicy",
    "PySide6.QtWebEngineCore.QWebEngineSettings.resetAttribute(self,attr:PySide6.QtWebEngineCore.QWebEngineSettings.WebAttribute)",
    "PySide6.QtWebEngineCore.QWebEngineSettings.resetFontFamily(self,which:PySide6.QtWebEngineCore.QWebEngineSettings.FontFamily)",
    "PySide6.QtWebEngineCore.QWebEngineSettings.resetFontSize(self,type:PySide6.QtWebEngineCore.QWebEngineSettings.FontSize)",
    "PySide6.QtWebEngineCore.QWebEngineSettings.resetImageAnimationPolicy(self)",
    "PySide6.QtWebEngineCore.QWebEngineSettings.resetUnknownUrlSchemePolicy(self)",
    "PySide6.QtWebEngineCore.QWebEngineSettings.setAttribute(self,attr:PySide6.QtWebEngineCore.QWebEngineSettings.WebAttribute,on:bool)",
    "PySide6.QtWebEngineCore.QWebEngineSettings.setDefaultTextEncoding(self,encoding:QString)",
    "PySide6.QtWebEngineCore.QWebEngineSettings.setFontFamily(self,which:PySide6.QtWebEngineCore.QWebEngineSettings.FontFamily,family:QString)",
    "PySide6.QtWebEngineCore.QWebEngineSettings.setFontSize(self,type:PySide6.QtWebEngineCore.QWebEngineSettings.FontSize,size:int)",
    "PySide6.QtWebEngineCore.QWebEngineSettings.setImageAnimationPolicy(self,policy:PySide6.QtWebEngineCore.QWebEngineSettings.ImageAnimationPolicy)",
    "PySide6.QtWebEngineCore.QWebEngineSettings.setUnknownUrlSchemePolicy(self,policy:PySide6.QtWebEngineCore.QWebEngineSettings.UnknownUrlSchemePolicy)",
    "PySide6.QtWebEngineCore.QWebEngineSettings.testAttribute(self,attr:PySide6.QtWebEngineCore.QWebEngineSettings.WebAttribute)->bool",
    "PySide6.QtWebEngineCore.QWebEngineSettings.unknownUrlSchemePolicy(self)->PySide6.QtWebEngineCore.QWebEngineSettings.UnknownUrlSchemePolicy",
    nullptr}; // Sentinel
#else
static constexpr size_t QWebEngineSettings_SignatureByteSize = 294;
static constexpr uint8_t QWebEngineSettings_SignatureBytes[294] = {
    0x78, 0xda, 0xad, 0x95, 0x3f, 0x6f, 0x83, 0x30, 0x10, 0xc5, 0xf7, 0x7c, 0x92, 0x44, 0x72, 0x18,
    0x3b, 0x30, 0x44, 0x8a, 0xd2, 0x20, 0x65, 0x03, 0x39, 0x51, 0x67, 0xfe, 0x1c, 0x60, 0xd5, 0x9c,
    0x23, 0x38, 0x94, 0xd2, 0x4f, 0x5f, 0x87, 0x52, 0x26, 0x88, 0x7a, 0xe0, 0x05, 0x73, 0x96, 0xf8,
    0xbd, 0xa7, 0xf3, 0xf3, 0x11, 0x76, 0x52, 0x65, 0xf0, 0xe6, 0x45, 0xf4, 0x01, 0xc9, 0x19, 0x0b,
    0x85, 0x70, 0x32, 0x35, 0x78, 0xd1, 0x58, 0x4a, 0x20, 0x52, 0x58, 0x34, 0x5e, 0x06, 0x79, 0xdc,
    0x6a, 0xba, 0xc2, 0x17, 0x9d, 0x31, 0x35, 0x99, 0xdd, 0xdc, 0x36, 0xa0, 0xf3, 0xdd, 0xfe, 0x10,
    0x49, 0xaa, 0x6d, 0xb9, 0x09, 0xff, 0x4f, 0xcb, 0x0d, 0x52, 0x10, 0x57, 0x4a, 0x77, 0x3d, 0x44,
    0x3c, 0x4a, 0x95, 0x96, 0x3e, 0x03, 0x10, 0x8c, 0x80, 0xe5, 0x06, 0xa4, 0xfa, 0x86, 0x5f, 0x79,
    0xea, 0xee, 0xc0, 0x55, 0x7f, 0x7e, 0x6d, 0xb5, 0x15, 0x12, 0x47, 0x57, 0x55, 0x71, 0x01, 0x47,
    0xb4, 0x0b, 0x29, 0x83, 0xa1, 0xd1, 0x2a, 0xed, 0xfe, 0xfa, 0xc8, 0xc0, 0x5c, 0x26, 0x30, 0x1c,
    0x1b, 0x35, 0x34, 0x40, 0x47, 0xb2, 0x6d, 0x4b, 0x5a, 0x1a, 0x9a, 0x10, 0xdb, 0x92, 0xd3, 0x04,
    0xbb, 0x33, 0x12, 0x76, 0x6c, 0xf1, 0xc0, 0x61, 0x02, 0x16, 0x89, 0x3b, 0x38, 0x7d, 0xb6, 0xee,
    0x65, 0xf6, 0xf4, 0xd9, 0xa8, 0x1b, 0x7e, 0xa2, 0x79, 0xe0, 0xad, 0xd6, 0x32, 0x2d, 0xa1, 0x82,
    0xa5, 0x30, 0xb7, 0x39, 0x10, 0x06, 0xfd, 0xc4, 0x18, 0xcd, 0xb5, 0xf0, 0x3e, 0x33, 0x5d, 0x04,
    0x0c, 0x95, 0x3f, 0xdc, 0x71, 0x2e, 0xd8, 0x61, 0xcc, 0x44, 0xde, 0x2f, 0x6b, 0x9c, 0xac, 0xcf,
    0x9c, 0x68, 0xec, 0xc3, 0xb7, 0x43, 0x87, 0x2b, 0x3f, 0x1b, 0x3d, 0x71, 0xef, 0xdf, 0xfd, 0x95,
    0xd3, 0x87, 0xeb, 0xe7, 0x45, 0x7e, 0x17, 0x38, 0x9a, 0xa6, 0xb1, 0x3c, 0x11, 0x34, 0x4e, 0x27,
    0xe2, 0xfe, 0xf0, 0xbc, 0x08, 0x1c, 0x07, 0xed, 0x8b, 0x2b, 0xcd, 0xfa, 0x3b, 0x4c, 0x77, 0x63,
    0xf3, 0x03, 0x96, 0x0e, 0xf3, 0xf7
};
#endif

PyTypeObject *init_QWebEngineSettings(PyObject *module)
{
    if (SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_IDX].type != nullptr)
        return SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_IDX].type;

    Shiboken::AutoDecRef Sbk_QWebEngineSettings_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QWebEngineSettings_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QWebEngineSettings",
        "QWebEngineSettings*",
        &Sbk_QWebEngineSettings_spec,
        &Shiboken::callCppDestructor< ::QWebEngineSettings >,
        Sbk_QWebEngineSettings_Type_bases.object(),
        0);
    auto *pyType = Sbk_QWebEngineSettings_TypeF(); // references _Sbk_QWebEngineSettings_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QWebEngineSettings_SignatureStrings);
#else
    InitSignatureBytes(pyType, QWebEngineSettings_SignatureBytes, QWebEngineSettings_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QWebEngineSettings_PropertyStrings);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QWebEngineSettings_PythonToCpp_QWebEngineSettings_PTR,
        is_QWebEngineSettings_PythonToCpp_QWebEngineSettings_PTR_Convertible,
        QWebEngineSettings_PTR_CppToPython_QWebEngineSettings);

    Shiboken::Conversions::registerConverterName(converter, "QWebEngineSettings");
    Shiboken::Conversions::registerConverterName(converter, "QWebEngineSettings*");
    Shiboken::Conversions::registerConverterName(converter, "QWebEngineSettings&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QWebEngineSettings).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QWebEngineSettings_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'FontFamily'.
    const char *FontFamily_Initializer[] = {
        "StandardFont",
        "FixedFont",
        "SerifFont",
        "SansSerifFont",
        "CursiveFont",
        "FantasyFont",
        "PictographFont",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t FontFamily_InitializerValues[] = {
        uint8_t(QWebEngineSettings::FontFamily::StandardFont),  //  0x00  0
        uint8_t(QWebEngineSettings::FontFamily::FixedFont),     //  0x01  1
        uint8_t(QWebEngineSettings::FontFamily::SerifFont),     //  0x02  2
        uint8_t(QWebEngineSettings::FontFamily::SansSerifFont), //  0x03  3
        uint8_t(QWebEngineSettings::FontFamily::CursiveFont),   //  0x04  4
        uint8_t(QWebEngineSettings::FontFamily::FantasyFont),   //  0x05  5
        uint8_t(QWebEngineSettings::FontFamily::PictographFont) //  0x06  6
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWebEngineSettings_TypeF(),
        "2:PySide6.QtWebEngineCore.QWebEngineSettings.FontFamily",
        FontFamily_Initializer, FontFamily_InitializerValues);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_FontFamily_IDX].type = EType;
    // Register converter for enum 'QWebEngineSettings::FontFamily'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWebEngineSettings_FontFamily_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QWebEngineSettings_FontFamily,
            is_Enum_PythonToCpp_QWebEngineSettings_FontFamily_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QWebEngineSettings::FontFamily");
        Shiboken::Conversions::registerConverterAlias(converter, "FontFamily");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'FontFamily' enum.

    // Initialization of enum 'WebAttribute'.
    const char *WebAttribute_Initializer[] = {
        "AutoLoadImages",
        "JavascriptEnabled",
        "JavascriptCanOpenWindows",
        "JavascriptCanAccessClipboard",
        "LinksIncludedInFocusChain",
        "LocalStorageEnabled",
        "LocalContentCanAccessRemoteUrls",
        "XSSAuditingEnabled",
        "SpatialNavigationEnabled",
        "LocalContentCanAccessFileUrls",
        "HyperlinkAuditingEnabled",
        "ScrollAnimatorEnabled",
        "ErrorPageEnabled",
        "PluginsEnabled",
        "FullScreenSupportEnabled",
        "ScreenCaptureEnabled",
        "WebGLEnabled",
        "Accelerated2dCanvasEnabled",
        "AutoLoadIconsForPage",
        "TouchIconsEnabled",
        "FocusOnNavigationEnabled",
        "PrintElementBackgrounds",
        "AllowRunningInsecureContent",
        "AllowGeolocationOnInsecureOrigins",
        "AllowWindowActivationFromJavaScript",
        "ShowScrollBars",
        "PlaybackRequiresUserGesture",
        "WebRTCPublicInterfacesOnly",
        "JavascriptCanPaste",
        "DnsPrefetchEnabled",
        "PdfViewerEnabled",
        "NavigateOnDropEnabled",
        "ReadingFromCanvasEnabled",
        "ForceDarkMode",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t WebAttribute_InitializerValues[] = {
        uint8_t(QWebEngineSettings::WebAttribute::AutoLoadImages),                      //  0x00  0
        uint8_t(QWebEngineSettings::WebAttribute::JavascriptEnabled),                   //  0x01  1
        uint8_t(QWebEngineSettings::WebAttribute::JavascriptCanOpenWindows),            //  0x02  2
        uint8_t(QWebEngineSettings::WebAttribute::JavascriptCanAccessClipboard),        //  0x03  3
        uint8_t(QWebEngineSettings::WebAttribute::LinksIncludedInFocusChain),           //  0x04  4
        uint8_t(QWebEngineSettings::WebAttribute::LocalStorageEnabled),                 //  0x05  5
        uint8_t(QWebEngineSettings::WebAttribute::LocalContentCanAccessRemoteUrls),     //  0x06  6
        uint8_t(QWebEngineSettings::WebAttribute::XSSAuditingEnabled),                  //  0x07  7
        uint8_t(QWebEngineSettings::WebAttribute::SpatialNavigationEnabled),            //  0x08  8
        uint8_t(QWebEngineSettings::WebAttribute::LocalContentCanAccessFileUrls),       //  0x09  9
        uint8_t(QWebEngineSettings::WebAttribute::HyperlinkAuditingEnabled),            //  0x0a  10
        uint8_t(QWebEngineSettings::WebAttribute::ScrollAnimatorEnabled),               //  0x0b  11
        uint8_t(QWebEngineSettings::WebAttribute::ErrorPageEnabled),                    //  0x0c  12
        uint8_t(QWebEngineSettings::WebAttribute::PluginsEnabled),                      //  0x0d  13
        uint8_t(QWebEngineSettings::WebAttribute::FullScreenSupportEnabled),            //  0x0e  14
        uint8_t(QWebEngineSettings::WebAttribute::ScreenCaptureEnabled),                //  0x0f  15
        uint8_t(QWebEngineSettings::WebAttribute::WebGLEnabled),                        //  0x10  16
        uint8_t(QWebEngineSettings::WebAttribute::Accelerated2dCanvasEnabled),          //  0x11  17
        uint8_t(QWebEngineSettings::WebAttribute::AutoLoadIconsForPage),                //  0x12  18
        uint8_t(QWebEngineSettings::WebAttribute::TouchIconsEnabled),                   //  0x13  19
        uint8_t(QWebEngineSettings::WebAttribute::FocusOnNavigationEnabled),            //  0x14  20
        uint8_t(QWebEngineSettings::WebAttribute::PrintElementBackgrounds),             //  0x15  21
        uint8_t(QWebEngineSettings::WebAttribute::AllowRunningInsecureContent),         //  0x16  22
        uint8_t(QWebEngineSettings::WebAttribute::AllowGeolocationOnInsecureOrigins),   //  0x17  23
        uint8_t(QWebEngineSettings::WebAttribute::AllowWindowActivationFromJavaScript), //  0x18  24
        uint8_t(QWebEngineSettings::WebAttribute::ShowScrollBars),                      //  0x19  25
        uint8_t(QWebEngineSettings::WebAttribute::PlaybackRequiresUserGesture),         //  0x1a  26
        uint8_t(QWebEngineSettings::WebAttribute::WebRTCPublicInterfacesOnly),          //  0x1b  27
        uint8_t(QWebEngineSettings::WebAttribute::JavascriptCanPaste),                  //  0x1c  28
        uint8_t(QWebEngineSettings::WebAttribute::DnsPrefetchEnabled),                  //  0x1d  29
        uint8_t(QWebEngineSettings::WebAttribute::PdfViewerEnabled),                    //  0x1e  30
        uint8_t(QWebEngineSettings::WebAttribute::NavigateOnDropEnabled),               //  0x1f  31
        uint8_t(QWebEngineSettings::WebAttribute::ReadingFromCanvasEnabled),            //  0x20  32
        uint8_t(QWebEngineSettings::WebAttribute::ForceDarkMode)                        //  0x21  33
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWebEngineSettings_TypeF(),
        "2:PySide6.QtWebEngineCore.QWebEngineSettings.WebAttribute",
        WebAttribute_Initializer, WebAttribute_InitializerValues);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_WebAttribute_IDX].type = EType;
    // Register converter for enum 'QWebEngineSettings::WebAttribute'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWebEngineSettings_WebAttribute_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QWebEngineSettings_WebAttribute,
            is_Enum_PythonToCpp_QWebEngineSettings_WebAttribute_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QWebEngineSettings::WebAttribute");
        Shiboken::Conversions::registerConverterAlias(converter, "WebAttribute");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'WebAttribute' enum.

    // Initialization of enum 'FontSize'.
    const char *FontSize_Initializer[] = {
        "MinimumFontSize",
        "MinimumLogicalFontSize",
        "DefaultFontSize",
        "DefaultFixedFontSize",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t FontSize_InitializerValues[] = {
        uint8_t(QWebEngineSettings::FontSize::MinimumFontSize),        //  0x00  0
        uint8_t(QWebEngineSettings::FontSize::MinimumLogicalFontSize), //  0x01  1
        uint8_t(QWebEngineSettings::FontSize::DefaultFontSize),        //  0x02  2
        uint8_t(QWebEngineSettings::FontSize::DefaultFixedFontSize)    //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWebEngineSettings_TypeF(),
        "2:PySide6.QtWebEngineCore.QWebEngineSettings.FontSize",
        FontSize_Initializer, FontSize_InitializerValues);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_FontSize_IDX].type = EType;
    // Register converter for enum 'QWebEngineSettings::FontSize'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWebEngineSettings_FontSize_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QWebEngineSettings_FontSize,
            is_Enum_PythonToCpp_QWebEngineSettings_FontSize_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QWebEngineSettings::FontSize");
        Shiboken::Conversions::registerConverterAlias(converter, "FontSize");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'FontSize' enum.

    // Initialization of enum 'UnknownUrlSchemePolicy'.
    const char *UnknownUrlSchemePolicy_Initializer[] = {
        "InheritedUnknownUrlSchemePolicy",
        "DisallowUnknownUrlSchemes",
        "AllowUnknownUrlSchemesFromUserInteraction",
        "AllowAllUnknownUrlSchemes",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t UnknownUrlSchemePolicy_InitializerValues[] = {
        uint8_t(QWebEngineSettings::UnknownUrlSchemePolicy::InheritedUnknownUrlSchemePolicy),           //  0x00  0
        uint8_t(QWebEngineSettings::UnknownUrlSchemePolicy::DisallowUnknownUrlSchemes),                 //  0x01  1
        uint8_t(QWebEngineSettings::UnknownUrlSchemePolicy::AllowUnknownUrlSchemesFromUserInteraction), //  0x02  2
        uint8_t(QWebEngineSettings::UnknownUrlSchemePolicy::AllowAllUnknownUrlSchemes)                  //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWebEngineSettings_TypeF(),
        "2:PySide6.QtWebEngineCore.QWebEngineSettings.UnknownUrlSchemePolicy",
        UnknownUrlSchemePolicy_Initializer, UnknownUrlSchemePolicy_InitializerValues);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_UnknownUrlSchemePolicy_IDX].type = EType;
    // Register converter for enum 'QWebEngineSettings::UnknownUrlSchemePolicy'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWebEngineSettings_UnknownUrlSchemePolicy_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QWebEngineSettings_UnknownUrlSchemePolicy,
            is_Enum_PythonToCpp_QWebEngineSettings_UnknownUrlSchemePolicy_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QWebEngineSettings::UnknownUrlSchemePolicy");
        Shiboken::Conversions::registerConverterAlias(converter, "UnknownUrlSchemePolicy");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'UnknownUrlSchemePolicy' enum.

    // Initialization of enum 'ImageAnimationPolicy'.
    const char *ImageAnimationPolicy_Initializer[] = {
        "Inherited",
        "Allow",
        "AnimateOnce",
        "Disallow",
        nullptr};
    // "int8_t" used instead of "__uint8_t"
    constexpr int8_t ImageAnimationPolicy_InitializerValues[] = {
        int8_t(QWebEngineSettings::ImageAnimationPolicy::Inherited),   //  0x00  0
        int8_t(QWebEngineSettings::ImageAnimationPolicy::Allow),       //  0x01  1
        int8_t(QWebEngineSettings::ImageAnimationPolicy::AnimateOnce), //  0x02  2
        int8_t(QWebEngineSettings::ImageAnimationPolicy::Disallow)     //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWebEngineSettings_TypeF(),
        "2:PySide6.QtWebEngineCore.QWebEngineSettings.ImageAnimationPolicy",
        ImageAnimationPolicy_Initializer, ImageAnimationPolicy_InitializerValues);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_ImageAnimationPolicy_IDX].type = EType;
    // Register converter for enum 'QWebEngineSettings::ImageAnimationPolicy'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWebEngineSettings_ImageAnimationPolicy_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QWebEngineSettings_ImageAnimationPolicy,
            is_Enum_PythonToCpp_QWebEngineSettings_ImageAnimationPolicy_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QWebEngineSettings::ImageAnimationPolicy");
        Shiboken::Conversions::registerConverterAlias(converter, "ImageAnimationPolicy");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ImageAnimationPolicy' enum.

    qRegisterMetaType< ::QWebEngineSettings *>();
    qRegisterMetaType< ::QWebEngineSettings::FontFamily >("QWebEngineSettings::FontFamily");
    qRegisterMetaType< ::QWebEngineSettings::WebAttribute >("QWebEngineSettings::WebAttribute");
    qRegisterMetaType< ::QWebEngineSettings::FontSize >("QWebEngineSettings::FontSize");
    qRegisterMetaType< ::QWebEngineSettings::UnknownUrlSchemePolicy >("QWebEngineSettings::UnknownUrlSchemePolicy");
    qRegisterMetaType< ::QWebEngineSettings::ImageAnimationPolicy >("QWebEngineSettings::ImageAnimationPolicy");

    return pyType;
}
