// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwebenginecore_python.h"

// main header
#include "qwebengineurlrequestjob_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QMap>
#include <QMultiMap>
#include <QString>
#include <QtWebEngineCore/qwebengineurlrequestjob.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qiodevice.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qurl.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QWebEngineUrlRequestJobWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

void QWebEngineUrlRequestJobWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWebEngineUrlRequestJob", funcName);
        return;
    }
}

void QWebEngineUrlRequestJobWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWebEngineUrlRequestJob", funcName);
        return;
    }
}

void QWebEngineUrlRequestJobWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWebEngineUrlRequestJob", funcName);
        return;
    }
}

void QWebEngineUrlRequestJobWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWebEngineUrlRequestJob", funcName);
        return;
    }
}

bool QWebEngineUrlRequestJobWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWebEngineUrlRequestJob", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QWebEngineUrlRequestJob", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QWebEngineUrlRequestJobWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWebEngineUrlRequestJob", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QWebEngineUrlRequestJob", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QWebEngineUrlRequestJobWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWebEngineUrlRequestJob", funcName);
        return;
    }
}

const QMetaObject *QWebEngineUrlRequestJobWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QWebEngineUrlRequestJob::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QWebEngineUrlRequestJobWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QWebEngineUrlRequestJob::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QWebEngineUrlRequestJobWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QWebEngineUrlRequestJobWrapper *>(this));
    return QWebEngineUrlRequestJob::qt_metacast(_clname);
}

QWebEngineUrlRequestJobWrapper::~QWebEngineUrlRequestJobWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QWebEngineUrlRequestJobFunc_fail(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineUrlRequestJob *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlRequestJob_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineUrlRequestJob::fail(QWebEngineUrlRequestJob::Error)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlRequestJob_Error_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // fail(QWebEngineUrlRequestJob::Error)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fail", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlRequestJob_IDX]);

    // Call function/method
    {
        ::QWebEngineUrlRequestJob::Error cppArg0{QWebEngineUrlRequestJob::NoError};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fail(QWebEngineUrlRequestJob::Error)
            cppSelf->fail(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineUrlRequestJobFunc_initiator(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineUrlRequestJob *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlRequestJob_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // initiator()const
        QUrl cppResult = const_cast<const ::QWebEngineUrlRequestJob *>(cppSelf)->initiator();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineUrlRequestJobFunc_redirect(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineUrlRequestJob *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlRequestJob_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineUrlRequestJob::redirect(QUrl)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // redirect(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "redirect", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlRequestJob_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // redirect(QUrl)
            cppSelf->redirect(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineUrlRequestJobFunc_reply(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineUrlRequestJob *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlRequestJob_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "reply", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QWebEngineUrlRequestJob::reply(QByteArray,QIODevice*)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), (pyArgs[1])))) {
        overloadId = 0; // reply(QByteArray,QIODevice*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "reply", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlRequestJob_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QIODevice *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // reply(QByteArray,QIODevice*)
            cppSelf->reply(*cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineUrlRequestJobFunc_requestBody(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineUrlRequestJob *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlRequestJob_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // requestBody()const
        QIODevice * cppResult = const_cast<const ::QWebEngineUrlRequestJob *>(cppSelf)->requestBody();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineUrlRequestJobFunc_requestHeaders(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineUrlRequestJob *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlRequestJob_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // requestHeaders()const
        QMap<QByteArray,QByteArray> cppResult = const_cast<const ::QWebEngineUrlRequestJob *>(cppSelf)->requestHeaders();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtWebEngineCoreTypeConverters[SBK_QtWebEngineCore_QMap_QByteArray_QByteArray_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineUrlRequestJobFunc_requestMethod(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineUrlRequestJob *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlRequestJob_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // requestMethod()const
        QByteArray cppResult = const_cast<const ::QWebEngineUrlRequestJob *>(cppSelf)->requestMethod();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineUrlRequestJobFunc_requestUrl(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineUrlRequestJob *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlRequestJob_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // requestUrl()const
        QUrl cppResult = const_cast<const ::QWebEngineUrlRequestJob *>(cppSelf)->requestUrl();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineUrlRequestJobFunc_setAdditionalResponseHeaders(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineUrlRequestJob *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlRequestJob_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineUrlRequestJob::setAdditionalResponseHeaders(QMultiMap<QByteArray,QByteArray>)const
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtWebEngineCoreTypeConverters[SBK_QtWebEngineCore_QMultiMap_QByteArray_QByteArray_IDX], (pyArg)))) {
        overloadId = 0; // setAdditionalResponseHeaders(QMultiMap<QByteArray,QByteArray>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAdditionalResponseHeaders", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlRequestJob_IDX]);

    // Call function/method
    {
        ::QMultiMap<QByteArray,QByteArray> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAdditionalResponseHeaders(QMultiMap<QByteArray,QByteArray>)const
            const_cast<const ::QWebEngineUrlRequestJob *>(cppSelf)->setAdditionalResponseHeaders(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QWebEngineUrlRequestJob_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QWebEngineUrlRequestJob_EnumFlagInfo[] = {
    "Error:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QWebEngineUrlRequestJob_methods[] = {
    {"fail", reinterpret_cast<PyCFunction>(Sbk_QWebEngineUrlRequestJobFunc_fail), METH_O, nullptr},
    {"initiator", reinterpret_cast<PyCFunction>(Sbk_QWebEngineUrlRequestJobFunc_initiator), METH_NOARGS, nullptr},
    {"redirect", reinterpret_cast<PyCFunction>(Sbk_QWebEngineUrlRequestJobFunc_redirect), METH_O, nullptr},
    {"reply", reinterpret_cast<PyCFunction>(Sbk_QWebEngineUrlRequestJobFunc_reply), METH_VARARGS, nullptr},
    {"requestBody", reinterpret_cast<PyCFunction>(Sbk_QWebEngineUrlRequestJobFunc_requestBody), METH_NOARGS, nullptr},
    {"requestHeaders", reinterpret_cast<PyCFunction>(Sbk_QWebEngineUrlRequestJobFunc_requestHeaders), METH_NOARGS, nullptr},
    {"requestMethod", reinterpret_cast<PyCFunction>(Sbk_QWebEngineUrlRequestJobFunc_requestMethod), METH_NOARGS, nullptr},
    {"requestUrl", reinterpret_cast<PyCFunction>(Sbk_QWebEngineUrlRequestJobFunc_requestUrl), METH_NOARGS, nullptr},
    {"setAdditionalResponseHeaders", reinterpret_cast<PyCFunction>(Sbk_QWebEngineUrlRequestJobFunc_setAdditionalResponseHeaders), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QWebEngineUrlRequestJob_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QWebEngineUrlRequestJob *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlRequestJob_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QWebEngineUrlRequestJobWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QWebEngineUrlRequestJob_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QWebEngineUrlRequestJob_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QWebEngineUrlRequestJob_Type = nullptr;
static PyTypeObject *Sbk_QWebEngineUrlRequestJob_TypeF(void)
{
    return _Sbk_QWebEngineUrlRequestJob_Type;
}

static PyType_Slot Sbk_QWebEngineUrlRequestJob_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QWebEngineUrlRequestJob_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QWebEngineUrlRequestJob_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QWebEngineUrlRequestJob_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QWebEngineUrlRequestJob_methods)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QWebEngineUrlRequestJob_spec = {
    "2:PySide6.QtWebEngineCore.QWebEngineUrlRequestJob",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QWebEngineUrlRequestJob_slots
};

} //extern "C"

static void *Sbk_QWebEngineUrlRequestJob_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QWebEngineUrlRequestJob *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QWebEngineUrlRequestJob_Error(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWebEngineUrlRequestJob::Error>(Shiboken::Enum::getValue(pyIn));
    switch (value) {
    case QWebEngineUrlRequestJob::Error::NoError:
        Shiboken::Warnings::warnDeprecatedEnumValue("QWebEngineUrlRequestJob::Error", "NoError");
        break;
    default:
        break;
    }
    *reinterpret_cast<::QWebEngineUrlRequestJob::Error *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QWebEngineUrlRequestJob_Error_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlRequestJob_Error_IDX])))
        return Enum_PythonToCpp_QWebEngineUrlRequestJob_Error;
    return {};
}

static PyObject *QWebEngineUrlRequestJob_Error_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QWebEngineUrlRequestJob::Error>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QWebEngineUrlRequestJob::Error *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlRequestJob_Error_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QWebEngineUrlRequestJob_PythonToCpp_QWebEngineUrlRequestJob_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QWebEngineUrlRequestJob_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QWebEngineUrlRequestJob_PythonToCpp_QWebEngineUrlRequestJob_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QWebEngineUrlRequestJob_TypeF()))
        return QWebEngineUrlRequestJob_PythonToCpp_QWebEngineUrlRequestJob_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QWebEngineUrlRequestJob_PTR_CppToPython_QWebEngineUrlRequestJob(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QWebEngineUrlRequestJob *>(const_cast<void *>(cppIn)), Sbk_QWebEngineUrlRequestJob_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QWebEngineUrlRequestJob_SignatureStrings[] = {
    "PySide6.QtWebEngineCore.QWebEngineUrlRequestJob.fail(self,error:PySide6.QtWebEngineCore.QWebEngineUrlRequestJob.Error)",
    "PySide6.QtWebEngineCore.QWebEngineUrlRequestJob.initiator(self)->PySide6.QtCore.QUrl",
    "PySide6.QtWebEngineCore.QWebEngineUrlRequestJob.redirect(self,url:typing.Union[PySide6.QtCore.QUrl, QString])",
    "PySide6.QtWebEngineCore.QWebEngineUrlRequestJob.reply(self,contentType:typing.Union[PySide6.QtCore.QByteArray, char*],device:PySide6.QtCore.QIODevice)",
    "PySide6.QtWebEngineCore.QWebEngineUrlRequestJob.requestBody(self)->PySide6.QtCore.QIODevice",
    "PySide6.QtWebEngineCore.QWebEngineUrlRequestJob.requestHeaders(self)->QMap[PySide6.QtCore.QByteArray, PySide6.QtCore.QByteArray]",
    "PySide6.QtWebEngineCore.QWebEngineUrlRequestJob.requestMethod(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtWebEngineCore.QWebEngineUrlRequestJob.requestUrl(self)->PySide6.QtCore.QUrl",
    "PySide6.QtWebEngineCore.QWebEngineUrlRequestJob.setAdditionalResponseHeaders(self,additionalResponseHeaders:QMultiMap[PySide6.QtCore.QByteArray, PySide6.QtCore.QByteArray])",
    nullptr}; // Sentinel
#else
static constexpr size_t QWebEngineUrlRequestJob_SignatureByteSize = 262;
static constexpr uint8_t QWebEngineUrlRequestJob_SignatureBytes[262] = {
    0x78, 0xda, 0xad, 0x92, 0xc1, 0x4e, 0xc3, 0x30, 0x0c, 0x86, 0xef, 0x7b, 0x8a, 0x1d, 0x29, 0x0a,
    0x3d, 0xee, 0xd0, 0x03, 0xd2, 0x06, 0x93, 0x00, 0xa9, 0xda, 0xc2, 0x98, 0x38, 0xa0, 0x1e, 0xb2,
    0xc6, 0xdb, 0x2c, 0x45, 0x49, 0x70, 0x5c, 0xa4, 0xbc, 0x3d, 0xa5, 0xd5, 0x06, 0x42, 0x74, 0x52,
    0x23, 0x6e, 0x89, 0xed, 0xff, 0xfb, 0x6d, 0xcb, 0xeb, 0xb8, 0x41, 0x0d, 0xb3, 0x5c, 0xf2, 0x2b,
    0xec, 0x96, 0xf6, 0x80, 0x16, 0xee, 0x1c, 0x41, 0x2e, 0xcf, 0xdf, 0x2d, 0x99, 0x67, 0x78, 0x6f,
    0x20, 0xf0, 0x93, 0xdb, 0xe5, 0x7b, 0x85, 0xe6, 0x2a, 0x80, 0xd9, 0x0b, 0x20, 0x72, 0x54, 0xac,
    0x47, 0xea, 0x97, 0x5f, 0xaa, 0x6c, 0x32, 0x56, 0x86, 0x16, 0x19, 0x15, 0x3b, 0xea, 0xbc, 0xb3,
    0x9b, 0xdb, 0x6f, 0x40, 0xaf, 0x6b, 0xcb, 0x47, 0x43, 0x09, 0x34, 0x12, 0xd4, 0xdc, 0xcf, 0xd3,
    0x90, 0x29, 0x38, 0x7a, 0xb4, 0x87, 0x7c, 0x6b, 0xd1, 0xd9, 0xb7, 0x3f, 0x2c, 0xc4, 0x54, 0x6e,
    0x98, 0xda, 0x92, 0x2a, 0x4b, 0x70, 0xf3, 0x26, 0xf6, 0x56, 0xb5, 0xb3, 0x0c, 0x96, 0x5f, 0xa2,
    0x87, 0xcb, 0x96, 0x8b, 0xc8, 0x30, 0x27, 0x52, 0x51, 0x4c, 0xeb, 0xa3, 0xa2, 0xeb, 0x4a, 0x68,
    0xf8, 0xc0, 0x1a, 0x8a, 0xdf, 0x85, 0x8f, 0xab, 0xfb, 0x2e, 0x91, 0xd2, 0x56, 0xf7, 0x5c, 0x38,
    0x1d, 0x87, 0x76, 0x7b, 0x82, 0xa7, 0xb2, 0x1f, 0x40, 0x69, 0xa0, 0x70, 0xc2, 0xcb, 0x52, 0xf9,
    0x4b, 0x93, 0x0e, 0xa6, 0xaa, 0xd4, 0x06, 0x4a, 0xe0, 0xa3, 0xd3, 0x43, 0xe3, 0x9d, 0xf9, 0xa9,
    0xf8, 0x36, 0xf8, 0x9f, 0x67, 0x19, 0x80, 0xe7, 0x5a, 0xb7, 0xf7, 0xee, 0xac, 0x6a, 0xe3, 0xc1,
    0x3b, 0x1b, 0xe0, 0xe7, 0x0e, 0x85, 0x1a, 0x4a, 0x17, 0xb2, 0x6c, 0x0c, 0x63, 0xf2, 0x82, 0xb3,
    0xc9, 0x27, 0x5d, 0x9b, 0x7b, 0xbe
};
#endif

PyTypeObject *init_QWebEngineUrlRequestJob(PyObject *module)
{
    if (SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlRequestJob_IDX].type != nullptr)
        return SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlRequestJob_IDX].type;

    Shiboken::AutoDecRef Sbk_QWebEngineUrlRequestJob_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QWebEngineUrlRequestJob_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QWebEngineUrlRequestJob",
        "QWebEngineUrlRequestJob*",
        &Sbk_QWebEngineUrlRequestJob_spec,
        &Shiboken::callCppDestructor< QWebEngineUrlRequestJob >,
        Sbk_QWebEngineUrlRequestJob_Type_bases.object(),
        0);
    auto *pyType = Sbk_QWebEngineUrlRequestJob_TypeF(); // references _Sbk_QWebEngineUrlRequestJob_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QWebEngineUrlRequestJob_SignatureStrings);
#else
    InitSignatureBytes(pyType, QWebEngineUrlRequestJob_SignatureBytes, QWebEngineUrlRequestJob_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QWebEngineUrlRequestJob_PropertyStrings);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlRequestJob_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QWebEngineUrlRequestJob_PythonToCpp_QWebEngineUrlRequestJob_PTR,
        is_QWebEngineUrlRequestJob_PythonToCpp_QWebEngineUrlRequestJob_PTR_Convertible,
        QWebEngineUrlRequestJob_PTR_CppToPython_QWebEngineUrlRequestJob);

    Shiboken::Conversions::registerConverterName(converter, "QWebEngineUrlRequestJob");
    Shiboken::Conversions::registerConverterName(converter, "QWebEngineUrlRequestJob*");
    Shiboken::Conversions::registerConverterName(converter, "QWebEngineUrlRequestJob&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QWebEngineUrlRequestJob).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QWebEngineUrlRequestJobWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QWebEngineUrlRequestJob_TypeF(), &Sbk_QWebEngineUrlRequestJob_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QWebEngineUrlRequestJob_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Error'.
    const char *Error_Initializer[] = {
        "NoError",
        "UrlNotFound",
        "UrlInvalid",
        "RequestAborted",
        "RequestDenied",
        "RequestFailed",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Error_InitializerValues[] = {
        uint8_t(QWebEngineUrlRequestJob::Error::NoError),        //  0x00  0
        uint8_t(QWebEngineUrlRequestJob::Error::UrlNotFound),    //  0x01  1
        uint8_t(QWebEngineUrlRequestJob::Error::UrlInvalid),     //  0x02  2
        uint8_t(QWebEngineUrlRequestJob::Error::RequestAborted), //  0x03  3
        uint8_t(QWebEngineUrlRequestJob::Error::RequestDenied),  //  0x04  4
        uint8_t(QWebEngineUrlRequestJob::Error::RequestFailed)   //  0x05  5
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWebEngineUrlRequestJob_TypeF(),
        "2:PySide6.QtWebEngineCore.QWebEngineUrlRequestJob.Error",
        Error_Initializer, Error_InitializerValues);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlRequestJob_Error_IDX].type = EType;
    // Register converter for enum 'QWebEngineUrlRequestJob::Error'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWebEngineUrlRequestJob_Error_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QWebEngineUrlRequestJob_Error,
            is_Enum_PythonToCpp_QWebEngineUrlRequestJob_Error_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QWebEngineUrlRequestJob::Error");
        Shiboken::Conversions::registerConverterAlias(converter, "Error");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Error' enum.

    qRegisterMetaType< ::QWebEngineUrlRequestJob::Error >("QWebEngineUrlRequestJob::Error");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QWebEngineUrlRequestJob::staticMetaObject, sizeof(QWebEngineUrlRequestJobWrapper));

    return pyType;
}
