// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwebenginecore_python.h"

// main header
#include "qwebengineurlscheme_wrapper.h"

// Argument includes
#include <QtWebEngineCore/qwebengineurlscheme.h>
#include <qbytearray.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QWebEngineUrlScheme_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QWebEngineUrlScheme >()))
        return -1;

    ::QWebEngineUrlScheme *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QWebEngineUrlScheme", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QWebEngineUrlScheme::QWebEngineUrlScheme()
    // 1: QWebEngineUrlScheme::QWebEngineUrlScheme(QByteArray)
    // 2: QWebEngineUrlScheme::QWebEngineUrlScheme(QWebEngineUrlScheme)
    if (numArgs == 0) {
        overloadId = 0; // QWebEngineUrlScheme()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlScheme_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QWebEngineUrlScheme(QWebEngineUrlScheme)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QWebEngineUrlScheme(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlScheme_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlScheme_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QWebEngineUrlScheme()
        {

            // QWebEngineUrlScheme()
            cptr = new ::QWebEngineUrlScheme();
            break;
        }
        case 1: // QWebEngineUrlScheme(const QByteArray &name)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QWebEngineUrlScheme(QByteArray)
                cptr = new ::QWebEngineUrlScheme(*cppArg0);
            }
            break;
        }
        case 2: // QWebEngineUrlScheme(const QWebEngineUrlScheme &that)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QWebEngineUrlScheme cppArg0_local;
            ::QWebEngineUrlScheme *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QWebEngineUrlScheme(QWebEngineUrlScheme)
                cptr = new ::QWebEngineUrlScheme(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QWebEngineUrlScheme >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlScheme_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QWebEngineUrlSchemeFunc_defaultPort(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineUrlScheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlScheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // defaultPort()const
        int cppResult = const_cast<const ::QWebEngineUrlScheme *>(cppSelf)->defaultPort();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineUrlSchemeFunc_flags(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineUrlScheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlScheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // flags()const
        QFlags<QWebEngineUrlScheme::Flag> cppResult = const_cast<const ::QWebEngineUrlScheme *>(cppSelf)->flags();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QFlags_QWebEngineUrlScheme_Flag_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineUrlSchemeFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineUrlScheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlScheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // name()const
        QByteArray cppResult = const_cast<const ::QWebEngineUrlScheme *>(cppSelf)->name();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineUrlSchemeFunc_registerScheme(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QWebEngineUrlScheme::registerScheme(QWebEngineUrlScheme)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlScheme_IDX]), (pyArg)))) {
        overloadId = 0; // registerScheme(QWebEngineUrlScheme)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "registerScheme", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlScheme_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QWebEngineUrlScheme cppArg0_local;
        ::QWebEngineUrlScheme *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // registerScheme(QWebEngineUrlScheme)
            ::QWebEngineUrlScheme::registerScheme(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineUrlSchemeFunc_schemeByName(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QWebEngineUrlScheme::schemeByName(QByteArray)->QWebEngineUrlScheme
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // schemeByName(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "schemeByName", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlScheme_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // schemeByName(QByteArray)
            QWebEngineUrlScheme cppResult = ::QWebEngineUrlScheme::schemeByName(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlScheme_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineUrlSchemeFunc_setDefaultPort(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineUrlScheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlScheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineUrlScheme::setDefaultPort(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setDefaultPort(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDefaultPort", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlScheme_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDefaultPort(int)
            cppSelf->setDefaultPort(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineUrlSchemeFunc_setFlags(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineUrlScheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlScheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineUrlScheme::setFlags(QFlags<QWebEngineUrlScheme::Flag>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QFlags_QWebEngineUrlScheme_Flag_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setFlags(QFlags<QWebEngineUrlScheme::Flag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFlags", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlScheme_IDX]);

    // Call function/method
    {
        ::QFlags<QWebEngineUrlScheme::Flag> cppArg0 = QFlags<QWebEngineUrlScheme::Flag>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFlags(QFlags<QWebEngineUrlScheme::Flag>)
            cppSelf->setFlags(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineUrlSchemeFunc_setName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineUrlScheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlScheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineUrlScheme::setName(QByteArray)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // setName(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setName", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlScheme_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setName(QByteArray)
            cppSelf->setName(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineUrlSchemeFunc_setSyntax(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineUrlScheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlScheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineUrlScheme::setSyntax(QWebEngineUrlScheme::Syntax)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlScheme_Syntax_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setSyntax(QWebEngineUrlScheme::Syntax)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSyntax", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlScheme_IDX]);

    // Call function/method
    {
        ::QWebEngineUrlScheme::Syntax cppArg0{QWebEngineUrlScheme::Syntax::HostPortAndUserInformation};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSyntax(QWebEngineUrlScheme::Syntax)
            cppSelf->setSyntax(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineUrlSchemeFunc_syntax(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineUrlScheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlScheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // syntax()const
        QWebEngineUrlScheme::Syntax cppResult = const_cast<const ::QWebEngineUrlScheme *>(cppSelf)->syntax();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlScheme_Syntax_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineUrlScheme__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QWebEngineUrlScheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlScheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlScheme_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QWebEngineUrlScheme_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QWebEngineUrlScheme_EnumFlagInfo[] = {
    "Flag:Flag:Flags",
    "SpecialPort:Enum",
    "Syntax:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QWebEngineUrlScheme_methods[] = {
    {"defaultPort", reinterpret_cast<PyCFunction>(Sbk_QWebEngineUrlSchemeFunc_defaultPort), METH_NOARGS, nullptr},
    {"flags", reinterpret_cast<PyCFunction>(Sbk_QWebEngineUrlSchemeFunc_flags), METH_NOARGS, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_QWebEngineUrlSchemeFunc_name), METH_NOARGS, nullptr},
    {"registerScheme", reinterpret_cast<PyCFunction>(Sbk_QWebEngineUrlSchemeFunc_registerScheme), METH_O|METH_STATIC, nullptr},
    {"schemeByName", reinterpret_cast<PyCFunction>(Sbk_QWebEngineUrlSchemeFunc_schemeByName), METH_O|METH_STATIC, nullptr},
    {"setDefaultPort", reinterpret_cast<PyCFunction>(Sbk_QWebEngineUrlSchemeFunc_setDefaultPort), METH_O, nullptr},
    {"setFlags", reinterpret_cast<PyCFunction>(Sbk_QWebEngineUrlSchemeFunc_setFlags), METH_O, nullptr},
    {"setName", reinterpret_cast<PyCFunction>(Sbk_QWebEngineUrlSchemeFunc_setName), METH_O, nullptr},
    {"setSyntax", reinterpret_cast<PyCFunction>(Sbk_QWebEngineUrlSchemeFunc_setSyntax), METH_O, nullptr},
    {"syntax", reinterpret_cast<PyCFunction>(Sbk_QWebEngineUrlSchemeFunc_syntax), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QWebEngineUrlScheme__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QWebEngineUrlScheme_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QWebEngineUrlScheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlScheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlScheme_IDX]), (pyArg)))) {
                // operator!=(const QWebEngineUrlScheme &that) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QWebEngineUrlScheme cppArg0_local;
                ::QWebEngineUrlScheme *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlScheme_IDX]), (pyArg)))) {
                // operator==(const QWebEngineUrlScheme &that) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QWebEngineUrlScheme cppArg0_local;
                ::QWebEngineUrlScheme *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QWebEngineUrlScheme_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QWebEngineUrlScheme_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QWebEngineUrlScheme_Type = nullptr;
static PyTypeObject *Sbk_QWebEngineUrlScheme_TypeF(void)
{
    return _Sbk_QWebEngineUrlScheme_Type;
}

static PyType_Slot Sbk_QWebEngineUrlScheme_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QWebEngineUrlScheme_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QWebEngineUrlScheme_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QWebEngineUrlScheme_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QWebEngineUrlScheme_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QWebEngineUrlScheme_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QWebEngineUrlScheme_spec = {
    "2:PySide6.QtWebEngineCore.QWebEngineUrlScheme",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QWebEngineUrlScheme_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QWebEngineUrlScheme_Syntax(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWebEngineUrlScheme::Syntax>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QWebEngineUrlScheme::Syntax *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QWebEngineUrlScheme_Syntax_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlScheme_Syntax_IDX])))
        return Enum_PythonToCpp_QWebEngineUrlScheme_Syntax;
    return {};
}

static PyObject *QWebEngineUrlScheme_Syntax_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QWebEngineUrlScheme::Syntax>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QWebEngineUrlScheme::Syntax *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlScheme_Syntax_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QWebEngineUrlScheme_SpecialPort(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWebEngineUrlScheme::SpecialPort>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QWebEngineUrlScheme::SpecialPort *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QWebEngineUrlScheme_SpecialPort_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlScheme_SpecialPort_IDX])))
        return Enum_PythonToCpp_QWebEngineUrlScheme_SpecialPort;
    return {};
}

static PyObject *QWebEngineUrlScheme_SpecialPort_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QWebEngineUrlScheme::SpecialPort>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QWebEngineUrlScheme::SpecialPort *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlScheme_SpecialPort_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QWebEngineUrlScheme_Flag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWebEngineUrlScheme::Flag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QWebEngineUrlScheme::Flag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QWebEngineUrlScheme_Flag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlScheme_Flag_IDX])))
        return Enum_PythonToCpp_QWebEngineUrlScheme_Flag;
    return {};
}

static PyObject *QWebEngineUrlScheme_Flag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QWebEngineUrlScheme::Flag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QWebEngineUrlScheme::Flag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlScheme_Flag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QWebEngineUrlScheme_Flag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QWebEngineUrlScheme::Flag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QWebEngineUrlScheme::Flag> *>(cppOut) = value;

}

static PyObject *QWebEngineUrlScheme_Flag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QWebEngineUrlScheme::Flag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlScheme_Flag_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QWebEngineUrlScheme_PythonToCpp_QWebEngineUrlScheme_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QWebEngineUrlScheme_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QWebEngineUrlScheme_PythonToCpp_QWebEngineUrlScheme_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QWebEngineUrlScheme_TypeF()))
        return QWebEngineUrlScheme_PythonToCpp_QWebEngineUrlScheme_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QWebEngineUrlScheme_PTR_CppToPython_QWebEngineUrlScheme(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QWebEngineUrlScheme_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QWebEngineUrlScheme_COPY_CppToPython_QWebEngineUrlScheme(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QWebEngineUrlScheme *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QWebEngineUrlScheme_TypeF(), new ::QWebEngineUrlScheme(*source), true, true);
}

// Python to C++ copy conversion.
static void QWebEngineUrlScheme_PythonToCpp_QWebEngineUrlScheme_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QWebEngineUrlScheme *>(cppOut) = *reinterpret_cast< ::QWebEngineUrlScheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlScheme_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QWebEngineUrlScheme_PythonToCpp_QWebEngineUrlScheme_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QWebEngineUrlScheme_TypeF()))
        return QWebEngineUrlScheme_PythonToCpp_QWebEngineUrlScheme_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QWebEngineUrlScheme_SignatureStrings[] = {
    "2:PySide6.QtWebEngineCore.QWebEngineUrlScheme(self)",
    "1:PySide6.QtWebEngineCore.QWebEngineUrlScheme(self,name:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "0:PySide6.QtWebEngineCore.QWebEngineUrlScheme(self,that:PySide6.QtWebEngineCore.QWebEngineUrlScheme)",
    "PySide6.QtWebEngineCore.QWebEngineUrlScheme.defaultPort(self)->int",
    "PySide6.QtWebEngineCore.QWebEngineUrlScheme.flags(self)->PySide6.QtWebEngineCore.QWebEngineUrlScheme.Flag",
    "PySide6.QtWebEngineCore.QWebEngineUrlScheme.name(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtWebEngineCore.QWebEngineUrlScheme.registerScheme(scheme:PySide6.QtWebEngineCore.QWebEngineUrlScheme)",
    "PySide6.QtWebEngineCore.QWebEngineUrlScheme.schemeByName(name:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtWebEngineCore.QWebEngineUrlScheme",
    "PySide6.QtWebEngineCore.QWebEngineUrlScheme.setDefaultPort(self,newValue:int)",
    "PySide6.QtWebEngineCore.QWebEngineUrlScheme.setFlags(self,newValue:PySide6.QtWebEngineCore.QWebEngineUrlScheme.Flag)",
    "PySide6.QtWebEngineCore.QWebEngineUrlScheme.setName(self,newValue:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "PySide6.QtWebEngineCore.QWebEngineUrlScheme.setSyntax(self,newValue:PySide6.QtWebEngineCore.QWebEngineUrlScheme.Syntax)",
    "PySide6.QtWebEngineCore.QWebEngineUrlScheme.syntax(self)->PySide6.QtWebEngineCore.QWebEngineUrlScheme.Syntax",
    "PySide6.QtWebEngineCore.QWebEngineUrlScheme.__copy__(self)->typing.Self",
    "PySide6.QtWebEngineCore.QWebEngineUrlScheme.__ne__(self,that:PySide6.QtWebEngineCore.QWebEngineUrlScheme)->bool",
    "PySide6.QtWebEngineCore.QWebEngineUrlScheme.__eq__(self,that:PySide6.QtWebEngineCore.QWebEngineUrlScheme)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QWebEngineUrlScheme_SignatureByteSize = 276;
static constexpr uint8_t QWebEngineUrlScheme_SignatureBytes[276] = {
    0x78, 0xda, 0xb5, 0x94, 0x31, 0x6b, 0xc3, 0x30, 0x14, 0x84, 0x77, 0xff, 0x8a, 0x8e, 0x75, 0x71,
    0x4c, 0xd2, 0xa1, 0x83, 0x87, 0x40, 0xd3, 0x36, 0x63, 0x48, 0x30, 0x69, 0x87, 0x52, 0x8c, 0xe2,
    0x3c, 0xdb, 0x02, 0xe5, 0x29, 0x95, 0x5f, 0x68, 0xf5, 0xef, 0xeb, 0xd4, 0xb1, 0x0d, 0xe9, 0x74,
    0x09, 0x9d, 0x84, 0x40, 0x77, 0x9f, 0x74, 0xdc, 0xd3, 0x7d, 0xb2, 0xf4, 0xa9, 0xde, 0xd2, 0x43,
    0xbc, 0x92, 0x37, 0xda, 0xbc, 0x70, 0xa9, 0x99, 0x9e, 0xac, 0xa3, 0x78, 0xd5, 0x6f, 0xd7, 0xce,
    0xa4, 0x79, 0x45, 0x3b, 0xba, 0xad, 0xc9, 0x14, 0x61, 0x30, 0x81, 0x35, 0x11, 0xab, 0x1d, 0x25,
    0xe2, 0xf7, 0x9a, 0xcb, 0x78, 0xcd, 0xda, 0xf2, 0xfb, 0x60, 0xd1, 0x2a, 0x67, 0x5e, 0xe8, 0xd1,
    0x39, 0xe5, 0xa3, 0x9b, 0xbc, 0x52, 0xee, 0xee, 0x23, 0x0c, 0xc6, 0x38, 0x47, 0x2a, 0x25, 0x88,
    0x2a, 0x0c, 0x80, 0xc3, 0xf1, 0x96, 0x0a, 0x75, 0x30, 0xb2, 0xb4, 0x4e, 0xda, 0x28, 0x46, 0x53,
    0xcd, 0x02, 0x59, 0x14, 0x46, 0x95, 0x75, 0x27, 0x46, 0x84, 0xf3, 0x46, 0x08, 0x91, 0x8e, 0x91,
    0xff, 0x05, 0x9d, 0x85, 0x0d, 0x39, 0x3a, 0x2a, 0x75, 0x2d, 0xe4, 0xba, 0xc0, 0x7f, 0x97, 0xff,
    0x4b, 0xbb, 0xf5, 0x9f, 0xf9, 0xc5, 0xf1, 0x21, 0x97, 0x14, 0x08, 0x0a, 0x18, 0xbb, 0x1a, 0xc9,
    0xf3, 0x59, 0x17, 0x22, 0xa6, 0xaf, 0x57, 0x65, 0x0e, 0x94, 0x34, 0x95, 0x08, 0x51, 0xb7, 0x79,
    0x5f, 0x8b, 0xc1, 0x07, 0x6d, 0x07, 0x0c, 0x5d, 0xa8, 0x7e, 0x3c, 0x3b, 0x26, 0x3a, 0xa2, 0x20,
    0x31, 0xf5, 0x2c, 0xea, 0xfb, 0x8a, 0x77, 0xb6, 0x06, 0x20, 0x77, 0x80, 0x82, 0x33, 0xd7, 0xd2,
    0x20, 0x58, 0x96, 0xe5, 0x76, 0xef, 0xb3, 0xac, 0xc3, 0x9d, 0x02, 0x4d, 0x9b, 0x1d, 0xe8, 0xc3,
    0x74, 0x72, 0xc1, 0x3f, 0xb5, 0xd1, 0x74, 0x63, 0xad, 0x01, 0x79, 0xf4, 0x79, 0x2d, 0xef, 0x07,
    0x99, 0x22, 0x48, 0xb9
};
#endif

PyTypeObject *init_QWebEngineUrlScheme(PyObject *module)
{
    if (SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlScheme_IDX].type != nullptr)
        return SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlScheme_IDX].type;

    Shiboken::AutoDecRef Sbk_QWebEngineUrlScheme_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QWebEngineUrlScheme_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QWebEngineUrlScheme",
        "QWebEngineUrlScheme",
        &Sbk_QWebEngineUrlScheme_spec,
        &Shiboken::callCppDestructor< ::QWebEngineUrlScheme >,
        Sbk_QWebEngineUrlScheme_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QWebEngineUrlScheme_TypeF(); // references _Sbk_QWebEngineUrlScheme_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QWebEngineUrlScheme_SignatureStrings);
#else
    InitSignatureBytes(pyType, QWebEngineUrlScheme_SignatureBytes, QWebEngineUrlScheme_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QWebEngineUrlScheme_PropertyStrings);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlScheme_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QWebEngineUrlScheme_PythonToCpp_QWebEngineUrlScheme_PTR,
        is_QWebEngineUrlScheme_PythonToCpp_QWebEngineUrlScheme_PTR_Convertible,
        QWebEngineUrlScheme_PTR_CppToPython_QWebEngineUrlScheme,
        QWebEngineUrlScheme_COPY_CppToPython_QWebEngineUrlScheme);

    Shiboken::Conversions::registerConverterName(converter, "QWebEngineUrlScheme");
    Shiboken::Conversions::registerConverterName(converter, "QWebEngineUrlScheme*");
    Shiboken::Conversions::registerConverterName(converter, "QWebEngineUrlScheme&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QWebEngineUrlScheme).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QWebEngineUrlScheme_PythonToCpp_QWebEngineUrlScheme_COPY,
        is_QWebEngineUrlScheme_PythonToCpp_QWebEngineUrlScheme_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QWebEngineUrlScheme_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Syntax'.
    const char *Syntax_Initializer[] = {
        "HostPortAndUserInformation",
        "HostAndPort",
        "Host",
        "Path",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t Syntax_InitializerValues[] = {
        int8_t(QWebEngineUrlScheme::Syntax::HostPortAndUserInformation), //  0x00  0
        int8_t(QWebEngineUrlScheme::Syntax::HostAndPort),                //  0x01  1
        int8_t(QWebEngineUrlScheme::Syntax::Host),                       //  0x02  2
        int8_t(QWebEngineUrlScheme::Syntax::Path)                        //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWebEngineUrlScheme_TypeF(),
        "2:PySide6.QtWebEngineCore.QWebEngineUrlScheme.Syntax",
        Syntax_Initializer, Syntax_InitializerValues);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlScheme_Syntax_IDX].type = EType;
    // Register converter for enum 'QWebEngineUrlScheme::Syntax'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWebEngineUrlScheme_Syntax_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QWebEngineUrlScheme_Syntax,
            is_Enum_PythonToCpp_QWebEngineUrlScheme_Syntax_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QWebEngineUrlScheme::Syntax");
        Shiboken::Conversions::registerConverterAlias(converter, "Syntax");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Syntax' enum.

    // Initialization of enum 'SpecialPort'.
    const char *SpecialPort_Initializer[] = {
        "PortUnspecified",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t SpecialPort_InitializerValues[] = {
        int8_t(QWebEngineUrlScheme::SpecialPort::PortUnspecified) // -0x01 -1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWebEngineUrlScheme_TypeF(),
        "2:PySide6.QtWebEngineCore.QWebEngineUrlScheme.SpecialPort",
        SpecialPort_Initializer, SpecialPort_InitializerValues);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlScheme_SpecialPort_IDX].type = EType;
    // Register converter for enum 'QWebEngineUrlScheme::SpecialPort'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWebEngineUrlScheme_SpecialPort_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QWebEngineUrlScheme_SpecialPort,
            is_Enum_PythonToCpp_QWebEngineUrlScheme_SpecialPort_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QWebEngineUrlScheme::SpecialPort");
        Shiboken::Conversions::registerConverterAlias(converter, "SpecialPort");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'SpecialPort' enum.

    // Initialization of enum 'Flag'.
    const char *Flag_Initializer[] = {
        "SecureScheme",
        "LocalScheme",
        "LocalAccessAllowed",
        "NoAccessAllowed",
        "ServiceWorkersAllowed",
        "ViewSourceAllowed",
        "ContentSecurityPolicyIgnored",
        "CorsEnabled",
        "FetchApiAllowed",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t Flag_InitializerValues[] = {
        uint16_t(QWebEngineUrlScheme::Flag::SecureScheme),                 //  0x0001  1
        uint16_t(QWebEngineUrlScheme::Flag::LocalScheme),                  //  0x0002  2
        uint16_t(QWebEngineUrlScheme::Flag::LocalAccessAllowed),           //  0x0004  4
        uint16_t(QWebEngineUrlScheme::Flag::NoAccessAllowed),              //  0x0008  8
        uint16_t(QWebEngineUrlScheme::Flag::ServiceWorkersAllowed),        //  0x0010  16
        uint16_t(QWebEngineUrlScheme::Flag::ViewSourceAllowed),            //  0x0020  32
        uint16_t(QWebEngineUrlScheme::Flag::ContentSecurityPolicyIgnored), //  0x0040  64
        uint16_t(QWebEngineUrlScheme::Flag::CorsEnabled),                  //  0x0080  128
        uint16_t(QWebEngineUrlScheme::Flag::FetchApiAllowed)               //  0x0100  256
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWebEngineUrlScheme_TypeF(),
        "2:PySide6.QtWebEngineCore.QWebEngineUrlScheme.Flag",
        Flag_Initializer, Flag_InitializerValues);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlScheme_Flag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QFlags_QWebEngineUrlScheme_Flag_IDX].type =
        EType;
    // Register converter for enum 'QWebEngineUrlScheme::Flag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWebEngineUrlScheme_Flag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QWebEngineUrlScheme_Flag,
            is_Enum_PythonToCpp_QWebEngineUrlScheme_Flag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QWebEngineUrlScheme::Flag");
        Shiboken::Conversions::registerConverterAlias(converter, "Flag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QWebEngineUrlScheme_Flag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QWebEngineUrlScheme_Flag,
            is_Enum_PythonToCpp_QWebEngineUrlScheme_Flag_Convertible);
        // Register converter for flag 'QFlags<QWebEngineUrlScheme::Flag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QWebEngineUrlScheme::Flag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QWebEngineUrlScheme::Flags");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'Flag' enum/flags.

    qRegisterMetaType< ::QWebEngineUrlScheme >("QWebEngineUrlScheme");
    qRegisterMetaType< ::QWebEngineUrlScheme::Syntax >("QWebEngineUrlScheme::Syntax");
    qRegisterMetaType< ::QWebEngineUrlScheme::SpecialPort >("QWebEngineUrlScheme::SpecialPort");
    qRegisterMetaType< ::QWebEngineUrlScheme::Flag >("QWebEngineUrlScheme::Flag");

    return pyType;
}
