// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwebenginecore_python.h"

// main header
#include "qwebenginewebauthuxrequest_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QStringList>
#include <QtWebEngineCore/qwebenginewebauthuxrequest.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QWebEngineWebAuthUxRequestWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

void QWebEngineWebAuthUxRequestWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWebEngineWebAuthUxRequest", funcName);
        return;
    }
}

void QWebEngineWebAuthUxRequestWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWebEngineWebAuthUxRequest", funcName);
        return;
    }
}

void QWebEngineWebAuthUxRequestWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWebEngineWebAuthUxRequest", funcName);
        return;
    }
}

void QWebEngineWebAuthUxRequestWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWebEngineWebAuthUxRequest", funcName);
        return;
    }
}

bool QWebEngineWebAuthUxRequestWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWebEngineWebAuthUxRequest", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QWebEngineWebAuthUxRequest", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QWebEngineWebAuthUxRequestWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWebEngineWebAuthUxRequest", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QWebEngineWebAuthUxRequest", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QWebEngineWebAuthUxRequestWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWebEngineWebAuthUxRequest", funcName);
        return;
    }
}

const QMetaObject *QWebEngineWebAuthUxRequestWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QWebEngineWebAuthUxRequest::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QWebEngineWebAuthUxRequestWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QWebEngineWebAuthUxRequest::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QWebEngineWebAuthUxRequestWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QWebEngineWebAuthUxRequestWrapper *>(this));
    return QWebEngineWebAuthUxRequest::qt_metacast(_clname);
}

QWebEngineWebAuthUxRequestWrapper::~QWebEngineWebAuthUxRequestWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QWebEngineWebAuthUxRequestFunc_cancel(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineWebAuthUxRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineWebAuthUxRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cancel()
        cppSelf->cancel();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineWebAuthUxRequestFunc_pinRequest(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineWebAuthUxRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineWebAuthUxRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pinRequest()const
        QWebEngineWebAuthPinRequest cppResult = const_cast<const ::QWebEngineWebAuthUxRequest *>(cppSelf)->pinRequest();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineWebAuthPinRequest_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineWebAuthUxRequestFunc_relyingPartyId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineWebAuthUxRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineWebAuthUxRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // relyingPartyId()const
        QString cppResult = const_cast<const ::QWebEngineWebAuthUxRequest *>(cppSelf)->relyingPartyId();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineWebAuthUxRequestFunc_requestFailureReason(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineWebAuthUxRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineWebAuthUxRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // requestFailureReason()const
        QWebEngineWebAuthUxRequest::RequestFailureReason cppResult = const_cast<const ::QWebEngineWebAuthUxRequest *>(cppSelf)->requestFailureReason();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineWebAuthUxRequest_RequestFailureReason_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineWebAuthUxRequestFunc_retry(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineWebAuthUxRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineWebAuthUxRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // retry()
        cppSelf->retry();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineWebAuthUxRequestFunc_setPin(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineWebAuthUxRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineWebAuthUxRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineWebAuthUxRequest::setPin(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setPin(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPin", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineWebAuthUxRequest_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPin(QString)
            cppSelf->setPin(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineWebAuthUxRequestFunc_setSelectedAccount(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineWebAuthUxRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineWebAuthUxRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineWebAuthUxRequest::setSelectedAccount(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setSelectedAccount(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSelectedAccount", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineWebAuthUxRequest_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSelectedAccount(QString)
            cppSelf->setSelectedAccount(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineWebAuthUxRequestFunc_state(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineWebAuthUxRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineWebAuthUxRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // state()const
        QWebEngineWebAuthUxRequest::WebAuthUxState cppResult = const_cast<const ::QWebEngineWebAuthUxRequest *>(cppSelf)->state();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineWebAuthUxRequest_WebAuthUxState_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineWebAuthUxRequestFunc_userNames(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineWebAuthUxRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineWebAuthUxRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // userNames()const
        QStringList cppResult = const_cast<const ::QWebEngineWebAuthUxRequest *>(cppSelf)->userNames();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QWebEngineWebAuthUxRequest_PropertyStrings[] = {
    "pinRequest:",
    "relyingPartyId:",
    "requestFailureReason:",
    "state:",
    "userNames:",
    nullptr // Sentinel
};

static const char *Sbk_QWebEngineWebAuthUxRequest_EnumFlagInfo[] = {
    "PinEntryError:Enum",
    "PinEntryReason:Enum",
    "RequestFailureReason:Enum",
    "WebAuthUxState:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QWebEngineWebAuthUxRequest_methods[] = {
    {"cancel", reinterpret_cast<PyCFunction>(Sbk_QWebEngineWebAuthUxRequestFunc_cancel), METH_NOARGS, nullptr},
    {"pinRequest", reinterpret_cast<PyCFunction>(Sbk_QWebEngineWebAuthUxRequestFunc_pinRequest), METH_NOARGS, nullptr},
    {"relyingPartyId", reinterpret_cast<PyCFunction>(Sbk_QWebEngineWebAuthUxRequestFunc_relyingPartyId), METH_NOARGS, nullptr},
    {"requestFailureReason", reinterpret_cast<PyCFunction>(Sbk_QWebEngineWebAuthUxRequestFunc_requestFailureReason), METH_NOARGS, nullptr},
    {"retry", reinterpret_cast<PyCFunction>(Sbk_QWebEngineWebAuthUxRequestFunc_retry), METH_NOARGS, nullptr},
    {"setPin", reinterpret_cast<PyCFunction>(Sbk_QWebEngineWebAuthUxRequestFunc_setPin), METH_O, nullptr},
    {"setSelectedAccount", reinterpret_cast<PyCFunction>(Sbk_QWebEngineWebAuthUxRequestFunc_setSelectedAccount), METH_O, nullptr},
    {"state", reinterpret_cast<PyCFunction>(Sbk_QWebEngineWebAuthUxRequestFunc_state), METH_NOARGS, nullptr},
    {"userNames", reinterpret_cast<PyCFunction>(Sbk_QWebEngineWebAuthUxRequestFunc_userNames), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QWebEngineWebAuthUxRequest_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QWebEngineWebAuthUxRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineWebAuthUxRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QWebEngineWebAuthUxRequestWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QWebEngineWebAuthUxRequest_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QWebEngineWebAuthUxRequest_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QWebEngineWebAuthUxRequest_Type = nullptr;
static PyTypeObject *Sbk_QWebEngineWebAuthUxRequest_TypeF(void)
{
    return _Sbk_QWebEngineWebAuthUxRequest_Type;
}

static PyType_Slot Sbk_QWebEngineWebAuthUxRequest_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QWebEngineWebAuthUxRequest_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QWebEngineWebAuthUxRequest_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QWebEngineWebAuthUxRequest_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QWebEngineWebAuthUxRequest_methods)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QWebEngineWebAuthUxRequest_spec = {
    "2:PySide6.QtWebEngineCore.QWebEngineWebAuthUxRequest",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QWebEngineWebAuthUxRequest_slots
};

} //extern "C"

static void *Sbk_QWebEngineWebAuthUxRequest_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QWebEngineWebAuthUxRequest *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QWebEngineWebAuthUxRequest_WebAuthUxState(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWebEngineWebAuthUxRequest::WebAuthUxState>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QWebEngineWebAuthUxRequest::WebAuthUxState *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QWebEngineWebAuthUxRequest_WebAuthUxState_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineWebAuthUxRequest_WebAuthUxState_IDX])))
        return Enum_PythonToCpp_QWebEngineWebAuthUxRequest_WebAuthUxState;
    return {};
}

static PyObject *QWebEngineWebAuthUxRequest_WebAuthUxState_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QWebEngineWebAuthUxRequest::WebAuthUxState>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QWebEngineWebAuthUxRequest::WebAuthUxState *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineWebAuthUxRequest_WebAuthUxState_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QWebEngineWebAuthUxRequest_PinEntryReason(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWebEngineWebAuthUxRequest::PinEntryReason>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QWebEngineWebAuthUxRequest::PinEntryReason *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QWebEngineWebAuthUxRequest_PinEntryReason_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineWebAuthUxRequest_PinEntryReason_IDX])))
        return Enum_PythonToCpp_QWebEngineWebAuthUxRequest_PinEntryReason;
    return {};
}

static PyObject *QWebEngineWebAuthUxRequest_PinEntryReason_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QWebEngineWebAuthUxRequest::PinEntryReason>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QWebEngineWebAuthUxRequest::PinEntryReason *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineWebAuthUxRequest_PinEntryReason_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QWebEngineWebAuthUxRequest_PinEntryError(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWebEngineWebAuthUxRequest::PinEntryError>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QWebEngineWebAuthUxRequest::PinEntryError *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QWebEngineWebAuthUxRequest_PinEntryError_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineWebAuthUxRequest_PinEntryError_IDX])))
        return Enum_PythonToCpp_QWebEngineWebAuthUxRequest_PinEntryError;
    return {};
}

static PyObject *QWebEngineWebAuthUxRequest_PinEntryError_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QWebEngineWebAuthUxRequest::PinEntryError>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QWebEngineWebAuthUxRequest::PinEntryError *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineWebAuthUxRequest_PinEntryError_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QWebEngineWebAuthUxRequest_RequestFailureReason(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWebEngineWebAuthUxRequest::RequestFailureReason>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QWebEngineWebAuthUxRequest::RequestFailureReason *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QWebEngineWebAuthUxRequest_RequestFailureReason_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineWebAuthUxRequest_RequestFailureReason_IDX])))
        return Enum_PythonToCpp_QWebEngineWebAuthUxRequest_RequestFailureReason;
    return {};
}

static PyObject *QWebEngineWebAuthUxRequest_RequestFailureReason_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QWebEngineWebAuthUxRequest::RequestFailureReason>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QWebEngineWebAuthUxRequest::RequestFailureReason *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineWebAuthUxRequest_RequestFailureReason_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QWebEngineWebAuthUxRequest_PythonToCpp_QWebEngineWebAuthUxRequest_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QWebEngineWebAuthUxRequest_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QWebEngineWebAuthUxRequest_PythonToCpp_QWebEngineWebAuthUxRequest_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QWebEngineWebAuthUxRequest_TypeF()))
        return QWebEngineWebAuthUxRequest_PythonToCpp_QWebEngineWebAuthUxRequest_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QWebEngineWebAuthUxRequest_PTR_CppToPython_QWebEngineWebAuthUxRequest(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QWebEngineWebAuthUxRequest *>(const_cast<void *>(cppIn)), Sbk_QWebEngineWebAuthUxRequest_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QWebEngineWebAuthUxRequest_SignatureStrings[] = {
    "PySide6.QtWebEngineCore.QWebEngineWebAuthUxRequest.cancel(self)",
    "PySide6.QtWebEngineCore.QWebEngineWebAuthUxRequest.pinRequest(self)->PySide6.QtWebEngineCore.QWebEngineWebAuthPinRequest",
    "PySide6.QtWebEngineCore.QWebEngineWebAuthUxRequest.relyingPartyId(self)->QString",
    "PySide6.QtWebEngineCore.QWebEngineWebAuthUxRequest.requestFailureReason(self)->PySide6.QtWebEngineCore.QWebEngineWebAuthUxRequest.RequestFailureReason",
    "PySide6.QtWebEngineCore.QWebEngineWebAuthUxRequest.retry(self)",
    "PySide6.QtWebEngineCore.QWebEngineWebAuthUxRequest.setPin(self,pin:QString)",
    "PySide6.QtWebEngineCore.QWebEngineWebAuthUxRequest.setSelectedAccount(self,selectedAccount:QString)",
    "PySide6.QtWebEngineCore.QWebEngineWebAuthUxRequest.state(self)->PySide6.QtWebEngineCore.QWebEngineWebAuthUxRequest.WebAuthUxState",
    "PySide6.QtWebEngineCore.QWebEngineWebAuthUxRequest.userNames(self)->QStringList",
    nullptr}; // Sentinel
#else
static constexpr size_t QWebEngineWebAuthUxRequest_SignatureByteSize = 200;
static constexpr uint8_t QWebEngineWebAuthUxRequest_SignatureBytes[200] = {
    0x78, 0xda, 0xa5, 0x92, 0x4f, 0x0b, 0xc2, 0x30, 0x0c, 0xc5, 0xef, 0x7e, 0x12, 0x85, 0xb9, 0xa3,
    0x07, 0x0f, 0xc2, 0x10, 0x05, 0x41, 0x64, 0x7f, 0x10, 0xcf, 0xb5, 0x7b, 0xce, 0x42, 0xed, 0xb4,
    0x4d, 0xc1, 0x7d, 0x7b, 0xeb, 0x36, 0x27, 0x8a, 0x07, 0xd7, 0x9d, 0x9a, 0x06, 0xf2, 0x7b, 0x49,
    0x5e, 0xe2, 0x2a, 0x13, 0x39, 0x66, 0x61, 0x42, 0x07, 0x1c, 0x57, 0xaa, 0x10, 0x0a, 0xcb, 0x52,
    0x23, 0x4c, 0xba, 0xaf, 0x0b, 0x22, 0x4b, 0xe7, 0xfd, 0x3d, 0xc5, 0xcd, 0xc2, 0x50, 0xc8, 0x99,
    0xe2, 0x90, 0x63, 0x03, 0x79, 0x9a, 0x8c, 0xe2, 0xfe, 0xf5, 0x57, 0xa1, 0xda, 0xb0, 0x61, 0x4c,
    0x17, 0x7f, 0x43, 0xe2, 0xae, 0xd4, 0x47, 0x58, 0x43, 0x56, 0x42, 0x15, 0x31, 0xd3, 0x54, 0x6d,
    0xf2, 0x97, 0x78, 0x92, 0x91, 0x76, 0x59, 0x3f, 0x60, 0xfd, 0xae, 0x99, 0x90, 0x56, 0x23, 0x05,
    0x33, 0xa5, 0xea, 0x3d, 0xd3, 0x1b, 0x97, 0xfe, 0xc0, 0xf9, 0xb5, 0x45, 0xba, 0xf2, 0xf7, 0xc7,
    0x80, 0xdc, 0x9e, 0xeb, 0xfa, 0xc0, 0x79, 0x35, 0x6f, 0x17, 0xe4, 0xcb, 0xca, 0x20, 0xc1, 0x09,
    0x79, 0xc4, 0x79, 0x69, 0x55, 0xe3, 0x79, 0x60, 0x3e, 0x93, 0xc3, 0x34, 0x88, 0x11, 0x06, 0xac,
    0xbd, 0x4b, 0x64, 0x4f, 0x90, 0x4f, 0x07, 0xd6, 0x40, 0xef, 0xd8, 0x05, 0xe6, 0xeb, 0xa6, 0xb6,
    0xc2, 0x1d, 0xea, 0x03, 0x46, 0x02, 0x41, 0x05
};
#endif

PyTypeObject *init_QWebEngineWebAuthUxRequest(PyObject *module)
{
    if (SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineWebAuthUxRequest_IDX].type != nullptr)
        return SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineWebAuthUxRequest_IDX].type;

    Shiboken::AutoDecRef Sbk_QWebEngineWebAuthUxRequest_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QWebEngineWebAuthUxRequest_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QWebEngineWebAuthUxRequest",
        "QWebEngineWebAuthUxRequest*",
        &Sbk_QWebEngineWebAuthUxRequest_spec,
        &Shiboken::callCppDestructor< QWebEngineWebAuthUxRequest >,
        Sbk_QWebEngineWebAuthUxRequest_Type_bases.object(),
        0);
    auto *pyType = Sbk_QWebEngineWebAuthUxRequest_TypeF(); // references _Sbk_QWebEngineWebAuthUxRequest_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QWebEngineWebAuthUxRequest_SignatureStrings);
#else
    InitSignatureBytes(pyType, QWebEngineWebAuthUxRequest_SignatureBytes, QWebEngineWebAuthUxRequest_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QWebEngineWebAuthUxRequest_PropertyStrings);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineWebAuthUxRequest_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QWebEngineWebAuthUxRequest_PythonToCpp_QWebEngineWebAuthUxRequest_PTR,
        is_QWebEngineWebAuthUxRequest_PythonToCpp_QWebEngineWebAuthUxRequest_PTR_Convertible,
        QWebEngineWebAuthUxRequest_PTR_CppToPython_QWebEngineWebAuthUxRequest);

    Shiboken::Conversions::registerConverterName(converter, "QWebEngineWebAuthUxRequest");
    Shiboken::Conversions::registerConverterName(converter, "QWebEngineWebAuthUxRequest*");
    Shiboken::Conversions::registerConverterName(converter, "QWebEngineWebAuthUxRequest&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QWebEngineWebAuthUxRequest).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QWebEngineWebAuthUxRequestWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QWebEngineWebAuthUxRequest_TypeF(), &Sbk_QWebEngineWebAuthUxRequest_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QWebEngineWebAuthUxRequest_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'WebAuthUxState'.
    const char *WebAuthUxState_Initializer[] = {
        "NotStarted",
        "SelectAccount",
        "CollectPin",
        "FinishTokenCollection",
        "RequestFailed",
        "Cancelled",
        "Completed",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t WebAuthUxState_InitializerValues[] = {
        int8_t(QWebEngineWebAuthUxRequest::WebAuthUxState::NotStarted),            //  0x00  0
        int8_t(QWebEngineWebAuthUxRequest::WebAuthUxState::SelectAccount),         //  0x01  1
        int8_t(QWebEngineWebAuthUxRequest::WebAuthUxState::CollectPin),            //  0x02  2
        int8_t(QWebEngineWebAuthUxRequest::WebAuthUxState::FinishTokenCollection), //  0x03  3
        int8_t(QWebEngineWebAuthUxRequest::WebAuthUxState::RequestFailed),         //  0x04  4
        int8_t(QWebEngineWebAuthUxRequest::WebAuthUxState::Cancelled),             //  0x05  5
        int8_t(QWebEngineWebAuthUxRequest::WebAuthUxState::Completed)              //  0x06  6
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWebEngineWebAuthUxRequest_TypeF(),
        "2:PySide6.QtWebEngineCore.QWebEngineWebAuthUxRequest.WebAuthUxState",
        WebAuthUxState_Initializer, WebAuthUxState_InitializerValues);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineWebAuthUxRequest_WebAuthUxState_IDX].type = EType;
    // Register converter for enum 'QWebEngineWebAuthUxRequest::WebAuthUxState'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWebEngineWebAuthUxRequest_WebAuthUxState_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QWebEngineWebAuthUxRequest_WebAuthUxState,
            is_Enum_PythonToCpp_QWebEngineWebAuthUxRequest_WebAuthUxState_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QWebEngineWebAuthUxRequest::WebAuthUxState");
        Shiboken::Conversions::registerConverterAlias(converter, "WebAuthUxState");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'WebAuthUxState' enum.

    // Initialization of enum 'PinEntryReason'.
    const char *PinEntryReason_Initializer[] = {
        "Set",
        "Change",
        "Challenge",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t PinEntryReason_InitializerValues[] = {
        int8_t(QWebEngineWebAuthUxRequest::PinEntryReason::Set),      //  0x00  0
        int8_t(QWebEngineWebAuthUxRequest::PinEntryReason::Change),   //  0x01  1
        int8_t(QWebEngineWebAuthUxRequest::PinEntryReason::Challenge) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWebEngineWebAuthUxRequest_TypeF(),
        "2:PySide6.QtWebEngineCore.QWebEngineWebAuthUxRequest.PinEntryReason",
        PinEntryReason_Initializer, PinEntryReason_InitializerValues);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineWebAuthUxRequest_PinEntryReason_IDX].type = EType;
    // Register converter for enum 'QWebEngineWebAuthUxRequest::PinEntryReason'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWebEngineWebAuthUxRequest_PinEntryReason_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QWebEngineWebAuthUxRequest_PinEntryReason,
            is_Enum_PythonToCpp_QWebEngineWebAuthUxRequest_PinEntryReason_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QWebEngineWebAuthUxRequest::PinEntryReason");
        Shiboken::Conversions::registerConverterAlias(converter, "PinEntryReason");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'PinEntryReason' enum.

    // Initialization of enum 'PinEntryError'.
    const char *PinEntryError_Initializer[] = {
        "NoError",
        "InternalUvLocked",
        "WrongPin",
        "TooShort",
        "InvalidCharacters",
        "SameAsCurrentPin",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t PinEntryError_InitializerValues[] = {
        int8_t(QWebEngineWebAuthUxRequest::PinEntryError::NoError),           //  0x00  0
        int8_t(QWebEngineWebAuthUxRequest::PinEntryError::InternalUvLocked),  //  0x01  1
        int8_t(QWebEngineWebAuthUxRequest::PinEntryError::WrongPin),          //  0x02  2
        int8_t(QWebEngineWebAuthUxRequest::PinEntryError::TooShort),          //  0x03  3
        int8_t(QWebEngineWebAuthUxRequest::PinEntryError::InvalidCharacters), //  0x04  4
        int8_t(QWebEngineWebAuthUxRequest::PinEntryError::SameAsCurrentPin)   //  0x05  5
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWebEngineWebAuthUxRequest_TypeF(),
        "2:PySide6.QtWebEngineCore.QWebEngineWebAuthUxRequest.PinEntryError",
        PinEntryError_Initializer, PinEntryError_InitializerValues);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineWebAuthUxRequest_PinEntryError_IDX].type = EType;
    // Register converter for enum 'QWebEngineWebAuthUxRequest::PinEntryError'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWebEngineWebAuthUxRequest_PinEntryError_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QWebEngineWebAuthUxRequest_PinEntryError,
            is_Enum_PythonToCpp_QWebEngineWebAuthUxRequest_PinEntryError_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QWebEngineWebAuthUxRequest::PinEntryError");
        Shiboken::Conversions::registerConverterAlias(converter, "PinEntryError");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'PinEntryError' enum.

    // Initialization of enum 'RequestFailureReason'.
    const char *RequestFailureReason_Initializer[] = {
        "Timeout",
        "KeyNotRegistered",
        "KeyAlreadyRegistered",
        "SoftPinBlock",
        "HardPinBlock",
        "AuthenticatorRemovedDuringPinEntry",
        "AuthenticatorMissingResidentKeys",
        "AuthenticatorMissingUserVerification",
        "AuthenticatorMissingLargeBlob",
        "NoCommonAlgorithms",
        "StorageFull",
        "UserConsentDenied",
        "WinUserCancelled",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t RequestFailureReason_InitializerValues[] = {
        int8_t(QWebEngineWebAuthUxRequest::RequestFailureReason::Timeout),                              //  0x00  0
        int8_t(QWebEngineWebAuthUxRequest::RequestFailureReason::KeyNotRegistered),                     //  0x01  1
        int8_t(QWebEngineWebAuthUxRequest::RequestFailureReason::KeyAlreadyRegistered),                 //  0x02  2
        int8_t(QWebEngineWebAuthUxRequest::RequestFailureReason::SoftPinBlock),                         //  0x03  3
        int8_t(QWebEngineWebAuthUxRequest::RequestFailureReason::HardPinBlock),                         //  0x04  4
        int8_t(QWebEngineWebAuthUxRequest::RequestFailureReason::AuthenticatorRemovedDuringPinEntry),   //  0x05  5
        int8_t(QWebEngineWebAuthUxRequest::RequestFailureReason::AuthenticatorMissingResidentKeys),     //  0x06  6
        int8_t(QWebEngineWebAuthUxRequest::RequestFailureReason::AuthenticatorMissingUserVerification), //  0x07  7
        int8_t(QWebEngineWebAuthUxRequest::RequestFailureReason::AuthenticatorMissingLargeBlob),        //  0x08  8
        int8_t(QWebEngineWebAuthUxRequest::RequestFailureReason::NoCommonAlgorithms),                   //  0x09  9
        int8_t(QWebEngineWebAuthUxRequest::RequestFailureReason::StorageFull),                          //  0x0a  10
        int8_t(QWebEngineWebAuthUxRequest::RequestFailureReason::UserConsentDenied),                    //  0x0b  11
        int8_t(QWebEngineWebAuthUxRequest::RequestFailureReason::WinUserCancelled)                      //  0x0c  12
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWebEngineWebAuthUxRequest_TypeF(),
        "2:PySide6.QtWebEngineCore.QWebEngineWebAuthUxRequest.RequestFailureReason",
        RequestFailureReason_Initializer, RequestFailureReason_InitializerValues);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineWebAuthUxRequest_RequestFailureReason_IDX].type = EType;
    // Register converter for enum 'QWebEngineWebAuthUxRequest::RequestFailureReason'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWebEngineWebAuthUxRequest_RequestFailureReason_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QWebEngineWebAuthUxRequest_RequestFailureReason,
            is_Enum_PythonToCpp_QWebEngineWebAuthUxRequest_RequestFailureReason_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QWebEngineWebAuthUxRequest::RequestFailureReason");
        Shiboken::Conversions::registerConverterAlias(converter, "RequestFailureReason");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'RequestFailureReason' enum.

    PySide::Signal::registerSignals(pyType, &::QWebEngineWebAuthUxRequest::staticMetaObject);
    qRegisterMetaType< ::QWebEngineWebAuthUxRequest::WebAuthUxState >("QWebEngineWebAuthUxRequest::WebAuthUxState");
    qRegisterMetaType< ::QWebEngineWebAuthUxRequest::PinEntryReason >("QWebEngineWebAuthUxRequest::PinEntryReason");
    qRegisterMetaType< ::QWebEngineWebAuthUxRequest::PinEntryError >("QWebEngineWebAuthUxRequest::PinEntryError");
    qRegisterMetaType< ::QWebEngineWebAuthUxRequest::RequestFailureReason >("QWebEngineWebAuthUxRequest::RequestFailureReason");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QWebEngineWebAuthUxRequest::staticMetaObject, sizeof(QWebEngineWebAuthUxRequestWrapper));

    return pyType;
}
