// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwebenginequick_python.h"

// main header
#include "qquickwebengineprofile_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QStringList>
#include <QtWebEngineCore/qwebengineclientcertificatestore.h>
#include <QtWebEngineCore/qwebengineclienthints.h>
#include <QtWebEngineCore/qwebenginecookiestore.h>
#include <QtWebEngineCore/qwebenginenotification.h>
#include <QtWebEngineCore/qwebenginepermission.h>
#include <QtWebEngineCore/qwebengineurlrequestinterceptor.h>
#include <QtWebEngineCore/qwebengineurlschemehandler.h>
#include <QtWebEngineQuick/qquickwebengineprofile.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qurl.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QQuickWebEngineProfileWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QQuickWebEngineProfileWrapper::QQuickWebEngineProfileWrapper(::QObject * parent) : QQuickWebEngineProfile(parent)
{
}

void QQuickWebEngineProfileWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickWebEngineProfile", funcName);
        return;
    }
}

void QQuickWebEngineProfileWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickWebEngineProfile", funcName);
        return;
    }
}

void QQuickWebEngineProfileWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickWebEngineProfile", funcName);
        return;
    }
}

void QQuickWebEngineProfileWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickWebEngineProfile", funcName);
        return;
    }
}

bool QQuickWebEngineProfileWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickWebEngineProfile", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QQuickWebEngineProfile", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QQuickWebEngineProfileWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickWebEngineProfile", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QQuickWebEngineProfile", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QQuickWebEngineProfileWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickWebEngineProfile", funcName);
        return;
    }
}

const QMetaObject *QQuickWebEngineProfileWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QQuickWebEngineProfile::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QQuickWebEngineProfileWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QQuickWebEngineProfile::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QQuickWebEngineProfileWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QQuickWebEngineProfileWrapper *>(this));
    return QQuickWebEngineProfile::qt_metacast(_clname);
}

QQuickWebEngineProfileWrapper::~QQuickWebEngineProfileWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QQuickWebEngineProfile_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QQuickWebEngineProfile >()))
        return -1;

    QQuickWebEngineProfileWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QQuickWebEngineProfile", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QQuickWebEngineProfile::QQuickWebEngineProfile(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QQuickWebEngineProfile(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QQuickWebEngineProfile(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                // fall through to handle extra keyword signals and properties
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QQuickWebEngineProfile(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QQuickWebEngineProfileWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QQuickWebEngineProfileWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QQuickWebEngineProfile >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QQuickWebEngineProfileFunc_cachePath(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cachePath()const
        QString cppResult = const_cast<const ::QQuickWebEngineProfile *>(cppSelf)->cachePath();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickWebEngineProfileFunc_clearHttpCache(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clearHttpCache()
        cppSelf->clearHttpCache();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickWebEngineProfileFunc_clientCertificateStore(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clientCertificateStore()
        QWebEngineClientCertificateStore * cppResult = cppSelf->clientCertificateStore();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineClientCertificateStore_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickWebEngineProfileFunc_clientHints(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clientHints()const
        QWebEngineClientHints * cppResult = const_cast<const ::QQuickWebEngineProfile *>(cppSelf)->clientHints();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineClientHints_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickWebEngineProfileFunc_cookieStore(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cookieStore()const
        QWebEngineCookieStore * cppResult = const_cast<const ::QQuickWebEngineProfile *>(cppSelf)->cookieStore();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineCookieStore_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickWebEngineProfileFunc_defaultProfile(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // defaultProfile()
        QQuickWebEngineProfile * cppResult = ::QQuickWebEngineProfile::defaultProfile();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickWebEngineProfileFunc_downloadPath(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // downloadPath()const
        QString cppResult = const_cast<const ::QQuickWebEngineProfile *>(cppSelf)->downloadPath();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickWebEngineProfileFunc_httpAcceptLanguage(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // httpAcceptLanguage()const
        QString cppResult = const_cast<const ::QQuickWebEngineProfile *>(cppSelf)->httpAcceptLanguage();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickWebEngineProfileFunc_httpCacheMaximumSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // httpCacheMaximumSize()const
        int cppResult = const_cast<const ::QQuickWebEngineProfile *>(cppSelf)->httpCacheMaximumSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickWebEngineProfileFunc_httpCacheType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // httpCacheType()const
        QQuickWebEngineProfile::HttpCacheType cppResult = const_cast<const ::QQuickWebEngineProfile *>(cppSelf)->httpCacheType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_HttpCacheType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickWebEngineProfileFunc_httpUserAgent(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // httpUserAgent()const
        QString cppResult = const_cast<const ::QQuickWebEngineProfile *>(cppSelf)->httpUserAgent();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickWebEngineProfileFunc_installUrlSchemeHandler(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "installUrlSchemeHandler", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QQuickWebEngineProfile::installUrlSchemeHandler(QByteArray,QWebEngineUrlSchemeHandler*)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlSchemeHandler_IDX]), (pyArgs[1])))) {
        overloadId = 0; // installUrlSchemeHandler(QByteArray,QWebEngineUrlSchemeHandler*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "installUrlSchemeHandler", errInfo, SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QWebEngineUrlSchemeHandler *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // installUrlSchemeHandler(QByteArray,QWebEngineUrlSchemeHandler*)
            cppSelf->installUrlSchemeHandler(*cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickWebEngineProfileFunc_isOffTheRecord(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isOffTheRecord()const
        bool cppResult = const_cast<const ::QQuickWebEngineProfile *>(cppSelf)->isOffTheRecord();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickWebEngineProfileFunc_isPushServiceEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isPushServiceEnabled()const
        bool cppResult = const_cast<const ::QQuickWebEngineProfile *>(cppSelf)->isPushServiceEnabled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickWebEngineProfileFunc_isSpellCheckEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isSpellCheckEnabled()const
        bool cppResult = const_cast<const ::QQuickWebEngineProfile *>(cppSelf)->isSpellCheckEnabled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickWebEngineProfileFunc_listAllPermissions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // listAllPermissions()const
        QList<QWebEnginePermission> cppResult = const_cast<const ::QQuickWebEngineProfile *>(cppSelf)->listAllPermissions();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtWebEngineQuickTypeConverters[SBK_QtWebEngineQuick_QList_QWebEnginePermission_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickWebEngineProfileFunc_listPermissionsForOrigin(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickWebEngineProfile::listPermissionsForOrigin(QUrl)const->QList<QWebEnginePermission>
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // listPermissionsForOrigin(QUrl)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "listPermissionsForOrigin", errInfo, SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // listPermissionsForOrigin(QUrl)const
            QList<QWebEnginePermission> cppResult = const_cast<const ::QQuickWebEngineProfile *>(cppSelf)->listPermissionsForOrigin(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtWebEngineQuickTypeConverters[SBK_QtWebEngineQuick_QList_QWebEnginePermission_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickWebEngineProfileFunc_listPermissionsForPermissionType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickWebEngineProfile::listPermissionsForPermissionType(QWebEnginePermission::PermissionType)const->QList<QWebEnginePermission>
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePermission_PermissionType_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // listPermissionsForPermissionType(QWebEnginePermission::PermissionType)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "listPermissionsForPermissionType", errInfo, SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]);

    // Call function/method
    {
        ::QWebEnginePermission::PermissionType cppArg0{QWebEnginePermission::PermissionType::Unsupported};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // listPermissionsForPermissionType(QWebEnginePermission::PermissionType)const
            QList<QWebEnginePermission> cppResult = const_cast<const ::QQuickWebEngineProfile *>(cppSelf)->listPermissionsForPermissionType(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtWebEngineQuickTypeConverters[SBK_QtWebEngineQuick_QList_QWebEnginePermission_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickWebEngineProfileFunc_persistentCookiesPolicy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // persistentCookiesPolicy()const
        QQuickWebEngineProfile::PersistentCookiesPolicy cppResult = const_cast<const ::QQuickWebEngineProfile *>(cppSelf)->persistentCookiesPolicy();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_PersistentCookiesPolicy_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickWebEngineProfileFunc_persistentPermissionsPolicy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // persistentPermissionsPolicy()const
        QQuickWebEngineProfile::PersistentPermissionsPolicy cppResult = const_cast<const ::QQuickWebEngineProfile *>(cppSelf)->persistentPermissionsPolicy();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_PersistentPermissionsPolicy_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickWebEngineProfileFunc_persistentStoragePath(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // persistentStoragePath()const
        QString cppResult = const_cast<const ::QQuickWebEngineProfile *>(cppSelf)->persistentStoragePath();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickWebEngineProfileFunc_queryPermission(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "queryPermission", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QQuickWebEngineProfile::queryPermission(QUrl,QWebEnginePermission::PermissionType)const->QWebEnginePermission
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePermission_PermissionType_IDX])))->converter, (pyArgs[1])))) {
        overloadId = 0; // queryPermission(QUrl,QWebEnginePermission::PermissionType)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "queryPermission", errInfo, SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QWebEnginePermission::PermissionType cppArg1{QWebEnginePermission::PermissionType::Unsupported};
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // queryPermission(QUrl,QWebEnginePermission::PermissionType)const
            QWebEnginePermission cppResult = const_cast<const ::QQuickWebEngineProfile *>(cppSelf)->queryPermission(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePermission_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickWebEngineProfileFunc_removeAllUrlSchemeHandlers(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // removeAllUrlSchemeHandlers()
        cppSelf->removeAllUrlSchemeHandlers();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickWebEngineProfileFunc_removeUrlScheme(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickWebEngineProfile::removeUrlScheme(QByteArray)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // removeUrlScheme(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeUrlScheme", errInfo, SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // removeUrlScheme(QByteArray)
            cppSelf->removeUrlScheme(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickWebEngineProfileFunc_removeUrlSchemeHandler(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickWebEngineProfile::removeUrlSchemeHandler(QWebEngineUrlSchemeHandler*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlSchemeHandler_IDX]), (pyArg)))) {
        overloadId = 0; // removeUrlSchemeHandler(QWebEngineUrlSchemeHandler*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeUrlSchemeHandler", errInfo, SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QWebEngineUrlSchemeHandler *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeUrlSchemeHandler(QWebEngineUrlSchemeHandler*)
            cppSelf->removeUrlSchemeHandler(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickWebEngineProfileFunc_setCachePath(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickWebEngineProfile::setCachePath(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setCachePath(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCachePath", errInfo, SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCachePath(QString)
            cppSelf->setCachePath(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickWebEngineProfileFunc_setDownloadPath(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickWebEngineProfile::setDownloadPath(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setDownloadPath(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDownloadPath", errInfo, SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDownloadPath(QString)
            cppSelf->setDownloadPath(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickWebEngineProfileFunc_setHttpAcceptLanguage(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickWebEngineProfile::setHttpAcceptLanguage(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setHttpAcceptLanguage(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHttpAcceptLanguage", errInfo, SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHttpAcceptLanguage(QString)
            cppSelf->setHttpAcceptLanguage(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickWebEngineProfileFunc_setHttpCacheMaximumSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickWebEngineProfile::setHttpCacheMaximumSize(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setHttpCacheMaximumSize(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHttpCacheMaximumSize", errInfo, SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHttpCacheMaximumSize(int)
            cppSelf->setHttpCacheMaximumSize(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickWebEngineProfileFunc_setHttpCacheType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickWebEngineProfile::setHttpCacheType(QQuickWebEngineProfile::HttpCacheType)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_HttpCacheType_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setHttpCacheType(QQuickWebEngineProfile::HttpCacheType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHttpCacheType", errInfo, SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]);

    // Call function/method
    {
        ::QQuickWebEngineProfile::HttpCacheType cppArg0{QQuickWebEngineProfile::MemoryHttpCache};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHttpCacheType(QQuickWebEngineProfile::HttpCacheType)
            cppSelf->setHttpCacheType(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickWebEngineProfileFunc_setHttpUserAgent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickWebEngineProfile::setHttpUserAgent(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setHttpUserAgent(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHttpUserAgent", errInfo, SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHttpUserAgent(QString)
            cppSelf->setHttpUserAgent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickWebEngineProfileFunc_setOffTheRecord(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickWebEngineProfile::setOffTheRecord(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setOffTheRecord(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOffTheRecord", errInfo, SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOffTheRecord(bool)
            cppSelf->setOffTheRecord(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickWebEngineProfileFunc_setPersistentCookiesPolicy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickWebEngineProfile::setPersistentCookiesPolicy(QQuickWebEngineProfile::PersistentCookiesPolicy)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_PersistentCookiesPolicy_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setPersistentCookiesPolicy(QQuickWebEngineProfile::PersistentCookiesPolicy)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPersistentCookiesPolicy", errInfo, SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]);

    // Call function/method
    {
        ::QQuickWebEngineProfile::PersistentCookiesPolicy cppArg0{QQuickWebEngineProfile::NoPersistentCookies};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPersistentCookiesPolicy(QQuickWebEngineProfile::PersistentCookiesPolicy)
            cppSelf->setPersistentCookiesPolicy(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickWebEngineProfileFunc_setPersistentPermissionsPolicy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickWebEngineProfile::setPersistentPermissionsPolicy(QQuickWebEngineProfile::PersistentPermissionsPolicy)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_PersistentPermissionsPolicy_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setPersistentPermissionsPolicy(QQuickWebEngineProfile::PersistentPermissionsPolicy)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPersistentPermissionsPolicy", errInfo, SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]);

    // Call function/method
    {
        ::QQuickWebEngineProfile::PersistentPermissionsPolicy cppArg0{QQuickWebEngineProfile::PersistentPermissionsPolicy::AskEveryTime};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPersistentPermissionsPolicy(QQuickWebEngineProfile::PersistentPermissionsPolicy)
            cppSelf->setPersistentPermissionsPolicy(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickWebEngineProfileFunc_setPersistentStoragePath(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickWebEngineProfile::setPersistentStoragePath(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setPersistentStoragePath(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPersistentStoragePath", errInfo, SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPersistentStoragePath(QString)
            cppSelf->setPersistentStoragePath(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickWebEngineProfileFunc_setPushServiceEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickWebEngineProfile::setPushServiceEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setPushServiceEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPushServiceEnabled", errInfo, SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPushServiceEnabled(bool)
            cppSelf->setPushServiceEnabled(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickWebEngineProfileFunc_setSpellCheckEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickWebEngineProfile::setSpellCheckEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setSpellCheckEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSpellCheckEnabled", errInfo, SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSpellCheckEnabled(bool)
            cppSelf->setSpellCheckEnabled(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickWebEngineProfileFunc_setSpellCheckLanguages(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickWebEngineProfile::setSpellCheckLanguages(QStringList)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // setSpellCheckLanguages(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSpellCheckLanguages", errInfo, SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSpellCheckLanguages(QStringList)
            cppSelf->setSpellCheckLanguages(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickWebEngineProfileFunc_setStorageName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickWebEngineProfile::setStorageName(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setStorageName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStorageName", errInfo, SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStorageName(QString)
            cppSelf->setStorageName(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickWebEngineProfileFunc_setUrlRequestInterceptor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickWebEngineProfile::setUrlRequestInterceptor(QWebEngineUrlRequestInterceptor*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlRequestInterceptor_IDX]), (pyArg)))) {
        overloadId = 0; // setUrlRequestInterceptor(QWebEngineUrlRequestInterceptor*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUrlRequestInterceptor", errInfo, SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QWebEngineUrlRequestInterceptor *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setUrlRequestInterceptor(QWebEngineUrlRequestInterceptor*)
            cppSelf->setUrlRequestInterceptor(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickWebEngineProfileFunc_spellCheckLanguages(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // spellCheckLanguages()const
        QStringList cppResult = const_cast<const ::QQuickWebEngineProfile *>(cppSelf)->spellCheckLanguages();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickWebEngineProfileFunc_storageName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // storageName()const
        QString cppResult = const_cast<const ::QQuickWebEngineProfile *>(cppSelf)->storageName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickWebEngineProfileFunc_urlSchemeHandler(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickWebEngineProfile::urlSchemeHandler(QByteArray)const->const QWebEngineUrlSchemeHandler*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // urlSchemeHandler(QByteArray)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "urlSchemeHandler", errInfo, SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // urlSchemeHandler(QByteArray)const
            const QWebEngineUrlSchemeHandler * cppResult = const_cast<const ::QQuickWebEngineProfile *>(cppSelf)->urlSchemeHandler(*cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlSchemeHandler_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QQuickWebEngineProfile_PropertyStrings[] = {
    "cachePath::",
    "clientHints:",
    "downloadPath::",
    "httpAcceptLanguage::",
    "httpCacheMaximumSize::",
    "httpCacheType::",
    "httpUserAgent::",
    "isPushServiceEnabled::setPushServiceEnabled",
    "offTheRecord:isOffTheRecord:",
    "persistentCookiesPolicy::",
    "persistentPermissionsPolicy::",
    "persistentStoragePath::",
    "spellCheckEnabled:isSpellCheckEnabled:",
    "spellCheckLanguages::",
    "storageName::",
    nullptr // Sentinel
};

static const char *Sbk_QQuickWebEngineProfile_EnumFlagInfo[] = {
    "HttpCacheType:Enum",
    "PersistentCookiesPolicy:Enum",
    "PersistentPermissionsPolicy:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QQuickWebEngineProfile_methods[] = {
    {"cachePath", reinterpret_cast<PyCFunction>(Sbk_QQuickWebEngineProfileFunc_cachePath), METH_NOARGS, nullptr},
    {"clearHttpCache", reinterpret_cast<PyCFunction>(Sbk_QQuickWebEngineProfileFunc_clearHttpCache), METH_NOARGS, nullptr},
    {"clientCertificateStore", reinterpret_cast<PyCFunction>(Sbk_QQuickWebEngineProfileFunc_clientCertificateStore), METH_NOARGS, nullptr},
    {"clientHints", reinterpret_cast<PyCFunction>(Sbk_QQuickWebEngineProfileFunc_clientHints), METH_NOARGS, nullptr},
    {"cookieStore", reinterpret_cast<PyCFunction>(Sbk_QQuickWebEngineProfileFunc_cookieStore), METH_NOARGS, nullptr},
    {"defaultProfile", reinterpret_cast<PyCFunction>(Sbk_QQuickWebEngineProfileFunc_defaultProfile), METH_NOARGS|METH_STATIC, nullptr},
    {"downloadPath", reinterpret_cast<PyCFunction>(Sbk_QQuickWebEngineProfileFunc_downloadPath), METH_NOARGS, nullptr},
    {"httpAcceptLanguage", reinterpret_cast<PyCFunction>(Sbk_QQuickWebEngineProfileFunc_httpAcceptLanguage), METH_NOARGS, nullptr},
    {"httpCacheMaximumSize", reinterpret_cast<PyCFunction>(Sbk_QQuickWebEngineProfileFunc_httpCacheMaximumSize), METH_NOARGS, nullptr},
    {"httpCacheType", reinterpret_cast<PyCFunction>(Sbk_QQuickWebEngineProfileFunc_httpCacheType), METH_NOARGS, nullptr},
    {"httpUserAgent", reinterpret_cast<PyCFunction>(Sbk_QQuickWebEngineProfileFunc_httpUserAgent), METH_NOARGS, nullptr},
    {"installUrlSchemeHandler", reinterpret_cast<PyCFunction>(Sbk_QQuickWebEngineProfileFunc_installUrlSchemeHandler), METH_VARARGS, nullptr},
    {"isOffTheRecord", reinterpret_cast<PyCFunction>(Sbk_QQuickWebEngineProfileFunc_isOffTheRecord), METH_NOARGS, nullptr},
    {"isPushServiceEnabled", reinterpret_cast<PyCFunction>(Sbk_QQuickWebEngineProfileFunc_isPushServiceEnabled), METH_NOARGS, nullptr},
    {"isSpellCheckEnabled", reinterpret_cast<PyCFunction>(Sbk_QQuickWebEngineProfileFunc_isSpellCheckEnabled), METH_NOARGS, nullptr},
    {"listAllPermissions", reinterpret_cast<PyCFunction>(Sbk_QQuickWebEngineProfileFunc_listAllPermissions), METH_NOARGS, nullptr},
    {"listPermissionsForOrigin", reinterpret_cast<PyCFunction>(Sbk_QQuickWebEngineProfileFunc_listPermissionsForOrigin), METH_O, nullptr},
    {"listPermissionsForPermissionType", reinterpret_cast<PyCFunction>(Sbk_QQuickWebEngineProfileFunc_listPermissionsForPermissionType), METH_O, nullptr},
    {"persistentCookiesPolicy", reinterpret_cast<PyCFunction>(Sbk_QQuickWebEngineProfileFunc_persistentCookiesPolicy), METH_NOARGS, nullptr},
    {"persistentPermissionsPolicy", reinterpret_cast<PyCFunction>(Sbk_QQuickWebEngineProfileFunc_persistentPermissionsPolicy), METH_NOARGS, nullptr},
    {"persistentStoragePath", reinterpret_cast<PyCFunction>(Sbk_QQuickWebEngineProfileFunc_persistentStoragePath), METH_NOARGS, nullptr},
    {"queryPermission", reinterpret_cast<PyCFunction>(Sbk_QQuickWebEngineProfileFunc_queryPermission), METH_VARARGS, nullptr},
    {"removeAllUrlSchemeHandlers", reinterpret_cast<PyCFunction>(Sbk_QQuickWebEngineProfileFunc_removeAllUrlSchemeHandlers), METH_NOARGS, nullptr},
    {"removeUrlScheme", reinterpret_cast<PyCFunction>(Sbk_QQuickWebEngineProfileFunc_removeUrlScheme), METH_O, nullptr},
    {"removeUrlSchemeHandler", reinterpret_cast<PyCFunction>(Sbk_QQuickWebEngineProfileFunc_removeUrlSchemeHandler), METH_O, nullptr},
    {"setCachePath", reinterpret_cast<PyCFunction>(Sbk_QQuickWebEngineProfileFunc_setCachePath), METH_O, nullptr},
    {"setDownloadPath", reinterpret_cast<PyCFunction>(Sbk_QQuickWebEngineProfileFunc_setDownloadPath), METH_O, nullptr},
    {"setHttpAcceptLanguage", reinterpret_cast<PyCFunction>(Sbk_QQuickWebEngineProfileFunc_setHttpAcceptLanguage), METH_O, nullptr},
    {"setHttpCacheMaximumSize", reinterpret_cast<PyCFunction>(Sbk_QQuickWebEngineProfileFunc_setHttpCacheMaximumSize), METH_O, nullptr},
    {"setHttpCacheType", reinterpret_cast<PyCFunction>(Sbk_QQuickWebEngineProfileFunc_setHttpCacheType), METH_O, nullptr},
    {"setHttpUserAgent", reinterpret_cast<PyCFunction>(Sbk_QQuickWebEngineProfileFunc_setHttpUserAgent), METH_O, nullptr},
    {"setOffTheRecord", reinterpret_cast<PyCFunction>(Sbk_QQuickWebEngineProfileFunc_setOffTheRecord), METH_O, nullptr},
    {"setPersistentCookiesPolicy", reinterpret_cast<PyCFunction>(Sbk_QQuickWebEngineProfileFunc_setPersistentCookiesPolicy), METH_O, nullptr},
    {"setPersistentPermissionsPolicy", reinterpret_cast<PyCFunction>(Sbk_QQuickWebEngineProfileFunc_setPersistentPermissionsPolicy), METH_O, nullptr},
    {"setPersistentStoragePath", reinterpret_cast<PyCFunction>(Sbk_QQuickWebEngineProfileFunc_setPersistentStoragePath), METH_O, nullptr},
    {"setPushServiceEnabled", reinterpret_cast<PyCFunction>(Sbk_QQuickWebEngineProfileFunc_setPushServiceEnabled), METH_O, nullptr},
    {"setSpellCheckEnabled", reinterpret_cast<PyCFunction>(Sbk_QQuickWebEngineProfileFunc_setSpellCheckEnabled), METH_O, nullptr},
    {"setSpellCheckLanguages", reinterpret_cast<PyCFunction>(Sbk_QQuickWebEngineProfileFunc_setSpellCheckLanguages), METH_O, nullptr},
    {"setStorageName", reinterpret_cast<PyCFunction>(Sbk_QQuickWebEngineProfileFunc_setStorageName), METH_O, nullptr},
    {"setUrlRequestInterceptor", reinterpret_cast<PyCFunction>(Sbk_QQuickWebEngineProfileFunc_setUrlRequestInterceptor), METH_O, nullptr},
    {"spellCheckLanguages", reinterpret_cast<PyCFunction>(Sbk_QQuickWebEngineProfileFunc_spellCheckLanguages), METH_NOARGS, nullptr},
    {"storageName", reinterpret_cast<PyCFunction>(Sbk_QQuickWebEngineProfileFunc_storageName), METH_NOARGS, nullptr},
    {"urlSchemeHandler", reinterpret_cast<PyCFunction>(Sbk_QQuickWebEngineProfileFunc_urlSchemeHandler), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QQuickWebEngineProfile_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QQuickWebEngineProfile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QQuickWebEngineProfileWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QQuickWebEngineProfile_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QQuickWebEngineProfile_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QQuickWebEngineProfile_Type = nullptr;
static PyTypeObject *Sbk_QQuickWebEngineProfile_TypeF(void)
{
    return _Sbk_QQuickWebEngineProfile_Type;
}

static PyType_Slot Sbk_QQuickWebEngineProfile_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QQuickWebEngineProfile_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QQuickWebEngineProfile_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QQuickWebEngineProfile_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QQuickWebEngineProfile_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QQuickWebEngineProfile_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QQuickWebEngineProfile_spec = {
    "2:PySide6.QtWebEngineQuick.QQuickWebEngineProfile",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QQuickWebEngineProfile_slots
};

} //extern "C"

static void *Sbk_QQuickWebEngineProfile_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QQuickWebEngineProfile *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QQuickWebEngineProfile_HttpCacheType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QQuickWebEngineProfile::HttpCacheType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QQuickWebEngineProfile::HttpCacheType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QQuickWebEngineProfile_HttpCacheType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_HttpCacheType_IDX])))
        return Enum_PythonToCpp_QQuickWebEngineProfile_HttpCacheType;
    return {};
}

static PyObject *QQuickWebEngineProfile_HttpCacheType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QQuickWebEngineProfile::HttpCacheType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QQuickWebEngineProfile::HttpCacheType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_HttpCacheType_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QQuickWebEngineProfile_PersistentCookiesPolicy(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QQuickWebEngineProfile::PersistentCookiesPolicy>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QQuickWebEngineProfile::PersistentCookiesPolicy *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QQuickWebEngineProfile_PersistentCookiesPolicy_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_PersistentCookiesPolicy_IDX])))
        return Enum_PythonToCpp_QQuickWebEngineProfile_PersistentCookiesPolicy;
    return {};
}

static PyObject *QQuickWebEngineProfile_PersistentCookiesPolicy_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QQuickWebEngineProfile::PersistentCookiesPolicy>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QQuickWebEngineProfile::PersistentCookiesPolicy *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_PersistentCookiesPolicy_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QQuickWebEngineProfile_PersistentPermissionsPolicy(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QQuickWebEngineProfile::PersistentPermissionsPolicy>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QQuickWebEngineProfile::PersistentPermissionsPolicy *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QQuickWebEngineProfile_PersistentPermissionsPolicy_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_PersistentPermissionsPolicy_IDX])))
        return Enum_PythonToCpp_QQuickWebEngineProfile_PersistentPermissionsPolicy;
    return {};
}

static PyObject *QQuickWebEngineProfile_PersistentPermissionsPolicy_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QQuickWebEngineProfile::PersistentPermissionsPolicy>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QQuickWebEngineProfile::PersistentPermissionsPolicy *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_PersistentPermissionsPolicy_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QQuickWebEngineProfile_PythonToCpp_QQuickWebEngineProfile_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QQuickWebEngineProfile_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QQuickWebEngineProfile_PythonToCpp_QQuickWebEngineProfile_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QQuickWebEngineProfile_TypeF()))
        return QQuickWebEngineProfile_PythonToCpp_QQuickWebEngineProfile_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QQuickWebEngineProfile_PTR_CppToPython_QQuickWebEngineProfile(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QQuickWebEngineProfile *>(const_cast<void *>(cppIn)), Sbk_QQuickWebEngineProfile_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QQuickWebEngineProfile_SignatureStrings[] = {
    "PySide6.QtWebEngineQuick.QQuickWebEngineProfile(self,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,storageName:QString=None,offTheRecord:bool=None,persistentStoragePath:QString=None,cachePath:QString=None,httpUserAgent:QString=None,httpCacheType:QQuickWebEngineProfile.HttpCacheType=None,httpAcceptLanguage:QString=None,persistentCookiesPolicy:QQuickWebEngineProfile.PersistentCookiesPolicy=None,persistentPermissionsPolicy:QQuickWebEngineProfile.PersistentPermissionsPolicy=None,httpCacheMaximumSize:int=None,spellCheckLanguages:QStringList=None,spellCheckEnabled:bool=None,downloadPath:QString=None,isPushServiceEnabled:bool=None,clientHints:QWebEngineClientHints=None)",
    "PySide6.QtWebEngineQuick.QQuickWebEngineProfile.cachePath(self)->QString",
    "PySide6.QtWebEngineQuick.QQuickWebEngineProfile.clearHttpCache(self)",
    "PySide6.QtWebEngineQuick.QQuickWebEngineProfile.clientCertificateStore(self)->PySide6.QtWebEngineCore.QWebEngineClientCertificateStore",
    "PySide6.QtWebEngineQuick.QQuickWebEngineProfile.clientHints(self)->PySide6.QtWebEngineCore.QWebEngineClientHints",
    "PySide6.QtWebEngineQuick.QQuickWebEngineProfile.cookieStore(self)->PySide6.QtWebEngineCore.QWebEngineCookieStore",
    "PySide6.QtWebEngineQuick.QQuickWebEngineProfile.defaultProfile()->PySide6.QtWebEngineQuick.QQuickWebEngineProfile",
    "PySide6.QtWebEngineQuick.QQuickWebEngineProfile.downloadPath(self)->QString",
    "PySide6.QtWebEngineQuick.QQuickWebEngineProfile.httpAcceptLanguage(self)->QString",
    "PySide6.QtWebEngineQuick.QQuickWebEngineProfile.httpCacheMaximumSize(self)->int",
    "PySide6.QtWebEngineQuick.QQuickWebEngineProfile.httpCacheType(self)->PySide6.QtWebEngineQuick.QQuickWebEngineProfile.HttpCacheType",
    "PySide6.QtWebEngineQuick.QQuickWebEngineProfile.httpUserAgent(self)->QString",
    "PySide6.QtWebEngineQuick.QQuickWebEngineProfile.installUrlSchemeHandler(self,scheme:typing.Union[PySide6.QtCore.QByteArray, char*],arg__2:PySide6.QtWebEngineCore.QWebEngineUrlSchemeHandler)",
    "PySide6.QtWebEngineQuick.QQuickWebEngineProfile.isOffTheRecord(self)->bool",
    "PySide6.QtWebEngineQuick.QQuickWebEngineProfile.isPushServiceEnabled(self)->bool",
    "PySide6.QtWebEngineQuick.QQuickWebEngineProfile.isSpellCheckEnabled(self)->bool",
    "PySide6.QtWebEngineQuick.QQuickWebEngineProfile.listAllPermissions(self)->QList[PySide6.QtWebEngineCore.QWebEnginePermission]",
    "PySide6.QtWebEngineQuick.QQuickWebEngineProfile.listPermissionsForOrigin(self,securityOrigin:typing.Union[PySide6.QtCore.QUrl, QString])->QList[PySide6.QtWebEngineCore.QWebEnginePermission]",
    "PySide6.QtWebEngineQuick.QQuickWebEngineProfile.listPermissionsForPermissionType(self,permissionType:PySide6.QtWebEngineCore.QWebEnginePermission.PermissionType)->QList[PySide6.QtWebEngineCore.QWebEnginePermission]",
    "PySide6.QtWebEngineQuick.QQuickWebEngineProfile.persistentCookiesPolicy(self)->PySide6.QtWebEngineQuick.QQuickWebEngineProfile.PersistentCookiesPolicy",
    "PySide6.QtWebEngineQuick.QQuickWebEngineProfile.persistentPermissionsPolicy(self)->PySide6.QtWebEngineQuick.QQuickWebEngineProfile.PersistentPermissionsPolicy",
    "PySide6.QtWebEngineQuick.QQuickWebEngineProfile.persistentStoragePath(self)->QString",
    "PySide6.QtWebEngineQuick.QQuickWebEngineProfile.queryPermission(self,securityOrigin:typing.Union[PySide6.QtCore.QUrl, QString],permissionType:PySide6.QtWebEngineCore.QWebEnginePermission.PermissionType)->PySide6.QtWebEngineCore.QWebEnginePermission",
    "PySide6.QtWebEngineQuick.QQuickWebEngineProfile.removeAllUrlSchemeHandlers(self)",
    "PySide6.QtWebEngineQuick.QQuickWebEngineProfile.removeUrlScheme(self,scheme:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "PySide6.QtWebEngineQuick.QQuickWebEngineProfile.removeUrlSchemeHandler(self,arg__1:PySide6.QtWebEngineCore.QWebEngineUrlSchemeHandler)",
    "PySide6.QtWebEngineQuick.QQuickWebEngineProfile.setCachePath(self,path:QString)",
    "PySide6.QtWebEngineQuick.QQuickWebEngineProfile.setDownloadPath(self,path:QString)",
    "PySide6.QtWebEngineQuick.QQuickWebEngineProfile.setHttpAcceptLanguage(self,httpAcceptLanguage:QString)",
    "PySide6.QtWebEngineQuick.QQuickWebEngineProfile.setHttpCacheMaximumSize(self,maxSize:int)",
    "PySide6.QtWebEngineQuick.QQuickWebEngineProfile.setHttpCacheType(self,arg__1:PySide6.QtWebEngineQuick.QQuickWebEngineProfile.HttpCacheType)",
    "PySide6.QtWebEngineQuick.QQuickWebEngineProfile.setHttpUserAgent(self,userAgent:QString)",
    "PySide6.QtWebEngineQuick.QQuickWebEngineProfile.setOffTheRecord(self,offTheRecord:bool)",
    "PySide6.QtWebEngineQuick.QQuickWebEngineProfile.setPersistentCookiesPolicy(self,arg__1:PySide6.QtWebEngineQuick.QQuickWebEngineProfile.PersistentCookiesPolicy)",
    "PySide6.QtWebEngineQuick.QQuickWebEngineProfile.setPersistentPermissionsPolicy(self,arg__1:PySide6.QtWebEngineQuick.QQuickWebEngineProfile.PersistentPermissionsPolicy)",
    "PySide6.QtWebEngineQuick.QQuickWebEngineProfile.setPersistentStoragePath(self,path:QString)",
    "PySide6.QtWebEngineQuick.QQuickWebEngineProfile.setPushServiceEnabled(self,enable:bool)",
    "PySide6.QtWebEngineQuick.QQuickWebEngineProfile.setSpellCheckEnabled(self,enabled:bool)",
    "PySide6.QtWebEngineQuick.QQuickWebEngineProfile.setSpellCheckLanguages(self,languages:QStringList)",
    "PySide6.QtWebEngineQuick.QQuickWebEngineProfile.setStorageName(self,name:QString)",
    "PySide6.QtWebEngineQuick.QQuickWebEngineProfile.setUrlRequestInterceptor(self,interceptor:PySide6.QtWebEngineCore.QWebEngineUrlRequestInterceptor)",
    "PySide6.QtWebEngineQuick.QQuickWebEngineProfile.spellCheckLanguages(self)->QStringList",
    "PySide6.QtWebEngineQuick.QQuickWebEngineProfile.storageName(self)->QString",
    "PySide6.QtWebEngineQuick.QQuickWebEngineProfile.urlSchemeHandler(self,arg__1:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtWebEngineCore.QWebEngineUrlSchemeHandler",
    nullptr}; // Sentinel
#else
static constexpr size_t QQuickWebEngineProfile_SignatureByteSize = 829;
static constexpr uint8_t QQuickWebEngineProfile_SignatureBytes[829] = {
    0x78, 0xda, 0xc5, 0x58, 0xdf, 0x4f, 0xdb, 0x30, 0x10, 0x7e, 0xe7, 0xaf, 0xe0, 0x71, 0xa0, 0x2c,
    0xd2, 0xf6, 0xb0, 0x87, 0x48, 0x4c, 0xea, 0x32, 0xa6, 0x4e, 0x63, 0x34, 0x25, 0xa0, 0x3d, 0x20,
    0x84, 0x5c, 0xf7, 0xda, 0x78, 0x38, 0x76, 0x66, 0x3b, 0x40, 0xf6, 0xd7, 0xcf, 0x49, 0xda, 0x24,
    0xcd, 0x8f, 0xd2, 0xd8, 0x88, 0x3d, 0x55, 0x75, 0x7c, 0xdf, 0x7d, 0x67, 0x9f, 0xef, 0x3b, 0x3b,
    0xc8, 0x42, 0xb2, 0x84, 0x4f, 0xee, 0x5c, 0xfd, 0x82, 0xc5, 0x39, 0x5b, 0x13, 0x06, 0xf3, 0x94,
    0xe0, 0x07, 0x77, 0x5e, 0xfc, 0x54, 0x83, 0x81, 0xe0, 0x2b, 0x42, 0xe1, 0x9d, 0x04, 0xba, 0x72,
    0x12, 0x24, 0x80, 0x29, 0x2f, 0xa8, 0x6c, 0x7d, 0x2e, 0xc0, 0x9d, 0xcf, 0x16, 0xbf, 0x01, 0xab,
    0x33, 0x96, 0x52, 0x9a, 0x28, 0xe1, 0x9c, 0x7a, 0x3f, 0x20, 0x7b, 0xe2, 0x62, 0x39, 0x63, 0x34,
    0x3b, 0xbb, 0xe4, 0x0c, 0x1c, 0xa9, 0xb8, 0x40, 0x6b, 0xb8, 0x44, 0x31, 0x78, 0xf3, 0x50, 0x09,
    0xc2, 0xd6, 0xe5, 0x07, 0xbe, 0x5a, 0x5d, 0x47, 0x70, 0x05, 0x58, 0x4f, 0xf7, 0x16, 0x9c, 0xd3,
    0x72, 0x38, 0x01, 0x21, 0x89, 0x54, 0xda, 0x59, 0x58, 0x5a, 0x06, 0x48, 0x45, 0xbb, 0x96, 0x18,
    0xe1, 0xa8, 0x67, 0x38, 0x52, 0x2a, 0xb9, 0x91, 0x20, 0x26, 0xeb, 0x9c, 0x69, 0xe7, 0x93, 0x9f,
    0x5b, 0x5d, 0x67, 0x89, 0xa6, 0xd1, 0x1b, 0xa7, 0x3b, 0x6d, 0x4e, 0xaa, 0xed, 0x26, 0x18, 0x43,
    0xa2, 0x2e, 0x10, 0x5b, 0xa7, 0x9a, 0xcd, 0x2e, 0x6e, 0x4d, 0xd6, 0xe7, 0xfc, 0x81, 0x80, 0x0c,
    0x38, 0x25, 0x38, 0x1b, 0xf2, 0x10, 0xf4, 0x4f, 0x6f, 0x63, 0xe9, 0x69, 0x31, 0x91, 0x92, 0x70,
    0x76, 0x30, 0x5e, 0xc7, 0xa4, 0x15, 0xf7, 0x4f, 0xf4, 0x4c, 0xe2, 0x34, 0x0e, 0xc9, 0x5f, 0xf0,
    0x08, 0x53, 0x9b, 0xad, 0x49, 0x80, 0x52, 0x3f, 0x02, 0xfc, 0xb0, 0x8d, 0x4e, 0x6e, 0xc3, 0xbb,
    0xd0, 0xb0, 0xed, 0x49, 0xe7, 0x0c, 0x2d, 0x28, 0x34, 0xf7, 0x6a, 0xc9, 0x9f, 0x18, 0xe5, 0x68,
    0xd9, 0xdd, 0x0b, 0x22, 0x83, 0x54, 0x46, 0x21, 0x88, 0x47, 0x82, 0xa1, 0x6b, 0x88, 0x29, 0xd1,
    0xa4, 0xa7, 0x9a, 0x89, 0xf6, 0x58, 0x85, 0xe5, 0xd7, 0xa3, 0xc5, 0xb4, 0x93, 0xa3, 0x60, 0x5c,
    0xaa, 0xba, 0x55, 0x66, 0x14, 0x49, 0x7b, 0xf2, 0xfe, 0xf3, 0x86, 0xd4, 0x78, 0x20, 0x0a, 0x48,
    0x54, 0x09, 0x51, 0xa2, 0x19, 0x80, 0xe4, 0xf1, 0xf8, 0x20, 0x14, 0x59, 0x11, 0x8c, 0x14, 0xe4,
    0x19, 0x0d, 0x5b, 0x6a, 0x3d, 0x68, 0xe5, 0x99, 0x6a, 0xad, 0x47, 0xdb, 0xde, 0x90, 0x46, 0xb1,
    0xac, 0x63, 0x7d, 0x17, 0x46, 0xe3, 0x1d, 0x16, 0xc9, 0x3d, 0x36, 0xd8, 0xda, 0x68, 0xb4, 0xc3,
    0x25, 0xac, 0x50, 0x4a, 0xd5, 0xb6, 0x60, 0xf5, 0xfb, 0xdb, 0x87, 0x30, 0xde, 0x63, 0x23, 0xf3,
    0x6d, 0x73, 0xad, 0x5b, 0x64, 0x5e, 0x03, 0xb1, 0x7d, 0xec, 0xb7, 0x98, 0x7a, 0x47, 0xcd, 0xf1,
    0xf2, 0xca, 0xb8, 0x67, 0x4b, 0xf7, 0x82, 0xec, 0x94, 0x57, 0x23, 0x0a, 0x55, 0x71, 0xb7, 0x5d,
    0x1f, 0xc2, 0xa4, 0x42, 0x94, 0xde, 0x08, 0x1a, 0x6a, 0x3e, 0x31, 0x4c, 0x11, 0x5b, 0x52, 0x10,
    0xa5, 0xd2, 0xc9, 0x62, 0xc8, 0x53, 0x59, 0xa2, 0xa1, 0xdd, 0x1b, 0xa6, 0x6b, 0xea, 0x6d, 0x5b,
    0xf6, 0xbe, 0x64, 0x0a, 0x26, 0x42, 0xa0, 0xcc, 0x39, 0xc6, 0x11, 0x12, 0xa7, 0x77, 0x0e, 0x12,
    0xeb, 0xfb, 0xfb, 0x8f, 0xde, 0xcb, 0x79, 0xde, 0x76, 0x3a, 0xbe, 0xac, 0x10, 0x39, 0x6b, 0x48,
    0xe7, 0x76, 0x2d, 0xf2, 0xe2, 0x6a, 0x00, 0xd5, 0x2d, 0xd3, 0x96, 0x80, 0x61, 0x5b, 0x2f, 0xac,
    0xf0, 0xa8, 0xd6, 0xa1, 0x09, 0xa5, 0x0d, 0x79, 0xab, 0xf6, 0x3e, 0x97, 0xa8, 0xdb, 0x97, 0xd7,
    0xbb, 0x36, 0xbd, 0x33, 0xf2, 0xde, 0x70, 0xfd, 0x8d, 0x8b, 0x99, 0x20, 0x7a, 0xc2, 0x26, 0x51,
    0x00, 0xa7, 0x82, 0xa8, 0xac, 0x1c, 0xdb, 0x9f, 0x30, 0x7a, 0xd7, 0x9d, 0xe3, 0x4d, 0xba, 0xde,
    0xfd, 0x37, 0xf6, 0xf5, 0xbf, 0xea, 0x20, 0xe7, 0x6d, 0x47, 0x63, 0xcc, 0x1b, 0x43, 0xc9, 0xdd,
    0xc5, 0x7b, 0xa3, 0xb0, 0x06, 0x7a, 0x2e, 0xd3, 0xb2, 0x34, 0xd0, 0x93, 0x59, 0xd0, 0xea, 0xf4,
    0x62, 0xf6, 0xd4, 0x3a, 0x90, 0x16, 0xf4, 0x1a, 0x6d, 0xb5, 0x6d, 0x1d, 0xfd, 0x93, 0x82, 0xc8,
    0x6a, 0x6e, 0x96, 0xc7, 0xe2, 0x75, 0x53, 0x71, 0x8c, 0xf5, 0xe8, 0xc0, 0x05, 0xc4, 0xfc, 0x11,
    0x26, 0x5d, 0x09, 0x91, 0x86, 0xad, 0x62, 0x09, 0x58, 0xa1, 0x59, 0x28, 0x91, 0xb5, 0xef, 0x1d,
    0x31, 0x2c, 0x64, 0xed, 0xc3, 0x9b, 0xc8, 0x9a, 0x04, 0xe5, 0xef, 0xb4, 0xef, 0xfa, 0xce, 0x59,
    0x5f, 0x2b, 0x8c, 0xf0, 0xbe, 0xb6, 0xbb, 0x34, 0x7b, 0xc8, 0x69, 0x7f, 0xb3, 0xb6, 0xe7, 0xa6,
    0x68, 0xec, 0xa6, 0xb7, 0x83, 0x73, 0x62, 0xf4, 0xbc, 0xbd, 0xc5, 0xd9, 0x21, 0xd7, 0x12, 0x30,
    0xbc, 0xc9, 0x87, 0x37, 0x74, 0xc6, 0x5c, 0x76, 0x9b, 0x3a, 0x27, 0x6d, 0x5f, 0xe0, 0x8d, 0x80,
    0x3b, 0x0d, 0x52, 0xf7, 0xb5, 0xc1, 0x08, 0x37, 0xd8, 0xa3, 0x3d, 0xa6, 0xcb, 0x38, 0x80, 0x69,
    0xc9, 0xaf, 0x5f, 0x84, 0xec, 0x39, 0x76, 0x70, 0x2d, 0x79, 0xb6, 0xd5, 0xc8, 0xfe, 0x84, 0x0e,
    0x74, 0xb4, 0x0e, 0x14, 0x7f, 0xcc, 0xf7, 0xbe, 0xbf, 0xb1, 0xdd, 0xc0, 0x2e, 0x5f, 0x03, 0xb7,
    0x7a, 0x85, 0x29, 0x91, 0x69, 0xdf, 0xa3, 0x8c, 0x99, 0x8b, 0xfa, 0x0d, 0xae, 0x84, 0x66, 0x8d,
    0xd7, 0x38, 0x23, 0x44, 0x5d, 0xee, 0xaf, 0x40, 0xcb, 0xbf, 0x54, 0xdf, 0x99, 0x02, 0x91, 0xd7,
    0x3d, 0xbe, 0x91, 0x0c, 0x52, 0x0f, 0x1c, 0xa6, 0x1b, 0x5d, 0x20, 0x03, 0x4a, 0x03, 0x8b, 0x58,
    0x37, 0x37, 0xf9, 0xe2, 0x8d, 0x87, 0x6d, 0x2d, 0x9c, 0x45, 0xaf, 0x94, 0xee, 0xd3, 0xd7, 0x91,
    0x12, 0x7f, 0x48, 0x77, 0xd3, 0x16, 0xe4, 0xa3, 0x7f, 0x64, 0x7b, 0x34, 0x78
};
#endif

PyTypeObject *init_QQuickWebEngineProfile(PyObject *module)
{
    if (SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX].type != nullptr)
        return SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX].type;

    Shiboken::AutoDecRef Sbk_QQuickWebEngineProfile_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QQuickWebEngineProfile_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QQuickWebEngineProfile",
        "QQuickWebEngineProfile*",
        &Sbk_QQuickWebEngineProfile_spec,
        &Shiboken::callCppDestructor< QQuickWebEngineProfile >,
        Sbk_QQuickWebEngineProfile_Type_bases.object(),
        0);
    auto *pyType = Sbk_QQuickWebEngineProfile_TypeF(); // references _Sbk_QQuickWebEngineProfile_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QQuickWebEngineProfile_SignatureStrings);
#else
    InitSignatureBytes(pyType, QQuickWebEngineProfile_SignatureBytes, QQuickWebEngineProfile_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QQuickWebEngineProfile_PropertyStrings);
    SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QQuickWebEngineProfile_PythonToCpp_QQuickWebEngineProfile_PTR,
        is_QQuickWebEngineProfile_PythonToCpp_QQuickWebEngineProfile_PTR_Convertible,
        QQuickWebEngineProfile_PTR_CppToPython_QQuickWebEngineProfile);

    Shiboken::Conversions::registerConverterName(converter, "QQuickWebEngineProfile");
    Shiboken::Conversions::registerConverterName(converter, "QQuickWebEngineProfile*");
    Shiboken::Conversions::registerConverterName(converter, "QQuickWebEngineProfile&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QQuickWebEngineProfile).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QQuickWebEngineProfileWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QQuickWebEngineProfile_TypeF(), &Sbk_QQuickWebEngineProfile_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QQuickWebEngineProfile_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'HttpCacheType'.
    const char *HttpCacheType_Initializer[] = {
        "MemoryHttpCache",
        "DiskHttpCache",
        "NoCache",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t HttpCacheType_InitializerValues[] = {
        uint8_t(QQuickWebEngineProfile::HttpCacheType::MemoryHttpCache), //  0x00  0
        uint8_t(QQuickWebEngineProfile::HttpCacheType::DiskHttpCache),   //  0x01  1
        uint8_t(QQuickWebEngineProfile::HttpCacheType::NoCache)          //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QQuickWebEngineProfile_TypeF(),
        "2:PySide6.QtWebEngineQuick.QQuickWebEngineProfile.HttpCacheType",
        HttpCacheType_Initializer, HttpCacheType_InitializerValues);
    SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_HttpCacheType_IDX].type = EType;
    // Register converter for enum 'QQuickWebEngineProfile::HttpCacheType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QQuickWebEngineProfile_HttpCacheType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QQuickWebEngineProfile_HttpCacheType,
            is_Enum_PythonToCpp_QQuickWebEngineProfile_HttpCacheType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QQuickWebEngineProfile::HttpCacheType");
        Shiboken::Conversions::registerConverterAlias(converter, "HttpCacheType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'HttpCacheType' enum.

    // Initialization of enum 'PersistentCookiesPolicy'.
    const char *PersistentCookiesPolicy_Initializer[] = {
        "NoPersistentCookies",
        "AllowPersistentCookies",
        "ForcePersistentCookies",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t PersistentCookiesPolicy_InitializerValues[] = {
        uint8_t(QQuickWebEngineProfile::PersistentCookiesPolicy::NoPersistentCookies),    //  0x00  0
        uint8_t(QQuickWebEngineProfile::PersistentCookiesPolicy::AllowPersistentCookies), //  0x01  1
        uint8_t(QQuickWebEngineProfile::PersistentCookiesPolicy::ForcePersistentCookies)  //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QQuickWebEngineProfile_TypeF(),
        "2:PySide6.QtWebEngineQuick.QQuickWebEngineProfile.PersistentCookiesPolicy",
        PersistentCookiesPolicy_Initializer, PersistentCookiesPolicy_InitializerValues);
    SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_PersistentCookiesPolicy_IDX].type = EType;
    // Register converter for enum 'QQuickWebEngineProfile::PersistentCookiesPolicy'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QQuickWebEngineProfile_PersistentCookiesPolicy_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QQuickWebEngineProfile_PersistentCookiesPolicy,
            is_Enum_PythonToCpp_QQuickWebEngineProfile_PersistentCookiesPolicy_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QQuickWebEngineProfile::PersistentCookiesPolicy");
        Shiboken::Conversions::registerConverterAlias(converter, "PersistentCookiesPolicy");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'PersistentCookiesPolicy' enum.

    // Initialization of enum 'PersistentPermissionsPolicy'.
    const char *PersistentPermissionsPolicy_Initializer[] = {
        "AskEveryTime",
        "StoreInMemory",
        "StoreOnDisk",
        nullptr};
    // "uint8_t" used instead of "unsigned char"
    constexpr uint8_t PersistentPermissionsPolicy_InitializerValues[] = {
        uint8_t(QQuickWebEngineProfile::PersistentPermissionsPolicy::AskEveryTime),  //  0x00  0
        uint8_t(QQuickWebEngineProfile::PersistentPermissionsPolicy::StoreInMemory), //  0x01  1
        uint8_t(QQuickWebEngineProfile::PersistentPermissionsPolicy::StoreOnDisk)    //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QQuickWebEngineProfile_TypeF(),
        "2:PySide6.QtWebEngineQuick.QQuickWebEngineProfile.PersistentPermissionsPolicy",
        PersistentPermissionsPolicy_Initializer, PersistentPermissionsPolicy_InitializerValues);
    SbkPySide6_QtWebEngineQuickTypeStructs[SBK_QQuickWebEngineProfile_PersistentPermissionsPolicy_IDX].type = EType;
    // Register converter for enum 'QQuickWebEngineProfile::PersistentPermissionsPolicy'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QQuickWebEngineProfile_PersistentPermissionsPolicy_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QQuickWebEngineProfile_PersistentPermissionsPolicy,
            is_Enum_PythonToCpp_QQuickWebEngineProfile_PersistentPermissionsPolicy_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QQuickWebEngineProfile::PersistentPermissionsPolicy");
        Shiboken::Conversions::registerConverterAlias(converter, "PersistentPermissionsPolicy");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'PersistentPermissionsPolicy' enum.

    PySide::Signal::registerSignals(pyType, &::QQuickWebEngineProfile::staticMetaObject);
    qRegisterMetaType< ::QQuickWebEngineProfile::HttpCacheType >("QQuickWebEngineProfile::HttpCacheType");
    qRegisterMetaType< ::QQuickWebEngineProfile::PersistentCookiesPolicy >("QQuickWebEngineProfile::PersistentCookiesPolicy");
    qRegisterMetaType< ::QQuickWebEngineProfile::PersistentPermissionsPolicy >("QQuickWebEngineProfile::PersistentPermissionsPolicy");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QQuickWebEngineProfile::staticMetaObject, sizeof(QQuickWebEngineProfileWrapper));

    return pyType;
}
