// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwebsockets_python.h"

// main header
#include "qwebsocket_wrapper.h"

// Extra includes
#include <QTcpSocket>

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QtNetwork/qabstractsocket.h>
#include <QtNetwork/qauthenticator.h>
#include <QtNetwork/qhostaddress.h>
#include <QtNetwork/qnetworkproxy.h>
#include <QtNetwork/qnetworkrequest.h>
#include <QtNetwork/qssl.h>
#include <QtNetwork/qsslconfiguration.h>
#include <QtNetwork/qsslerror.h>
#include <QtNetwork/qsslpresharedkeyauthenticator.h>
#include <QtWebSockets/qmaskgenerator.h>
#include <QtWebSockets/qwebsockethandshakeoptions.h>
#include <QtWebSockets/qwebsocketprotocol.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qurl.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QWebSocketWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QWebSocketWrapper::QWebSocketWrapper(const ::QString & origin, ::QWebSocketProtocol::Version version, ::QObject * parent) : QWebSocket(origin, version, parent)
{
}

void QWebSocketWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWebSocket", funcName);
        return;
    }
}

void QWebSocketWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWebSocket", funcName);
        return;
    }
}

void QWebSocketWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWebSocket", funcName);
        return;
    }
}

void QWebSocketWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWebSocket", funcName);
        return;
    }
}

bool QWebSocketWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWebSocket", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QWebSocket", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QWebSocketWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWebSocket", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QWebSocket", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QWebSocketWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWebSocket", funcName);
        return;
    }
}

const QMetaObject *QWebSocketWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QWebSocket::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QWebSocketWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QWebSocket::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QWebSocketWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QWebSocketWrapper *>(this));
    return QWebSocket::qt_metacast(_clname);
}

QWebSocketWrapper::~QWebSocketWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QWebSocket_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QWebSocket >()))
        return -1;

    QWebSocketWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OOO:QWebSocket", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QWebSocket::QWebSocket(const QString&=,QWebSocketProtocol::Version=,QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QWebSocket(QString,QWebSocketProtocol::Version,QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // QWebSocket(QString,QWebSocketProtocol::Version,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketProtocol_Version_IDX])))->converter, (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // QWebSocket(QString,QWebSocketProtocol::Version,QObject*)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[2])))) {
                overloadId = 0; // QWebSocket(QString,QWebSocketProtocol::Version,QObject*)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_origin = Shiboken::String::createStaticString("origin");
            if (PyDict_Contains(kwds, key_origin) != 0) {
                value = PyDict_GetItem(kwds, key_origin);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_origin);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_origin);
            }
            static PyObject *const key_version = Shiboken::String::createStaticString("version");
            if (PyDict_Contains(kwds, key_version) != 0) {
                value = PyDict_GetItem(kwds, key_version);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_version);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketProtocol_Version_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_version);
            }
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                // fall through to handle extra keyword signals and properties
            }
        }
        ::QString cppArg0 = QString();
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QWebSocketProtocol::Version cppArg1(QWebSocketProtocol::VersionLatest);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return -1;
        ::QObject *cppArg2 = nullptr;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QWebSocket(QString,QWebSocketProtocol::Version,QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QWebSocketWrapper(cppArg0, cppArg1, cppArg2);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QWebSocketWrapper(cppArg0, cppArg1, cppArg2);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[2], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QWebSocket >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QWebSocketFunc_abort(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // abort()
        cppSelf->abort();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebSocketFunc_bytesToWrite(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // bytesToWrite()const
        qint64 cppResult = const_cast<const ::QWebSocket *>(cppSelf)->bytesToWrite();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebSocketFunc_close(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "close", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]);

    if (PyArg_ParseTuple(args, "|OO:close", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QWebSocket::close(QWebSocketProtocol::CloseCode=,const QString&=)
    if (numArgs == 0) {
        overloadId = 0; // close(QWebSocketProtocol::CloseCode,QString)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketProtocol_CloseCode_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // close(QWebSocketProtocol::CloseCode,QString)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 0; // close(QWebSocketProtocol::CloseCode,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "close", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_closeCode = Shiboken::String::createStaticString("closeCode");
            if (PyDict_Contains(kwds, key_closeCode) != 0) {
                value = PyDict_GetItem(kwds, key_closeCode);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_closeCode);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "close", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketProtocol_CloseCode_IDX])))->converter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "close", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_closeCode);
            }
            static PyObject *const key_reason = Shiboken::String::createStaticString("reason");
            if (PyDict_Contains(kwds, key_reason) != 0) {
                value = PyDict_GetItem(kwds, key_reason);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_reason);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "close", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "close", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_reason);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "close", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]);
            }
        }
        ::QWebSocketProtocol::CloseCode cppArg0(QWebSocketProtocol::CloseCodeNormal);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1 = QString();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // close(QWebSocketProtocol::CloseCode,QString)
            cppSelf->close(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebSocketFunc_closeCode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // closeCode()const
        QWebSocketProtocol::CloseCode cppResult = const_cast<const ::QWebSocket *>(cppSelf)->closeCode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketProtocol_CloseCode_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebSocketFunc_closeReason(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // closeReason()const
        QString cppResult = const_cast<const ::QWebSocket *>(cppSelf)->closeReason();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebSocketFunc_continueInterruptedHandshake(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // continueInterruptedHandshake()
        cppSelf->continueInterruptedHandshake();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebSocketFunc_error(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // error()const
        QAbstractSocket::SocketError cppResult = const_cast<const ::QWebSocket *>(cppSelf)->error();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_SocketError_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebSocketFunc_errorString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // errorString()const
        QString cppResult = const_cast<const ::QWebSocket *>(cppSelf)->errorString();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebSocketFunc_flush(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // flush()
        bool cppResult = cppSelf->flush();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebSocketFunc_handshakeOptions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // handshakeOptions()const
        QWebSocketHandshakeOptions cppResult = const_cast<const ::QWebSocket *>(cppSelf)->handshakeOptions();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketHandshakeOptions_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebSocketFunc_ignoreSslErrors(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "ignoreSslErrors", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QWebSocket::ignoreSslErrors()
    // 1: QWebSocket::ignoreSslErrors(QList<QSslError>)
    if (numArgs == 0) {
        overloadId = 0; // ignoreSslErrors()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtWebSocketsTypeConverters[SBK_QtWebSockets_QList_QSslError_IDX], (pyArgs[0])))) {
        overloadId = 1; // ignoreSslErrors(QList<QSslError>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "ignoreSslErrors", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // ignoreSslErrors()
        {

            // ignoreSslErrors()
            cppSelf->ignoreSslErrors();
            break;
        }
        case 1: // ignoreSslErrors(const QList<QSslError> &errors)
        {
            ::QList<QSslError> cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // ignoreSslErrors(QList<QSslError>)
                cppSelf->ignoreSslErrors(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebSocketFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QWebSocket *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebSocketFunc_localAddress(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // localAddress()const
        QHostAddress cppResult = const_cast<const ::QWebSocket *>(cppSelf)->localAddress();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebSocketFunc_localPort(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // localPort()const
        quint16 cppResult = const_cast<const ::QWebSocket *>(cppSelf)->localPort();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebSocketFunc_maskGenerator(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maskGenerator()const
        const QMaskGenerator * cppResult = const_cast<const ::QWebSocket *>(cppSelf)->maskGenerator();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QMaskGenerator_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebSocketFunc_maxAllowedIncomingFrameSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maxAllowedIncomingFrameSize()const
        quint64 cppResult = const_cast<const ::QWebSocket *>(cppSelf)->maxAllowedIncomingFrameSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebSocketFunc_maxAllowedIncomingMessageSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maxAllowedIncomingMessageSize()const
        quint64 cppResult = const_cast<const ::QWebSocket *>(cppSelf)->maxAllowedIncomingMessageSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebSocketFunc_maxIncomingFrameSize(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maxIncomingFrameSize()
        quint64 cppResult = ::QWebSocket::maxIncomingFrameSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebSocketFunc_maxIncomingMessageSize(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maxIncomingMessageSize()
        quint64 cppResult = ::QWebSocket::maxIncomingMessageSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebSocketFunc_maxOutgoingFrameSize(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maxOutgoingFrameSize()
        quint64 cppResult = ::QWebSocket::maxOutgoingFrameSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebSocketFunc_open(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "open", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QWebSocket::open(QNetworkRequest)
    // 1: QWebSocket::open(QNetworkRequest,QWebSocketHandshakeOptions)
    // 2: QWebSocket::open(QUrl)
    // 3: QWebSocket::open(QUrl,QWebSocketHandshakeOptions)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 2; // open(QUrl)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketHandshakeOptions_IDX]), (pyArgs[1])))) {
            overloadId = 3; // open(QUrl,QWebSocketHandshakeOptions)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // open(QNetworkRequest)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketHandshakeOptions_IDX]), (pyArgs[1])))) {
            overloadId = 1; // open(QNetworkRequest,QWebSocketHandshakeOptions)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "open", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // open(const QNetworkRequest &request)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0_local;
            ::QNetworkRequest *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // open(QNetworkRequest)
                cppSelf->open(*cppArg0);
            }
            break;
        }
        case 1: // open(const QNetworkRequest &request, const QWebSocketHandshakeOptions &options)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QNetworkRequest cppArg0_local;
            ::QNetworkRequest *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QWebSocketHandshakeOptions cppArg1_local;
            ::QWebSocketHandshakeOptions *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // open(QNetworkRequest,QWebSocketHandshakeOptions)
                cppSelf->open(*cppArg0, *cppArg1);
            }
            break;
        }
        case 2: // open(const QUrl &url)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QUrl cppArg0_local;
            ::QUrl *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // open(QUrl)
                cppSelf->open(*cppArg0);
            }
            break;
        }
        case 3: // open(const QUrl &url, const QWebSocketHandshakeOptions &options)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QUrl cppArg0_local;
            ::QUrl *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QWebSocketHandshakeOptions cppArg1_local;
            ::QWebSocketHandshakeOptions *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // open(QUrl,QWebSocketHandshakeOptions)
                cppSelf->open(*cppArg0, *cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebSocketFunc_origin(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // origin()const
        QString cppResult = const_cast<const ::QWebSocket *>(cppSelf)->origin();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebSocketFunc_outgoingFrameSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // outgoingFrameSize()const
        quint64 cppResult = const_cast<const ::QWebSocket *>(cppSelf)->outgoingFrameSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebSocketFunc_pauseMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pauseMode()const
        QFlags<QAbstractSocket::PauseMode> cppResult = const_cast<const ::QWebSocket *>(cppSelf)->pauseMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFlags_QAbstractSocket_PauseMode_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebSocketFunc_peerAddress(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // peerAddress()const
        QHostAddress cppResult = const_cast<const ::QWebSocket *>(cppSelf)->peerAddress();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebSocketFunc_peerName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // peerName()const
        QString cppResult = const_cast<const ::QWebSocket *>(cppSelf)->peerName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebSocketFunc_peerPort(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // peerPort()const
        quint16 cppResult = const_cast<const ::QWebSocket *>(cppSelf)->peerPort();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebSocketFunc_ping(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "ping", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]);

    if (PyArg_ParseTuple(args, "|O:ping", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QWebSocket::ping(const QByteArray&=)
    if (numArgs == 0) {
        overloadId = 0; // ping(QByteArray)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        overloadId = 0; // ping(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "ping", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_payload = Shiboken::String::createStaticString("payload");
            if (PyDict_Contains(kwds, key_payload) != 0) {
                value = PyDict_GetItem(kwds, key_payload);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_payload);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "ping", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "ping", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_payload);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "ping", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QByteArray cppArg0_local = QByteArray();
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0]) {
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // ping(QByteArray)
            cppSelf->ping(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebSocketFunc_proxy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // proxy()const
        QNetworkProxy cppResult = const_cast<const ::QWebSocket *>(cppSelf)->proxy();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxy_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebSocketFunc_readBufferSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // readBufferSize()const
        qint64 cppResult = const_cast<const ::QWebSocket *>(cppSelf)->readBufferSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebSocketFunc_request(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // request()const
        QNetworkRequest cppResult = const_cast<const ::QWebSocket *>(cppSelf)->request();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkRequest_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebSocketFunc_requestUrl(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // requestUrl()const
        QUrl cppResult = const_cast<const ::QWebSocket *>(cppSelf)->requestUrl();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebSocketFunc_resourceName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // resourceName()const
        QString cppResult = const_cast<const ::QWebSocket *>(cppSelf)->resourceName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebSocketFunc_resume(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // resume()
        cppSelf->resume();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebSocketFunc_sendBinaryMessage(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebSocket::sendBinaryMessage(QByteArray)->qint64
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // sendBinaryMessage(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "sendBinaryMessage", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // sendBinaryMessage(QByteArray)
            qint64 cppResult = cppSelf->sendBinaryMessage(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebSocketFunc_sendTextMessage(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebSocket::sendTextMessage(QString)->qint64
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // sendTextMessage(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "sendTextMessage", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // sendTextMessage(QString)
            qint64 cppResult = cppSelf->sendTextMessage(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebSocketFunc_setMaskGenerator(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebSocket::setMaskGenerator(const QMaskGenerator*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QMaskGenerator_IDX]), (pyArg)))) {
        overloadId = 0; // setMaskGenerator(const QMaskGenerator*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMaskGenerator", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMaskGenerator *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMaskGenerator(const QMaskGenerator*)
            cppSelf->setMaskGenerator(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebSocketFunc_setMaxAllowedIncomingFrameSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebSocket::setMaxAllowedIncomingFrameSize(quint64)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyArg)))) {
        overloadId = 0; // setMaxAllowedIncomingFrameSize(quint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMaxAllowedIncomingFrameSize", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]);

    // Call function/method
    {
        quint64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMaxAllowedIncomingFrameSize(quint64)
            cppSelf->setMaxAllowedIncomingFrameSize(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebSocketFunc_setMaxAllowedIncomingMessageSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebSocket::setMaxAllowedIncomingMessageSize(quint64)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyArg)))) {
        overloadId = 0; // setMaxAllowedIncomingMessageSize(quint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMaxAllowedIncomingMessageSize", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]);

    // Call function/method
    {
        quint64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMaxAllowedIncomingMessageSize(quint64)
            cppSelf->setMaxAllowedIncomingMessageSize(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebSocketFunc_setOutgoingFrameSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebSocket::setOutgoingFrameSize(quint64)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyArg)))) {
        overloadId = 0; // setOutgoingFrameSize(quint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOutgoingFrameSize", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]);

    // Call function/method
    {
        quint64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOutgoingFrameSize(quint64)
            cppSelf->setOutgoingFrameSize(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebSocketFunc_setPauseMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebSocket::setPauseMode(QFlags<QAbstractSocket::PauseMode>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFlags_QAbstractSocket_PauseMode_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setPauseMode(QFlags<QAbstractSocket::PauseMode>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPauseMode", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]);

    // Call function/method
    {
        ::QFlags<QAbstractSocket::PauseMode> cppArg0 = QFlags<QAbstractSocket::PauseMode>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPauseMode(QFlags<QAbstractSocket::PauseMode>)
            cppSelf->setPauseMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebSocketFunc_setProxy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebSocket::setProxy(QNetworkProxy)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxy_IDX]), (pyArg)))) {
        overloadId = 0; // setProxy(QNetworkProxy)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setProxy", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QNetworkProxy cppArg0_local;
        ::QNetworkProxy *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setProxy(QNetworkProxy)
            cppSelf->setProxy(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebSocketFunc_setReadBufferSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebSocket::setReadBufferSize(qint64)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArg)))) {
        overloadId = 0; // setReadBufferSize(qint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setReadBufferSize", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]);

    // Call function/method
    {
        qint64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setReadBufferSize(qint64)
            cppSelf->setReadBufferSize(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebSocketFunc_setSslConfiguration(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebSocket::setSslConfiguration(QSslConfiguration)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslConfiguration_IDX]), (pyArg)))) {
        overloadId = 0; // setSslConfiguration(QSslConfiguration)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSslConfiguration", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSslConfiguration cppArg0_local;
        ::QSslConfiguration *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setSslConfiguration(QSslConfiguration)
            cppSelf->setSslConfiguration(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebSocketFunc_sslConfiguration(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sslConfiguration()const
        QSslConfiguration cppResult = const_cast<const ::QWebSocket *>(cppSelf)->sslConfiguration();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslConfiguration_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebSocketFunc_state(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // state()const
        QAbstractSocket::SocketState cppResult = const_cast<const ::QWebSocket *>(cppSelf)->state();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_SocketState_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebSocketFunc_subprotocol(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // subprotocol()const
        QString cppResult = const_cast<const ::QWebSocket *>(cppSelf)->subprotocol();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebSocketFunc_version(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // version()const
        QWebSocketProtocol::Version cppResult = const_cast<const ::QWebSocket *>(cppSelf)->version();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketProtocol_Version_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QWebSocket_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QWebSocket_methods[] = {
    {"abort", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_abort), METH_NOARGS, nullptr},
    {"bytesToWrite", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_bytesToWrite), METH_NOARGS, nullptr},
    {"close", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_close), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"closeCode", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_closeCode), METH_NOARGS, nullptr},
    {"closeReason", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_closeReason), METH_NOARGS, nullptr},
    {"continueInterruptedHandshake", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_continueInterruptedHandshake), METH_NOARGS, nullptr},
    {"error", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_error), METH_NOARGS, nullptr},
    {"errorString", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_errorString), METH_NOARGS, nullptr},
    {"flush", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_flush), METH_NOARGS, nullptr},
    {"handshakeOptions", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_handshakeOptions), METH_NOARGS, nullptr},
    {"ignoreSslErrors", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_ignoreSslErrors), METH_VARARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_isValid), METH_NOARGS, nullptr},
    {"localAddress", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_localAddress), METH_NOARGS, nullptr},
    {"localPort", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_localPort), METH_NOARGS, nullptr},
    {"maskGenerator", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_maskGenerator), METH_NOARGS, nullptr},
    {"maxAllowedIncomingFrameSize", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_maxAllowedIncomingFrameSize), METH_NOARGS, nullptr},
    {"maxAllowedIncomingMessageSize", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_maxAllowedIncomingMessageSize), METH_NOARGS, nullptr},
    {"maxIncomingFrameSize", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_maxIncomingFrameSize), METH_NOARGS|METH_STATIC, nullptr},
    {"maxIncomingMessageSize", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_maxIncomingMessageSize), METH_NOARGS|METH_STATIC, nullptr},
    {"maxOutgoingFrameSize", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_maxOutgoingFrameSize), METH_NOARGS|METH_STATIC, nullptr},
    {"open", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_open), METH_VARARGS, nullptr},
    {"origin", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_origin), METH_NOARGS, nullptr},
    {"outgoingFrameSize", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_outgoingFrameSize), METH_NOARGS, nullptr},
    {"pauseMode", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_pauseMode), METH_NOARGS, nullptr},
    {"peerAddress", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_peerAddress), METH_NOARGS, nullptr},
    {"peerName", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_peerName), METH_NOARGS, nullptr},
    {"peerPort", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_peerPort), METH_NOARGS, nullptr},
    {"ping", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_ping), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"proxy", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_proxy), METH_NOARGS, nullptr},
    {"readBufferSize", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_readBufferSize), METH_NOARGS, nullptr},
    {"request", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_request), METH_NOARGS, nullptr},
    {"requestUrl", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_requestUrl), METH_NOARGS, nullptr},
    {"resourceName", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_resourceName), METH_NOARGS, nullptr},
    {"resume", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_resume), METH_NOARGS, nullptr},
    {"sendBinaryMessage", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_sendBinaryMessage), METH_O, nullptr},
    {"sendTextMessage", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_sendTextMessage), METH_O, nullptr},
    {"setMaskGenerator", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_setMaskGenerator), METH_O, nullptr},
    {"setMaxAllowedIncomingFrameSize", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_setMaxAllowedIncomingFrameSize), METH_O, nullptr},
    {"setMaxAllowedIncomingMessageSize", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_setMaxAllowedIncomingMessageSize), METH_O, nullptr},
    {"setOutgoingFrameSize", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_setOutgoingFrameSize), METH_O, nullptr},
    {"setPauseMode", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_setPauseMode), METH_O, nullptr},
    {"setProxy", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_setProxy), METH_O, nullptr},
    {"setReadBufferSize", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_setReadBufferSize), METH_O, nullptr},
    {"setSslConfiguration", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_setSslConfiguration), METH_O, nullptr},
    {"sslConfiguration", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_sslConfiguration), METH_NOARGS, nullptr},
    {"state", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_state), METH_NOARGS, nullptr},
    {"subprotocol", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_subprotocol), METH_NOARGS, nullptr},
    {"version", reinterpret_cast<PyCFunction>(Sbk_QWebSocketFunc_version), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QWebSocket_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QWebSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QWebSocketWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QWebSocket_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QWebSocket_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QWebSocket_Type = nullptr;
static PyTypeObject *Sbk_QWebSocket_TypeF(void)
{
    return _Sbk_QWebSocket_Type;
}

static PyType_Slot Sbk_QWebSocket_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QWebSocket_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QWebSocket_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QWebSocket_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QWebSocket_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QWebSocket_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QWebSocket_spec = {
    "2:PySide6.QtWebSockets.QWebSocket",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QWebSocket_slots
};

} //extern "C"

static void *Sbk_QWebSocket_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QWebSocket *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QWebSocket_PythonToCpp_QWebSocket_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QWebSocket_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QWebSocket_PythonToCpp_QWebSocket_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QWebSocket_TypeF()))
        return QWebSocket_PythonToCpp_QWebSocket_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QWebSocket_PTR_CppToPython_QWebSocket(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QWebSocket *>(const_cast<void *>(cppIn)), Sbk_QWebSocket_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QWebSocket_SignatureStrings[] = {
    "PySide6.QtWebSockets.QWebSocket(self,origin:QString=QString(),version:PySide6.QtWebSockets.QWebSocketProtocol.Version=QWebSocketProtocol.VersionLatest,parent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtWebSockets.QWebSocket.abort(self)",
    "PySide6.QtWebSockets.QWebSocket.bytesToWrite(self)->qint64",
    "PySide6.QtWebSockets.QWebSocket.close(self,closeCode:PySide6.QtWebSockets.QWebSocketProtocol.CloseCode=QWebSocketProtocol.CloseCodeNormal,reason:QString=QString())",
    "PySide6.QtWebSockets.QWebSocket.closeCode(self)->PySide6.QtWebSockets.QWebSocketProtocol.CloseCode",
    "PySide6.QtWebSockets.QWebSocket.closeReason(self)->QString",
    "PySide6.QtWebSockets.QWebSocket.continueInterruptedHandshake(self)",
    "PySide6.QtWebSockets.QWebSocket.error(self)->PySide6.QtNetwork.QAbstractSocket.SocketError",
    "PySide6.QtWebSockets.QWebSocket.errorString(self)->QString",
    "PySide6.QtWebSockets.QWebSocket.flush(self)->bool",
    "PySide6.QtWebSockets.QWebSocket.handshakeOptions(self)->PySide6.QtWebSockets.QWebSocketHandshakeOptions",
    "1:PySide6.QtWebSockets.QWebSocket.ignoreSslErrors(self)",
    "0:PySide6.QtWebSockets.QWebSocket.ignoreSslErrors(self,errors:QList[PySide6.QtNetwork.QSslError])",
    "PySide6.QtWebSockets.QWebSocket.isValid(self)->bool",
    "PySide6.QtWebSockets.QWebSocket.localAddress(self)->PySide6.QtNetwork.QHostAddress",
    "PySide6.QtWebSockets.QWebSocket.localPort(self)->quint16",
    "PySide6.QtWebSockets.QWebSocket.maskGenerator(self)->PySide6.QtWebSockets.QMaskGenerator",
    "PySide6.QtWebSockets.QWebSocket.maxAllowedIncomingFrameSize(self)->quint64",
    "PySide6.QtWebSockets.QWebSocket.maxAllowedIncomingMessageSize(self)->quint64",
    "PySide6.QtWebSockets.QWebSocket.maxIncomingFrameSize()->quint64",
    "PySide6.QtWebSockets.QWebSocket.maxIncomingMessageSize()->quint64",
    "PySide6.QtWebSockets.QWebSocket.maxOutgoingFrameSize()->quint64",
    "3:PySide6.QtWebSockets.QWebSocket.open(self,request:PySide6.QtNetwork.QNetworkRequest)",
    "2:PySide6.QtWebSockets.QWebSocket.open(self,request:PySide6.QtNetwork.QNetworkRequest,options:PySide6.QtWebSockets.QWebSocketHandshakeOptions)",
    "1:PySide6.QtWebSockets.QWebSocket.open(self,url:typing.Union[PySide6.QtCore.QUrl, QString])",
    "0:PySide6.QtWebSockets.QWebSocket.open(self,url:typing.Union[PySide6.QtCore.QUrl, QString],options:PySide6.QtWebSockets.QWebSocketHandshakeOptions)",
    "PySide6.QtWebSockets.QWebSocket.origin(self)->QString",
    "PySide6.QtWebSockets.QWebSocket.outgoingFrameSize(self)->quint64",
    "PySide6.QtWebSockets.QWebSocket.pauseMode(self)->PySide6.QtNetwork.QAbstractSocket.PauseMode",
    "PySide6.QtWebSockets.QWebSocket.peerAddress(self)->PySide6.QtNetwork.QHostAddress",
    "PySide6.QtWebSockets.QWebSocket.peerName(self)->QString",
    "PySide6.QtWebSockets.QWebSocket.peerPort(self)->quint16",
    "PySide6.QtWebSockets.QWebSocket.ping(self,payload:typing.Union[PySide6.QtCore.QByteArray, char*]=QByteArray())",
    "PySide6.QtWebSockets.QWebSocket.proxy(self)->PySide6.QtNetwork.QNetworkProxy",
    "PySide6.QtWebSockets.QWebSocket.readBufferSize(self)->qint64",
    "PySide6.QtWebSockets.QWebSocket.request(self)->PySide6.QtNetwork.QNetworkRequest",
    "PySide6.QtWebSockets.QWebSocket.requestUrl(self)->PySide6.QtCore.QUrl",
    "PySide6.QtWebSockets.QWebSocket.resourceName(self)->QString",
    "PySide6.QtWebSockets.QWebSocket.resume(self)",
    "PySide6.QtWebSockets.QWebSocket.sendBinaryMessage(self,data:typing.Union[PySide6.QtCore.QByteArray, char*])->qint64",
    "PySide6.QtWebSockets.QWebSocket.sendTextMessage(self,message:QString)->qint64",
    "PySide6.QtWebSockets.QWebSocket.setMaskGenerator(self,maskGenerator:PySide6.QtWebSockets.QMaskGenerator)",
    "PySide6.QtWebSockets.QWebSocket.setMaxAllowedIncomingFrameSize(self,maxAllowedIncomingFrameSize:quint64)",
    "PySide6.QtWebSockets.QWebSocket.setMaxAllowedIncomingMessageSize(self,maxAllowedIncomingMessageSize:quint64)",
    "PySide6.QtWebSockets.QWebSocket.setOutgoingFrameSize(self,outgoingFrameSize:quint64)",
    "PySide6.QtWebSockets.QWebSocket.setPauseMode(self,pauseMode:PySide6.QtNetwork.QAbstractSocket.PauseMode)",
    "PySide6.QtWebSockets.QWebSocket.setProxy(self,networkProxy:typing.Union[PySide6.QtNetwork.QNetworkProxy, PySide6.QtNetwork.QNetworkProxy.ProxyType])",
    "PySide6.QtWebSockets.QWebSocket.setReadBufferSize(self,size:qint64)",
    "PySide6.QtWebSockets.QWebSocket.setSslConfiguration(self,sslConfiguration:PySide6.QtNetwork.QSslConfiguration)",
    "PySide6.QtWebSockets.QWebSocket.sslConfiguration(self)->PySide6.QtNetwork.QSslConfiguration",
    "PySide6.QtWebSockets.QWebSocket.state(self)->PySide6.QtNetwork.QAbstractSocket.SocketState",
    "PySide6.QtWebSockets.QWebSocket.subprotocol(self)->QString",
    "PySide6.QtWebSockets.QWebSocket.version(self)->PySide6.QtWebSockets.QWebSocketProtocol.Version",
    nullptr}; // Sentinel
#else
static constexpr size_t QWebSocket_SignatureByteSize = 813;
static constexpr uint8_t QWebSocket_SignatureBytes[813] = {
    0x78, 0xda, 0xb5, 0x58, 0x4d, 0x73, 0xda, 0x30, 0x10, 0xbd, 0xf3, 0x2b, 0x72, 0x0c, 0x1d, 0xd5,
    0xd3, 0xb4, 0x9d, 0x1c, 0x3c, 0x43, 0x67, 0x08, 0xd3, 0x36, 0x99, 0x09, 0xe1, 0x2b, 0x1f, 0x87,
    0x0c, 0x07, 0x61, 0x2f, 0xa0, 0x22, 0x24, 0x47, 0x92, 0x9b, 0xb8, 0xbf, 0xbe, 0x02, 0xcb, 0x04,
    0xb0, 0xb1, 0x24, 0x4f, 0x7b, 0xc1, 0xc6, 0xde, 0xf7, 0x76, 0xb5, 0x5e, 0xbd, 0x5d, 0x7b, 0x98,
    0x4d, 0x48, 0x0c, 0x97, 0xc1, 0x48, 0x3d, 0xc1, 0x6c, 0xc2, 0xa3, 0x15, 0x28, 0x19, 0x8c, 0x76,
    0xe7, 0xe7, 0x12, 0xe8, 0x1c, 0x71, 0x41, 0x16, 0x84, 0x85, 0xa3, 0x89, 0x12, 0x84, 0x2d, 0x3a,
    0xe6, 0x78, 0xde, 0x46, 0xbf, 0x41, 0x48, 0xc2, 0x59, 0x38, 0xac, 0x67, 0x19, 0x0a, 0xae, 0x78,
    0xc4, 0x69, 0xf0, 0x98, 0xdb, 0x77, 0x4e, 0xdf, 0xba, 0xc5, 0x0a, 0xa4, 0x42, 0x09, 0x16, 0xc0,
    0xd4, 0x1e, 0x6f, 0x8f, 0x0b, 0x08, 0x46, 0x83, 0xd9, 0x2f, 0x88, 0x54, 0x87, 0xa5, 0x94, 0x26,
    0x4a, 0xb4, 0x5b, 0x16, 0xbf, 0x01, 0x9e, 0x71, 0x91, 0xaf, 0xc1, 0x6e, 0x3b, 0xcb, 0xb4, 0xe7,
    0x7b, 0xfe, 0x24, 0x88, 0x82, 0x1c, 0xf2, 0xf1, 0xdb, 0x0b, 0x61, 0xea, 0xf2, 0xab, 0x15, 0x1a,
    0x51, 0x2e, 0x73, 0x0c, 0xda, 0x9e, 0xf6, 0x78, 0x0c, 0xce, 0x39, 0xe9, 0x15, 0x88, 0x4e, 0xdd,
    0xcd, 0x3b, 0x2e, 0xd6, 0x98, 0x22, 0x01, 0x58, 0xf2, 0x8a, 0x27, 0xd1, 0x76, 0x8b, 0x71, 0xc3,
    0x54, 0xac, 0xcd, 0x3b, 0x3e, 0x37, 0x17, 0xe3, 0x6d, 0x84, 0x85, 0x13, 0x13, 0xa0, 0x1d, 0xca,
    0x99, 0x22, 0x2c, 0x85, 0x1b, 0xa6, 0x40, 0x88, 0x34, 0x51, 0x10, 0x5f, 0x63, 0x16, 0xcb, 0x25,
    0x5e, 0x81, 0xe3, 0xf3, 0xd3, 0x38, 0x2e, 0xca, 0x8b, 0xbb, 0x03, 0xf5, 0xca, 0xc5, 0x2a, 0x18,
    0x75, 0x67, 0x52, 0x09, 0x1c, 0x29, 0x63, 0x9e, 0x1f, 0xbe, 0x6f, 0x40, 0x6e, 0xd4, 0x26, 0xd5,
    0x9e, 0x0b, 0x9b, 0xd3, 0x54, 0x2e, 0x0b, 0xd0, 0x8c, 0x73, 0x6a, 0x45, 0x2c, 0x8b, 0x75, 0x0f,
    0x12, 0xa5, 0x37, 0x84, 0x74, 0x7c, 0x5e, 0xd7, 0x47, 0xb0, 0xd6, 0x85, 0xad, 0x02, 0x03, 0xb2,
    0x60, 0x7a, 0x57, 0x4d, 0x24, 0xdd, 0x66, 0xc1, 0x38, 0x6a, 0x7d, 0x6a, 0x84, 0x43, 0xdb, 0x1c,
    0xc9, 0x70, 0x74, 0x4b, 0xa4, 0x7a, 0xae, 0x48, 0x7f, 0x61, 0x3e, 0xb5, 0x3f, 0x49, 0x22, 0x1f,
    0x31, 0x25, 0xb1, 0x57, 0xd6, 0x28, 0x8f, 0x30, 0xed, 0xc6, 0xb1, 0x00, 0x29, 0x6b, 0x8a, 0xe0,
    0x9a, 0x4b, 0x65, 0xac, 0xdc, 0x28, 0x87, 0x3b, 0x01, 0xd1, 0x6a, 0x90, 0x6a, 0x39, 0xb8, 0xb8,
    0xb4, 0x02, 0xd7, 0x58, 0xae, 0x7e, 0x02, 0x03, 0x81, 0x55, 0x55, 0x45, 0xee, 0x83, 0xfa, 0xfb,
    0xa6, 0x0e, 0xc4, 0x6f, 0x5d, 0x4a, 0xf9, 0x2b, 0xc4, 0x37, 0x2c, 0xe2, 0x6b, 0x5d, 0x7f, 0x3f,
    0x04, 0x5e, 0xc3, 0x84, 0xfc, 0x81, 0x83, 0x18, 0x1d, 0x24, 0xab, 0x4c, 0xd5, 0xd7, 0x39, 0xc1,
    0x8b, 0xa6, 0x64, 0xe5, 0x80, 0x9a, 0xe1, 0xf7, 0xa3, 0xf0, 0x63, 0x18, 0xa4, 0x6a, 0xc1, 0x4f,
    0x45, 0xf0, 0xc5, 0x5a, 0xd4, 0x3c, 0x81, 0x5c, 0xb5, 0xb4, 0xc6, 0xbe, 0xa4, 0xba, 0x07, 0x85,
    0x15, 0xe5, 0x63, 0x4e, 0xc6, 0xb9, 0x45, 0xbb, 0xf5, 0xf9, 0x7f, 0xd0, 0x22, 0x9e, 0xef, 0xe0,
    0xd0, 0x73, 0xc7, 0xb7, 0x1d, 0xb6, 0xfc, 0x7b, 0x38, 0xa9, 0xa0, 0xa1, 0xca, 0x12, 0x9d, 0xb0,
    0xe0, 0x81, 0x69, 0xf8, 0xf3, 0x71, 0xaf, 0x7d, 0x10, 0x14, 0x9d, 0x19, 0x99, 0x9b, 0xba, 0xc8,
    0x42, 0x53, 0xee, 0xe6, 0xeb, 0xb5, 0x46, 0xb4, 0x9d, 0x5b, 0x7c, 0x25, 0x9b, 0x97, 0x0a, 0xc9,
    0x73, 0x3b, 0x24, 0x38, 0x95, 0xd0, 0xaf, 0x6c, 0xb5, 0xa7, 0xba, 0xd1, 0xb0, 0x80, 0xd8, 0xc9,
    0x01, 0xc4, 0xbf, 0xd5, 0xb9, 0x0d, 0xe3, 0x9d, 0x5e, 0xaa, 0x6f, 0x9e, 0x36, 0xb8, 0x26, 0xf2,
    0x98, 0x14, 0x6d, 0x54, 0x4f, 0x79, 0x19, 0xe5, 0x38, 0xae, 0xaf, 0x95, 0x2b, 0x3d, 0x97, 0x75,
    0x85, 0xc0, 0x19, 0x3a, 0x8b, 0x96, 0x58, 0x7c, 0x98, 0x76, 0xde, 0x2f, 0xb9, 0x0c, 0x3e, 0x89,
    0xe0, 0x6f, 0x59, 0x4d, 0xaa, 0xcc, 0xc9, 0x70, 0x63, 0x66, 0x25, 0xd3, 0xf3, 0x57, 0x7c, 0x95,
    0xce, 0xe7, 0x20, 0x0e, 0x0a, 0xc3, 0xad, 0x2e, 0x8c, 0x02, 0xd8, 0x63, 0x31, 0x42, 0xe0, 0x4a,
    0xa8, 0x77, 0x53, 0x99, 0x73, 0xb7, 0xd1, 0x1c, 0x58, 0x24, 0x4f, 0x45, 0x04, 0x4d, 0x6a, 0x40,
    0x63, 0xd3, 0xb5, 0xeb, 0x84, 0x26, 0x81, 0xc5, 0x57, 0x84, 0x61, 0x91, 0x19, 0x95, 0xcf, 0xab,
    0x20, 0xc6, 0x0a, 0x7b, 0x96, 0x80, 0x7b, 0xce, 0x37, 0x3e, 0xef, 0xe1, 0x4d, 0x1d, 0x78, 0x5c,
    0xe7, 0x7f, 0x8a, 0x31, 0xda, 0x87, 0x4d, 0xf5, 0x4b, 0xcd, 0x1d, 0x1d, 0xf4, 0xfb, 0xd0, 0xa1,
    0xd1, 0xb7, 0xdd, 0x1c, 0xd5, 0x37, 0x7b, 0x54, 0x33, 0x0d, 0x84, 0x46, 0xaa, 0x1a, 0x3a, 0x3a,
    0x1e, 0x05, 0x50, 0xed, 0xb4, 0xe0, 0xe5, 0x6c, 0x50, 0x29, 0xae, 0xa8, 0xa4, 0xb9, 0x5e, 0xa4,
    0xc3, 0x03, 0xc1, 0x45, 0x3b, 0xfd, 0x0d, 0x3d, 0x84, 0xd7, 0xcd, 0xd1, 0x4e, 0x4b, 0x10, 0xdb,
    0x93, 0x8d, 0x53, 0xd5, 0x5b, 0xa9, 0x31, 0xe8, 0xcc, 0x62, 0x10, 0x6c, 0x7f, 0xef, 0xb3, 0x04,
    0xa6, 0x4e, 0x41, 0x8d, 0xcb, 0x9a, 0x84, 0xe4, 0x36, 0x85, 0xee, 0x19, 0xd4, 0xd3, 0x79, 0x8f,
    0xb3, 0x39, 0x59, 0xa4, 0xba, 0x40, 0x89, 0x79, 0x7f, 0x43, 0xf2, 0xe8, 0x6a, 0x58, 0x3d, 0xd7,
    0x1f, 0xd8, 0x38, 0xb8, 0xab, 0xf2, 0x55, 0xad, 0x87, 0xc7, 0xe4, 0x76, 0x6e, 0x85, 0x15, 0xf8,
    0xbe, 0x04, 0x4e, 0x36, 0x20, 0x3b, 0x75, 0x3a, 0x4b, 0xcc, 0x3b, 0xb1, 0xaf, 0x4a, 0x9a, 0xcf,
    0x24, 0xbe, 0x6f, 0xde, 0xe6, 0x93, 0x48, 0xeb, 0x2f, 0x9b, 0xe9, 0x76, 0xfd
};
#endif

PyTypeObject *init_QWebSocket(PyObject *module)
{
    if (SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX].type != nullptr)
        return SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX].type;

    Shiboken::AutoDecRef Sbk_QWebSocket_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QWebSocket_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QWebSocket",
        "QWebSocket*",
        &Sbk_QWebSocket_spec,
        &Shiboken::callCppDestructor< QWebSocket >,
        Sbk_QWebSocket_Type_bases.object(),
        0);
    auto *pyType = Sbk_QWebSocket_TypeF(); // references _Sbk_QWebSocket_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QWebSocket_SignatureStrings);
#else
    InitSignatureBytes(pyType, QWebSocket_SignatureBytes, QWebSocket_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QWebSocket_PropertyStrings);
    SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QWebSocket_PythonToCpp_QWebSocket_PTR,
        is_QWebSocket_PythonToCpp_QWebSocket_PTR_Convertible,
        QWebSocket_PTR_CppToPython_QWebSocket);

    Shiboken::Conversions::registerConverterName(converter, "QWebSocket");
    Shiboken::Conversions::registerConverterName(converter, "QWebSocket*");
    Shiboken::Conversions::registerConverterName(converter, "QWebSocket&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QWebSocket).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QWebSocketWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QWebSocket_TypeF(), &Sbk_QWebSocket_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::QWebSocket::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QWebSocket::staticMetaObject, sizeof(QWebSocketWrapper));

    return pyType;
}
