// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qapplication_wrapper.h"

// Extra includes
#include <QBasicTimer>
#include <QFont>
#include <QFontMetrics>
#include <QIcon>
#include <QLocale>
#include <QPalette>
#include <QStyle>
#include <pysidecleanup.h>
#include <pysideqapp.h>

// Argument includes
#include <QList>
#include <QString>
#include <QStringList>
#include <QtGui/qclipboard.h>
#include <QtGui/qcursor.h>
#include <QtGui/qfont.h>
#include <QtGui/qfontmetrics.h>
#include <QtGui/qicon.h>
#include <QtGui/qinputmethod.h>
#include <QtGui/qpalette.h>
#include <QtGui/qscreen.h>
#include <QtGui/qstylehints.h>
#include <QtGui/qwindow.h>
#include <QtWidgets/qstyle.h>
#include <QtWidgets/qwidget.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Begin code injection
// ========================================================================
// START of custom code block [file: ../glue/qtwidgets.cpp (qapplication-init)]
static void QApplicationConstructor(PyObject *self, PyObject *pyargv, QApplicationWrapper **cptr)
{
    static int argc;
    static char **argv;
    PyObject *stringlist = PyTuple_GetItem(pyargv, 0);
    if (Shiboken::listToArgcArgv(stringlist, &argc, &argv, "PySideApp")) {
        *cptr = new QApplicationWrapper(argc, argv, 0);
        Shiboken::Object::releaseOwnership(reinterpret_cast<SbkObject *>(self));
        PySide::registerCleanupFunction(&PySide::destroyQCoreApplication);
    }
}
// END of custom code block [file: ../glue/qtwidgets.cpp (qapplication-init)]
// ========================================================================
// End of code injection


// Native ---------------------------------------------------------

void QApplicationWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QApplicationWrapper::QApplicationWrapper(int & argc, char ** argv, int arg__3) : QApplication(argc, argv, arg__3)
{
}

void QApplicationWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QApplication", funcName);
        return;
    }
}

void QApplicationWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QApplication", funcName);
        return;
    }
}

void QApplicationWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QApplication", funcName);
        return;
    }
}

void QApplicationWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QApplication", funcName);
        return;
    }
}

bool QApplicationWrapper::event(::QEvent * arg__1)
{
    if (m_PyMethodCache[4])
        return this->::QApplication::event(arg__1);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QApplication::event(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), arg__1)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), arg__1)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QApplication", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QApplication", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QApplicationWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QApplication", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QApplication", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QApplicationWrapper::notify(::QObject * arg__1, ::QEvent * arg__2)
{
    if (m_PyMethodCache[6])
        return this->::QApplication::notify(arg__1, arg__2);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "notify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QApplication::notify(arg__1, arg__2);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), arg__1),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), arg__2)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), arg__1),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), arg__2)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QApplication", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QApplication", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QApplicationWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[7]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[7] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QApplication", funcName);
        return;
    }
}

const QMetaObject *QApplicationWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QApplication::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QApplicationWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QApplication::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QApplicationWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QApplicationWrapper *>(this));
    return QApplication::qt_metacast(_clname);
}

QApplicationWrapper::~QApplicationWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QApplication_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QApplication >()))
        return -1;

    QApplicationWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QApplication", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QApplication::QApplication()
    // 1: QApplication::QApplication(QStringList)
    if (numArgs == 0) {
        overloadId = 0; // QApplication()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[0])))) {
        overloadId = 1; // QApplication(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QApplication()
        {

            // QApplication()
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtwidgets.cpp (qapplication-2)]
            PyObject *empty = PyTuple_New(2);
            if (!PyTuple_SetItem(empty, 0, PyList_New(0)))
                QApplicationConstructor(self, empty, &cptr);
            // END of custom code block [file: ../glue/qtwidgets.cpp (qapplication-2)]
            // ========================================================================
            // End of code injection

            break;
        }
        case 1: // QApplication(QStringList arguments)
        {
            ::QStringList cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)

            if (Shiboken::Errors::occurred() == nullptr) {
                // QApplication(QStringList)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtwidgets.cpp (qapplication-1)]
                QApplicationConstructor(self, args, &cptr);
                // END of custom code block [file: ../glue/qtwidgets.cpp (qapplication-1)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QApplication >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QApplicationFunc_aboutQt(PyObject *self)
{
    SBK_UNUSED(self)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // aboutQt()
        ::QApplication::aboutQt();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QApplicationFunc_activeModalWidget(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // activeModalWidget()
        QWidget * cppResult = ::QApplication::activeModalWidget();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QApplicationFunc_activePopupWidget(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // activePopupWidget()
        QWidget * cppResult = ::QApplication::activePopupWidget();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QApplicationFunc_activeWindow(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // activeWindow()
        QWidget * cppResult = ::QApplication::activeWindow();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QApplicationFunc_alert(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "alert", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]);

    if (PyArg_ParseTuple(args, "|OO:alert", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QApplication::alert(QWidget*,int=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // alert(QWidget*,int)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 0; // alert(QWidget*,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "alert", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_duration = Shiboken::String::createStaticString("duration");
            if (PyDict_Contains(kwds, key_duration) != 0) {
                value = PyDict_GetItem(kwds, key_duration);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_duration);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "alert", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "alert", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_duration);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "alert", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QWidget *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1 = 0;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // alert(QWidget*,int)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            ::QApplication::alert(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QApplicationFunc_allWidgets(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // allWidgets()
        QList<QWidget*> cppResult = ::QApplication::allWidgets();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QWidgetPTR_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QApplicationFunc_autoSipEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QApplication *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // autoSipEnabled()const
        bool cppResult = const_cast<const ::QApplication *>(cppSelf)->autoSipEnabled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QApplicationFunc_beep(PyObject *self)
{
    SBK_UNUSED(self)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // beep()
        ::QApplication::beep();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QApplicationFunc_closeAllWindows(PyObject *self)
{
    SBK_UNUSED(self)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // closeAllWindows()
        ::QApplication::closeAllWindows();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QApplicationFunc_cursorFlashTime(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cursorFlashTime()
        int cppResult = ::QApplication::cursorFlashTime();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QApplicationFunc_doubleClickInterval(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // doubleClickInterval()
        int cppResult = ::QApplication::doubleClickInterval();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QApplicationFunc_event(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QApplication *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::event(QEvent*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "event", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // event(QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QApplication::event(cppArg0)
                : cppSelf->event(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QApplicationFunc_exec(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;
    pcm.setBlocking();

    // Call function/method
    {

        // exec()
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        int cppResult = ::QApplication::exec();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QApplicationFunc_exec_(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QApplication *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;
    pcm.setBlocking();

    // Call function/method
    {

        // exec_()
        // Begin code injection
        // ========================================================================
        // START of custom code block [file: ../glue/qtwidgets.cpp (qapplication-exec)]
        if (PyErr_WarnEx(PyExc_DeprecationWarning,
                         "'exec_' will be removed in the future. "
                         "Use 'exec' instead.",
                         1)) {
            return nullptr;
        }
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        int cppResult = cppSelf->exec();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        // END of custom code block [file: ../glue/qtwidgets.cpp (qapplication-exec)]
        // ========================================================================
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QApplicationFunc_focusWidget(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // focusWidget()
        QWidget * cppResult = ::QApplication::focusWidget();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QApplicationFunc_font(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "font", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QGuiApplication::font()->QFont
    // 1: static QApplication::font(const QWidget*)->QFont
    // 2: static QApplication::font(const char*)->QFont
    if (numArgs == 0) {
        overloadId = 0; // font()
    } else if (numArgs == 1
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))) {
        overloadId = 2; // font(const char*)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        overloadId = 1; // font(const QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "font", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // font()
        {

            // font()
            QFont cppResult = ::QApplication::font();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), &cppResult);
            break;
        }
        case 1: // font(const QWidget *arg__1)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QWidget *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // font(const QWidget*)
                QFont cppResult = ::QApplication::font(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), &cppResult);
            }
            break;
        }
        case 2: // font(const char *className)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // font(const char*)
                QFont cppResult = ::QApplication::font(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QApplicationFunc_fontMetrics(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QApplication", "fontMetrics()");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // fontMetrics()
        QFontMetrics cppResult = ::QApplication::fontMetrics();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QApplicationFunc_isEffectEnabled(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QApplication::isEffectEnabled(Qt::UIEffect)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_UIEffect_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // isEffectEnabled(Qt::UIEffect)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isEffectEnabled", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]);

    // Call function/method
    {
        ::Qt::UIEffect cppArg0{Qt::UI_General};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isEffectEnabled(Qt::UIEffect)
            bool cppResult = ::QApplication::isEffectEnabled(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QApplicationFunc_keyboardInputInterval(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // keyboardInputInterval()
        int cppResult = ::QApplication::keyboardInputInterval();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QApplicationFunc_notify(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QApplication *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "notify", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCoreApplication::notify(QObject*,QEvent*)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArgs[1])))) {
        overloadId = 0; // notify(QObject*,QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "notify", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QObject *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QEvent *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // notify(QObject*,QEvent*)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QApplication::notify(cppArg0, cppArg1)
                : cppSelf->notify(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QApplicationFunc_palette(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "palette", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QApplication::palette(const QWidget*)->QPalette
    // 1: static QGuiApplication::palette()->QPalette
    // 2: static QApplication::palette(const char*)->QPalette
    if (numArgs == 0) {
        overloadId = 1; // palette()
    } else if (numArgs == 1
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))) {
        overloadId = 2; // palette(const char*)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        overloadId = 0; // palette(const QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "palette", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // palette(const QWidget *arg__1)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QWidget *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // palette(const QWidget*)
                QPalette cppResult = ::QApplication::palette(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPalette_IDX]), &cppResult);
            }
            break;
        }
        case 1: // palette()
        {

            // palette()
            QPalette cppResult = ::QGuiApplication::palette();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPalette_IDX]), &cppResult);
            break;
        }
        case 2: // palette(const char *className)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // palette(const char*)
                QPalette cppResult = ::QApplication::palette(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPalette_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QApplicationFunc_resolveInterface(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QApplication *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "resolveInterface", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCoreApplication::resolveInterface(const char*,int)const->void*
    if (numArgs == 2
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // resolveInterface(const char*,int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "resolveInterface", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // resolveInterface(const char*,int)const
            void * cppResult = const_cast<const ::QApplication *>(cppSelf)->resolveInterface(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QApplicationFunc_setActiveWindow(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QApplication::setActiveWindow(QWidget*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArg)))) {
        overloadId = 0; // setActiveWindow(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setActiveWindow", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]);

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QApplication", "setActiveWindow(QWidget *act)");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QWidget *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setActiveWindow(QWidget*)
            ::QApplication::setActiveWindow(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QApplicationFunc_setAutoSipEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QApplication *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QApplication::setAutoSipEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAutoSipEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAutoSipEnabled", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAutoSipEnabled(bool)
            cppSelf->setAutoSipEnabled(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QApplicationFunc_setCursorFlashTime(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QApplication::setCursorFlashTime(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setCursorFlashTime(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCursorFlashTime", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCursorFlashTime(int)
            ::QApplication::setCursorFlashTime(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QApplicationFunc_setDoubleClickInterval(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QApplication::setDoubleClickInterval(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setDoubleClickInterval(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDoubleClickInterval", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDoubleClickInterval(int)
            ::QApplication::setDoubleClickInterval(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QApplicationFunc_setEffectEnabled(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setEffectEnabled", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setEffectEnabled", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QApplication::setEffectEnabled(Qt::UIEffect,bool=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_UIEffect_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setEffectEnabled(Qt::UIEffect,bool)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 0; // setEffectEnabled(Qt::UIEffect,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setEffectEnabled", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_enable = Shiboken::String::createStaticString("enable");
            if (PyDict_Contains(kwds, key_enable) != 0) {
                value = PyDict_GetItem(kwds, key_enable);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_enable);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setEffectEnabled", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "setEffectEnabled", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_enable);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setEffectEnabled", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]);
            }
        }
        ::Qt::UIEffect cppArg0{Qt::UI_General};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        bool cppArg1 = true;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setEffectEnabled(Qt::UIEffect,bool)
            ::QApplication::setEffectEnabled(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QApplicationFunc_setFont(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setFont", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setFont", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QApplication::setFont(QFont,const char*=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setFont(QFont,const char*)
        } else if (numArgs >= 2
            && Shiboken::String::check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[1])))) {
            overloadId = 0; // setFont(QFont,const char*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setFont", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_className = Shiboken::String::createStaticString("className");
            if (PyDict_Contains(kwds, key_className) != 0) {
                value = PyDict_GetItem(kwds, key_className);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_className);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setFont", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!Shiboken::String::check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "setFont", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_className);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setFont", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QFont cppArg0_local;
        ::QFont *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        const char* cppArg1 = nullptr;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFont(QFont,const char*)
            ::QApplication::setFont(*cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QApplicationFunc_setKeyboardInputInterval(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QApplication::setKeyboardInputInterval(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setKeyboardInputInterval(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setKeyboardInputInterval", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setKeyboardInputInterval(int)
            ::QApplication::setKeyboardInputInterval(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QApplicationFunc_setPalette(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setPalette", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setPalette", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QApplication::setPalette(QPalette,const char*=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPalette_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setPalette(QPalette,const char*)
        } else if (numArgs >= 2
            && Shiboken::String::check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[1])))) {
            overloadId = 0; // setPalette(QPalette,const char*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setPalette", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_className = Shiboken::String::createStaticString("className");
            if (PyDict_Contains(kwds, key_className) != 0) {
                value = PyDict_GetItem(kwds, key_className);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_className);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setPalette", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!Shiboken::String::check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "setPalette", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_className);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setPalette", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QPalette cppArg0_local;
        ::QPalette *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        const char* cppArg1 = nullptr;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPalette(QPalette,const char*)
            ::QApplication::setPalette(*cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QApplicationFunc_setStartDragDistance(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QApplication::setStartDragDistance(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setStartDragDistance(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStartDragDistance", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStartDragDistance(int)
            ::QApplication::setStartDragDistance(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QApplicationFunc_setStartDragTime(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QApplication::setStartDragTime(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setStartDragTime(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStartDragTime", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStartDragTime(int)
            ::QApplication::setStartDragTime(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QApplicationFunc_setStyle(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QApplication::setStyle(QStyle*)
    // 1: static QApplication::setStyle(QString)->QStyle*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_IDX]), (pyArg)))) {
        overloadId = 0; // setStyle(QStyle*)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 1; // setStyle(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStyle", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setStyle(QStyle *arg__1)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QStyle *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setStyle(QStyle*)
                ::QApplication::setStyle(cppArg0);
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtwidgets.cpp (qapplication-setStyle)]
                if (qApp) {
                    Shiboken::AutoDecRef pyApp(Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]), qApp));
                    Shiboken::Object::setParent(pyApp, pyArg);
                    Shiboken::Object::releaseOwnership(pyArg);
                }
                // END of custom code block [file: ../glue/qtwidgets.cpp (qapplication-setStyle)]
                // ========================================================================
                // End of code injection

                pyResult = Py_None;
                Py_INCREF(Py_None);
            }
            break;
        }
        case 1: // setStyle(const QString &arg__1)
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setStyle(QString)
                QStyle * cppResult = ::QApplication::setStyle(cppArg0);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_IDX]), cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QApplicationFunc_setStyleSheet(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QApplication *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QApplication::setStyleSheet(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setStyleSheet(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStyleSheet", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStyleSheet(QString)
            cppSelf->setStyleSheet(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QApplicationFunc_setWheelScrollLines(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QApplication::setWheelScrollLines(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setWheelScrollLines(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setWheelScrollLines", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setWheelScrollLines(int)
            ::QApplication::setWheelScrollLines(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QApplicationFunc_startDragDistance(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // startDragDistance()
        int cppResult = ::QApplication::startDragDistance();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QApplicationFunc_startDragTime(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // startDragTime()
        int cppResult = ::QApplication::startDragTime();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QApplicationFunc_style(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // style()
        QStyle * cppResult = ::QApplication::style();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QApplicationFunc_styleSheet(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QApplication *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // styleSheet()const
        QString cppResult = const_cast<const ::QApplication *>(cppSelf)->styleSheet();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QApplicationFunc_topLevelAt(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "topLevelAt", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QGuiApplication::topLevelAt(QPoint)->QWidget*
    // 1: static QApplication::topLevelAt(int,int)->QWidget*
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 1; // topLevelAt(int,int)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[0])))) {
        overloadId = 0; // topLevelAt(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "topLevelAt", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // topLevelAt(const QPoint &p)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPoint cppArg0_local;
            ::QPoint *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // topLevelAt(QPoint)
                QWidget * cppResult = ::QApplication::topLevelAt(*cppArg0);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), cppResult);
            }
            break;
        }
        case 1: // topLevelAt(int x, int y)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // topLevelAt(int,int)
                QWidget * cppResult = ::QApplication::topLevelAt(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QApplicationFunc_topLevelWidgets(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // topLevelWidgets()
        QList<QWidget*> cppResult = ::QApplication::topLevelWidgets();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QWidgetPTR_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QApplicationFunc_wheelScrollLines(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // wheelScrollLines()
        int cppResult = ::QApplication::wheelScrollLines();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QApplicationFunc_widgetAt(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "widgetAt", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QApplication::widgetAt(QPoint)->QWidget*
    // 1: static QApplication::widgetAt(int,int)->QWidget*
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 1; // widgetAt(int,int)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[0])))) {
        overloadId = 0; // widgetAt(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "widgetAt", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // widgetAt(const QPoint &p)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPoint cppArg0_local;
            ::QPoint *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // widgetAt(QPoint)
                QWidget * cppResult = ::QApplication::widgetAt(*cppArg0);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), cppResult);
            }
            break;
        }
        case 1: // widgetAt(int x, int y)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // widgetAt(int,int)
                QWidget * cppResult = ::QApplication::widgetAt(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QApplication_PropertyStrings[] = {
    "autoSipEnabled::",
    "cursorFlashTime::",
    "doubleClickInterval::",
    "keyboardInputInterval::",
    "startDragDistance::",
    "startDragTime::",
    "styleSheet::",
    "wheelScrollLines::",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QApplication_methods[] = {
    {"aboutQt", reinterpret_cast<PyCFunction>(Sbk_QApplicationFunc_aboutQt), METH_NOARGS|METH_STATIC, nullptr},
    {"activeModalWidget", reinterpret_cast<PyCFunction>(Sbk_QApplicationFunc_activeModalWidget), METH_NOARGS|METH_STATIC, nullptr},
    {"activePopupWidget", reinterpret_cast<PyCFunction>(Sbk_QApplicationFunc_activePopupWidget), METH_NOARGS|METH_STATIC, nullptr},
    {"activeWindow", reinterpret_cast<PyCFunction>(Sbk_QApplicationFunc_activeWindow), METH_NOARGS|METH_STATIC, nullptr},
    {"alert", reinterpret_cast<PyCFunction>(Sbk_QApplicationFunc_alert), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"allWidgets", reinterpret_cast<PyCFunction>(Sbk_QApplicationFunc_allWidgets), METH_NOARGS|METH_STATIC, nullptr},
    {"autoSipEnabled", reinterpret_cast<PyCFunction>(Sbk_QApplicationFunc_autoSipEnabled), METH_NOARGS, nullptr},
    {"beep", reinterpret_cast<PyCFunction>(Sbk_QApplicationFunc_beep), METH_NOARGS|METH_STATIC, nullptr},
    {"closeAllWindows", reinterpret_cast<PyCFunction>(Sbk_QApplicationFunc_closeAllWindows), METH_NOARGS|METH_STATIC, nullptr},
    {"cursorFlashTime", reinterpret_cast<PyCFunction>(Sbk_QApplicationFunc_cursorFlashTime), METH_NOARGS|METH_STATIC, nullptr},
    {"doubleClickInterval", reinterpret_cast<PyCFunction>(Sbk_QApplicationFunc_doubleClickInterval), METH_NOARGS|METH_STATIC, nullptr},
    {"event", reinterpret_cast<PyCFunction>(Sbk_QApplicationFunc_event), METH_O, nullptr},
    {"exec", reinterpret_cast<PyCFunction>(Sbk_QApplicationFunc_exec), METH_NOARGS|METH_STATIC, nullptr},
    {"exec_", reinterpret_cast<PyCFunction>(Sbk_QApplicationFunc_exec_), METH_NOARGS, nullptr},
    {"focusWidget", reinterpret_cast<PyCFunction>(Sbk_QApplicationFunc_focusWidget), METH_NOARGS|METH_STATIC, nullptr},
    {"font", reinterpret_cast<PyCFunction>(Sbk_QApplicationFunc_font), METH_VARARGS|METH_STATIC, nullptr},
    {"fontMetrics", reinterpret_cast<PyCFunction>(Sbk_QApplicationFunc_fontMetrics), METH_NOARGS|METH_STATIC, nullptr},
    {"isEffectEnabled", reinterpret_cast<PyCFunction>(Sbk_QApplicationFunc_isEffectEnabled), METH_O|METH_STATIC, nullptr},
    {"keyboardInputInterval", reinterpret_cast<PyCFunction>(Sbk_QApplicationFunc_keyboardInputInterval), METH_NOARGS|METH_STATIC, nullptr},
    {"notify", reinterpret_cast<PyCFunction>(Sbk_QApplicationFunc_notify), METH_VARARGS, nullptr},
    {"palette", reinterpret_cast<PyCFunction>(Sbk_QApplicationFunc_palette), METH_VARARGS|METH_STATIC, nullptr},
    {"resolveInterface", reinterpret_cast<PyCFunction>(Sbk_QApplicationFunc_resolveInterface), METH_VARARGS, nullptr},
    {"setActiveWindow", reinterpret_cast<PyCFunction>(Sbk_QApplicationFunc_setActiveWindow), METH_O|METH_STATIC, nullptr},
    {"setAutoSipEnabled", reinterpret_cast<PyCFunction>(Sbk_QApplicationFunc_setAutoSipEnabled), METH_O, nullptr},
    {"setCursorFlashTime", reinterpret_cast<PyCFunction>(Sbk_QApplicationFunc_setCursorFlashTime), METH_O|METH_STATIC, nullptr},
    {"setDoubleClickInterval", reinterpret_cast<PyCFunction>(Sbk_QApplicationFunc_setDoubleClickInterval), METH_O|METH_STATIC, nullptr},
    {"setEffectEnabled", reinterpret_cast<PyCFunction>(Sbk_QApplicationFunc_setEffectEnabled), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"setFont", reinterpret_cast<PyCFunction>(Sbk_QApplicationFunc_setFont), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"setKeyboardInputInterval", reinterpret_cast<PyCFunction>(Sbk_QApplicationFunc_setKeyboardInputInterval), METH_O|METH_STATIC, nullptr},
    {"setPalette", reinterpret_cast<PyCFunction>(Sbk_QApplicationFunc_setPalette), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"setStartDragDistance", reinterpret_cast<PyCFunction>(Sbk_QApplicationFunc_setStartDragDistance), METH_O|METH_STATIC, nullptr},
    {"setStartDragTime", reinterpret_cast<PyCFunction>(Sbk_QApplicationFunc_setStartDragTime), METH_O|METH_STATIC, nullptr},
    {"setStyle", reinterpret_cast<PyCFunction>(Sbk_QApplicationFunc_setStyle), METH_O|METH_STATIC, nullptr},
    {"setStyleSheet", reinterpret_cast<PyCFunction>(Sbk_QApplicationFunc_setStyleSheet), METH_O, nullptr},
    {"setWheelScrollLines", reinterpret_cast<PyCFunction>(Sbk_QApplicationFunc_setWheelScrollLines), METH_O|METH_STATIC, nullptr},
    {"startDragDistance", reinterpret_cast<PyCFunction>(Sbk_QApplicationFunc_startDragDistance), METH_NOARGS|METH_STATIC, nullptr},
    {"startDragTime", reinterpret_cast<PyCFunction>(Sbk_QApplicationFunc_startDragTime), METH_NOARGS|METH_STATIC, nullptr},
    {"style", reinterpret_cast<PyCFunction>(Sbk_QApplicationFunc_style), METH_NOARGS|METH_STATIC, nullptr},
    {"styleSheet", reinterpret_cast<PyCFunction>(Sbk_QApplicationFunc_styleSheet), METH_NOARGS, nullptr},
    {"topLevelAt", reinterpret_cast<PyCFunction>(Sbk_QApplicationFunc_topLevelAt), METH_VARARGS|METH_STATIC, nullptr},
    {"topLevelWidgets", reinterpret_cast<PyCFunction>(Sbk_QApplicationFunc_topLevelWidgets), METH_NOARGS|METH_STATIC, nullptr},
    {"wheelScrollLines", reinterpret_cast<PyCFunction>(Sbk_QApplicationFunc_wheelScrollLines), METH_NOARGS|METH_STATIC, nullptr},
    {"widgetAt", reinterpret_cast<PyCFunction>(Sbk_QApplicationFunc_widgetAt), METH_VARARGS|METH_STATIC, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QApplication_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QApplication *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QApplicationWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QApplication_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QApplication_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QApplication_Type = nullptr;
static PyTypeObject *Sbk_QApplication_TypeF(void)
{
    return _Sbk_QApplication_Type;
}

static PyType_Slot Sbk_QApplication_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocQAppWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QApplication_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QApplication_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QApplication_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QApplication_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QApplication_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkQApp_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QApplication_spec = {
    "2:PySide6.QtWidgets.QApplication",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QApplication_slots
};

} //extern "C"

static void *Sbk_QApplication_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QApplication *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QApplication_PythonToCpp_QApplication_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QApplication_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QApplication_PythonToCpp_QApplication_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QApplication_TypeF()))
        return QApplication_PythonToCpp_QApplication_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QApplication_PTR_CppToPython_QApplication(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QApplication *>(const_cast<void *>(cppIn)), Sbk_QApplication_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QApplication_SignatureStrings[] = {
    "1:PySide6.QtWidgets.QApplication(self,*:KeywordOnly=None,cursorFlashTime:int=None,doubleClickInterval:int=None,keyboardInputInterval:int=None,wheelScrollLines:int=None,startDragTime:int=None,startDragDistance:int=None,styleSheet:QString=None,autoSipEnabled:bool=None)",
    "0:PySide6.QtWidgets.QApplication(self,arguments:QStringList,*:KeywordOnly=None,cursorFlashTime:int=None,doubleClickInterval:int=None,keyboardInputInterval:int=None,wheelScrollLines:int=None,startDragTime:int=None,startDragDistance:int=None,styleSheet:QString=None,autoSipEnabled:bool=None)",
    "PySide6.QtWidgets.QApplication.aboutQt()",
    "PySide6.QtWidgets.QApplication.activeModalWidget()->PySide6.QtWidgets.QWidget",
    "PySide6.QtWidgets.QApplication.activePopupWidget()->PySide6.QtWidgets.QWidget",
    "PySide6.QtWidgets.QApplication.activeWindow()->PySide6.QtWidgets.QWidget",
    "PySide6.QtWidgets.QApplication.alert(widget:PySide6.QtWidgets.QWidget,duration:int=0)",
    "PySide6.QtWidgets.QApplication.allWidgets()->QList[PySide6.QtWidgets.QWidget]",
    "PySide6.QtWidgets.QApplication.autoSipEnabled(self)->bool",
    "PySide6.QtWidgets.QApplication.beep()",
    "PySide6.QtWidgets.QApplication.closeAllWindows()",
    "PySide6.QtWidgets.QApplication.cursorFlashTime()->int",
    "PySide6.QtWidgets.QApplication.doubleClickInterval()->int",
    "PySide6.QtWidgets.QApplication.event(self,arg__1:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtWidgets.QApplication.exec()->int",
    "PySide6.QtWidgets.QApplication.exec_(self)->int",
    "PySide6.QtWidgets.QApplication.focusWidget()->PySide6.QtWidgets.QWidget",
    "2:PySide6.QtWidgets.QApplication.font()->PySide6.QtGui.QFont",
    "1:PySide6.QtWidgets.QApplication.font(arg__1:PySide6.QtWidgets.QWidget)->PySide6.QtGui.QFont",
    "0:PySide6.QtWidgets.QApplication.font(className:char*)->PySide6.QtGui.QFont",
    "PySide6.QtWidgets.QApplication.fontMetrics()->PySide6.QtGui.QFontMetrics",
    "PySide6.QtWidgets.QApplication.isEffectEnabled(arg__1:PySide6.QtCore.Qt.UIEffect)->bool",
    "PySide6.QtWidgets.QApplication.keyboardInputInterval()->int",
    "PySide6.QtWidgets.QApplication.notify(self,arg__1:PySide6.QtCore.QObject,arg__2:PySide6.QtCore.QEvent)->bool",
    "2:PySide6.QtWidgets.QApplication.palette(arg__1:PySide6.QtWidgets.QWidget)->PySide6.QtGui.QPalette",
    "1:PySide6.QtWidgets.QApplication.palette()->PySide6.QtGui.QPalette",
    "0:PySide6.QtWidgets.QApplication.palette(className:char*)->PySide6.QtGui.QPalette",
    "PySide6.QtWidgets.QApplication.resolveInterface(self,name:char*,revision:int)->void",
    "PySide6.QtWidgets.QApplication.setActiveWindow(act:PySide6.QtWidgets.QWidget)",
    "PySide6.QtWidgets.QApplication.setAutoSipEnabled(self,enabled:bool)",
    "PySide6.QtWidgets.QApplication.setCursorFlashTime(arg__1:int)",
    "PySide6.QtWidgets.QApplication.setDoubleClickInterval(arg__1:int)",
    "PySide6.QtWidgets.QApplication.setEffectEnabled(arg__1:PySide6.QtCore.Qt.UIEffect,enable:bool=true)",
    "PySide6.QtWidgets.QApplication.setFont(arg__1:typing.Union[PySide6.QtGui.QFont, QString, QStringList],className:char*=nullptr)",
    "PySide6.QtWidgets.QApplication.setKeyboardInputInterval(arg__1:int)",
    "PySide6.QtWidgets.QApplication.setPalette(arg__1:typing.Union[PySide6.QtGui.QPalette, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor],className:char*=nullptr)",
    "PySide6.QtWidgets.QApplication.setStartDragDistance(l:int)",
    "PySide6.QtWidgets.QApplication.setStartDragTime(ms:int)",
    "1:PySide6.QtWidgets.QApplication.setStyle(arg__1:PySide6.QtWidgets.QStyle)",
    "0:PySide6.QtWidgets.QApplication.setStyle(arg__1:QString)->PySide6.QtWidgets.QStyle",
    "PySide6.QtWidgets.QApplication.setStyleSheet(self,sheet:QString)",
    "PySide6.QtWidgets.QApplication.setWheelScrollLines(arg__1:int)",
    "PySide6.QtWidgets.QApplication.startDragDistance()->int",
    "PySide6.QtWidgets.QApplication.startDragTime()->int",
    "PySide6.QtWidgets.QApplication.style()->PySide6.QtWidgets.QStyle",
    "PySide6.QtWidgets.QApplication.styleSheet(self)->QString",
    "1:PySide6.QtWidgets.QApplication.topLevelAt(p:PySide6.QtCore.QPoint)->PySide6.QtWidgets.QWidget",
    "0:PySide6.QtWidgets.QApplication.topLevelAt(x:int,y:int)->PySide6.QtWidgets.QWidget",
    "PySide6.QtWidgets.QApplication.topLevelWidgets()->QList[PySide6.QtWidgets.QWidget]",
    "PySide6.QtWidgets.QApplication.wheelScrollLines()->int",
    "1:PySide6.QtWidgets.QApplication.widgetAt(p:PySide6.QtCore.QPoint)->PySide6.QtWidgets.QWidget",
    "0:PySide6.QtWidgets.QApplication.widgetAt(x:int,y:int)->PySide6.QtWidgets.QWidget",
    nullptr}; // Sentinel
#else
static constexpr size_t QApplication_SignatureByteSize = 767;
static constexpr uint8_t QApplication_SignatureBytes[767] = {
    0x78, 0xda, 0xe5, 0x97, 0x4d, 0x4f, 0xe3, 0x30, 0x10, 0x86, 0xef, 0xfc, 0x0a, 0x8e, 0x01, 0x65,
    0xa3, 0xc2, 0x61, 0x0f, 0x91, 0x58, 0xa9, 0x6a, 0x0b, 0x42, 0x7c, 0x35, 0xca, 0x22, 0x0e, 0x08,
    0x21, 0x27, 0x99, 0x16, 0x2f, 0xc6, 0x8e, 0x6c, 0xa7, 0x25, 0xff, 0x7e, 0x9d, 0x38, 0x2d, 0xf9,
    0xac, 0x5d, 0x60, 0x4f, 0x7b, 0x8b, 0x3c, 0x9e, 0xc7, 0xf6, 0x3b, 0xe3, 0xf1, 0xe4, 0xc4, 0x9f,
    0xe7, 0x21, 0x4e, 0xe0, 0xa7, 0x17, 0xc8, 0x07, 0x9c, 0x2c, 0x41, 0x0a, 0x2f, 0x18, 0xa7, 0x29,
    0xc1, 0x31, 0x92, 0x98, 0x51, 0x47, 0x00, 0x59, 0xb8, 0xc7, 0xfe, 0x15, 0xe4, 0x6b, 0xc6, 0x93,
    0x3b, 0x4a, 0xf2, 0xb3, 0x5b, 0x46, 0xc1, 0x8d, 0x33, 0x2e, 0x18, 0x3f, 0x27, 0x48, 0xbc, 0xfc,
    0xc6, 0x6f, 0xe0, 0x63, 0x2a, 0xb5, 0x21, 0x61, 0x59, 0x44, 0x60, 0xa2, 0x00, 0xaf, 0x97, 0x54,
    0x02, 0x5f, 0x21, 0xf2, 0x61, 0x7c, 0x85, 0x3c, 0x62, 0x88, 0x27, 0x97, 0x34, 0xcd, 0x64, 0xd7,
    0xbc, 0x7e, 0x01, 0x20, 0x61, 0xcc, 0x19, 0x21, 0xd7, 0x98, 0x82, 0xf8, 0xb0, 0x08, 0x89, 0xb8,
    0x9c, 0x72, 0xb4, 0x6c, 0x2e, 0xb6, 0x1d, 0x9e, 0x62, 0xf5, 0x49, 0xe3, 0x86, 0x29, 0x27, 0x10,
    0x2a, 0xa0, 0xf4, 0x83, 0x50, 0x72, 0x4c, 0x97, 0x7a, 0x1c, 0x65, 0x92, 0x85, 0x38, 0x9d, 0x51,
    0xa4, 0xb6, 0x99, 0xf8, 0x11, 0x63, 0xa4, 0x34, 0x1c, 0x1d, 0x8c, 0xac, 0xb4, 0x40, 0x7c, 0x99,
    0xbd, 0x01, 0x95, 0x62, 0x83, 0xbd, 0x56, 0x4b, 0xff, 0x27, 0x0a, 0xed, 0xd6, 0xc7, 0x43, 0x11,
    0xcb, 0x64, 0x20, 0x1d, 0xf3, 0xc4, 0x58, 0xe2, 0x15, 0xdc, 0xb0, 0x04, 0x11, 0x6d, 0x77, 0x8e,
    0x7e, 0xfc, 0xea, 0xf1, 0xd1, 0x1f, 0x76, 0xb4, 0x39, 0x4b, 0xb3, 0xf4, 0xdb, 0x68, 0x0f, 0x98,
    0x26, 0x6c, 0xfd, 0x35, 0x10, 0x01, 0x2e, 0x9d, 0x75, 0x69, 0xf2, 0x07, 0x29, 0x6e, 0x92, 0xf1,
    0x72, 0x7e, 0x19, 0x97, 0x91, 0x59, 0x3a, 0x52, 0x49, 0x26, 0x8a, 0xcd, 0x05, 0x45, 0xf2, 0x3d,
    0x0e, 0xc2, 0x9f, 0x8c, 0xb4, 0x46, 0xa8, 0xcb, 0x04, 0x57, 0xd4, 0x22, 0xe2, 0x26, 0xcf, 0x08,
    0x20, 0x35, 0x07, 0x3a, 0x26, 0x4c, 0xc0, 0xb8, 0xd8, 0x72, 0x21, 0xa7, 0xb0, 0x70, 0x68, 0x5e,
    0x9a, 0xe2, 0x8c, 0x4a, 0x17, 0x93, 0x57, 0xcf, 0x8d, 0xb2, 0xf4, 0x84, 0x95, 0xba, 0xca, 0xdb,
    0x8b, 0xfd, 0xfc, 0x7c, 0x52, 0x8b, 0xd4, 0x84, 0x71, 0xf0, 0x82, 0x59, 0x31, 0xc3, 0x52, 0x14,
    0x78, 0x87, 0xd8, 0x76, 0x61, 0x35, 0xf5, 0x79, 0x23, 0xb8, 0xc5, 0xfc, 0x05, 0x8b, 0x33, 0x61,
    0x93, 0xde, 0xa7, 0xbe, 0x91, 0x44, 0x5b, 0x88, 0x8b, 0x0c, 0x7b, 0xc1, 0xb9, 0x1a, 0x3e, 0x38,
    0xb1, 0x72, 0xee, 0x28, 0xd5, 0xda, 0xc3, 0x00, 0x7c, 0x64, 0x05, 0x8f, 0x55, 0xec, 0xc5, 0x2d,
    0x52, 0x35, 0x2c, 0x7e, 0x41, 0xfc, 0x78, 0x80, 0x65, 0x41, 0xba, 0x01, 0x55, 0xd3, 0x62, 0x31,
    0x70, 0xd4, 0xca, 0x6a, 0x02, 0x61, 0x31, 0x5b, 0x2c, 0x20, 0x96, 0x9b, 0x1b, 0x32, 0x90, 0x24,
    0xd2, 0xbb, 0xbf, 0xd4, 0x13, 0x2d, 0x33, 0xa5, 0xb7, 0xcc, 0x5b, 0xa6, 0x0e, 0x65, 0x12, 0x2f,
    0xf2, 0x9d, 0x49, 0x7b, 0x17, 0xfd, 0x51, 0x7b, 0xd1, 0xd6, 0xd3, 0xdd, 0x29, 0x6d, 0xcc, 0x97,
    0x54, 0x15, 0x32, 0x29, 0xe1, 0x13, 0x51, 0x9f, 0x6b, 0x4f, 0x73, 0x56, 0x6d, 0x96, 0x18, 0x46,
    0x8c, 0x6c, 0x11, 0xc6, 0xf4, 0xd9, 0x10, 0x0d, 0x3c, 0x0e, 0x82, 0x91, 0x15, 0x94, 0xa1, 0x59,
    0xa0, 0x18, 0xb4, 0xdc, 0x74, 0x0b, 0x76, 0x39, 0xac, 0xb0, 0xa8, 0xea, 0xb6, 0x5a, 0x65, 0xc5,
    0x70, 0x62, 0x62, 0x0a, 0x90, 0xe3, 0xfa, 0xeb, 0xa2, 0x9e, 0x9a, 0x1d, 0x72, 0xda, 0xd0, 0xba,
    0xe5, 0xdb, 0x85, 0xda, 0xb3, 0x6d, 0xc3, 0x98, 0xb4, 0x2a, 0x6e, 0x15, 0xe6, 0xe2, 0x54, 0x16,
    0xde, 0xd3, 0x9e, 0xca, 0xbb, 0x1f, 0x61, 0xcf, 0xfb, 0x55, 0x9d, 0x4f, 0x77, 0x25, 0x92, 0x67,
    0x60, 0xb3, 0xc6, 0x79, 0xad, 0x6a, 0xc9, 0x3c, 0x55, 0x9d, 0x8e, 0x77, 0x4f, 0x95, 0xed, 0xb1,
    0xa7, 0x30, 0xb8, 0x87, 0x55, 0x33, 0xb4, 0xfd, 0x28, 0xde, 0xd8, 0x27, 0xb7, 0x95, 0x58, 0x67,
    0x34, 0x23, 0x24, 0x95, 0xdc, 0x66, 0xf9, 0xab, 0xde, 0xcb, 0xbe, 0x9f, 0x4c, 0xf3, 0xe6, 0x2d,
    0xdc, 0x75, 0x8a, 0x6a, 0xaa, 0x7b, 0xd8, 0x55, 0xf1, 0x82, 0xb0, 0x08, 0x91, 0x09, 0x23, 0x8c,
    0xd7, 0xcd, 0xa5, 0x5b, 0x39, 0xfa, 0xa5, 0x73, 0x86, 0xed, 0x5e, 0xd3, 0x21, 0xb6, 0xc7, 0x0b,
    0xeb, 0xdd, 0xab, 0xf3, 0x26, 0xb4, 0x9f, 0xb1, 0x70, 0x94, 0x9e, 0xaa, 0x8b, 0xdd, 0x51, 0x9c,
    0x4a, 0xbb, 0xb9, 0xb9, 0xef, 0xa0, 0xaa, 0xe0, 0xf7, 0xbf, 0xb5, 0xe5, 0xcc, 0x03, 0x4b, 0x62,
    0xd9, 0x62, 0xeb, 0xcb, 0x29, 0xea, 0xdd, 0xb6, 0x8d, 0x2e, 0x0f, 0xad, 0x7e, 0x7f, 0xaf, 0xac,
    0xe9, 0x84, 0xc3, 0xee, 0x7d, 0x69, 0xfc, 0x49, 0x58, 0xfb, 0x14, 0xd2, 0x7d, 0x45, 0xac, 0xa6,
    0x52, 0x45, 0x6f, 0xab, 0x55, 0x32, 0x27, 0x81, 0x64, 0xe9, 0xb5, 0xea, 0xe3, 0xc8, 0x58, 0x3a,
    0x69, 0xa7, 0x72, 0xcc, 0x99, 0xae, 0xcf, 0xc3, 0x0d, 0xd3, 0x68, 0x0f, 0xfe, 0x7b, 0x21, 0xbc,
    0x9b, 0xfb, 0x26, 0xa6, 0x25, 0xf1, 0x1b, 0x3b, 0xf9, 0xf6, 0x8f, 0xe1, 0x26, 0x6e, 0x46, 0xf5,
    0xf4, 0x0f, 0xca, 0xbf, 0xd2, 0x6e, 0x4b, 0xb7, 0x55, 0xee, 0x2f, 0xbc, 0x7b, 0x01, 0x76
};
#endif

PyTypeObject *init_QApplication(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX].type;

    Shiboken::AutoDecRef Sbk_QApplication_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGuiApplication_IDX]))));

    _Sbk_QApplication_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QApplication",
        "QApplication*",
        &Sbk_QApplication_spec,
        &Shiboken::callCppDestructor< QApplication >,
        Sbk_QApplication_Type_bases.object(),
        0);
    auto *pyType = Sbk_QApplication_TypeF(); // references _Sbk_QApplication_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QApplication_SignatureStrings);
#else
    InitSignatureBytes(pyType, QApplication_SignatureBytes, QApplication_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QApplication_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QApplication_PythonToCpp_QApplication_PTR,
        is_QApplication_PythonToCpp_QApplication_PTR_Convertible,
        QApplication_PTR_CppToPython_QApplication);

    Shiboken::Conversions::registerConverterName(converter, "QApplication");
    Shiboken::Conversions::registerConverterName(converter, "QApplication*");
    Shiboken::Conversions::registerConverterName(converter, "QApplication&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QApplication).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QApplicationWrapper).name());


    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QApplication_TypeF(), &Sbk_QApplication_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::QApplication::staticMetaObject);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QApplication::staticMetaObject, sizeof(QApplicationWrapper));

    return pyType;
}

