// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qcolormap_wrapper.h"

// Argument includes
#include <QList>
#include <QtGui/qcolor.h>
#include <QtWidgets/qcolormap.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QColormap_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QColormap >()))
        return -1;

    ::QColormap *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QColormap", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QColormap::QColormap(QColormap)
    if (numArgs == 1
        && (pyArgs[0] != Py_None && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QColormap_IDX]), (pyArgs[0]))))) {
        overloadId = 0; // QColormap(QColormap)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QColormap_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWidgetsTypeStructs[SBK_QColormap_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QColormap *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QColormap(QColormap)
            cptr = new ::QColormap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QColormap >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QColormap_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QColormapFunc_cleanup(PyObject *self)
{
    SBK_UNUSED(self)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cleanup()
        ::QColormap::cleanup();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QColormapFunc_colorAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColormap *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QColormap_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QColormap::colorAt(uint)const->const QColor
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArg)))) {
        overloadId = 0; // colorAt(uint)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "colorAt", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QColormap_IDX]);

    // Call function/method
    {
        uint cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // colorAt(uint)const
            const QColor cppResult = const_cast<const ::QColormap *>(cppSelf)->colorAt(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColormapFunc_colormap(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColormap *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QColormap_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // colormap()const
        const QList<QColor> cppResult = const_cast<const ::QColormap *>(cppSelf)->colormap();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QColor_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColormapFunc_depth(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColormap *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QColormap_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // depth()const
        int cppResult = const_cast<const ::QColormap *>(cppSelf)->depth();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColormapFunc_initialize(PyObject *self)
{
    SBK_UNUSED(self)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // initialize()
        ::QColormap::initialize();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QColormapFunc_instance(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "instance", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QColormap_IDX]);

    if (PyArg_ParseTuple(args, "|O:instance", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QColormap::instance(int=)->QColormap
    if (numArgs == 0) {
        overloadId = 0; // instance(int)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // instance(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "instance", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QColormap_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_screen = Shiboken::String::createStaticString("screen");
            if (PyDict_Contains(kwds, key_screen) != 0) {
                value = PyDict_GetItem(kwds, key_screen);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_screen);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "instance", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QColormap_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "instance", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QColormap_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_screen);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "instance", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QColormap_IDX]);
            }
        }
        int cppArg0 = -1;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // instance(int)
            QColormap cppResult = ::QColormap::instance(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QColormap_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColormapFunc_mode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColormap *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QColormap_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // mode()const
        QColormap::Mode cppResult = const_cast<const ::QColormap *>(cppSelf)->mode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QColormap_Mode_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColormapFunc_pixel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColormap *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QColormap_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QColormap::pixel(QColor)const->uint
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArg)))) {
        overloadId = 0; // pixel(QColor)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "pixel", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QColormap_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QColor cppArg0_local;
        ::QColor *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // pixel(QColor)const
            uint cppResult = const_cast<const ::QColormap *>(cppSelf)->pixel(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColormapFunc_size(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColormap *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QColormap_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // size()const
        int cppResult = const_cast<const ::QColormap *>(cppSelf)->size();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColormap__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QColormap *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QColormap_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QColormap_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QColormap_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QColormap_EnumFlagInfo[] = {
    "Mode:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QColormap_methods[] = {
    {"cleanup", reinterpret_cast<PyCFunction>(Sbk_QColormapFunc_cleanup), METH_NOARGS|METH_STATIC, nullptr},
    {"colorAt", reinterpret_cast<PyCFunction>(Sbk_QColormapFunc_colorAt), METH_O, nullptr},
    {"colormap", reinterpret_cast<PyCFunction>(Sbk_QColormapFunc_colormap), METH_NOARGS, nullptr},
    {"depth", reinterpret_cast<PyCFunction>(Sbk_QColormapFunc_depth), METH_NOARGS, nullptr},
    {"initialize", reinterpret_cast<PyCFunction>(Sbk_QColormapFunc_initialize), METH_NOARGS|METH_STATIC, nullptr},
    {"instance", reinterpret_cast<PyCFunction>(Sbk_QColormapFunc_instance), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"mode", reinterpret_cast<PyCFunction>(Sbk_QColormapFunc_mode), METH_NOARGS, nullptr},
    {"pixel", reinterpret_cast<PyCFunction>(Sbk_QColormapFunc_pixel), METH_O, nullptr},
    {"size", reinterpret_cast<PyCFunction>(Sbk_QColormapFunc_size), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QColormap__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QColormap_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QColormap_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QColormap_Type = nullptr;
static PyTypeObject *Sbk_QColormap_TypeF(void)
{
    return _Sbk_QColormap_Type;
}

static PyType_Slot Sbk_QColormap_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QColormap_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QColormap_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QColormap_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QColormap_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QColormap_spec = {
    "2:PySide6.QtWidgets.QColormap",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QColormap_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QColormap_Mode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QColormap::Mode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QColormap::Mode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QColormap_Mode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QColormap_Mode_IDX])))
        return Enum_PythonToCpp_QColormap_Mode;
    return {};
}

static PyObject *QColormap_Mode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QColormap::Mode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QColormap::Mode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QColormap_Mode_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QColormap_PythonToCpp_QColormap_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QColormap_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QColormap_PythonToCpp_QColormap_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QColormap_TypeF()))
        return QColormap_PythonToCpp_QColormap_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QColormap_PTR_CppToPython_QColormap(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QColormap_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QColormap_COPY_CppToPython_QColormap(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QColormap *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QColormap_TypeF(), new ::QColormap(*source), true, true);
}

// Python to C++ copy conversion.
static void QColormap_PythonToCpp_QColormap_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QColormap *>(cppOut) = *reinterpret_cast< ::QColormap *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QColormap_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QColormap_PythonToCpp_QColormap_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QColormap_TypeF()))
        return QColormap_PythonToCpp_QColormap_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QColormap_SignatureStrings[] = {
    "PySide6.QtWidgets.QColormap(self,colormap:PySide6.QtWidgets.QColormap)",
    "PySide6.QtWidgets.QColormap.cleanup()",
    "PySide6.QtWidgets.QColormap.colorAt(self,pixel:uint)->PySide6.QtGui.QColor",
    "PySide6.QtWidgets.QColormap.colormap(self)->QList[PySide6.QtGui.QColor]",
    "PySide6.QtWidgets.QColormap.depth(self)->int",
    "PySide6.QtWidgets.QColormap.initialize()",
    "PySide6.QtWidgets.QColormap.instance(screen:int=-1)->PySide6.QtWidgets.QColormap",
    "PySide6.QtWidgets.QColormap.mode(self)->PySide6.QtWidgets.QColormap.Mode",
    "PySide6.QtWidgets.QColormap.pixel(self,color:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])->uint",
    "PySide6.QtWidgets.QColormap.size(self)->int",
    "PySide6.QtWidgets.QColormap.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QColormap_SignatureByteSize = 265;
static constexpr uint8_t QColormap_SignatureBytes[265] = {
    0x78, 0xda, 0x8d, 0x91, 0x41, 0x4b, 0xc3, 0x30, 0x14, 0xc7, 0xef, 0xfb, 0x14, 0x3d, 0x76, 0xd0,
    0x15, 0x06, 0x63, 0x87, 0x82, 0x82, 0xec, 0xb0, 0xcb, 0x06, 0xab, 0x45, 0x3d, 0xc8, 0x28, 0x59,
    0xfb, 0xac, 0x0f, 0xb2, 0x97, 0x90, 0xbc, 0x80, 0xf5, 0xd3, 0x9b, 0x69, 0x83, 0x53, 0x67, 0xba,
    0x53, 0x12, 0xfa, 0x7b, 0xbf, 0xe6, 0xff, 0xcf, 0xae, 0xaf, 0xb0, 0x85, 0x65, 0x5e, 0xf2, 0x13,
    0xb6, 0x1d, 0xb0, 0xcd, 0xcb, 0x95, 0x92, 0xca, 0x1c, 0x85, 0x4e, 0x2d, 0xc8, 0x97, 0xac, 0x19,
    0x4e, 0xc5, 0xee, 0x7f, 0x72, 0x3a, 0x89, 0x7c, 0xcc, 0x1b, 0x09, 0x82, 0x9c, 0x4e, 0x47, 0xa8,
    0xd3, 0xe6, 0x8e, 0xbf, 0x7e, 0xaa, 0xf1, 0x0d, 0x64, 0xe1, 0x90, 0x78, 0x3a, 0xbb, 0xfd, 0x9e,
    0x5a, 0x3b, 0x1c, 0x26, 0xc6, 0x55, 0x21, 0x80, 0x17, 0x94, 0x1b, 0xb4, 0xfc, 0x7c, 0x49, 0xb3,
    0x8f, 0x7a, 0x5a, 0xd0, 0xfc, 0x1a, 0x24, 0xfe, 0x2e, 0x51, 0x18, 0x09, 0x19, 0x85, 0xc4, 0x77,
    0x18, 0x09, 0x8a, 0x64, 0x59, 0x50, 0x03, 0xa9, 0x6d, 0x0c, 0x00, 0x15, 0x5e, 0x7c, 0x33, 0x9b,
    0xff, 0xc8, 0xf9, 0x67, 0x28, 0x2a, 0x3c, 0xaa, 0x16, 0xc2, 0x2d, 0x63, 0xdc, 0xd6, 0x73, 0x51,
    0xd1, 0x67, 0xeb, 0x67, 0xaf, 0x5e, 0x70, 0xaf, 0x91, 0xba, 0xfc, 0x81, 0x50, 0xd1, 0xc5, 0xfe,
    0xb2, 0xa4, 0xdc, 0x08, 0x46, 0x9a, 0x57, 0x6c, 0x3c, 0x99, 0x25, 0xbf, 0xa0, 0xfb, 0xee, 0x20,
    0x96, 0x0b, 0x4f, 0x3d, 0x0a, 0x83, 0x82, 0xf8, 0x1c, 0x58, 0x29, 0x03, 0x7e, 0xc9, 0xd7, 0x52,
    0x1d, 0x84, 0x0c, 0xba, 0x20, 0x72, 0x64, 0xb1, 0x23, 0x68, 0x13, 0x5f, 0xcf, 0xde, 0x07, 0x73,
    0x63, 0xfd, 0xdb, 0x53, 0xf3, 0x57, 0xbe, 0x55, 0x5d, 0x37, 0x4a, 0xf7, 0x75, 0x1d, 0xf8, 0x21,
    0x67, 0xe5, 0x4f, 0x93, 0x0f, 0x6a, 0x4a, 0x18, 0x51
};
#endif

PyTypeObject *init_QColormap(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QColormap_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QColormap_IDX].type;

    Shiboken::AutoDecRef Sbk_QColormap_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QColormap_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QColormap",
        "QColormap",
        &Sbk_QColormap_spec,
        &Shiboken::callCppDestructor< ::QColormap >,
        Sbk_QColormap_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QColormap_TypeF(); // references _Sbk_QColormap_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QColormap_SignatureStrings);
#else
    InitSignatureBytes(pyType, QColormap_SignatureBytes, QColormap_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QColormap_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QColormap_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QColormap_PythonToCpp_QColormap_PTR,
        is_QColormap_PythonToCpp_QColormap_PTR_Convertible,
        QColormap_PTR_CppToPython_QColormap,
        QColormap_COPY_CppToPython_QColormap);

    Shiboken::Conversions::registerConverterName(converter, "QColormap");
    Shiboken::Conversions::registerConverterName(converter, "QColormap*");
    Shiboken::Conversions::registerConverterName(converter, "QColormap&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QColormap).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QColormap_PythonToCpp_QColormap_COPY,
        is_QColormap_PythonToCpp_QColormap_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QColormap_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Mode'.
    const char *Mode_Initializer[] = {
        "Direct",
        "Indexed",
        "Gray",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Mode_InitializerValues[] = {
        uint8_t(QColormap::Mode::Direct),  //  0x00  0
        uint8_t(QColormap::Mode::Indexed), //  0x01  1
        uint8_t(QColormap::Mode::Gray)     //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QColormap_TypeF(),
        "2:PySide6.QtWidgets.QColormap.Mode",
        Mode_Initializer, Mode_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QColormap_Mode_IDX].type = EType;
    // Register converter for enum 'QColormap::Mode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QColormap_Mode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QColormap_Mode,
            is_Enum_PythonToCpp_QColormap_Mode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QColormap::Mode");
        Shiboken::Conversions::registerConverterAlias(converter, "Mode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Mode' enum.

    qRegisterMetaType< ::QColormap::Mode >("QColormap::Mode");

    return pyType;
}
