// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qgraphicslayoutitem_wrapper.h"

// Argument includes
#include <QtWidgets/qgraphicsitem.h>
#include <QtWidgets/qgraphicslayoutitem.h>
#include <QtWidgets/qsizepolicy.h>
#include <qnamespace.h>
#include <qrect.h>
#include <qsize.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QGraphicsLayoutItemWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QGraphicsLayoutItemWrapper::QGraphicsLayoutItemWrapper(::QGraphicsLayoutItem * parent, bool isLayout) : QGraphicsLayoutItem(parent, isLayout)
{
}

void QGraphicsLayoutItemWrapper::getContentsMargins(qreal * left, qreal * top, qreal * right, qreal * bottom) const
{
    if (m_PyMethodCache[0]) {
        return this->::QGraphicsLayoutItem::getContentsMargins(left, top, right, bottom);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "getContentsMargins";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QGraphicsLayoutItem::getContentsMargins(left, top, right, bottom);
    }

    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphicsLayoutItem", funcName);
        return;
    }

    // Begin code injection
    // TEMPLATE - fix_native_return_number*,number*,number*,number* - START
    PyObject* _obj = pyResult.object();
    Shiboken::AutoDecRef _obj0(PySequence_GetItem(_obj, 0));
    Shiboken::AutoDecRef _obj1(PySequence_GetItem(_obj, 1));
    Shiboken::AutoDecRef _obj2(PySequence_GetItem(_obj, 2));
    Shiboken::AutoDecRef _obj3(PySequence_GetItem(_obj, 3));
    if (!PySequence_Check(_obj)
        || PySequence_Size(_obj) != 4
        || !PyNumber_Check(_obj0)
        || !PyNumber_Check(_obj1)
        || !PyNumber_Check(_obj2)
        || !PyNumber_Check(_obj3)) {
        PyErr_SetString(PyExc_TypeError, "Sequence of 4 numbers expected");
    } else {
        Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), _obj0, (left));
        Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), _obj1, (top));
        Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), _obj2, (right));
        Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), _obj3, (bottom));
    }
    // TEMPLATE - fix_native_return_number*,number*,number*,number* - END
    // End of code injection

}

bool QGraphicsLayoutItemWrapper::isEmpty() const
{
    if (m_PyMethodCache[1])
        return this->::QGraphicsLayoutItem::isEmpty();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "isEmpty";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QGraphicsLayoutItem::isEmpty();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphicsLayoutItem", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QGraphicsLayoutItem", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QGraphicsLayoutItemWrapper::setGeometry(const ::QRectF & rect)
{
    if (m_PyMethodCache[2]) {
        return this->::QGraphicsLayoutItem::setGeometry(rect);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setGeometry";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QGraphicsLayoutItem::setGeometry(rect);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &rect)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &rect)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphicsLayoutItem", funcName);
        return;
    }
}

::QSizeF QGraphicsLayoutItemWrapper::sizeHint(::Qt::SizeHint which, const ::QSizeF & constraint) const
{
    if (m_PyMethodCache[3]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QGraphicsLayoutItem.sizeHint");
        return {};
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return {};
    static PyObject *nameCache[2] = {};
    static const char *funcName = "sizeHint";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        Shiboken::Errors::setPureVirtualMethodError("QGraphicsLayoutItem.sizeHint");
        return {};
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_SizeHint_IDX])))->converter, &which),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), &constraint)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_SizeHint_IDX])))->converter, &which),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), &constraint)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphicsLayoutItem", funcName);
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QGraphicsLayoutItem", funcName, Shiboken::SbkType< QSizeF >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QSizeF cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QGraphicsLayoutItemWrapper::updateGeometry()
{
    if (m_PyMethodCache[4]) {
        return this->::QGraphicsLayoutItem::updateGeometry();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "updateGeometry";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QGraphicsLayoutItem::updateGeometry();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphicsLayoutItem", funcName);
        return;
    }
}

QGraphicsLayoutItemWrapper::~QGraphicsLayoutItemWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGraphicsLayoutItem_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QGraphicsLayoutItem");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QGraphicsLayoutItem >()))
        return -1;

    QGraphicsLayoutItemWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]);

    if (PyArg_ParseTuple(args, "|OO:QGraphicsLayoutItem", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QGraphicsLayoutItem::QGraphicsLayoutItem(QGraphicsLayoutItem*=,bool=)
    if (numArgs == 0) {
        overloadId = 0; // QGraphicsLayoutItem(QGraphicsLayoutItem*,bool)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // QGraphicsLayoutItem(QGraphicsLayoutItem*,bool)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 0; // QGraphicsLayoutItem(QGraphicsLayoutItem*,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            static PyObject *const key_isLayout = Shiboken::String::createStaticString("isLayout");
            if (PyDict_Contains(kwds, key_isLayout) != 0) {
                value = PyDict_GetItem(kwds, key_isLayout);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_isLayout);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_isLayout);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QGraphicsLayoutItem *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);
        bool cppArg1 = false;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QGraphicsLayoutItem(QGraphicsLayoutItem*,bool)
            cptr = new QGraphicsLayoutItemWrapper(cppArg0, cppArg1);
            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QGraphicsLayoutItem >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QGraphicsLayoutItemFunc_contentsRect(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsLayoutItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // contentsRect()const
        QRectF cppResult = const_cast<const ::QGraphicsLayoutItem *>(cppSelf)->contentsRect();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsLayoutItemFunc_effectiveSizeHint(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsLayoutItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "effectiveSizeHint", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]);

    if (PyArg_ParseTuple(args, "|OO:effectiveSizeHint", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsLayoutItem::effectiveSizeHint(Qt::SizeHint,const QSizeF&=)const->QSizeF
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_SizeHint_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // effectiveSizeHint(Qt::SizeHint,QSizeF)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), (pyArgs[1])))) {
            overloadId = 0; // effectiveSizeHint(Qt::SizeHint,QSizeF)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "effectiveSizeHint", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_constraint = Shiboken::String::createStaticString("constraint");
            if (PyDict_Contains(kwds, key_constraint) != 0) {
                value = PyDict_GetItem(kwds, key_constraint);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_constraint);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "effectiveSizeHint", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "effectiveSizeHint", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_constraint);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "effectiveSizeHint", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]);
            }
        }
        ::Qt::SizeHint cppArg0{Qt::MinimumSize};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QSizeF cppArg1_local = QSizeF();
        ::QSizeF *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1]) {
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // effectiveSizeHint(Qt::SizeHint,QSizeF)const
            QSizeF cppResult = const_cast<const ::QGraphicsLayoutItem *>(cppSelf)->effectiveSizeHint(cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsLayoutItemFunc_geometry(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsLayoutItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // geometry()const
        QRectF cppResult = const_cast<const ::QGraphicsLayoutItem *>(cppSelf)->geometry();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsLayoutItemFunc_getContentsMargins(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsLayoutItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // getContentsMargins(qreal*,qreal*,qreal*,qreal*)const
            // Begin code injection
            // TEMPLATE - fix_number*,number*,number*,number* - START
            qreal a, b, c, d;
            cppSelf->::QGraphicsLayoutItem::getContentsMargins(&a, &b, &c, &d);
            // TEMPLATE - tuple_abcd_same_type - START
            pyResult = PyTuple_New(4);
            PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &a));
            PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &b));
            PyTuple_SetItem(pyResult, 2, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &c));
            PyTuple_SetItem(pyResult, 3, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &d));
            // TEMPLATE - tuple_abcd_same_type - END
            // TEMPLATE - fix_number*,number*,number*,number* - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsLayoutItemFunc_graphicsItem(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsLayoutItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // graphicsItem()const
        QGraphicsItem * cppResult = const_cast<const ::QGraphicsLayoutItem *>(cppSelf)->graphicsItem();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItem_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsLayoutItemFunc_isEmpty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsLayoutItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isEmpty()const
        bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QGraphicsLayoutItem *>(cppSelf)->::QGraphicsLayoutItem::isEmpty()
            : const_cast<const ::QGraphicsLayoutItem *>(cppSelf)->isEmpty();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsLayoutItemFunc_isLayout(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsLayoutItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isLayout()const
        bool cppResult = const_cast<const ::QGraphicsLayoutItem *>(cppSelf)->isLayout();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsLayoutItemFunc_maximumHeight(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsLayoutItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maximumHeight()const
        qreal cppResult = const_cast<const ::QGraphicsLayoutItem *>(cppSelf)->maximumHeight();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsLayoutItemFunc_maximumSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsLayoutItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maximumSize()const
        QSizeF cppResult = const_cast<const ::QGraphicsLayoutItem *>(cppSelf)->maximumSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsLayoutItemFunc_maximumWidth(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsLayoutItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maximumWidth()const
        qreal cppResult = const_cast<const ::QGraphicsLayoutItem *>(cppSelf)->maximumWidth();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsLayoutItemFunc_minimumHeight(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsLayoutItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // minimumHeight()const
        qreal cppResult = const_cast<const ::QGraphicsLayoutItem *>(cppSelf)->minimumHeight();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsLayoutItemFunc_minimumSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsLayoutItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // minimumSize()const
        QSizeF cppResult = const_cast<const ::QGraphicsLayoutItem *>(cppSelf)->minimumSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsLayoutItemFunc_minimumWidth(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsLayoutItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // minimumWidth()const
        qreal cppResult = const_cast<const ::QGraphicsLayoutItem *>(cppSelf)->minimumWidth();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsLayoutItemFunc_ownedByLayout(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsLayoutItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ownedByLayout()const
        bool cppResult = const_cast<const ::QGraphicsLayoutItem *>(cppSelf)->ownedByLayout();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsLayoutItemFunc_parentLayoutItem(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsLayoutItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // parentLayoutItem()const
        QGraphicsLayoutItem * cppResult = const_cast<const ::QGraphicsLayoutItem *>(cppSelf)->parentLayoutItem();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsLayoutItemFunc_preferredHeight(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsLayoutItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // preferredHeight()const
        qreal cppResult = const_cast<const ::QGraphicsLayoutItem *>(cppSelf)->preferredHeight();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsLayoutItemFunc_preferredSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsLayoutItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // preferredSize()const
        QSizeF cppResult = const_cast<const ::QGraphicsLayoutItem *>(cppSelf)->preferredSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsLayoutItemFunc_preferredWidth(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsLayoutItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // preferredWidth()const
        qreal cppResult = const_cast<const ::QGraphicsLayoutItem *>(cppSelf)->preferredWidth();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsLayoutItemFunc_setGeometry(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsLayoutItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsLayoutItem::setGeometry(QRectF)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArg)))) {
        overloadId = 0; // setGeometry(QRectF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setGeometry", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRectF cppArg0_local;
        ::QRectF *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setGeometry(QRectF)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsLayoutItem::setGeometry(*cppArg0)
                : cppSelf->setGeometry(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsLayoutItemFunc_setGraphicsItem(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsLayoutItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsLayoutItem::setGraphicsItem(QGraphicsItem*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItem_IDX]), (pyArg)))) {
        overloadId = 0; // setGraphicsItem(QGraphicsItem*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setGraphicsItem", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGraphicsItem *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setGraphicsItem(QGraphicsItem*)
            cppSelf->setGraphicsItem(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsLayoutItemFunc_setMaximumHeight(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsLayoutItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsLayoutItem::setMaximumHeight(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setMaximumHeight(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMaximumHeight", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMaximumHeight(qreal)
            cppSelf->setMaximumHeight(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsLayoutItemFunc_setMaximumSize(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsLayoutItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setMaximumSize", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsLayoutItem::setMaximumSize(QSizeF)
    // 1: QGraphicsLayoutItem::setMaximumSize(qreal,qreal)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))) {
        overloadId = 1; // setMaximumSize(qreal,qreal)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), (pyArgs[0])))) {
        overloadId = 0; // setMaximumSize(QSizeF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setMaximumSize", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setMaximumSize(const QSizeF &size)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QSizeF cppArg0_local;
            ::QSizeF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setMaximumSize(QSizeF)
                cppSelf->setMaximumSize(*cppArg0);
            }
            break;
        }
        case 1: // setMaximumSize(qreal w, qreal h)
        {
            qreal cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setMaximumSize(qreal,qreal)
                cppSelf->setMaximumSize(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsLayoutItemFunc_setMaximumWidth(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsLayoutItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsLayoutItem::setMaximumWidth(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setMaximumWidth(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMaximumWidth", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMaximumWidth(qreal)
            cppSelf->setMaximumWidth(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsLayoutItemFunc_setMinimumHeight(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsLayoutItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsLayoutItem::setMinimumHeight(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setMinimumHeight(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMinimumHeight", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMinimumHeight(qreal)
            cppSelf->setMinimumHeight(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsLayoutItemFunc_setMinimumSize(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsLayoutItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setMinimumSize", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsLayoutItem::setMinimumSize(QSizeF)
    // 1: QGraphicsLayoutItem::setMinimumSize(qreal,qreal)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))) {
        overloadId = 1; // setMinimumSize(qreal,qreal)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), (pyArgs[0])))) {
        overloadId = 0; // setMinimumSize(QSizeF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setMinimumSize", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setMinimumSize(const QSizeF &size)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QSizeF cppArg0_local;
            ::QSizeF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setMinimumSize(QSizeF)
                cppSelf->setMinimumSize(*cppArg0);
            }
            break;
        }
        case 1: // setMinimumSize(qreal w, qreal h)
        {
            qreal cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setMinimumSize(qreal,qreal)
                cppSelf->setMinimumSize(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsLayoutItemFunc_setMinimumWidth(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsLayoutItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsLayoutItem::setMinimumWidth(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setMinimumWidth(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMinimumWidth", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMinimumWidth(qreal)
            cppSelf->setMinimumWidth(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsLayoutItemFunc_setOwnedByLayout(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsLayoutItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsLayoutItem::setOwnedByLayout(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setOwnedByLayout(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOwnedByLayout", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOwnedByLayout(bool)
            cppSelf->setOwnedByLayout(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsLayoutItemFunc_setParentLayoutItem(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsLayoutItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsLayoutItem::setParentLayoutItem(QGraphicsLayoutItem*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), (pyArg)))) {
        overloadId = 0; // setParentLayoutItem(QGraphicsLayoutItem*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setParentLayoutItem", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGraphicsLayoutItem *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setParentLayoutItem(QGraphicsLayoutItem*)
            cppSelf->setParentLayoutItem(cppArg0);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArg);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsLayoutItemFunc_setPreferredHeight(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsLayoutItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsLayoutItem::setPreferredHeight(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setPreferredHeight(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPreferredHeight", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPreferredHeight(qreal)
            cppSelf->setPreferredHeight(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsLayoutItemFunc_setPreferredSize(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsLayoutItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setPreferredSize", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsLayoutItem::setPreferredSize(QSizeF)
    // 1: QGraphicsLayoutItem::setPreferredSize(qreal,qreal)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))) {
        overloadId = 1; // setPreferredSize(qreal,qreal)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), (pyArgs[0])))) {
        overloadId = 0; // setPreferredSize(QSizeF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setPreferredSize", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setPreferredSize(const QSizeF &size)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QSizeF cppArg0_local;
            ::QSizeF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setPreferredSize(QSizeF)
                cppSelf->setPreferredSize(*cppArg0);
            }
            break;
        }
        case 1: // setPreferredSize(qreal w, qreal h)
        {
            qreal cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setPreferredSize(qreal,qreal)
                cppSelf->setPreferredSize(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsLayoutItemFunc_setPreferredWidth(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsLayoutItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsLayoutItem::setPreferredWidth(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setPreferredWidth(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPreferredWidth", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPreferredWidth(qreal)
            cppSelf->setPreferredWidth(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsLayoutItemFunc_setSizePolicy(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsLayoutItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setSizePolicy", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:setSizePolicy", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsLayoutItem::setSizePolicy(QSizePolicy::Policy,QSizePolicy::Policy,QSizePolicy::ControlType=)
    // 1: QGraphicsLayoutItem::setSizePolicy(QSizePolicy)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QSizePolicy_IDX]), (pyArgs[0])))) {
        overloadId = 1; // setSizePolicy(QSizePolicy)
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QSizePolicy_Policy_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QSizePolicy_Policy_IDX])))->converter, (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // setSizePolicy(QSizePolicy::Policy,QSizePolicy::Policy,QSizePolicy::ControlType)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QSizePolicy_ControlType_IDX])))->converter, (pyArgs[2])))) {
            overloadId = 0; // setSizePolicy(QSizePolicy::Policy,QSizePolicy::Policy,QSizePolicy::ControlType)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setSizePolicy", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setSizePolicy(QSizePolicy::Policy hPolicy, QSizePolicy::Policy vPolicy, QSizePolicy::ControlType controlType)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_controlType = Shiboken::String::createStaticString("controlType");
                if (PyDict_Contains(kwds, key_controlType) != 0) {
                    value = PyDict_GetItem(kwds, key_controlType);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_controlType);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "setSizePolicy", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QSizePolicy_ControlType_IDX])))->converter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "setSizePolicy", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_controlType);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "setSizePolicy", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]);
                }
            }
            ::QSizePolicy::Policy cppArg0{QSizePolicy::Fixed};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QSizePolicy::Policy cppArg1{QSizePolicy::Fixed};
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QSizePolicy::ControlType cppArg2(QSizePolicy::DefaultType);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setSizePolicy(QSizePolicy::Policy,QSizePolicy::Policy,QSizePolicy::ControlType)
                cppSelf->setSizePolicy(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
        case 1: // setSizePolicy(const QSizePolicy &policy)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setSizePolicy", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QSizePolicy cppArg0_local;
            ::QSizePolicy *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setSizePolicy(QSizePolicy)
                cppSelf->setSizePolicy(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsLayoutItemFunc_sizeHint(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsLayoutItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "sizeHint", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]);

    if (PyArg_ParseTuple(args, "|OO:sizeHint", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsLayoutItem::sizeHint(Qt::SizeHint,const QSizeF&=)const->QSizeF
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_SizeHint_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // sizeHint(Qt::SizeHint,QSizeF)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), (pyArgs[1])))) {
            overloadId = 0; // sizeHint(Qt::SizeHint,QSizeF)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "sizeHint", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_constraint = Shiboken::String::createStaticString("constraint");
            if (PyDict_Contains(kwds, key_constraint) != 0) {
                value = PyDict_GetItem(kwds, key_constraint);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_constraint);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "sizeHint", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "sizeHint", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_constraint);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "sizeHint", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]);
            }
        }
        ::Qt::SizeHint cppArg0{Qt::MinimumSize};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QSizeF cppArg1_local = QSizeF();
        ::QSizeF *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1]) {
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // sizeHint(Qt::SizeHint,QSizeF)const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QGraphicsLayoutItem.sizeHint");
                return {};
            }
            QSizeF cppResult = const_cast<const ::QGraphicsLayoutItem *>(cppSelf)->sizeHint(cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsLayoutItemFunc_sizePolicy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsLayoutItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sizePolicy()const
        QSizePolicy cppResult = const_cast<const ::QGraphicsLayoutItem *>(cppSelf)->sizePolicy();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QSizePolicy_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsLayoutItemFunc_updateGeometry(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsLayoutItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // updateGeometry()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QGraphicsLayoutItem::updateGeometry()
            : cppSelf->updateGeometry();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QGraphicsLayoutItem_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QGraphicsLayoutItem_methods[] = {
    {"contentsRect", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutItemFunc_contentsRect), METH_NOARGS, nullptr},
    {"effectiveSizeHint", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutItemFunc_effectiveSizeHint), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"geometry", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutItemFunc_geometry), METH_NOARGS, nullptr},
    {"getContentsMargins", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutItemFunc_getContentsMargins), METH_NOARGS, nullptr},
    {"graphicsItem", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutItemFunc_graphicsItem), METH_NOARGS, nullptr},
    {"isEmpty", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutItemFunc_isEmpty), METH_NOARGS, nullptr},
    {"isLayout", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutItemFunc_isLayout), METH_NOARGS, nullptr},
    {"maximumHeight", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutItemFunc_maximumHeight), METH_NOARGS, nullptr},
    {"maximumSize", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutItemFunc_maximumSize), METH_NOARGS, nullptr},
    {"maximumWidth", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutItemFunc_maximumWidth), METH_NOARGS, nullptr},
    {"minimumHeight", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutItemFunc_minimumHeight), METH_NOARGS, nullptr},
    {"minimumSize", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutItemFunc_minimumSize), METH_NOARGS, nullptr},
    {"minimumWidth", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutItemFunc_minimumWidth), METH_NOARGS, nullptr},
    {"ownedByLayout", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutItemFunc_ownedByLayout), METH_NOARGS, nullptr},
    {"parentLayoutItem", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutItemFunc_parentLayoutItem), METH_NOARGS, nullptr},
    {"preferredHeight", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutItemFunc_preferredHeight), METH_NOARGS, nullptr},
    {"preferredSize", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutItemFunc_preferredSize), METH_NOARGS, nullptr},
    {"preferredWidth", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutItemFunc_preferredWidth), METH_NOARGS, nullptr},
    {"setGeometry", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutItemFunc_setGeometry), METH_O, nullptr},
    {"setGraphicsItem", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutItemFunc_setGraphicsItem), METH_O, nullptr},
    {"setMaximumHeight", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutItemFunc_setMaximumHeight), METH_O, nullptr},
    {"setMaximumSize", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutItemFunc_setMaximumSize), METH_VARARGS, nullptr},
    {"setMaximumWidth", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutItemFunc_setMaximumWidth), METH_O, nullptr},
    {"setMinimumHeight", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutItemFunc_setMinimumHeight), METH_O, nullptr},
    {"setMinimumSize", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutItemFunc_setMinimumSize), METH_VARARGS, nullptr},
    {"setMinimumWidth", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutItemFunc_setMinimumWidth), METH_O, nullptr},
    {"setOwnedByLayout", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutItemFunc_setOwnedByLayout), METH_O, nullptr},
    {"setParentLayoutItem", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutItemFunc_setParentLayoutItem), METH_O, nullptr},
    {"setPreferredHeight", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutItemFunc_setPreferredHeight), METH_O, nullptr},
    {"setPreferredSize", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutItemFunc_setPreferredSize), METH_VARARGS, nullptr},
    {"setPreferredWidth", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutItemFunc_setPreferredWidth), METH_O, nullptr},
    {"setSizePolicy", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutItemFunc_setSizePolicy), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"sizeHint", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutItemFunc_sizeHint), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"sizePolicy", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutItemFunc_sizePolicy), METH_NOARGS, nullptr},
    {"updateGeometry", reinterpret_cast<PyCFunction>(Sbk_QGraphicsLayoutItemFunc_updateGeometry), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QGraphicsLayoutItem_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QGraphicsLayoutItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QGraphicsLayoutItemWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QGraphicsLayoutItem_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QGraphicsLayoutItem_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QGraphicsLayoutItem_Type = nullptr;
static PyTypeObject *Sbk_QGraphicsLayoutItem_TypeF(void)
{
    return _Sbk_QGraphicsLayoutItem_Type;
}

static PyType_Slot Sbk_QGraphicsLayoutItem_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QGraphicsLayoutItem_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QGraphicsLayoutItem_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QGraphicsLayoutItem_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QGraphicsLayoutItem_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QGraphicsLayoutItem_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QGraphicsLayoutItem_spec = {
    "2:PySide6.QtWidgets.QGraphicsLayoutItem",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QGraphicsLayoutItem_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QGraphicsLayoutItem_PythonToCpp_QGraphicsLayoutItem_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QGraphicsLayoutItem_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QGraphicsLayoutItem_PythonToCpp_QGraphicsLayoutItem_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QGraphicsLayoutItem_TypeF()))
        return QGraphicsLayoutItem_PythonToCpp_QGraphicsLayoutItem_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QGraphicsLayoutItem_PTR_CppToPython_QGraphicsLayoutItem(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QGraphicsLayoutItem *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QGraphicsLayoutItem_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QGraphicsLayoutItem_SignatureStrings[] = {
    "PySide6.QtWidgets.QGraphicsLayoutItem(self,parent:PySide6.QtWidgets.QGraphicsLayoutItem=nullptr,isLayout:bool=false)",
    "PySide6.QtWidgets.QGraphicsLayoutItem.contentsRect(self)->PySide6.QtCore.QRectF",
    "PySide6.QtWidgets.QGraphicsLayoutItem.effectiveSizeHint(self,which:PySide6.QtCore.Qt.SizeHint,constraint:typing.Union[PySide6.QtCore.QSizeF, PySide6.QtCore.QSize]=QSizeF())->PySide6.QtCore.QSizeF",
    "PySide6.QtWidgets.QGraphicsLayoutItem.geometry(self)->PySide6.QtCore.QRectF",
    "PySide6.QtWidgets.QGraphicsLayoutItem.getContentsMargins(self)->PyObject",
    "PySide6.QtWidgets.QGraphicsLayoutItem.graphicsItem(self)->PySide6.QtWidgets.QGraphicsItem",
    "PySide6.QtWidgets.QGraphicsLayoutItem.isEmpty(self)->bool",
    "PySide6.QtWidgets.QGraphicsLayoutItem.isLayout(self)->bool",
    "PySide6.QtWidgets.QGraphicsLayoutItem.maximumHeight(self)->qreal",
    "PySide6.QtWidgets.QGraphicsLayoutItem.maximumSize(self)->PySide6.QtCore.QSizeF",
    "PySide6.QtWidgets.QGraphicsLayoutItem.maximumWidth(self)->qreal",
    "PySide6.QtWidgets.QGraphicsLayoutItem.minimumHeight(self)->qreal",
    "PySide6.QtWidgets.QGraphicsLayoutItem.minimumSize(self)->PySide6.QtCore.QSizeF",
    "PySide6.QtWidgets.QGraphicsLayoutItem.minimumWidth(self)->qreal",
    "PySide6.QtWidgets.QGraphicsLayoutItem.ownedByLayout(self)->bool",
    "PySide6.QtWidgets.QGraphicsLayoutItem.parentLayoutItem(self)->PySide6.QtWidgets.QGraphicsLayoutItem",
    "PySide6.QtWidgets.QGraphicsLayoutItem.preferredHeight(self)->qreal",
    "PySide6.QtWidgets.QGraphicsLayoutItem.preferredSize(self)->PySide6.QtCore.QSizeF",
    "PySide6.QtWidgets.QGraphicsLayoutItem.preferredWidth(self)->qreal",
    "PySide6.QtWidgets.QGraphicsLayoutItem.setGeometry(self,rect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect])",
    "PySide6.QtWidgets.QGraphicsLayoutItem.setGraphicsItem(self,item:PySide6.QtWidgets.QGraphicsItem)",
    "PySide6.QtWidgets.QGraphicsLayoutItem.setMaximumHeight(self,height:qreal)",
    "1:PySide6.QtWidgets.QGraphicsLayoutItem.setMaximumSize(self,size:typing.Union[PySide6.QtCore.QSizeF, PySide6.QtCore.QSize])",
    "0:PySide6.QtWidgets.QGraphicsLayoutItem.setMaximumSize(self,w:qreal,h:qreal)",
    "PySide6.QtWidgets.QGraphicsLayoutItem.setMaximumWidth(self,width:qreal)",
    "PySide6.QtWidgets.QGraphicsLayoutItem.setMinimumHeight(self,height:qreal)",
    "1:PySide6.QtWidgets.QGraphicsLayoutItem.setMinimumSize(self,size:typing.Union[PySide6.QtCore.QSizeF, PySide6.QtCore.QSize])",
    "0:PySide6.QtWidgets.QGraphicsLayoutItem.setMinimumSize(self,w:qreal,h:qreal)",
    "PySide6.QtWidgets.QGraphicsLayoutItem.setMinimumWidth(self,width:qreal)",
    "PySide6.QtWidgets.QGraphicsLayoutItem.setOwnedByLayout(self,ownedByLayout:bool)",
    "PySide6.QtWidgets.QGraphicsLayoutItem.setParentLayoutItem(self,parent:PySide6.QtWidgets.QGraphicsLayoutItem)",
    "PySide6.QtWidgets.QGraphicsLayoutItem.setPreferredHeight(self,height:qreal)",
    "1:PySide6.QtWidgets.QGraphicsLayoutItem.setPreferredSize(self,size:typing.Union[PySide6.QtCore.QSizeF, PySide6.QtCore.QSize])",
    "0:PySide6.QtWidgets.QGraphicsLayoutItem.setPreferredSize(self,w:qreal,h:qreal)",
    "PySide6.QtWidgets.QGraphicsLayoutItem.setPreferredWidth(self,width:qreal)",
    "1:PySide6.QtWidgets.QGraphicsLayoutItem.setSizePolicy(self,hPolicy:PySide6.QtWidgets.QSizePolicy.Policy,vPolicy:PySide6.QtWidgets.QSizePolicy.Policy,controlType:PySide6.QtWidgets.QSizePolicy.ControlType=QSizePolicy.DefaultType)",
    "0:PySide6.QtWidgets.QGraphicsLayoutItem.setSizePolicy(self,policy:PySide6.QtWidgets.QSizePolicy)",
    "PySide6.QtWidgets.QGraphicsLayoutItem.sizeHint(self,which:PySide6.QtCore.Qt.SizeHint,constraint:typing.Union[PySide6.QtCore.QSizeF, PySide6.QtCore.QSize]=QSizeF())->PySide6.QtCore.QSizeF",
    "PySide6.QtWidgets.QGraphicsLayoutItem.sizePolicy(self)->PySide6.QtWidgets.QSizePolicy",
    "PySide6.QtWidgets.QGraphicsLayoutItem.updateGeometry(self)",
    nullptr}; // Sentinel
#else
static constexpr size_t QGraphicsLayoutItem_SignatureByteSize = 550;
static constexpr uint8_t QGraphicsLayoutItem_SignatureBytes[550] = {
    0x78, 0xda, 0xd5, 0x57, 0x4d, 0x6f, 0x9c, 0x30, 0x10, 0xbd, 0xef, 0xaf, 0xe8, 0x31, 0x48, 0x2e,
    0x6a, 0x2e, 0x3d, 0x20, 0x6d, 0x0f, 0xdd, 0x36, 0x49, 0xa5, 0x46, 0x61, 0x9b, 0x56, 0x3d, 0x44,
    0x39, 0x38, 0xcb, 0x00, 0xae, 0xc0, 0xa6, 0xb6, 0xc9, 0x96, 0xfe, 0xfa, 0xda, 0x98, 0x40, 0xf8,
    0x68, 0x62, 0x7b, 0x57, 0x91, 0x72, 0xc2, 0x8c, 0x67, 0xde, 0xcc, 0x3c, 0x0f, 0x6f, 0xbd, 0x71,
    0x73, 0x4d, 0x12, 0x78, 0x1f, 0x6e, 0xe5, 0x4f, 0x92, 0x64, 0x20, 0x45, 0xb8, 0x3d, 0xe7, 0xb8,
    0xca, 0xc9, 0x4e, 0x7c, 0xc5, 0x0d, 0xab, 0xe5, 0x17, 0x09, 0xe5, 0x89, 0x80, 0x22, 0x45, 0x15,
    0xe6, 0x40, 0x65, 0x14, 0xdb, 0x44, 0xac, 0x69, 0x5d, 0x14, 0x95, 0xe4, 0x88, 0x74, 0xc6, 0xe8,
    0x8e, 0xb1, 0x62, 0x9d, 0xe2, 0x42, 0x40, 0xb0, 0xb2, 0x82, 0x08, 0x77, 0x8c, 0x4a, 0x95, 0x50,
    0x7c, 0x83, 0x9d, 0x6c, 0x2b, 0x08, 0xde, 0x7e, 0x18, 0x22, 0x37, 0x8c, 0x43, 0xb8, 0xd5, 0x7b,
    0x67, 0x96, 0x78, 0x90, 0xa6, 0xca, 0x9b, 0xdc, 0xc3, 0x35, 0xf9, 0x0b, 0x17, 0x84, 0x1a, 0x50,
    0xb4, 0x57, 0x6e, 0x79, 0x34, 0x05, 0x96, 0xe1, 0x83, 0x17, 0x52, 0x75, 0x08, 0xc9, 0xb1, 0x5a,
    0x46, 0xb2, 0xa9, 0x08, 0xcd, 0xc2, 0x1f, 0x94, 0x30, 0x7a, 0x33, 0x0d, 0xd1, 0x01, 0x67, 0xe8,
    0xcd, 0x92, 0xf9, 0x76, 0x6d, 0x76, 0x4f, 0x82, 0x85, 0x1e, 0xda, 0x1d, 0xcb, 0x1e, 0x32, 0x60,
    0x25, 0x48, 0xde, 0x1c, 0x83, 0x0f, 0xb5, 0xb1, 0xe9, 0x28, 0xbe, 0xc4, 0x3c, 0x23, 0x54, 0x0c,
    0xa8, 0x57, 0x77, 0xbf, 0x14, 0x92, 0x2d, 0x50, 0x67, 0xea, 0x47, 0x65, 0x54, 0xd8, 0x2c, 0x52,
    0xbb, 0x59, 0x22, 0x13, 0xf1, 0xb9, 0xac, 0x64, 0xdf, 0xad, 0x9e, 0x21, 0xeb, 0x48, 0xf3, 0xe2,
    0x11, 0x5a, 0xe2, 0x3f, 0xa4, 0xac, 0xcb, 0x0b, 0x20, 0x59, 0xde, 0xc7, 0xff, 0xe6, 0x80, 0x1d,
    0x01, 0xf4, 0xb9, 0xfe, 0xef, 0x9c, 0x5c, 0xce, 0xbc, 0x83, 0x53, 0x2e, 0x32, 0xf7, 0x2a, 0x87,
    0xd0, 0x03, 0xfb, 0x31, 0x00, 0x47, 0xeb, 0xc7, 0xc0, 0x79, 0xf7, 0xc3, 0xf6, 0x14, 0x92, 0x8f,
    0x8d, 0xf7, 0xf9, 0x1a, 0x1d, 0x9b, 0xa8, 0xdb, 0xd3, 0x23, 0x3b, 0x38, 0xdb, 0xe6, 0xe0, 0x90,
    0x02, 0xe7, 0x90, 0xf8, 0xb3, 0xde, 0x43, 0x1c, 0x8b, 0xf7, 0x1e, 0xd0, 0x9b, 0x79, 0x01, 0xf2,
    0xfc, 0xb1, 0x00, 0x21, 0xae, 0x44, 0xe2, 0x69, 0x51, 0x6c, 0x05, 0x69, 0x2e, 0x8a, 0xda, 0x7c,
    0x1b, 0x38, 0xa4, 0x9d, 0x4a, 0x0c, 0x22, 0x6a, 0x15, 0x3d, 0xa3, 0x32, 0x0e, 0x09, 0x2e, 0x67,
    0x1f, 0x3d, 0xca, 0xdb, 0x75, 0xd4, 0x12, 0x14, 0xac, 0x4e, 0x23, 0x57, 0xac, 0xfe, 0xdc, 0x90,
    0x50, 0x2b, 0xff, 0xdf, 0x8e, 0x60, 0xf5, 0xee, 0x80, 0xdc, 0x7b, 0xd3, 0x00, 0xca, 0x1f, 0x1a,
    0x71, 0x85, 0x1a, 0xa6, 0x05, 0xed, 0xf5, 0xd2, 0x1d, 0x67, 0xa6, 0x3f, 0x07, 0x50, 0x3b, 0x91,
    0xa2, 0x17, 0xa5, 0x76, 0x9a, 0xfb, 0x00, 0x6a, 0xa7, 0x12, 0xe8, 0x49, 0xed, 0xd5, 0x4c, 0x0a,
    0xd1, 0x48, 0x1d, 0xdb, 0x5b, 0x97, 0x03, 0x5e, 0xbc, 0x24, 0x8d, 0x4e, 0x17, 0x3f, 0x97, 0x64,
    0x0b, 0x1a, 0xe9, 0x3f, 0x19, 0xf1, 0x4c, 0x2e, 0x5f, 0x72, 0x36, 0x16, 0xb2, 0xfb, 0x4f, 0x47,
    0x3c, 0x17, 0xea, 0xf1, 0x7c, 0x38, 0xd0, 0xa2, 0xeb, 0x89, 0x59, 0x41, 0x76, 0x9d, 0x62, 0xe7,
    0xe6, 0x65, 0x09, 0x60, 0x70, 0x0d, 0xcd, 0x03, 0xdd, 0xbb, 0x38, 0xeb, 0xeb, 0x3a, 0x67, 0xc5,
    0xf7, 0xa6, 0x82, 0x67, 0x02, 0x36, 0x83, 0xe7, 0xfa, 0xb1, 0xfd, 0x13, 0xa4, 0xb8, 0x2e, 0xa4,
    0xb6, 0x3b, 0x91, 0x3f, 0xed, 0xb1, 0xb2, 0xa8, 0xda, 0xfa, 0x38, 0x5e, 0xef, 0x7f, 0x05, 0x31,
    0xa6, 0x65, 0xf9, 0x86, 0x33, 0x30, 0x62, 0x89, 0x5a, 0x57, 0x09, 0x96, 0x30, 0xba, 0x06, 0x04,
    0xab, 0x7f, 0x96, 0x48, 0x41, 0x2a
};
#endif

PyTypeObject *init_QGraphicsLayoutItem(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX].type;

    Shiboken::AutoDecRef Sbk_QGraphicsLayoutItem_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QGraphicsLayoutItem_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QGraphicsLayoutItem",
        "QGraphicsLayoutItem*",
        &Sbk_QGraphicsLayoutItem_spec,
        &Shiboken::callCppDestructor< QGraphicsLayoutItem >,
        Sbk_QGraphicsLayoutItem_Type_bases.object(),
        0);
    auto *pyType = Sbk_QGraphicsLayoutItem_TypeF(); // references _Sbk_QGraphicsLayoutItem_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QGraphicsLayoutItem_SignatureStrings);
#else
    InitSignatureBytes(pyType, QGraphicsLayoutItem_SignatureBytes, QGraphicsLayoutItem_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QGraphicsLayoutItem_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QGraphicsLayoutItem_PythonToCpp_QGraphicsLayoutItem_PTR,
        is_QGraphicsLayoutItem_PythonToCpp_QGraphicsLayoutItem_PTR_Convertible,
        QGraphicsLayoutItem_PTR_CppToPython_QGraphicsLayoutItem);

    Shiboken::Conversions::registerConverterName(converter, "QGraphicsLayoutItem");
    Shiboken::Conversions::registerConverterName(converter, "QGraphicsLayoutItem*");
    Shiboken::Conversions::registerConverterName(converter, "QGraphicsLayoutItem&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QGraphicsLayoutItem).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QGraphicsLayoutItemWrapper).name());

    qRegisterMetaType< ::QGraphicsLayoutItem *>();

    return pyType;
}
