// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qgraphicssceneresizeevent_wrapper.h"

// Argument includes
#include <QtWidgets/qwidget.h>
#include <qcoreevent.h>
#include <qsize.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QGraphicsSceneResizeEventWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QGraphicsSceneResizeEventWrapper::QGraphicsSceneResizeEventWrapper()
{
}

::QEvent * QGraphicsSceneResizeEventWrapper::clone() const
{
    if (m_PyMethodCache[0])
        return this->::QEvent::clone();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "clone";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QEvent::clone();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphicsSceneResizeEvent", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QGraphicsSceneResizeEvent", funcName, Shiboken::SbkType< QEvent >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QEvent *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QGraphicsSceneResizeEventWrapper::setAccepted(bool accepted)
{
    if (m_PyMethodCache[1]) {
        return this->::QEvent::setAccepted(accepted);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setAccepted";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QEvent::setAccepted(accepted);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &accepted)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &accepted)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphicsSceneResizeEvent", funcName);
        return;
    }
}

QGraphicsSceneResizeEventWrapper::~QGraphicsSceneResizeEventWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGraphicsSceneResizeEvent_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QGraphicsSceneResizeEvent >()))
        return -1;

    QGraphicsSceneResizeEventWrapper *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneResizeEvent_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QGraphicsSceneResizeEvent()
        cptr = new QGraphicsSceneResizeEventWrapper();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QGraphicsSceneResizeEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QGraphicsSceneResizeEventFunc_newSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsSceneResizeEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneResizeEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // newSize()const
        QSizeF cppResult = const_cast<const ::QGraphicsSceneResizeEvent *>(cppSelf)->newSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneResizeEventFunc_oldSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsSceneResizeEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneResizeEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // oldSize()const
        QSizeF cppResult = const_cast<const ::QGraphicsSceneResizeEvent *>(cppSelf)->oldSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneResizeEventFunc_setNewSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsSceneResizeEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneResizeEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsSceneResizeEvent::setNewSize(QSizeF)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), (pyArg)))) {
        overloadId = 0; // setNewSize(QSizeF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setNewSize", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneResizeEvent_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSizeF cppArg0_local;
        ::QSizeF *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setNewSize(QSizeF)
            cppSelf->setNewSize(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneResizeEventFunc_setOldSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsSceneResizeEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneResizeEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsSceneResizeEvent::setOldSize(QSizeF)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), (pyArg)))) {
        overloadId = 0; // setOldSize(QSizeF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOldSize", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneResizeEvent_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSizeF cppArg0_local;
        ::QSizeF *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setOldSize(QSizeF)
            cppSelf->setOldSize(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QGraphicsSceneResizeEvent_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QGraphicsSceneResizeEvent_methods[] = {
    {"newSize", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneResizeEventFunc_newSize), METH_NOARGS, nullptr},
    {"oldSize", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneResizeEventFunc_oldSize), METH_NOARGS, nullptr},
    {"setNewSize", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneResizeEventFunc_setNewSize), METH_O, nullptr},
    {"setOldSize", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneResizeEventFunc_setOldSize), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QGraphicsSceneResizeEvent_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QGraphicsSceneResizeEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneResizeEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QGraphicsSceneResizeEventWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QGraphicsSceneResizeEvent_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QGraphicsSceneResizeEvent_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QGraphicsSceneResizeEvent_Type = nullptr;
static PyTypeObject *Sbk_QGraphicsSceneResizeEvent_TypeF(void)
{
    return _Sbk_QGraphicsSceneResizeEvent_Type;
}

static PyType_Slot Sbk_QGraphicsSceneResizeEvent_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QGraphicsSceneResizeEvent_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QGraphicsSceneResizeEvent_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QGraphicsSceneResizeEvent_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QGraphicsSceneResizeEvent_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QGraphicsSceneResizeEvent_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QGraphicsSceneResizeEvent_spec = {
    "2:PySide6.QtWidgets.QGraphicsSceneResizeEvent",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QGraphicsSceneResizeEvent_slots
};

} //extern "C"

static void *Sbk_QGraphicsSceneResizeEvent_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if ( reinterpret_cast< ::QEvent *>(cptr)->type() == QEvent::GraphicsSceneResize)
        return cptr;
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QGraphicsSceneResizeEvent_PythonToCpp_QGraphicsSceneResizeEvent_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QGraphicsSceneResizeEvent_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QGraphicsSceneResizeEvent_PythonToCpp_QGraphicsSceneResizeEvent_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QGraphicsSceneResizeEvent_TypeF()))
        return QGraphicsSceneResizeEvent_PythonToCpp_QGraphicsSceneResizeEvent_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QGraphicsSceneResizeEvent_PTR_CppToPython_QGraphicsSceneResizeEvent(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QGraphicsSceneResizeEvent *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QGraphicsSceneResizeEvent_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QGraphicsSceneResizeEvent_SignatureStrings[] = {
    "PySide6.QtWidgets.QGraphicsSceneResizeEvent(self)",
    "PySide6.QtWidgets.QGraphicsSceneResizeEvent.newSize(self)->PySide6.QtCore.QSizeF",
    "PySide6.QtWidgets.QGraphicsSceneResizeEvent.oldSize(self)->PySide6.QtCore.QSizeF",
    "PySide6.QtWidgets.QGraphicsSceneResizeEvent.setNewSize(self,size:typing.Union[PySide6.QtCore.QSizeF, PySide6.QtCore.QSize])",
    "PySide6.QtWidgets.QGraphicsSceneResizeEvent.setOldSize(self,size:typing.Union[PySide6.QtCore.QSizeF, PySide6.QtCore.QSize])",
    nullptr}; // Sentinel
#else
static constexpr size_t QGraphicsSceneResizeEvent_SignatureByteSize = 131;
static constexpr uint8_t QGraphicsSceneResizeEvent_SignatureBytes[131] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x09, 0xcf, 0x4c, 0x49,
    0x4f, 0x2d, 0x29, 0xd6, 0x0b, 0x74, 0x2f, 0x4a, 0x2c, 0xc8, 0xc8, 0x4c, 0x2e, 0x0e, 0x4e, 0x4e,
    0xcd, 0x4b, 0x0d, 0x4a, 0x2d, 0xce, 0xac, 0x4a, 0x75, 0x2d, 0x4b, 0xcd, 0x2b, 0xd1, 0x28, 0x4e,
    0xcd, 0x49, 0xd3, 0xe4, 0x0a, 0x20, 0x5e, 0x87, 0x5e, 0x5e, 0x6a, 0x79, 0x30, 0x90, 0x03, 0xd1,
    0xa9, 0x6b, 0x87, 0xd0, 0xea, 0x9c, 0x5f, 0x94, 0xaa, 0x17, 0x08, 0x92, 0x73, 0x23, 0xc9, 0xc0,
    0xfc, 0x9c, 0x14, 0xea, 0x1a, 0x58, 0x9c, 0x5a, 0xe2, 0x87, 0xe4, 0x48, 0x1d, 0x90, 0x8c, 0x55,
    0x49, 0x65, 0x41, 0x66, 0x5e, 0xba, 0x5e, 0x68, 0x5e, 0x66, 0x7e, 0x5e, 0x34, 0x56, 0x3b, 0x74,
    0x14, 0xb0, 0x09, 0xc7, 0x6a, 0x92, 0x6a, 0xb7, 0x3f, 0x92, 0x7f, 0x28, 0xb6, 0x1b, 0x00, 0x52,
    0xe5, 0xa7, 0x00
};
#endif

PyTypeObject *init_QGraphicsSceneResizeEvent(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneResizeEvent_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneResizeEvent_IDX].type;

    Shiboken::AutoDecRef Sbk_QGraphicsSceneResizeEvent_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneEvent_IDX]))));

    _Sbk_QGraphicsSceneResizeEvent_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QGraphicsSceneResizeEvent",
        "QGraphicsSceneResizeEvent*",
        &Sbk_QGraphicsSceneResizeEvent_spec,
        &Shiboken::callCppDestructor< QGraphicsSceneResizeEvent >,
        Sbk_QGraphicsSceneResizeEvent_Type_bases.object(),
        0);
    auto *pyType = Sbk_QGraphicsSceneResizeEvent_TypeF(); // references _Sbk_QGraphicsSceneResizeEvent_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QGraphicsSceneResizeEvent_SignatureStrings);
#else
    InitSignatureBytes(pyType, QGraphicsSceneResizeEvent_SignatureBytes, QGraphicsSceneResizeEvent_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QGraphicsSceneResizeEvent_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneResizeEvent_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QGraphicsSceneResizeEvent_PythonToCpp_QGraphicsSceneResizeEvent_PTR,
        is_QGraphicsSceneResizeEvent_PythonToCpp_QGraphicsSceneResizeEvent_PTR_Convertible,
        QGraphicsSceneResizeEvent_PTR_CppToPython_QGraphicsSceneResizeEvent);

    Shiboken::Conversions::registerConverterName(converter, "QGraphicsSceneResizeEvent");
    Shiboken::Conversions::registerConverterName(converter, "QGraphicsSceneResizeEvent*");
    Shiboken::Conversions::registerConverterName(converter, "QGraphicsSceneResizeEvent&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QGraphicsSceneResizeEvent).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QGraphicsSceneResizeEventWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QGraphicsSceneResizeEvent_TypeF(), &Sbk_QGraphicsSceneResizeEvent_typeDiscovery);


    return pyType;
}
