// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qscroller_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QtWidgets/qscroller.h>
#include <QtWidgets/qscrollerproperties.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qrect.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QScrollerFunc_activeScrollers(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // activeScrollers()
        QList<QScroller*> cppResult = ::QScroller::activeScrollers();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QScrollerPTR_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScrollerFunc_ensureVisible(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScroller *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "ensureVisible", 3, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QScroller::ensureVisible(QRectF,qreal,qreal)
    // 1: QScroller::ensureVisible(QRectF,qreal,qreal,int)
    if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // ensureVisible(QRectF,qreal,qreal)
        } else if (numArgs == 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
            overloadId = 1; // ensureVisible(QRectF,qreal,qreal,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "ensureVisible", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // ensureVisible(const QRectF &rect, qreal xmargin, qreal ymargin)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRectF cppArg0_local;
            ::QRectF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            qreal cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // ensureVisible(QRectF,qreal,qreal)
                cppSelf->ensureVisible(*cppArg0, cppArg1, cppArg2);
            }
            break;
        }
        case 1: // ensureVisible(const QRectF &rect, qreal xmargin, qreal ymargin, int scrollTime)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRectF cppArg0_local;
            ::QRectF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            qreal cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // ensureVisible(QRectF,qreal,qreal,int)
                cppSelf->ensureVisible(*cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QScrollerFunc_finalPosition(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScroller *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // finalPosition()const
        QPointF cppResult = const_cast<const ::QScroller *>(cppSelf)->finalPosition();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScrollerFunc_grabGesture(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "grabGesture", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_IDX]);

    if (PyArg_ParseTuple(args, "|OO:grabGesture", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QScroller::grabGesture(QObject*,QScroller::ScrollerGestureType=)->Qt::GestureType
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // grabGesture(QObject*,QScroller::ScrollerGestureType)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_ScrollerGestureType_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // grabGesture(QObject*,QScroller::ScrollerGestureType)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "grabGesture", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_gestureType = Shiboken::String::createStaticString("gestureType");
            if (PyDict_Contains(kwds, key_gestureType) != 0) {
                value = PyDict_GetItem(kwds, key_gestureType);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_gestureType);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "grabGesture", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_ScrollerGestureType_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "grabGesture", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_gestureType);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "grabGesture", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QObject *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QScroller::ScrollerGestureType cppArg1(QScroller::ScrollerGestureType::TouchGesture);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // grabGesture(QObject*,QScroller::ScrollerGestureType)
            Qt::GestureType cppResult = ::QScroller::grabGesture(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_GestureType_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScrollerFunc_grabbedGesture(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QScroller::grabbedGesture(QObject*)->Qt::GestureType
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArg)))) {
        overloadId = 0; // grabbedGesture(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "grabbedGesture", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QObject *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // grabbedGesture(QObject*)
            Qt::GestureType cppResult = ::QScroller::grabbedGesture(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_GestureType_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScrollerFunc_handleInput(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScroller *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "handleInput", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:handleInput", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QScroller::handleInput(QScroller::Input,QPointF,qint64=)->bool
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_Input_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // handleInput(QScroller::Input,QPointF,qint64)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[2])))) {
            overloadId = 0; // handleInput(QScroller::Input,QPointF,qint64)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "handleInput", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_timestamp = Shiboken::String::createStaticString("timestamp");
            if (PyDict_Contains(kwds, key_timestamp) != 0) {
                value = PyDict_GetItem(kwds, key_timestamp);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_timestamp);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "handleInput", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "handleInput", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_timestamp);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "handleInput", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_IDX]);
            }
        }
        ::QScroller::Input cppArg0 = static_cast< ::QScroller::Input>(0);
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QPointF cppArg1_local;
        ::QPointF *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        qint64 cppArg2 = 0;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // handleInput(QScroller::Input,QPointF,qint64)
            bool cppResult = cppSelf->handleInput(cppArg0, *cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScrollerFunc_hasScroller(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QScroller::hasScroller(QObject*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArg)))) {
        overloadId = 0; // hasScroller(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "hasScroller", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QObject *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // hasScroller(QObject*)
            bool cppResult = ::QScroller::hasScroller(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScrollerFunc_pixelPerMeter(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScroller *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pixelPerMeter()const
        QPointF cppResult = const_cast<const ::QScroller *>(cppSelf)->pixelPerMeter();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScrollerFunc_resendPrepareEvent(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScroller *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // resendPrepareEvent()
        cppSelf->resendPrepareEvent();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QScrollerFunc_scrollTo(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScroller *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "scrollTo", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QScroller::scrollTo(QPointF)
    // 1: QScroller::scrollTo(QPointF,int)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // scrollTo(QPointF)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 1; // scrollTo(QPointF,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "scrollTo", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // scrollTo(const QPointF &pos)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPointF cppArg0_local;
            ::QPointF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // scrollTo(QPointF)
                cppSelf->scrollTo(*cppArg0);
            }
            break;
        }
        case 1: // scrollTo(const QPointF &pos, int scrollTime)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPointF cppArg0_local;
            ::QPointF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // scrollTo(QPointF,int)
                cppSelf->scrollTo(*cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QScrollerFunc_scroller(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QScroller::scroller(QObject*)->QScroller*
    // 1: static QScroller::scroller(const QObject*)->const QScroller*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArg)))) {
        overloadId = 0; // scroller(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "scroller", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // scroller(QObject *target)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QObject *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // scroller(QObject*)
                QScroller * cppResult = ::QScroller::scroller(cppArg0);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_IDX]), cppResult);
            }
            break;
        }
        case 1: // scroller(const QObject *target)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QObject *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // scroller(const QObject*)
                const QScroller * cppResult = ::QScroller::scroller(cppArg0);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_IDX]), cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScrollerFunc_scrollerProperties(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScroller *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // scrollerProperties()const
        QScrollerProperties cppResult = const_cast<const ::QScroller *>(cppSelf)->scrollerProperties();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScrollerProperties_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScrollerFunc_setScrollerProperties(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScroller *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QScroller::setScrollerProperties(QScrollerProperties)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScrollerProperties_IDX]), (pyArg)))) {
        overloadId = 0; // setScrollerProperties(QScrollerProperties)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setScrollerProperties", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QScrollerProperties cppArg0_local;
        ::QScrollerProperties *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setScrollerProperties(QScrollerProperties)
            cppSelf->setScrollerProperties(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QScrollerFunc_setSnapPositionsX(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScroller *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setSnapPositionsX", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QScroller::setSnapPositionsX(QList<qreal>)
    // 1: QScroller::setSnapPositionsX(qreal,qreal)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))) {
        overloadId = 1; // setSnapPositionsX(qreal,qreal)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_qreal_IDX], (pyArgs[0])))) {
        overloadId = 0; // setSnapPositionsX(QList<qreal>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setSnapPositionsX", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setSnapPositionsX(const QList<qreal> &positions)
        {
            ::QList<qreal> cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setSnapPositionsX(QList<qreal>)
                cppSelf->setSnapPositionsX(cppArg0);
            }
            break;
        }
        case 1: // setSnapPositionsX(qreal first, qreal interval)
        {
            qreal cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setSnapPositionsX(qreal,qreal)
                cppSelf->setSnapPositionsX(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QScrollerFunc_setSnapPositionsY(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScroller *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setSnapPositionsY", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QScroller::setSnapPositionsY(QList<qreal>)
    // 1: QScroller::setSnapPositionsY(qreal,qreal)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))) {
        overloadId = 1; // setSnapPositionsY(qreal,qreal)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_qreal_IDX], (pyArgs[0])))) {
        overloadId = 0; // setSnapPositionsY(QList<qreal>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setSnapPositionsY", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setSnapPositionsY(const QList<qreal> &positions)
        {
            ::QList<qreal> cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setSnapPositionsY(QList<qreal>)
                cppSelf->setSnapPositionsY(cppArg0);
            }
            break;
        }
        case 1: // setSnapPositionsY(qreal first, qreal interval)
        {
            qreal cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setSnapPositionsY(qreal,qreal)
                cppSelf->setSnapPositionsY(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QScrollerFunc_state(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScroller *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // state()const
        QScroller::State cppResult = const_cast<const ::QScroller *>(cppSelf)->state();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_State_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScrollerFunc_stop(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScroller *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // stop()
        cppSelf->stop();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QScrollerFunc_target(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScroller *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // target()const
        QObject * cppResult = const_cast<const ::QScroller *>(cppSelf)->target();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScrollerFunc_ungrabGesture(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QScroller::ungrabGesture(QObject*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArg)))) {
        overloadId = 0; // ungrabGesture(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "ungrabGesture", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QObject *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // ungrabGesture(QObject*)
            ::QScroller::ungrabGesture(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QScrollerFunc_velocity(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScroller *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // velocity()const
        QPointF cppResult = const_cast<const ::QScroller *>(cppSelf)->velocity();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QScroller_PropertyStrings[] = {
    "scrollerProperties::",
    "state:",
    nullptr // Sentinel
};

static const char *Sbk_QScroller_EnumFlagInfo[] = {
    "Input:Enum",
    "ScrollerGestureType:Enum",
    "State:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QScroller_methods[] = {
    {"activeScrollers", reinterpret_cast<PyCFunction>(Sbk_QScrollerFunc_activeScrollers), METH_NOARGS|METH_STATIC, nullptr},
    {"ensureVisible", reinterpret_cast<PyCFunction>(Sbk_QScrollerFunc_ensureVisible), METH_VARARGS, nullptr},
    {"finalPosition", reinterpret_cast<PyCFunction>(Sbk_QScrollerFunc_finalPosition), METH_NOARGS, nullptr},
    {"grabGesture", reinterpret_cast<PyCFunction>(Sbk_QScrollerFunc_grabGesture), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"grabbedGesture", reinterpret_cast<PyCFunction>(Sbk_QScrollerFunc_grabbedGesture), METH_O|METH_STATIC, nullptr},
    {"handleInput", reinterpret_cast<PyCFunction>(Sbk_QScrollerFunc_handleInput), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"hasScroller", reinterpret_cast<PyCFunction>(Sbk_QScrollerFunc_hasScroller), METH_O|METH_STATIC, nullptr},
    {"pixelPerMeter", reinterpret_cast<PyCFunction>(Sbk_QScrollerFunc_pixelPerMeter), METH_NOARGS, nullptr},
    {"resendPrepareEvent", reinterpret_cast<PyCFunction>(Sbk_QScrollerFunc_resendPrepareEvent), METH_NOARGS, nullptr},
    {"scrollTo", reinterpret_cast<PyCFunction>(Sbk_QScrollerFunc_scrollTo), METH_VARARGS, nullptr},
    {"scroller", reinterpret_cast<PyCFunction>(Sbk_QScrollerFunc_scroller), METH_O|METH_STATIC, nullptr},
    {"scrollerProperties", reinterpret_cast<PyCFunction>(Sbk_QScrollerFunc_scrollerProperties), METH_NOARGS, nullptr},
    {"setScrollerProperties", reinterpret_cast<PyCFunction>(Sbk_QScrollerFunc_setScrollerProperties), METH_O, nullptr},
    {"setSnapPositionsX", reinterpret_cast<PyCFunction>(Sbk_QScrollerFunc_setSnapPositionsX), METH_VARARGS, nullptr},
    {"setSnapPositionsY", reinterpret_cast<PyCFunction>(Sbk_QScrollerFunc_setSnapPositionsY), METH_VARARGS, nullptr},
    {"state", reinterpret_cast<PyCFunction>(Sbk_QScrollerFunc_state), METH_NOARGS, nullptr},
    {"stop", reinterpret_cast<PyCFunction>(Sbk_QScrollerFunc_stop), METH_NOARGS, nullptr},
    {"target", reinterpret_cast<PyCFunction>(Sbk_QScrollerFunc_target), METH_NOARGS, nullptr},
    {"ungrabGesture", reinterpret_cast<PyCFunction>(Sbk_QScrollerFunc_ungrabGesture), METH_O|METH_STATIC, nullptr},
    {"velocity", reinterpret_cast<PyCFunction>(Sbk_QScrollerFunc_velocity), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QScroller_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QScroller_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QScroller_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QScroller_Type = nullptr;
static PyTypeObject *Sbk_QScroller_TypeF(void)
{
    return _Sbk_QScroller_Type;
}

static PyType_Slot Sbk_QScroller_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(SbkDeallocWrapperWithPrivateDtor)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QScroller_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QScroller_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QScroller_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QScroller_methods)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QScroller_spec = {
    "2:PySide6.QtWidgets.QScroller",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QScroller_slots
};

} //extern "C"

static void *Sbk_QScroller_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QScroller *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QScroller_State(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QScroller::State>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QScroller::State *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QScroller_State_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_State_IDX])))
        return Enum_PythonToCpp_QScroller_State;
    return {};
}

static PyObject *QScroller_State_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QScroller::State>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QScroller::State *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_State_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QScroller_ScrollerGestureType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QScroller::ScrollerGestureType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QScroller::ScrollerGestureType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QScroller_ScrollerGestureType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_ScrollerGestureType_IDX])))
        return Enum_PythonToCpp_QScroller_ScrollerGestureType;
    return {};
}

static PyObject *QScroller_ScrollerGestureType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QScroller::ScrollerGestureType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QScroller::ScrollerGestureType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_ScrollerGestureType_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QScroller_Input(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QScroller::Input>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QScroller::Input *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QScroller_Input_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_Input_IDX])))
        return Enum_PythonToCpp_QScroller_Input;
    return {};
}

static PyObject *QScroller_Input_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QScroller::Input>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QScroller::Input *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_Input_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QScroller_PythonToCpp_QScroller_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QScroller_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QScroller_PythonToCpp_QScroller_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QScroller_TypeF()))
        return QScroller_PythonToCpp_QScroller_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QScroller_PTR_CppToPython_QScroller(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QScroller *>(const_cast<void *>(cppIn)), Sbk_QScroller_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QScroller_SignatureStrings[] = {
    "PySide6.QtWidgets.QScroller.activeScrollers()->QList[PySide6.QtWidgets.QScroller]",
    "1:PySide6.QtWidgets.QScroller.ensureVisible(self,rect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect],xmargin:qreal,ymargin:qreal)",
    "0:PySide6.QtWidgets.QScroller.ensureVisible(self,rect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect],xmargin:qreal,ymargin:qreal,scrollTime:int)",
    "PySide6.QtWidgets.QScroller.finalPosition(self)->PySide6.QtCore.QPointF",
    "PySide6.QtWidgets.QScroller.grabGesture(target:PySide6.QtCore.QObject,gestureType:PySide6.QtWidgets.QScroller.ScrollerGestureType=QScroller.ScrollerGestureType.TouchGesture)->PySide6.QtCore.Qt.GestureType",
    "PySide6.QtWidgets.QScroller.grabbedGesture(target:PySide6.QtCore.QObject)->PySide6.QtCore.Qt.GestureType",
    "PySide6.QtWidgets.QScroller.handleInput(self,input:PySide6.QtWidgets.QScroller.Input,position:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],timestamp:qint64=0)->bool",
    "PySide6.QtWidgets.QScroller.hasScroller(target:PySide6.QtCore.QObject)->bool",
    "PySide6.QtWidgets.QScroller.pixelPerMeter(self)->PySide6.QtCore.QPointF",
    "PySide6.QtWidgets.QScroller.resendPrepareEvent(self)",
    "1:PySide6.QtWidgets.QScroller.scrollTo(self,pos:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element])",
    "0:PySide6.QtWidgets.QScroller.scrollTo(self,pos:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],scrollTime:int)",
    "1:PySide6.QtWidgets.QScroller.scroller(target:PySide6.QtCore.QObject)->PySide6.QtWidgets.QScroller",
    "0:PySide6.QtWidgets.QScroller.scroller(target:PySide6.QtCore.QObject)->PySide6.QtWidgets.QScroller",
    "PySide6.QtWidgets.QScroller.scrollerProperties(self)->PySide6.QtWidgets.QScrollerProperties",
    "PySide6.QtWidgets.QScroller.setScrollerProperties(self,prop:PySide6.QtWidgets.QScrollerProperties)",
    "1:PySide6.QtWidgets.QScroller.setSnapPositionsX(self,positions:QList[qreal])",
    "0:PySide6.QtWidgets.QScroller.setSnapPositionsX(self,first:qreal,interval:qreal)",
    "1:PySide6.QtWidgets.QScroller.setSnapPositionsY(self,positions:QList[qreal])",
    "0:PySide6.QtWidgets.QScroller.setSnapPositionsY(self,first:qreal,interval:qreal)",
    "PySide6.QtWidgets.QScroller.state(self)->PySide6.QtWidgets.QScroller.State",
    "PySide6.QtWidgets.QScroller.stop(self)",
    "PySide6.QtWidgets.QScroller.target(self)->PySide6.QtCore.QObject",
    "PySide6.QtWidgets.QScroller.ungrabGesture(target:PySide6.QtCore.QObject)",
    "PySide6.QtWidgets.QScroller.velocity(self)->PySide6.QtCore.QPointF",
    nullptr}; // Sentinel
#else
static constexpr size_t QScroller_SignatureByteSize = 494;
static constexpr uint8_t QScroller_SignatureBytes[494] = {
    0x78, 0xda, 0xcd, 0x55, 0x4d, 0x6f, 0xdb, 0x30, 0x0c, 0xbd, 0xe7, 0x57, 0xec, 0x98, 0x00, 0x9e,
    0xd0, 0x01, 0x43, 0x0f, 0x06, 0xba, 0xcb, 0xd0, 0x06, 0x03, 0x36, 0xcc, 0x59, 0xb2, 0x8f, 0x62,
    0xe8, 0x41, 0xb6, 0x19, 0x87, 0x83, 0x22, 0xa9, 0x12, 0x1d, 0xd4, 0xff, 0x7e, 0xac, 0x3f, 0xd6,
    0xa0, 0x49, 0x25, 0x0f, 0x59, 0x8b, 0xdd, 0x24, 0x8a, 0x7e, 0x7c, 0x24, 0x9f, 0xc9, 0xac, 0x59,
    0x62, 0x09, 0xe7, 0x62, 0x41, 0xdf, 0xb1, 0xac, 0x80, 0xbc, 0x58, 0x2c, 0x0b, 0x67, 0x94, 0x02,
    0x27, 0x64, 0x41, 0xb8, 0x83, 0xe1, 0xea, 0xa7, 0xb3, 0xd7, 0xef, 0x16, 0x1f, 0xd1, 0xd3, 0xcf,
    0xec, 0xe9, 0x8f, 0x6e, 0x26, 0x6f, 0xd2, 0xc0, 0xb3, 0x00, 0xed, 0x6b, 0x07, 0xdf, 0xd0, 0x63,
    0xae, 0x60, 0xea, 0x41, 0xad, 0x13, 0x07, 0x05, 0xa5, 0xd4, 0x58, 0xd4, 0x95, 0xf8, 0xaa, 0xd1,
    0xe8, 0x3d, 0xfc, 0xf7, 0xc6, 0x81, 0x58, 0x7c, 0x61, 0x8f, 0xab, 0xe4, 0xd5, 0x31, 0xf3, 0x4d,
    0x72, 0xb7, 0x95, 0xae, 0x42, 0x9d, 0xde, 0x3a, 0x90, 0x2a, 0x69, 0xf6, 0x6f, 0xb3, 0xc9, 0xd9,
    0xff, 0x43, 0x26, 0xf1, 0x6d, 0xd8, 0x15, 0x6e, 0x21, 0x45, 0x4d, 0xb3, 0x49, 0x88, 0xd9, 0x1a,
    0xb5, 0x54, 0x99, 0xf1, 0x48, 0x4c, 0xa1, 0x65, 0xc6, 0xc5, 0x7f, 0x1c, 0x32, 0x33, 0x8c, 0x73,
    0x15, 0xc4, 0xa9, 0x9c, 0xcc, 0xe7, 0xe0, 0x89, 0xd3, 0x9c, 0x12, 0x93, 0x01, 0x4a, 0x1f, 0xa3,
    0x7c, 0xce, 0x7f, 0x31, 0xf5, 0xa4, 0xea, 0xbc, 0x56, 0x8d, 0x85, 0x60, 0xcd, 0x86, 0xc3, 0xfc,
    0xc1, 0xff, 0x22, 0xf8, 0x2a, 0x56, 0xa6, 0x2e, 0x36, 0xbd, 0xe1, 0x48, 0x16, 0x24, 0xf6, 0x9c,
    0xa3, 0xc9, 0xe4, 0x50, 0x8e, 0xca, 0xe7, 0xa4, 0x40, 0x1b, 0xa9, 0x4b, 0x05, 0x1f, 0xb4, 0xad,
    0xa9, 0x53, 0x05, 0xde, 0x1f, 0x83, 0x65, 0x69, 0x9d, 0x13, 0xdb, 0x77, 0x2c, 0xac, 0xa0, 0xae,
    0x6f, 0x87, 0x12, 0x6a, 0xed, 0xfb, 0xe6, 0x79, 0x8d, 0x6c, 0x95, 0x6c, 0x05, 0x97, 0x49, 0xda,
    0x88, 0x4b, 0x05, 0x5b, 0xd0, 0xac, 0x33, 0x62, 0x15, 0x79, 0x92, 0x5b, 0x9b, 0xde, 0xf2, 0xeb,
    0xf9, 0xdb, 0x8b, 0x33, 0x4e, 0x38, 0x37, 0x46, 0x45, 0xf2, 0xf2, 0xc3, 0x39, 0x5a, 0xbd, 0x28,
    0x98, 0xc5, 0x3b, 0x50, 0x19, 0xb8, 0x4f, 0xc0, 0xec, 0x4e, 0x90, 0xa8, 0x03, 0x0f, 0xba, 0xcc,
    0x1c, 0x58, 0xe9, 0xe0, 0x72, 0xc7, 0xe9, 0x75, 0x60, 0x91, 0x41, 0xd2, 0xff, 0x4d, 0xa6, 0x6b,
    0x10, 0x17, 0xfe, 0xb9, 0x6b, 0x1e, 0x1b, 0x26, 0x2f, 0x4e, 0xe8, 0x60, 0xa0, 0x8c, 0x29, 0xd8,
    0x88, 0xce, 0x07, 0x40, 0x46, 0x95, 0xe0, 0xc4, 0x10, 0x63, 0x02, 0x64, 0xce, 0x58, 0x70, 0x84,
    0xe0, 0x0f, 0x85, 0x77, 0xf0, 0xd5, 0x83, 0x73, 0x18, 0x1b, 0x68, 0x79, 0x1c, 0x3e, 0xb1, 0x7c,
    0x4f, 0x47, 0x45, 0x88, 0x36, 0x81, 0x83, 0x68, 0x69, 0x87, 0xc9, 0xee, 0x7f, 0xfc, 0x51, 0x4b,
    0x77, 0x4f, 0xbb, 0x05, 0xdb, 0x2e, 0x8c, 0xb8, 0xe2, 0x8e, 0x83, 0xad, 0xd1, 0x79, 0xea, 0x77,
    0x4e, 0xab, 0x9a, 0x9d, 0x54, 0xc3, 0x3e, 0xfc, 0x3b, 0x76, 0xd7, 0xff, 0x92, 0xdd, 0x75, 0x9c,
    0x5d, 0x10, 0x8e, 0x24, 0xc1, 0x88, 0x6e, 0x8b, 0xe5, 0xbd, 0x63, 0x04, 0xca, 0xd8, 0x7e, 0xc6,
    0x84, 0xdc, 0x3a, 0x11, 0x3f, 0x35, 0xd9, 0x3a, 0x2d, 0x07, 0x01, 0x6a, 0x3d, 0x7a, 0xfd, 0x86,
    0x99, 0xec, 0x40, 0x99, 0x02, 0xa9, 0x89, 0x4c, 0xd9, 0xdf, 0xa7, 0x45, 0x92, 0xe4
};
#endif

PyTypeObject *init_QScroller(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_IDX].type;

    Shiboken::AutoDecRef Sbk_QScroller_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QScroller_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QScroller",
        "QScroller*",
        &Sbk_QScroller_spec,
        nullptr,
        Sbk_QScroller_Type_bases.object(),
        0);
    auto *pyType = Sbk_QScroller_TypeF(); // references _Sbk_QScroller_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QScroller_SignatureStrings);
#else
    InitSignatureBytes(pyType, QScroller_SignatureBytes, QScroller_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QScroller_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QScroller_PythonToCpp_QScroller_PTR,
        is_QScroller_PythonToCpp_QScroller_PTR_Convertible,
        QScroller_PTR_CppToPython_QScroller);

    Shiboken::Conversions::registerConverterName(converter, "QScroller");
    Shiboken::Conversions::registerConverterName(converter, "QScroller*");
    Shiboken::Conversions::registerConverterName(converter, "QScroller&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QScroller).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QScroller_TypeF(), &Sbk_QScroller_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QScroller_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'State'.
    const char *State_Initializer[] = {
        "Inactive",
        "Pressed",
        "Dragging",
        "Scrolling",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t State_InitializerValues[] = {
        uint8_t(QScroller::State::Inactive), //  0x00  0
        uint8_t(QScroller::State::Pressed),  //  0x01  1
        uint8_t(QScroller::State::Dragging), //  0x02  2
        uint8_t(QScroller::State::Scrolling) //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QScroller_TypeF(),
        "2:PySide6.QtWidgets.QScroller.State",
        State_Initializer, State_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_State_IDX].type = EType;
    // Register converter for enum 'QScroller::State'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QScroller_State_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QScroller_State,
            is_Enum_PythonToCpp_QScroller_State_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QScroller::State");
        Shiboken::Conversions::registerConverterAlias(converter, "State");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'State' enum.

    // Initialization of enum 'ScrollerGestureType'.
    const char *ScrollerGestureType_Initializer[] = {
        "TouchGesture",
        "LeftMouseButtonGesture",
        "RightMouseButtonGesture",
        "MiddleMouseButtonGesture",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ScrollerGestureType_InitializerValues[] = {
        uint8_t(QScroller::ScrollerGestureType::TouchGesture),            //  0x00  0
        uint8_t(QScroller::ScrollerGestureType::LeftMouseButtonGesture),  //  0x01  1
        uint8_t(QScroller::ScrollerGestureType::RightMouseButtonGesture), //  0x02  2
        uint8_t(QScroller::ScrollerGestureType::MiddleMouseButtonGesture) //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QScroller_TypeF(),
        "2:PySide6.QtWidgets.QScroller.ScrollerGestureType",
        ScrollerGestureType_Initializer, ScrollerGestureType_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_ScrollerGestureType_IDX].type = EType;
    // Register converter for enum 'QScroller::ScrollerGestureType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QScroller_ScrollerGestureType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QScroller_ScrollerGestureType,
            is_Enum_PythonToCpp_QScroller_ScrollerGestureType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QScroller::ScrollerGestureType");
        Shiboken::Conversions::registerConverterAlias(converter, "ScrollerGestureType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ScrollerGestureType' enum.

    // Initialization of enum 'Input'.
    const char *Input_Initializer[] = {
        "InputPress",
        "InputMove",
        "InputRelease",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Input_InitializerValues[] = {
        uint8_t(QScroller::Input::InputPress),  //  0x01  1
        uint8_t(QScroller::Input::InputMove),   //  0x02  2
        uint8_t(QScroller::Input::InputRelease) //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QScroller_TypeF(),
        "2:PySide6.QtWidgets.QScroller.Input",
        Input_Initializer, Input_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_Input_IDX].type = EType;
    // Register converter for enum 'QScroller::Input'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QScroller_Input_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QScroller_Input,
            is_Enum_PythonToCpp_QScroller_Input_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QScroller::Input");
        Shiboken::Conversions::registerConverterAlias(converter, "Input");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Input' enum.

    PySide::Signal::registerSignals(pyType, &::QScroller::staticMetaObject);
    qRegisterMetaType< ::QScroller::State >("QScroller::State");
    qRegisterMetaType< ::QScroller::ScrollerGestureType >("QScroller::ScrollerGestureType");
    qRegisterMetaType< ::QScroller::Input >("QScroller::Input");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QScroller::staticMetaObject, sizeof(::QScroller));

    return pyType;
}
