// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QStyleWrapper_H
#define SBK_QStyleWrapper_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtWidgets/qstyle.h>

namespace PySide { class DynamicQMetaObject; }

class QStyleWrapper : public QStyle
{
public:
    QStyleWrapper(const QStyleWrapper &) = delete;
    QStyleWrapper& operator=(const QStyleWrapper &) = delete;
    QStyleWrapper(QStyleWrapper &&) = delete;
    QStyleWrapper& operator=(QStyleWrapper &&) = delete;

    QStyleWrapper();
    void childEvent(::QChildEvent * event) override;
    void connectNotify(const ::QMetaMethod & signal) override;
    void customEvent(::QEvent * event) override;
    void disconnectNotify(const ::QMetaMethod & signal) override;
    void drawComplexControl(::QStyle::ComplexControl cc, const ::QStyleOptionComplex * opt, ::QPainter * p, const ::QWidget * widget = nullptr) const override;
    void drawControl(::QStyle::ControlElement element, const ::QStyleOption * opt, ::QPainter * p, const ::QWidget * widget = nullptr) const override;
    void drawItemPixmap(::QPainter * painter, const ::QRect & rect, int alignment, const ::QPixmap & pixmap) const override;
    void drawItemText(::QPainter * painter, const ::QRect & rect, int flags, const ::QPalette & pal, bool enabled, const ::QString & text, ::QPalette::ColorRole textRole = QPalette::NoRole) const override;
    void drawPrimitive(::QStyle::PrimitiveElement pe, const ::QStyleOption * opt, ::QPainter * p, const ::QWidget * widget = nullptr) const override;
    bool event(::QEvent * event) override;
    bool eventFilter(::QObject * watched, ::QEvent * event) override;
    ::QPixmap generatedIconPixmap(::QIcon::Mode iconMode, const ::QPixmap & pixmap, const ::QStyleOption * opt) const override;
    ::QStyle::SubControl hitTestComplexControl(::QStyle::ComplexControl cc, const ::QStyleOptionComplex * opt, const ::QPoint & pt, const ::QWidget * widget = nullptr) const override;
    ::QRect itemPixmapRect(const ::QRect & r, int flags, const ::QPixmap & pixmap) const override;
    ::QRect itemTextRect(const ::QFontMetrics & fm, const ::QRect & r, int flags, bool enabled, const ::QString & text) const override;
    int layoutSpacing(::QSizePolicy::ControlType control1, ::QSizePolicy::ControlType control2, ::Qt::Orientation orientation, const ::QStyleOption * option = nullptr, const ::QWidget * widget = nullptr) const override;
    int pixelMetric(::QStyle::PixelMetric metric, const ::QStyleOption * option = nullptr, const ::QWidget * widget = nullptr) const override;
    void polish(::QApplication * application) override;
    void polish(::QPalette & palette) override;
    void polish(::QWidget * widget) override;
    ::QSize sizeFromContents(::QStyle::ContentsType ct, const ::QStyleOption * opt, const ::QSize & contentsSize, const ::QWidget * w = nullptr) const override;
    ::QIcon standardIcon(::QStyle::StandardPixmap standardIcon, const ::QStyleOption * option = nullptr, const ::QWidget * widget = nullptr) const override;
    ::QPalette standardPalette() const override;
    ::QPixmap standardPixmap(::QStyle::StandardPixmap standardPixmap, const ::QStyleOption * opt = nullptr, const ::QWidget * widget = nullptr) const override;
    int styleHint(::QStyle::StyleHint stylehint, const ::QStyleOption * opt = nullptr, const ::QWidget * widget = nullptr, ::QStyleHintReturn * returnData = nullptr) const override;
    ::QRect subControlRect(::QStyle::ComplexControl cc, const ::QStyleOptionComplex * opt, ::QStyle::SubControl sc, const ::QWidget * widget = nullptr) const override;
    ::QRect subElementRect(::QStyle::SubElement subElement, const ::QStyleOption * option, const ::QWidget * widget = nullptr) const override;
    void timerEvent(::QTimerEvent * event) override;
    void unpolish(::QApplication * application) override;
    void unpolish(::QWidget * widget) override;
    ~QStyleWrapper() override;

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();
    void resetPyMethodCache();
private:
    mutable bool m_PyMethodCache[30] = {false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QStyleWrapper_H

