// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qstylefactory_wrapper.h"

// Argument includes
#include <QString>
#include <QStringList>
#include <QtWidgets/qstyle.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStyleFactory_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QStyleFactory >()))
        return -1;

    ::QStyleFactory *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleFactory_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QStyleFactory()
        cptr = new ::QStyleFactory();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QStyleFactory >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QStyleFactoryFunc_create(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QStyleFactory::create(QString)->QStyle*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // create(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "create", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleFactory_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // create(QString)
            QStyle * cppResult = ::QStyleFactory::create(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_IDX]), cppResult);

            // Ownership transferences.
            Shiboken::Object::getOwnership(pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleFactoryFunc_keys(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // keys()
        QStringList cppResult = ::QStyleFactory::keys();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QStyleFactory_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QStyleFactory_methods[] = {
    {"create", reinterpret_cast<PyCFunction>(Sbk_QStyleFactoryFunc_create), METH_O|METH_STATIC, nullptr},
    {"keys", reinterpret_cast<PyCFunction>(Sbk_QStyleFactoryFunc_keys), METH_NOARGS|METH_STATIC, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QStyleFactory_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QStyleFactory_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QStyleFactory_Type = nullptr;
static PyTypeObject *Sbk_QStyleFactory_TypeF(void)
{
    return _Sbk_QStyleFactory_Type;
}

static PyType_Slot Sbk_QStyleFactory_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QStyleFactory_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QStyleFactory_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QStyleFactory_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QStyleFactory_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QStyleFactory_spec = {
    "2:PySide6.QtWidgets.QStyleFactory",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QStyleFactory_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QStyleFactory_PythonToCpp_QStyleFactory_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QStyleFactory_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QStyleFactory_PythonToCpp_QStyleFactory_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QStyleFactory_TypeF()))
        return QStyleFactory_PythonToCpp_QStyleFactory_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QStyleFactory_PTR_CppToPython_QStyleFactory(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QStyleFactory_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QStyleFactory_SignatureStrings[] = {
    "PySide6.QtWidgets.QStyleFactory(self)",
    "PySide6.QtWidgets.QStyleFactory.create(arg__1:QString)->PySide6.QtWidgets.QStyle",
    "PySide6.QtWidgets.QStyleFactory.keys()->QStringList",
    nullptr}; // Sentinel
#else
static constexpr size_t QStyleFactory_SignatureByteSize = 92;
static constexpr uint8_t QStyleFactory_SignatureBytes[92] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x09, 0xcf, 0x4c, 0x49,
    0x4f, 0x2d, 0x29, 0xd6, 0x0b, 0x0c, 0x2e, 0xa9, 0xcc, 0x49, 0x75, 0x4b, 0x4c, 0x2e, 0xc9, 0x2f,
    0xaa, 0xd4, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0xe4, 0x0a, 0xc0, 0xaf, 0x4a, 0x2f, 0xb9, 0x28, 0x35,
    0xb1, 0x24, 0x55, 0x23, 0xb1, 0x28, 0x3d, 0x3e, 0xde, 0xd0, 0x0a, 0x28, 0x57, 0x94, 0x99, 0x97,
    0xae, 0xa9, 0x6b, 0x87, 0x4b, 0x1f, 0x41, 0x03, 0xb3, 0x53, 0x2b, 0x8b, 0x35, 0x80, 0x06, 0x40,
    0x8d, 0xf2, 0xc9, 0x2c, 0x2e, 0xe1, 0x02, 0x00, 0xd2, 0x55, 0x3d, 0xad
};
#endif

PyTypeObject *init_QStyleFactory(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleFactory_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleFactory_IDX].type;

    Shiboken::AutoDecRef Sbk_QStyleFactory_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QStyleFactory_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QStyleFactory",
        "QStyleFactory*",
        &Sbk_QStyleFactory_spec,
        &Shiboken::callCppDestructor< ::QStyleFactory >,
        Sbk_QStyleFactory_Type_bases.object(),
        0);
    auto *pyType = Sbk_QStyleFactory_TypeF(); // references _Sbk_QStyleFactory_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QStyleFactory_SignatureStrings);
#else
    InitSignatureBytes(pyType, QStyleFactory_SignatureBytes, QStyleFactory_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QStyleFactory_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleFactory_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QStyleFactory_PythonToCpp_QStyleFactory_PTR,
        is_QStyleFactory_PythonToCpp_QStyleFactory_PTR_Convertible,
        QStyleFactory_PTR_CppToPython_QStyleFactory);

    Shiboken::Conversions::registerConverterName(converter, "QStyleFactory");
    Shiboken::Conversions::registerConverterName(converter, "QStyleFactory*");
    Shiboken::Conversions::registerConverterName(converter, "QStyleFactory&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QStyleFactory).name());

    qRegisterMetaType< ::QStyleFactory *>();

    return pyType;
}
