// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qstylehintreturn_wrapper.h"

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStyleHintReturn_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QStyleHintReturn >()))
        return -1;

    ::QStyleHintReturn *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleHintReturn_IDX]);

    if (PyArg_ParseTuple(args, "|OO:QStyleHintReturn", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QStyleHintReturn::QStyleHintReturn(int=,int=)
    if (numArgs == 0) {
        overloadId = 0; // QStyleHintReturn(int,int)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // QStyleHintReturn(int,int)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 0; // QStyleHintReturn(int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleHintReturn_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleHintReturn_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_version = Shiboken::String::createStaticString("version");
            if (PyDict_Contains(kwds, key_version) != 0) {
                value = PyDict_GetItem(kwds, key_version);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_version);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleHintReturn_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleHintReturn_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_version);
            }
            static PyObject *const key_type = Shiboken::String::createStaticString("type");
            if (PyDict_Contains(kwds, key_type) != 0) {
                value = PyDict_GetItem(kwds, key_type);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_type);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleHintReturn_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleHintReturn_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_type);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleHintReturn_IDX]);
            }
        }
        int cppArg0 = QStyleOption::Version;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1 = QStyleHintReturn::HintReturnType::SH_Default;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QStyleHintReturn(int,int)
            cptr = new ::QStyleHintReturn(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QStyleHintReturn >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleHintReturn_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}


static const char *Sbk_QStyleHintReturn_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QStyleHintReturn_EnumFlagInfo[] = {
    "HintReturnType:Enum",
    "StyleOptionType:Enum",
    "StyleOptionVersion:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QStyleHintReturn_methods[] = {
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QStyleHintReturn_get_version(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleHintReturn *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleHintReturn_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int cppOut_local = cppSelf->version;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QStyleHintReturn_set_version(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleHintReturn *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleHintReturn_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("version");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("version", "int");
        return -1;
    }

    auto cppOut_local = cppSelf->version;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->version = cppOut_local;

    return 0;
}

static PyObject *Sbk_QStyleHintReturn_get_type(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleHintReturn *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleHintReturn_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int cppOut_local = cppSelf->type;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QStyleHintReturn_set_type(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleHintReturn *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleHintReturn_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("type");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("type", "int");
        return -1;
    }

    auto cppOut_local = cppSelf->type;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->type = cppOut_local;

    return 0;
}

// Getters and Setters for QStyleHintReturn
static PyGetSetDef Sbk_QStyleHintReturn_getsetlist[] = {
    {const_cast<char *>("version"), Sbk_QStyleHintReturn_get_version, Sbk_QStyleHintReturn_set_version, nullptr, nullptr},
    {const_cast<char *>("type"), Sbk_QStyleHintReturn_get_type, Sbk_QStyleHintReturn_set_type, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QStyleHintReturn_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QStyleHintReturn_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QStyleHintReturn_Type = nullptr;
static PyTypeObject *Sbk_QStyleHintReturn_TypeF(void)
{
    return _Sbk_QStyleHintReturn_Type;
}

static PyType_Slot Sbk_QStyleHintReturn_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QStyleHintReturn_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QStyleHintReturn_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QStyleHintReturn_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QStyleHintReturn_getsetlist)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QStyleHintReturn_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QStyleHintReturn_spec = {
    "2:PySide6.QtWidgets.QStyleHintReturn",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QStyleHintReturn_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QStyleHintReturn_HintReturnType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStyleHintReturn::HintReturnType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStyleHintReturn::HintReturnType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QStyleHintReturn_HintReturnType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleHintReturn_HintReturnType_IDX])))
        return Enum_PythonToCpp_QStyleHintReturn_HintReturnType;
    return {};
}

static PyObject *QStyleHintReturn_HintReturnType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QStyleHintReturn::HintReturnType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QStyleHintReturn::HintReturnType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleHintReturn_HintReturnType_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QStyleHintReturn_StyleOptionType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStyleHintReturn::StyleOptionType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStyleHintReturn::StyleOptionType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QStyleHintReturn_StyleOptionType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleHintReturn_StyleOptionType_IDX])))
        return Enum_PythonToCpp_QStyleHintReturn_StyleOptionType;
    return {};
}

static PyObject *QStyleHintReturn_StyleOptionType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QStyleHintReturn::StyleOptionType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QStyleHintReturn::StyleOptionType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleHintReturn_StyleOptionType_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QStyleHintReturn_StyleOptionVersion(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStyleHintReturn::StyleOptionVersion>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStyleHintReturn::StyleOptionVersion *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QStyleHintReturn_StyleOptionVersion_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleHintReturn_StyleOptionVersion_IDX])))
        return Enum_PythonToCpp_QStyleHintReturn_StyleOptionVersion;
    return {};
}

static PyObject *QStyleHintReturn_StyleOptionVersion_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QStyleHintReturn::StyleOptionVersion>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QStyleHintReturn::StyleOptionVersion *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleHintReturn_StyleOptionVersion_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QStyleHintReturn_PythonToCpp_QStyleHintReturn_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QStyleHintReturn_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QStyleHintReturn_PythonToCpp_QStyleHintReturn_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QStyleHintReturn_TypeF()))
        return QStyleHintReturn_PythonToCpp_QStyleHintReturn_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QStyleHintReturn_PTR_CppToPython_QStyleHintReturn(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QStyleHintReturn_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QStyleHintReturn_SignatureStrings[] = {
    "PySide6.QtWidgets.QStyleHintReturn(self,version:int=QStyleOption.Version,type:int=QStyleHintReturn.HintReturnType.SH_Default)",
    nullptr}; // Sentinel
#else
static constexpr size_t QStyleHintReturn_SignatureByteSize = 97;
static constexpr uint8_t QStyleHintReturn_SignatureBytes[97] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x09, 0xcf, 0x4c, 0x49,
    0x4f, 0x2d, 0x29, 0xd6, 0x0b, 0x0c, 0x2e, 0xa9, 0xcc, 0x49, 0xf5, 0xc8, 0xcc, 0x2b, 0x09, 0x4a,
    0x2d, 0x29, 0x2d, 0xca, 0xd3, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0x29, 0x4b, 0x2d, 0x2a, 0xce, 0xcc,
    0xcf, 0xb3, 0x02, 0x0a, 0xdb, 0x42, 0x54, 0xf8, 0x17, 0x94, 0x00, 0x05, 0xf4, 0xc2, 0x20, 0x12,
    0x3a, 0x25, 0x95, 0x05, 0xa9, 0x48, 0xb2, 0x08, 0xfd, 0x7a, 0x08, 0x66, 0x08, 0x50, 0x8d, 0x5e,
    0xb0, 0x47, 0xbc, 0x4b, 0x6a, 0x5a, 0x62, 0x69, 0x4e, 0x89, 0x26, 0x17, 0x00, 0xec, 0x52, 0x2f,
    0xcf
};
#endif

PyTypeObject *init_QStyleHintReturn(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleHintReturn_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleHintReturn_IDX].type;

    Shiboken::AutoDecRef Sbk_QStyleHintReturn_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QStyleHintReturn_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QStyleHintReturn",
        "QStyleHintReturn*",
        &Sbk_QStyleHintReturn_spec,
        &Shiboken::callCppDestructor< ::QStyleHintReturn >,
        Sbk_QStyleHintReturn_Type_bases.object(),
        0);
    auto *pyType = Sbk_QStyleHintReturn_TypeF(); // references _Sbk_QStyleHintReturn_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QStyleHintReturn_SignatureStrings);
#else
    InitSignatureBytes(pyType, QStyleHintReturn_SignatureBytes, QStyleHintReturn_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QStyleHintReturn_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleHintReturn_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QStyleHintReturn_PythonToCpp_QStyleHintReturn_PTR,
        is_QStyleHintReturn_PythonToCpp_QStyleHintReturn_PTR_Convertible,
        QStyleHintReturn_PTR_CppToPython_QStyleHintReturn);

    Shiboken::Conversions::registerConverterName(converter, "QStyleHintReturn");
    Shiboken::Conversions::registerConverterName(converter, "QStyleHintReturn*");
    Shiboken::Conversions::registerConverterName(converter, "QStyleHintReturn&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QStyleHintReturn).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QStyleHintReturn_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'HintReturnType'.
    const char *HintReturnType_Initializer[] = {
        "SH_Default",
        "SH_Mask",
        "SH_Variant",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t HintReturnType_InitializerValues[] = {
        uint16_t(QStyleHintReturn::HintReturnType::SH_Default), //  0xf000  61440
        uint16_t(QStyleHintReturn::HintReturnType::SH_Mask),    //  0xf001  61441
        uint16_t(QStyleHintReturn::HintReturnType::SH_Variant)  //  0xf002  61442
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStyleHintReturn_TypeF(),
        "2:PySide6.QtWidgets.QStyleHintReturn.HintReturnType",
        HintReturnType_Initializer, HintReturnType_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleHintReturn_HintReturnType_IDX].type = EType;
    // Register converter for enum 'QStyleHintReturn::HintReturnType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStyleHintReturn_HintReturnType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QStyleHintReturn_HintReturnType,
            is_Enum_PythonToCpp_QStyleHintReturn_HintReturnType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QStyleHintReturn::HintReturnType");
        Shiboken::Conversions::registerConverterAlias(converter, "HintReturnType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'HintReturnType' enum.

    // Initialization of enum 'StyleOptionType'.
    const char *StyleOptionType_Initializer[] = {
        "Type",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t StyleOptionType_InitializerValues[] = {
        uint16_t(QStyleHintReturn::StyleOptionType::Type) //  0xf000  61440
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStyleHintReturn_TypeF(),
        "2:PySide6.QtWidgets.QStyleHintReturn.StyleOptionType",
        StyleOptionType_Initializer, StyleOptionType_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleHintReturn_StyleOptionType_IDX].type = EType;
    // Register converter for enum 'QStyleHintReturn::StyleOptionType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStyleHintReturn_StyleOptionType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QStyleHintReturn_StyleOptionType,
            is_Enum_PythonToCpp_QStyleHintReturn_StyleOptionType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QStyleHintReturn::StyleOptionType");
        Shiboken::Conversions::registerConverterAlias(converter, "StyleOptionType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'StyleOptionType' enum.

    // Initialization of enum 'StyleOptionVersion'.
    const char *StyleOptionVersion_Initializer[] = {
        "Version",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t StyleOptionVersion_InitializerValues[] = {
        uint8_t(QStyleHintReturn::StyleOptionVersion::Version) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStyleHintReturn_TypeF(),
        "2:PySide6.QtWidgets.QStyleHintReturn.StyleOptionVersion",
        StyleOptionVersion_Initializer, StyleOptionVersion_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleHintReturn_StyleOptionVersion_IDX].type = EType;
    // Register converter for enum 'QStyleHintReturn::StyleOptionVersion'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStyleHintReturn_StyleOptionVersion_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QStyleHintReturn_StyleOptionVersion,
            is_Enum_PythonToCpp_QStyleHintReturn_StyleOptionVersion_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QStyleHintReturn::StyleOptionVersion");
        Shiboken::Conversions::registerConverterAlias(converter, "StyleOptionVersion");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'StyleOptionVersion' enum.

    qRegisterMetaType< ::QStyleHintReturn *>();
    qRegisterMetaType< ::QStyleHintReturn::HintReturnType >("QStyleHintReturn::HintReturnType");
    qRegisterMetaType< ::QStyleHintReturn::StyleOptionType >("QStyleHintReturn::StyleOptionType");
    qRegisterMetaType< ::QStyleHintReturn::StyleOptionVersion >("QStyleHintReturn::StyleOptionVersion");

    return pyType;
}
