// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qstyleoptionbutton_wrapper.h"

// Argument includes
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStyleOptionButton_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QStyleOptionButton >()))
        return -1;

    ::QStyleOptionButton *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QStyleOptionButton", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QStyleOptionButton::QStyleOptionButton()
    // 1: QStyleOptionButton::QStyleOptionButton(QStyleOptionButton)
    // 2: QStyleOptionButton::QStyleOptionButton(int)
    if (numArgs == 0) {
        overloadId = 0; // QStyleOptionButton()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 2; // QStyleOptionButton(int)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionButton_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QStyleOptionButton(QStyleOptionButton)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionButton_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionButton_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QStyleOptionButton()
        {

            // QStyleOptionButton()
            cptr = new ::QStyleOptionButton();
            break;
        }
        case 1: // QStyleOptionButton(const QStyleOptionButton &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QStyleOptionButton *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QStyleOptionButton(QStyleOptionButton)
                cptr = new ::QStyleOptionButton(*cppArg0);
            }
            break;
        }
        case 2: // QStyleOptionButton(int version)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QStyleOptionButton(int)
                cptr = new ::QStyleOptionButton(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QStyleOptionButton >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionButton_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}


static const char *Sbk_QStyleOptionButton_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QStyleOptionButton_EnumFlagInfo[] = {
    "ButtonFeature:Flag:ButtonFeatures",
    "StyleOptionType:Enum",
    "StyleOptionVersion:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QStyleOptionButton_methods[] = {
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QStyleOptionButton_get_features(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionButton *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionButton_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QStyleOptionButton_ButtonFeature_IDX])))->flagsConverter, &cppSelf->features);
    return pyOut;
}
static int Sbk_QStyleOptionButton_set_features(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionButton *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionButton_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("features");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QStyleOptionButton_ButtonFeature_IDX])))->flagsConverter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("features", "ButtonFeatures");
        return -1;
    }

    auto cppOut_local = cppSelf->features;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->features = cppOut_local;

    return 0;
}

static PyObject *Sbk_QStyleOptionButton_get_text(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionButton *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionButton_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppSelf->text);
    return pyOut;
}
static int Sbk_QStyleOptionButton_set_text(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionButton *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionButton_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("text");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("text", "QString");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->text;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

static PyObject *Sbk_QStyleOptionButton_get_icon(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionButton *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionButton_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    if (reinterpret_cast<void *>(&(cppSelf->icon)) == reinterpret_cast<void *>(cppSelf)) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::Object::findColocatedChild(reinterpret_cast<SbkObject *>(self), Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QIcon_IDX])));
        if (pyOut != nullptr) {
            Py_IncRef(pyOut);
            return pyOut;
        }
    } else if (Shiboken::BindingManager::instance().hasWrapper(&(cppSelf->icon))) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(&(cppSelf->icon)));
        Py_IncRef(pyOut);
        return pyOut;
    }
    pyOut = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QIcon_IDX]), &(cppSelf->icon), false, true);
    Shiboken::Object::setParent(self, pyOut);
    return pyOut;
}
static int Sbk_QStyleOptionButton_set_icon(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionButton *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionButton_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("icon");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QIcon_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("icon", "QIcon");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->icon;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

static PyObject *Sbk_QStyleOptionButton_get_iconSize(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionButton *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionButton_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    if (reinterpret_cast<void *>(&(cppSelf->iconSize)) == reinterpret_cast<void *>(cppSelf)) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::Object::findColocatedChild(reinterpret_cast<SbkObject *>(self), Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX])));
        if (pyOut != nullptr) {
            Py_IncRef(pyOut);
            return pyOut;
        }
    } else if (Shiboken::BindingManager::instance().hasWrapper(&(cppSelf->iconSize))) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(&(cppSelf->iconSize)));
        Py_IncRef(pyOut);
        return pyOut;
    }
    pyOut = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &(cppSelf->iconSize), false, true);
    Shiboken::Object::setParent(self, pyOut);
    return pyOut;
}
static int Sbk_QStyleOptionButton_set_iconSize(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionButton *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionButton_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("iconSize");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("iconSize", "QSize");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->iconSize;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

// Getters and Setters for QStyleOptionButton
static PyGetSetDef Sbk_QStyleOptionButton_getsetlist[] = {
    {const_cast<char *>("features"), Sbk_QStyleOptionButton_get_features, Sbk_QStyleOptionButton_set_features, nullptr, nullptr},
    {const_cast<char *>("text"), Sbk_QStyleOptionButton_get_text, Sbk_QStyleOptionButton_set_text, nullptr, nullptr},
    {const_cast<char *>("icon"), Sbk_QStyleOptionButton_get_icon, Sbk_QStyleOptionButton_set_icon, nullptr, nullptr},
    {const_cast<char *>("iconSize"), Sbk_QStyleOptionButton_get_iconSize, Sbk_QStyleOptionButton_set_iconSize, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QStyleOptionButton_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QStyleOptionButton_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QStyleOptionButton_Type = nullptr;
static PyTypeObject *Sbk_QStyleOptionButton_TypeF(void)
{
    return _Sbk_QStyleOptionButton_Type;
}

static PyType_Slot Sbk_QStyleOptionButton_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QStyleOptionButton_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QStyleOptionButton_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QStyleOptionButton_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QStyleOptionButton_getsetlist)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QStyleOptionButton_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QStyleOptionButton_spec = {
    "2:PySide6.QtWidgets.QStyleOptionButton",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QStyleOptionButton_slots
};

} //extern "C"

static void *Sbk_QStyleOptionButton_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (qstyleoption_cast<const QStyleOptionButton *>( reinterpret_cast< ::QStyleOption *>(cptr)) != nullptr)
        return cptr;
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QStyleOptionButton_StyleOptionType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStyleOptionButton::StyleOptionType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStyleOptionButton::StyleOptionType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QStyleOptionButton_StyleOptionType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionButton_StyleOptionType_IDX])))
        return Enum_PythonToCpp_QStyleOptionButton_StyleOptionType;
    return {};
}

static PyObject *QStyleOptionButton_StyleOptionType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QStyleOptionButton::StyleOptionType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QStyleOptionButton::StyleOptionType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionButton_StyleOptionType_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QStyleOptionButton_StyleOptionVersion(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStyleOptionButton::StyleOptionVersion>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStyleOptionButton::StyleOptionVersion *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QStyleOptionButton_StyleOptionVersion_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionButton_StyleOptionVersion_IDX])))
        return Enum_PythonToCpp_QStyleOptionButton_StyleOptionVersion;
    return {};
}

static PyObject *QStyleOptionButton_StyleOptionVersion_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QStyleOptionButton::StyleOptionVersion>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QStyleOptionButton::StyleOptionVersion *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionButton_StyleOptionVersion_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QStyleOptionButton_ButtonFeature(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStyleOptionButton::ButtonFeature>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStyleOptionButton::ButtonFeature *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QStyleOptionButton_ButtonFeature_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionButton_ButtonFeature_IDX])))
        return Enum_PythonToCpp_QStyleOptionButton_ButtonFeature;
    return {};
}

static PyObject *QStyleOptionButton_ButtonFeature_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QStyleOptionButton::ButtonFeature>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QStyleOptionButton::ButtonFeature *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionButton_ButtonFeature_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QStyleOptionButton_ButtonFeature(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QStyleOptionButton::ButtonFeature>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QStyleOptionButton::ButtonFeature> *>(cppOut) = value;

}

static PyObject *QStyleOptionButton_ButtonFeature_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QStyleOptionButton::ButtonFeature> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionButton_ButtonFeature_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QStyleOptionButton_PythonToCpp_QStyleOptionButton_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QStyleOptionButton_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QStyleOptionButton_PythonToCpp_QStyleOptionButton_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QStyleOptionButton_TypeF()))
        return QStyleOptionButton_PythonToCpp_QStyleOptionButton_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QStyleOptionButton_PTR_CppToPython_QStyleOptionButton(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QStyleOptionButton_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QStyleOptionButton_SignatureStrings[] = {
    "2:PySide6.QtWidgets.QStyleOptionButton(self)",
    "1:PySide6.QtWidgets.QStyleOptionButton(self,other:PySide6.QtWidgets.QStyleOptionButton)",
    "0:PySide6.QtWidgets.QStyleOptionButton(self,version:int)",
    nullptr}; // Sentinel
#else
static constexpr size_t QStyleOptionButton_SignatureByteSize = 82;
static constexpr uint8_t QStyleOptionButton_SignatureBytes[82] = {
    0x78, 0xda, 0x33, 0xb2, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x09, 0xcf,
    0x4c, 0x49, 0x4f, 0x2d, 0x29, 0xd6, 0x0b, 0x0c, 0x2e, 0xa9, 0xcc, 0x49, 0xf5, 0x2f, 0x28, 0xc9,
    0xcc, 0xcf, 0x73, 0x2a, 0x2d, 0x29, 0xc9, 0xcf, 0xd3, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0xe4, 0x32,
    0x24, 0x5e, 0xb1, 0x4e, 0x7e, 0x49, 0x46, 0x6a, 0x11, 0x51, 0xea, 0x35, 0xb9, 0x0c, 0x48, 0x30,
    0xb7, 0x2c, 0xb5, 0xa8, 0x18, 0x28, 0x64, 0x95, 0x99, 0x57, 0xa2, 0xc9, 0x05, 0x00, 0xe9, 0xdf,
    0x45, 0xdc
};
#endif

PyTypeObject *init_QStyleOptionButton(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionButton_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionButton_IDX].type;

    Shiboken::AutoDecRef Sbk_QStyleOptionButton_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]))));

    _Sbk_QStyleOptionButton_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QStyleOptionButton",
        "QStyleOptionButton*",
        &Sbk_QStyleOptionButton_spec,
        &Shiboken::callCppDestructor< ::QStyleOptionButton >,
        Sbk_QStyleOptionButton_Type_bases.object(),
        0);
    auto *pyType = Sbk_QStyleOptionButton_TypeF(); // references _Sbk_QStyleOptionButton_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QStyleOptionButton_SignatureStrings);
#else
    InitSignatureBytes(pyType, QStyleOptionButton_SignatureBytes, QStyleOptionButton_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QStyleOptionButton_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionButton_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QStyleOptionButton_PythonToCpp_QStyleOptionButton_PTR,
        is_QStyleOptionButton_PythonToCpp_QStyleOptionButton_PTR_Convertible,
        QStyleOptionButton_PTR_CppToPython_QStyleOptionButton);

    Shiboken::Conversions::registerConverterName(converter, "QStyleOptionButton");
    Shiboken::Conversions::registerConverterName(converter, "QStyleOptionButton*");
    Shiboken::Conversions::registerConverterName(converter, "QStyleOptionButton&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QStyleOptionButton).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QStyleOptionButton_TypeF(), &Sbk_QStyleOptionButton_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QStyleOptionButton_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'StyleOptionType'.
    const char *StyleOptionType_Initializer[] = {
        "Type",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t StyleOptionType_InitializerValues[] = {
        uint8_t(QStyleOptionButton::StyleOptionType::Type) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStyleOptionButton_TypeF(),
        "2:PySide6.QtWidgets.QStyleOptionButton.StyleOptionType",
        StyleOptionType_Initializer, StyleOptionType_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionButton_StyleOptionType_IDX].type = EType;
    // Register converter for enum 'QStyleOptionButton::StyleOptionType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStyleOptionButton_StyleOptionType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QStyleOptionButton_StyleOptionType,
            is_Enum_PythonToCpp_QStyleOptionButton_StyleOptionType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QStyleOptionButton::StyleOptionType");
        Shiboken::Conversions::registerConverterAlias(converter, "StyleOptionType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'StyleOptionType' enum.

    // Initialization of enum 'StyleOptionVersion'.
    const char *StyleOptionVersion_Initializer[] = {
        "Version",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t StyleOptionVersion_InitializerValues[] = {
        uint8_t(QStyleOptionButton::StyleOptionVersion::Version) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStyleOptionButton_TypeF(),
        "2:PySide6.QtWidgets.QStyleOptionButton.StyleOptionVersion",
        StyleOptionVersion_Initializer, StyleOptionVersion_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionButton_StyleOptionVersion_IDX].type = EType;
    // Register converter for enum 'QStyleOptionButton::StyleOptionVersion'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStyleOptionButton_StyleOptionVersion_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QStyleOptionButton_StyleOptionVersion,
            is_Enum_PythonToCpp_QStyleOptionButton_StyleOptionVersion_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QStyleOptionButton::StyleOptionVersion");
        Shiboken::Conversions::registerConverterAlias(converter, "StyleOptionVersion");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'StyleOptionVersion' enum.

    // Initialization of enum 'ButtonFeature'.
    const char *ButtonFeature_Initializer[] = {
        "None_",
        "Flat",
        "HasMenu",
        "DefaultButton",
        "AutoDefaultButton",
        "CommandLinkButton",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ButtonFeature_InitializerValues[] = {
        uint8_t(QStyleOptionButton::ButtonFeature::None),              //  0x00  0
        uint8_t(QStyleOptionButton::ButtonFeature::Flat),              //  0x01  1
        uint8_t(QStyleOptionButton::ButtonFeature::HasMenu),           //  0x02  2
        uint8_t(QStyleOptionButton::ButtonFeature::DefaultButton),     //  0x04  4
        uint8_t(QStyleOptionButton::ButtonFeature::AutoDefaultButton), //  0x08  8
        uint8_t(QStyleOptionButton::ButtonFeature::CommandLinkButton)  //  0x10  16
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStyleOptionButton_TypeF(),
        "2:PySide6.QtWidgets.QStyleOptionButton.ButtonFeature",
        ButtonFeature_Initializer, ButtonFeature_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionButton_ButtonFeature_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QStyleOptionButton_ButtonFeature_IDX].type =
        EType;
    // Register converter for enum 'QStyleOptionButton::ButtonFeature'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStyleOptionButton_ButtonFeature_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QStyleOptionButton_ButtonFeature,
            is_Enum_PythonToCpp_QStyleOptionButton_ButtonFeature_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QStyleOptionButton::ButtonFeature");
        Shiboken::Conversions::registerConverterAlias(converter, "ButtonFeature");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QStyleOptionButton_ButtonFeature_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QStyleOptionButton_ButtonFeature,
            is_Enum_PythonToCpp_QStyleOptionButton_ButtonFeature_Convertible);
        // Register converter for flag 'QFlags<QStyleOptionButton::ButtonFeature>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QStyleOptionButton::ButtonFeature>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QStyleOptionButton::ButtonFeatures");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'ButtonFeature' enum/flags.

    qRegisterMetaType< ::QStyleOptionButton *>();
    qRegisterMetaType< ::QStyleOptionButton::StyleOptionType >("QStyleOptionButton::StyleOptionType");
    qRegisterMetaType< ::QStyleOptionButton::StyleOptionVersion >("QStyleOptionButton::StyleOptionVersion");
    qRegisterMetaType< ::QStyleOptionButton::ButtonFeature >("QStyleOptionButton::ButtonFeature");

    return pyType;
}
