// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qstyleoptioncomplex_wrapper.h"

// Argument includes
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStyleOptionComplex_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QStyleOptionComplex >()))
        return -1;

    ::QStyleOptionComplex *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComplex_IDX]);

    if (PyArg_ParseTuple(args, "|OO:QStyleOptionComplex", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QStyleOptionComplex::QStyleOptionComplex(QStyleOptionComplex)
    // 1: QStyleOptionComplex::QStyleOptionComplex(int=,int=)
    if (numArgs == 0) {
        overloadId = 1; // QStyleOptionComplex(int,int)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QStyleOptionComplex(int,int)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 1; // QStyleOptionComplex(int,int)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComplex_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QStyleOptionComplex(QStyleOptionComplex)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComplex_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComplex_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QStyleOptionComplex(const QStyleOptionComplex &other)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComplex_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QStyleOptionComplex *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QStyleOptionComplex(QStyleOptionComplex)
                cptr = new ::QStyleOptionComplex(*cppArg0);
            }
            break;
        }
        case 1: // QStyleOptionComplex(int version, int type)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_version = Shiboken::String::createStaticString("version");
                if (PyDict_Contains(kwds, key_version) != 0) {
                    value = PyDict_GetItem(kwds, key_version);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_version);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComplex_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComplex_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_version);
                }
                static PyObject *const key_type = Shiboken::String::createStaticString("type");
                if (PyDict_Contains(kwds, key_type) != 0) {
                    value = PyDict_GetItem(kwds, key_type);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_type);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComplex_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComplex_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_type);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComplex_IDX]);
                }
            }
            int cppArg0 = QStyleOptionComplex::StyleOptionVersion::Version;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1 = QStyleOption::OptionType::SO_Complex;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QStyleOptionComplex(int,int)
                cptr = new ::QStyleOptionComplex(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QStyleOptionComplex >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComplex_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}


static const char *Sbk_QStyleOptionComplex_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QStyleOptionComplex_EnumFlagInfo[] = {
    "StyleOptionType:Enum",
    "StyleOptionVersion:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QStyleOptionComplex_methods[] = {
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QStyleOptionComplex_get_subControls(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionComplex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComplex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QStyle_SubControl_IDX])))->flagsConverter, &cppSelf->subControls);
    return pyOut;
}
static int Sbk_QStyleOptionComplex_set_subControls(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionComplex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComplex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("subControls");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QStyle_SubControl_IDX])))->flagsConverter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("subControls", "SubControls");
        return -1;
    }

    auto cppOut_local = cppSelf->subControls;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->subControls = cppOut_local;

    return 0;
}

static PyObject *Sbk_QStyleOptionComplex_get_activeSubControls(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionComplex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComplex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QStyle_SubControl_IDX])))->flagsConverter, &cppSelf->activeSubControls);
    return pyOut;
}
static int Sbk_QStyleOptionComplex_set_activeSubControls(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionComplex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComplex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("activeSubControls");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QStyle_SubControl_IDX])))->flagsConverter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("activeSubControls", "SubControls");
        return -1;
    }

    auto cppOut_local = cppSelf->activeSubControls;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->activeSubControls = cppOut_local;

    return 0;
}

// Getters and Setters for QStyleOptionComplex
static PyGetSetDef Sbk_QStyleOptionComplex_getsetlist[] = {
    {const_cast<char *>("subControls"), Sbk_QStyleOptionComplex_get_subControls, Sbk_QStyleOptionComplex_set_subControls, nullptr, nullptr},
    {const_cast<char *>("activeSubControls"), Sbk_QStyleOptionComplex_get_activeSubControls, Sbk_QStyleOptionComplex_set_activeSubControls, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QStyleOptionComplex_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QStyleOptionComplex_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QStyleOptionComplex_Type = nullptr;
static PyTypeObject *Sbk_QStyleOptionComplex_TypeF(void)
{
    return _Sbk_QStyleOptionComplex_Type;
}

static PyType_Slot Sbk_QStyleOptionComplex_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QStyleOptionComplex_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QStyleOptionComplex_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QStyleOptionComplex_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QStyleOptionComplex_getsetlist)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QStyleOptionComplex_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QStyleOptionComplex_spec = {
    "2:PySide6.QtWidgets.QStyleOptionComplex",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QStyleOptionComplex_slots
};

} //extern "C"

static void *Sbk_QStyleOptionComplex_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (qstyleoption_cast<const QStyleOptionComplex *>( reinterpret_cast< ::QStyleOption *>(cptr)) != nullptr)
        return cptr;
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QStyleOptionComplex_StyleOptionType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStyleOptionComplex::StyleOptionType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStyleOptionComplex::StyleOptionType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QStyleOptionComplex_StyleOptionType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComplex_StyleOptionType_IDX])))
        return Enum_PythonToCpp_QStyleOptionComplex_StyleOptionType;
    return {};
}

static PyObject *QStyleOptionComplex_StyleOptionType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QStyleOptionComplex::StyleOptionType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QStyleOptionComplex::StyleOptionType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComplex_StyleOptionType_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QStyleOptionComplex_StyleOptionVersion(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStyleOptionComplex::StyleOptionVersion>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStyleOptionComplex::StyleOptionVersion *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QStyleOptionComplex_StyleOptionVersion_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComplex_StyleOptionVersion_IDX])))
        return Enum_PythonToCpp_QStyleOptionComplex_StyleOptionVersion;
    return {};
}

static PyObject *QStyleOptionComplex_StyleOptionVersion_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QStyleOptionComplex::StyleOptionVersion>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QStyleOptionComplex::StyleOptionVersion *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComplex_StyleOptionVersion_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QStyleOptionComplex_PythonToCpp_QStyleOptionComplex_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QStyleOptionComplex_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QStyleOptionComplex_PythonToCpp_QStyleOptionComplex_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QStyleOptionComplex_TypeF()))
        return QStyleOptionComplex_PythonToCpp_QStyleOptionComplex_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QStyleOptionComplex_PTR_CppToPython_QStyleOptionComplex(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QStyleOptionComplex_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QStyleOptionComplex_SignatureStrings[] = {
    "1:PySide6.QtWidgets.QStyleOptionComplex(self,other:PySide6.QtWidgets.QStyleOptionComplex)",
    "0:PySide6.QtWidgets.QStyleOptionComplex(self,version:int=QStyleOptionComplex.StyleOptionVersion.Version,type:int=QStyleOption.OptionType.SO_Complex)",
    nullptr}; // Sentinel
#else
static constexpr size_t QStyleOptionComplex_SignatureByteSize = 106;
static constexpr uint8_t QStyleOptionComplex_SignatureBytes[106] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x09, 0xcf,
    0x4c, 0x49, 0x4f, 0x2d, 0x29, 0xd6, 0x0b, 0x0c, 0x2e, 0xa9, 0xcc, 0x49, 0xf5, 0x2f, 0x28, 0xc9,
    0xcc, 0xcf, 0x73, 0xce, 0xcf, 0x2d, 0xc8, 0x49, 0xad, 0xd0, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0xc9,
    0x2f, 0xc9, 0x48, 0x2d, 0x22, 0x4e, 0x83, 0x26, 0x97, 0x01, 0x29, 0x26, 0x97, 0xa5, 0x16, 0x15,
    0x03, 0xc5, 0xac, 0x32, 0xf3, 0x4a, 0x6c, 0xb1, 0x28, 0xd2, 0x43, 0x12, 0x0a, 0x83, 0x28, 0xd5,
    0x83, 0xd2, 0x3a, 0x25, 0x95, 0x05, 0xa9, 0x18, 0xfa, 0xf4, 0x20, 0x54, 0x08, 0x50, 0x4e, 0x2f,
    0xd8, 0x3f, 0x1e, 0xee, 0x28, 0x00, 0xec, 0x54, 0x5a, 0x29
};
#endif

PyTypeObject *init_QStyleOptionComplex(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComplex_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComplex_IDX].type;

    Shiboken::AutoDecRef Sbk_QStyleOptionComplex_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]))));

    _Sbk_QStyleOptionComplex_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QStyleOptionComplex",
        "QStyleOptionComplex*",
        &Sbk_QStyleOptionComplex_spec,
        &Shiboken::callCppDestructor< ::QStyleOptionComplex >,
        Sbk_QStyleOptionComplex_Type_bases.object(),
        0);
    auto *pyType = Sbk_QStyleOptionComplex_TypeF(); // references _Sbk_QStyleOptionComplex_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QStyleOptionComplex_SignatureStrings);
#else
    InitSignatureBytes(pyType, QStyleOptionComplex_SignatureBytes, QStyleOptionComplex_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QStyleOptionComplex_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComplex_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QStyleOptionComplex_PythonToCpp_QStyleOptionComplex_PTR,
        is_QStyleOptionComplex_PythonToCpp_QStyleOptionComplex_PTR_Convertible,
        QStyleOptionComplex_PTR_CppToPython_QStyleOptionComplex);

    Shiboken::Conversions::registerConverterName(converter, "QStyleOptionComplex");
    Shiboken::Conversions::registerConverterName(converter, "QStyleOptionComplex*");
    Shiboken::Conversions::registerConverterName(converter, "QStyleOptionComplex&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QStyleOptionComplex).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QStyleOptionComplex_TypeF(), &Sbk_QStyleOptionComplex_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QStyleOptionComplex_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'StyleOptionType'.
    const char *StyleOptionType_Initializer[] = {
        "Type",
        nullptr};
    // "uint32_t" used instead of "unsigned int"
    constexpr uint32_t StyleOptionType_InitializerValues[] = {
        uint32_t(QStyleOptionComplex::StyleOptionType::Type) //  0x000f0000  983040
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStyleOptionComplex_TypeF(),
        "2:PySide6.QtWidgets.QStyleOptionComplex.StyleOptionType",
        StyleOptionType_Initializer, StyleOptionType_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComplex_StyleOptionType_IDX].type = EType;
    // Register converter for enum 'QStyleOptionComplex::StyleOptionType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStyleOptionComplex_StyleOptionType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QStyleOptionComplex_StyleOptionType,
            is_Enum_PythonToCpp_QStyleOptionComplex_StyleOptionType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QStyleOptionComplex::StyleOptionType");
        Shiboken::Conversions::registerConverterAlias(converter, "StyleOptionType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'StyleOptionType' enum.

    // Initialization of enum 'StyleOptionVersion'.
    const char *StyleOptionVersion_Initializer[] = {
        "Version",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t StyleOptionVersion_InitializerValues[] = {
        uint8_t(QStyleOptionComplex::StyleOptionVersion::Version) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStyleOptionComplex_TypeF(),
        "2:PySide6.QtWidgets.QStyleOptionComplex.StyleOptionVersion",
        StyleOptionVersion_Initializer, StyleOptionVersion_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComplex_StyleOptionVersion_IDX].type = EType;
    // Register converter for enum 'QStyleOptionComplex::StyleOptionVersion'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStyleOptionComplex_StyleOptionVersion_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QStyleOptionComplex_StyleOptionVersion,
            is_Enum_PythonToCpp_QStyleOptionComplex_StyleOptionVersion_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QStyleOptionComplex::StyleOptionVersion");
        Shiboken::Conversions::registerConverterAlias(converter, "StyleOptionVersion");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'StyleOptionVersion' enum.

    qRegisterMetaType< ::QStyleOptionComplex *>();
    qRegisterMetaType< ::QStyleOptionComplex::StyleOptionType >("QStyleOptionComplex::StyleOptionType");
    qRegisterMetaType< ::QStyleOptionComplex::StyleOptionVersion >("QStyleOptionComplex::StyleOptionVersion");

    return pyType;
}
