// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qstyleoptiongraphicsitem_wrapper.h"

// Argument includes
#include <QtGui/qtransform.h>
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStyleOptionGraphicsItem_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QStyleOptionGraphicsItem >()))
        return -1;

    ::QStyleOptionGraphicsItem *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QStyleOptionGraphicsItem", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QStyleOptionGraphicsItem::QStyleOptionGraphicsItem()
    // 1: QStyleOptionGraphicsItem::QStyleOptionGraphicsItem(QStyleOptionGraphicsItem)
    // 2: QStyleOptionGraphicsItem::QStyleOptionGraphicsItem(int)
    if (numArgs == 0) {
        overloadId = 0; // QStyleOptionGraphicsItem()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 2; // QStyleOptionGraphicsItem(int)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionGraphicsItem_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QStyleOptionGraphicsItem(QStyleOptionGraphicsItem)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionGraphicsItem_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionGraphicsItem_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QStyleOptionGraphicsItem()
        {

            // QStyleOptionGraphicsItem()
            cptr = new ::QStyleOptionGraphicsItem();
            break;
        }
        case 1: // QStyleOptionGraphicsItem(const QStyleOptionGraphicsItem &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QStyleOptionGraphicsItem *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QStyleOptionGraphicsItem(QStyleOptionGraphicsItem)
                cptr = new ::QStyleOptionGraphicsItem(*cppArg0);
            }
            break;
        }
        case 2: // QStyleOptionGraphicsItem(int version)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QStyleOptionGraphicsItem(int)
                cptr = new ::QStyleOptionGraphicsItem(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QStyleOptionGraphicsItem >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionGraphicsItem_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QStyleOptionGraphicsItemFunc_levelOfDetailFromTransform(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QStyleOptionGraphicsItem::levelOfDetailFromTransform(QTransform)->qreal
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), (pyArg)))) {
        overloadId = 0; // levelOfDetailFromTransform(QTransform)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "levelOfDetailFromTransform", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionGraphicsItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTransform cppArg0_local;
        ::QTransform *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // levelOfDetailFromTransform(QTransform)
            qreal cppResult = ::QStyleOptionGraphicsItem::levelOfDetailFromTransform(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QStyleOptionGraphicsItem_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QStyleOptionGraphicsItem_EnumFlagInfo[] = {
    "StyleOptionType:Enum",
    "StyleOptionVersion:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QStyleOptionGraphicsItem_methods[] = {
    {"levelOfDetailFromTransform", reinterpret_cast<PyCFunction>(Sbk_QStyleOptionGraphicsItemFunc_levelOfDetailFromTransform), METH_O|METH_STATIC, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QStyleOptionGraphicsItem_get_exposedRect(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionGraphicsItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionGraphicsItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    if (reinterpret_cast<void *>(&(cppSelf->exposedRect)) == reinterpret_cast<void *>(cppSelf)) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::Object::findColocatedChild(reinterpret_cast<SbkObject *>(self), Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX])));
        if (pyOut != nullptr) {
            Py_IncRef(pyOut);
            return pyOut;
        }
    } else if (Shiboken::BindingManager::instance().hasWrapper(&(cppSelf->exposedRect))) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(&(cppSelf->exposedRect)));
        Py_IncRef(pyOut);
        return pyOut;
    }
    pyOut = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &(cppSelf->exposedRect), false, true);
    Shiboken::Object::setParent(self, pyOut);
    return pyOut;
}
static int Sbk_QStyleOptionGraphicsItem_set_exposedRect(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionGraphicsItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionGraphicsItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("exposedRect");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("exposedRect", "QRectF");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->exposedRect;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

// Getters and Setters for QStyleOptionGraphicsItem
static PyGetSetDef Sbk_QStyleOptionGraphicsItem_getsetlist[] = {
    {const_cast<char *>("exposedRect"), Sbk_QStyleOptionGraphicsItem_get_exposedRect, Sbk_QStyleOptionGraphicsItem_set_exposedRect, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QStyleOptionGraphicsItem_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QStyleOptionGraphicsItem_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QStyleOptionGraphicsItem_Type = nullptr;
static PyTypeObject *Sbk_QStyleOptionGraphicsItem_TypeF(void)
{
    return _Sbk_QStyleOptionGraphicsItem_Type;
}

static PyType_Slot Sbk_QStyleOptionGraphicsItem_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QStyleOptionGraphicsItem_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QStyleOptionGraphicsItem_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QStyleOptionGraphicsItem_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QStyleOptionGraphicsItem_getsetlist)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QStyleOptionGraphicsItem_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QStyleOptionGraphicsItem_spec = {
    "2:PySide6.QtWidgets.QStyleOptionGraphicsItem",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QStyleOptionGraphicsItem_slots
};

} //extern "C"

static void *Sbk_QStyleOptionGraphicsItem_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (qstyleoption_cast<const QStyleOptionGraphicsItem *>( reinterpret_cast< ::QStyleOption *>(cptr)) != nullptr)
        return cptr;
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QStyleOptionGraphicsItem_StyleOptionType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStyleOptionGraphicsItem::StyleOptionType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStyleOptionGraphicsItem::StyleOptionType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QStyleOptionGraphicsItem_StyleOptionType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionGraphicsItem_StyleOptionType_IDX])))
        return Enum_PythonToCpp_QStyleOptionGraphicsItem_StyleOptionType;
    return {};
}

static PyObject *QStyleOptionGraphicsItem_StyleOptionType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QStyleOptionGraphicsItem::StyleOptionType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QStyleOptionGraphicsItem::StyleOptionType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionGraphicsItem_StyleOptionType_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QStyleOptionGraphicsItem_StyleOptionVersion(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStyleOptionGraphicsItem::StyleOptionVersion>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStyleOptionGraphicsItem::StyleOptionVersion *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QStyleOptionGraphicsItem_StyleOptionVersion_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionGraphicsItem_StyleOptionVersion_IDX])))
        return Enum_PythonToCpp_QStyleOptionGraphicsItem_StyleOptionVersion;
    return {};
}

static PyObject *QStyleOptionGraphicsItem_StyleOptionVersion_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QStyleOptionGraphicsItem::StyleOptionVersion>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QStyleOptionGraphicsItem::StyleOptionVersion *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionGraphicsItem_StyleOptionVersion_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QStyleOptionGraphicsItem_PythonToCpp_QStyleOptionGraphicsItem_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QStyleOptionGraphicsItem_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QStyleOptionGraphicsItem_PythonToCpp_QStyleOptionGraphicsItem_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QStyleOptionGraphicsItem_TypeF()))
        return QStyleOptionGraphicsItem_PythonToCpp_QStyleOptionGraphicsItem_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QStyleOptionGraphicsItem_PTR_CppToPython_QStyleOptionGraphicsItem(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QStyleOptionGraphicsItem_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QStyleOptionGraphicsItem_SignatureStrings[] = {
    "2:PySide6.QtWidgets.QStyleOptionGraphicsItem(self)",
    "1:PySide6.QtWidgets.QStyleOptionGraphicsItem(self,other:PySide6.QtWidgets.QStyleOptionGraphicsItem)",
    "0:PySide6.QtWidgets.QStyleOptionGraphicsItem(self,version:int)",
    "PySide6.QtWidgets.QStyleOptionGraphicsItem.levelOfDetailFromTransform(worldTransform:PySide6.QtGui.QTransform)->qreal",
    nullptr}; // Sentinel
#else
static constexpr size_t QStyleOptionGraphicsItem_SignatureByteSize = 139;
static constexpr uint8_t QStyleOptionGraphicsItem_SignatureBytes[139] = {
    0x78, 0xda, 0x95, 0x8e, 0x31, 0x0b, 0xc2, 0x30, 0x10, 0x46, 0xf7, 0xfc, 0x92, 0x06, 0x34, 0xa8,
    0x83, 0x43, 0x07, 0x27, 0xb1, 0x38, 0xd5, 0x50, 0xc1, 0x39, 0x98, 0x8b, 0x3d, 0xb8, 0x26, 0xf5,
    0x72, 0x56, 0xfa, 0xef, 0x75, 0x2a, 0x8e, 0x66, 0xfc, 0x78, 0x3c, 0xde, 0xb7, 0xab, 0x2f, 0x73,
    0x87, 0x1e, 0xf6, 0xc6, 0xca, 0x0d, 0xfd, 0x03, 0x24, 0x1b, 0xdb, 0xc9, 0x4c, 0xd0, 0x8e, 0x82,
    0x29, 0x36, 0xec, 0xc6, 0x1e, 0xef, 0xf9, 0x2c, 0x30, 0x54, 0x19, 0x28, 0x68, 0xb5, 0x2d, 0x55,
    0x56, 0x49, 0x7a, 0xe0, 0x02, 0x4b, 0xab, 0x4d, 0x71, 0x63, 0x02, 0xce, 0x5f, 0x50, 0x63, 0x14,
    0xad, 0xfe, 0x97, 0x0d, 0xc1, 0x04, 0xd4, 0x86, 0x23, 0x88, 0x43, 0x3a, 0x71, 0x1a, 0xae, 0xec,
    0x62, 0x0e, 0x89, 0x87, 0xea, 0x9d, 0x98, 0xfc, 0x32, 0x7f, 0x1e, 0x35, 0x2f, 0x34, 0x76, 0x01,
    0x7a, 0x7d, 0x78, 0x32, 0x38, 0x52, 0x1f, 0xdc, 0x8e, 0x7b, 0x71
};
#endif

PyTypeObject *init_QStyleOptionGraphicsItem(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionGraphicsItem_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionGraphicsItem_IDX].type;

    Shiboken::AutoDecRef Sbk_QStyleOptionGraphicsItem_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]))));

    _Sbk_QStyleOptionGraphicsItem_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QStyleOptionGraphicsItem",
        "QStyleOptionGraphicsItem*",
        &Sbk_QStyleOptionGraphicsItem_spec,
        &Shiboken::callCppDestructor< ::QStyleOptionGraphicsItem >,
        Sbk_QStyleOptionGraphicsItem_Type_bases.object(),
        0);
    auto *pyType = Sbk_QStyleOptionGraphicsItem_TypeF(); // references _Sbk_QStyleOptionGraphicsItem_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QStyleOptionGraphicsItem_SignatureStrings);
#else
    InitSignatureBytes(pyType, QStyleOptionGraphicsItem_SignatureBytes, QStyleOptionGraphicsItem_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QStyleOptionGraphicsItem_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionGraphicsItem_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QStyleOptionGraphicsItem_PythonToCpp_QStyleOptionGraphicsItem_PTR,
        is_QStyleOptionGraphicsItem_PythonToCpp_QStyleOptionGraphicsItem_PTR_Convertible,
        QStyleOptionGraphicsItem_PTR_CppToPython_QStyleOptionGraphicsItem);

    Shiboken::Conversions::registerConverterName(converter, "QStyleOptionGraphicsItem");
    Shiboken::Conversions::registerConverterName(converter, "QStyleOptionGraphicsItem*");
    Shiboken::Conversions::registerConverterName(converter, "QStyleOptionGraphicsItem&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QStyleOptionGraphicsItem).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QStyleOptionGraphicsItem_TypeF(), &Sbk_QStyleOptionGraphicsItem_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QStyleOptionGraphicsItem_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'StyleOptionType'.
    const char *StyleOptionType_Initializer[] = {
        "Type",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t StyleOptionType_InitializerValues[] = {
        uint8_t(QStyleOptionGraphicsItem::StyleOptionType::Type) //  0x0f  15
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStyleOptionGraphicsItem_TypeF(),
        "2:PySide6.QtWidgets.QStyleOptionGraphicsItem.StyleOptionType",
        StyleOptionType_Initializer, StyleOptionType_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionGraphicsItem_StyleOptionType_IDX].type = EType;
    // Register converter for enum 'QStyleOptionGraphicsItem::StyleOptionType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStyleOptionGraphicsItem_StyleOptionType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QStyleOptionGraphicsItem_StyleOptionType,
            is_Enum_PythonToCpp_QStyleOptionGraphicsItem_StyleOptionType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QStyleOptionGraphicsItem::StyleOptionType");
        Shiboken::Conversions::registerConverterAlias(converter, "StyleOptionType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'StyleOptionType' enum.

    // Initialization of enum 'StyleOptionVersion'.
    const char *StyleOptionVersion_Initializer[] = {
        "Version",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t StyleOptionVersion_InitializerValues[] = {
        uint8_t(QStyleOptionGraphicsItem::StyleOptionVersion::Version) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStyleOptionGraphicsItem_TypeF(),
        "2:PySide6.QtWidgets.QStyleOptionGraphicsItem.StyleOptionVersion",
        StyleOptionVersion_Initializer, StyleOptionVersion_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionGraphicsItem_StyleOptionVersion_IDX].type = EType;
    // Register converter for enum 'QStyleOptionGraphicsItem::StyleOptionVersion'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStyleOptionGraphicsItem_StyleOptionVersion_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QStyleOptionGraphicsItem_StyleOptionVersion,
            is_Enum_PythonToCpp_QStyleOptionGraphicsItem_StyleOptionVersion_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QStyleOptionGraphicsItem::StyleOptionVersion");
        Shiboken::Conversions::registerConverterAlias(converter, "StyleOptionVersion");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'StyleOptionVersion' enum.

    qRegisterMetaType< ::QStyleOptionGraphicsItem *>();
    qRegisterMetaType< ::QStyleOptionGraphicsItem::StyleOptionType >("QStyleOptionGraphicsItem::StyleOptionType");
    qRegisterMetaType< ::QStyleOptionGraphicsItem::StyleOptionVersion >("QStyleOptionGraphicsItem::StyleOptionVersion");

    return pyType;
}
