// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qstyleoptionprogressbar_wrapper.h"

// Argument includes
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStyleOptionProgressBar_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QStyleOptionProgressBar >()))
        return -1;

    ::QStyleOptionProgressBar *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QStyleOptionProgressBar", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QStyleOptionProgressBar::QStyleOptionProgressBar()
    // 1: QStyleOptionProgressBar::QStyleOptionProgressBar(QStyleOptionProgressBar)
    // 2: QStyleOptionProgressBar::QStyleOptionProgressBar(int)
    if (numArgs == 0) {
        overloadId = 0; // QStyleOptionProgressBar()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 2; // QStyleOptionProgressBar(int)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionProgressBar_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QStyleOptionProgressBar(QStyleOptionProgressBar)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionProgressBar_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionProgressBar_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QStyleOptionProgressBar()
        {

            // QStyleOptionProgressBar()
            cptr = new ::QStyleOptionProgressBar();
            break;
        }
        case 1: // QStyleOptionProgressBar(const QStyleOptionProgressBar &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QStyleOptionProgressBar *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QStyleOptionProgressBar(QStyleOptionProgressBar)
                cptr = new ::QStyleOptionProgressBar(*cppArg0);
            }
            break;
        }
        case 2: // QStyleOptionProgressBar(int version)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QStyleOptionProgressBar(int)
                cptr = new ::QStyleOptionProgressBar(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QStyleOptionProgressBar >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionProgressBar_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}


static const char *Sbk_QStyleOptionProgressBar_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QStyleOptionProgressBar_EnumFlagInfo[] = {
    "StyleOptionType:Enum",
    "StyleOptionVersion:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QStyleOptionProgressBar_methods[] = {
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QStyleOptionProgressBar_get_minimum(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionProgressBar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionProgressBar_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int cppOut_local = cppSelf->minimum;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QStyleOptionProgressBar_set_minimum(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionProgressBar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionProgressBar_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("minimum");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("minimum", "int");
        return -1;
    }

    auto cppOut_local = cppSelf->minimum;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->minimum = cppOut_local;

    return 0;
}

static PyObject *Sbk_QStyleOptionProgressBar_get_maximum(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionProgressBar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionProgressBar_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int cppOut_local = cppSelf->maximum;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QStyleOptionProgressBar_set_maximum(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionProgressBar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionProgressBar_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("maximum");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("maximum", "int");
        return -1;
    }

    auto cppOut_local = cppSelf->maximum;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->maximum = cppOut_local;

    return 0;
}

static PyObject *Sbk_QStyleOptionProgressBar_get_progress(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionProgressBar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionProgressBar_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int cppOut_local = cppSelf->progress;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QStyleOptionProgressBar_set_progress(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionProgressBar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionProgressBar_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("progress");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("progress", "int");
        return -1;
    }

    auto cppOut_local = cppSelf->progress;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->progress = cppOut_local;

    return 0;
}

static PyObject *Sbk_QStyleOptionProgressBar_get_text(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionProgressBar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionProgressBar_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppSelf->text);
    return pyOut;
}
static int Sbk_QStyleOptionProgressBar_set_text(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionProgressBar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionProgressBar_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("text");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("text", "QString");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->text;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

static PyObject *Sbk_QStyleOptionProgressBar_get_textAlignment(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionProgressBar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionProgressBar_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_AlignmentFlag_IDX])))->flagsConverter, &cppSelf->textAlignment);
    return pyOut;
}
static int Sbk_QStyleOptionProgressBar_set_textAlignment(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionProgressBar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionProgressBar_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("textAlignment");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_AlignmentFlag_IDX])))->flagsConverter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("textAlignment", "Alignment");
        return -1;
    }

    auto cppOut_local = cppSelf->textAlignment;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->textAlignment = cppOut_local;

    return 0;
}

static PyObject *Sbk_QStyleOptionProgressBar_get_textVisible(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionProgressBar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionProgressBar_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    bool cppOut_local = cppSelf->textVisible;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QStyleOptionProgressBar_set_textVisible(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionProgressBar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionProgressBar_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("textVisible");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("textVisible", "bool");
        return -1;
    }

    auto cppOut_local = cppSelf->textVisible;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->textVisible = cppOut_local;

    return 0;
}

static PyObject *Sbk_QStyleOptionProgressBar_get_invertedAppearance(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionProgressBar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionProgressBar_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    bool cppOut_local = cppSelf->invertedAppearance;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QStyleOptionProgressBar_set_invertedAppearance(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionProgressBar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionProgressBar_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("invertedAppearance");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("invertedAppearance", "bool");
        return -1;
    }

    auto cppOut_local = cppSelf->invertedAppearance;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->invertedAppearance = cppOut_local;

    return 0;
}

static PyObject *Sbk_QStyleOptionProgressBar_get_bottomToTop(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionProgressBar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionProgressBar_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    bool cppOut_local = cppSelf->bottomToTop;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QStyleOptionProgressBar_set_bottomToTop(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionProgressBar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionProgressBar_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("bottomToTop");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("bottomToTop", "bool");
        return -1;
    }

    auto cppOut_local = cppSelf->bottomToTop;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->bottomToTop = cppOut_local;

    return 0;
}

// Getters and Setters for QStyleOptionProgressBar
static PyGetSetDef Sbk_QStyleOptionProgressBar_getsetlist[] = {
    {const_cast<char *>("minimum"), Sbk_QStyleOptionProgressBar_get_minimum, Sbk_QStyleOptionProgressBar_set_minimum, nullptr, nullptr},
    {const_cast<char *>("maximum"), Sbk_QStyleOptionProgressBar_get_maximum, Sbk_QStyleOptionProgressBar_set_maximum, nullptr, nullptr},
    {const_cast<char *>("progress"), Sbk_QStyleOptionProgressBar_get_progress, Sbk_QStyleOptionProgressBar_set_progress, nullptr, nullptr},
    {const_cast<char *>("text"), Sbk_QStyleOptionProgressBar_get_text, Sbk_QStyleOptionProgressBar_set_text, nullptr, nullptr},
    {const_cast<char *>("textAlignment"), Sbk_QStyleOptionProgressBar_get_textAlignment, Sbk_QStyleOptionProgressBar_set_textAlignment, nullptr, nullptr},
    {const_cast<char *>("textVisible"), Sbk_QStyleOptionProgressBar_get_textVisible, Sbk_QStyleOptionProgressBar_set_textVisible, nullptr, nullptr},
    {const_cast<char *>("invertedAppearance"), Sbk_QStyleOptionProgressBar_get_invertedAppearance, Sbk_QStyleOptionProgressBar_set_invertedAppearance, nullptr, nullptr},
    {const_cast<char *>("bottomToTop"), Sbk_QStyleOptionProgressBar_get_bottomToTop, Sbk_QStyleOptionProgressBar_set_bottomToTop, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QStyleOptionProgressBar_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QStyleOptionProgressBar_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QStyleOptionProgressBar_Type = nullptr;
static PyTypeObject *Sbk_QStyleOptionProgressBar_TypeF(void)
{
    return _Sbk_QStyleOptionProgressBar_Type;
}

static PyType_Slot Sbk_QStyleOptionProgressBar_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QStyleOptionProgressBar_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QStyleOptionProgressBar_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QStyleOptionProgressBar_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QStyleOptionProgressBar_getsetlist)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QStyleOptionProgressBar_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QStyleOptionProgressBar_spec = {
    "2:PySide6.QtWidgets.QStyleOptionProgressBar",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QStyleOptionProgressBar_slots
};

} //extern "C"

static void *Sbk_QStyleOptionProgressBar_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (qstyleoption_cast<const QStyleOptionProgressBar *>( reinterpret_cast< ::QStyleOption *>(cptr)) != nullptr)
        return cptr;
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QStyleOptionProgressBar_StyleOptionType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStyleOptionProgressBar::StyleOptionType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStyleOptionProgressBar::StyleOptionType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QStyleOptionProgressBar_StyleOptionType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionProgressBar_StyleOptionType_IDX])))
        return Enum_PythonToCpp_QStyleOptionProgressBar_StyleOptionType;
    return {};
}

static PyObject *QStyleOptionProgressBar_StyleOptionType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QStyleOptionProgressBar::StyleOptionType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QStyleOptionProgressBar::StyleOptionType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionProgressBar_StyleOptionType_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QStyleOptionProgressBar_StyleOptionVersion(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStyleOptionProgressBar::StyleOptionVersion>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStyleOptionProgressBar::StyleOptionVersion *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QStyleOptionProgressBar_StyleOptionVersion_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionProgressBar_StyleOptionVersion_IDX])))
        return Enum_PythonToCpp_QStyleOptionProgressBar_StyleOptionVersion;
    return {};
}

static PyObject *QStyleOptionProgressBar_StyleOptionVersion_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QStyleOptionProgressBar::StyleOptionVersion>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QStyleOptionProgressBar::StyleOptionVersion *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionProgressBar_StyleOptionVersion_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QStyleOptionProgressBar_PythonToCpp_QStyleOptionProgressBar_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QStyleOptionProgressBar_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QStyleOptionProgressBar_PythonToCpp_QStyleOptionProgressBar_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QStyleOptionProgressBar_TypeF()))
        return QStyleOptionProgressBar_PythonToCpp_QStyleOptionProgressBar_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QStyleOptionProgressBar_PTR_CppToPython_QStyleOptionProgressBar(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QStyleOptionProgressBar_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QStyleOptionProgressBar_SignatureStrings[] = {
    "2:PySide6.QtWidgets.QStyleOptionProgressBar(self)",
    "1:PySide6.QtWidgets.QStyleOptionProgressBar(self,other:PySide6.QtWidgets.QStyleOptionProgressBar)",
    "0:PySide6.QtWidgets.QStyleOptionProgressBar(self,version:int)",
    nullptr}; // Sentinel
#else
static constexpr size_t QStyleOptionProgressBar_SignatureByteSize = 87;
static constexpr uint8_t QStyleOptionProgressBar_SignatureBytes[87] = {
    0x78, 0xda, 0x33, 0xb2, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x09, 0xcf,
    0x4c, 0x49, 0x4f, 0x2d, 0x29, 0xd6, 0x0b, 0x0c, 0x2e, 0xa9, 0xcc, 0x49, 0xf5, 0x2f, 0x28, 0xc9,
    0xcc, 0xcf, 0x0b, 0x28, 0xca, 0x4f, 0x2f, 0x4a, 0x2d, 0x2e, 0x76, 0x4a, 0x2c, 0xd2, 0x28, 0x4e,
    0xcd, 0x49, 0xd3, 0xe4, 0x32, 0x24, 0x51, 0x87, 0x4e, 0x7e, 0x49, 0x46, 0x6a, 0x11, 0xf1, 0x9a,
    0x34, 0xb9, 0x0c, 0x48, 0xb5, 0xa1, 0x2c, 0xb5, 0xa8, 0x18, 0x28, 0x6e, 0x95, 0x99, 0x57, 0xa2,
    0xc9, 0x05, 0x00, 0xd4, 0x76, 0x4d, 0x94
};
#endif

PyTypeObject *init_QStyleOptionProgressBar(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionProgressBar_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionProgressBar_IDX].type;

    Shiboken::AutoDecRef Sbk_QStyleOptionProgressBar_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]))));

    _Sbk_QStyleOptionProgressBar_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QStyleOptionProgressBar",
        "QStyleOptionProgressBar*",
        &Sbk_QStyleOptionProgressBar_spec,
        &Shiboken::callCppDestructor< ::QStyleOptionProgressBar >,
        Sbk_QStyleOptionProgressBar_Type_bases.object(),
        0);
    auto *pyType = Sbk_QStyleOptionProgressBar_TypeF(); // references _Sbk_QStyleOptionProgressBar_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QStyleOptionProgressBar_SignatureStrings);
#else
    InitSignatureBytes(pyType, QStyleOptionProgressBar_SignatureBytes, QStyleOptionProgressBar_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QStyleOptionProgressBar_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionProgressBar_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QStyleOptionProgressBar_PythonToCpp_QStyleOptionProgressBar_PTR,
        is_QStyleOptionProgressBar_PythonToCpp_QStyleOptionProgressBar_PTR_Convertible,
        QStyleOptionProgressBar_PTR_CppToPython_QStyleOptionProgressBar);

    Shiboken::Conversions::registerConverterName(converter, "QStyleOptionProgressBar");
    Shiboken::Conversions::registerConverterName(converter, "QStyleOptionProgressBar*");
    Shiboken::Conversions::registerConverterName(converter, "QStyleOptionProgressBar&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QStyleOptionProgressBar).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QStyleOptionProgressBar_TypeF(), &Sbk_QStyleOptionProgressBar_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QStyleOptionProgressBar_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'StyleOptionType'.
    const char *StyleOptionType_Initializer[] = {
        "Type",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t StyleOptionType_InitializerValues[] = {
        uint8_t(QStyleOptionProgressBar::StyleOptionType::Type) //  0x06  6
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStyleOptionProgressBar_TypeF(),
        "2:PySide6.QtWidgets.QStyleOptionProgressBar.StyleOptionType",
        StyleOptionType_Initializer, StyleOptionType_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionProgressBar_StyleOptionType_IDX].type = EType;
    // Register converter for enum 'QStyleOptionProgressBar::StyleOptionType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStyleOptionProgressBar_StyleOptionType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QStyleOptionProgressBar_StyleOptionType,
            is_Enum_PythonToCpp_QStyleOptionProgressBar_StyleOptionType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QStyleOptionProgressBar::StyleOptionType");
        Shiboken::Conversions::registerConverterAlias(converter, "StyleOptionType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'StyleOptionType' enum.

    // Initialization of enum 'StyleOptionVersion'.
    const char *StyleOptionVersion_Initializer[] = {
        "Version",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t StyleOptionVersion_InitializerValues[] = {
        uint8_t(QStyleOptionProgressBar::StyleOptionVersion::Version) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStyleOptionProgressBar_TypeF(),
        "2:PySide6.QtWidgets.QStyleOptionProgressBar.StyleOptionVersion",
        StyleOptionVersion_Initializer, StyleOptionVersion_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionProgressBar_StyleOptionVersion_IDX].type = EType;
    // Register converter for enum 'QStyleOptionProgressBar::StyleOptionVersion'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStyleOptionProgressBar_StyleOptionVersion_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QStyleOptionProgressBar_StyleOptionVersion,
            is_Enum_PythonToCpp_QStyleOptionProgressBar_StyleOptionVersion_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QStyleOptionProgressBar::StyleOptionVersion");
        Shiboken::Conversions::registerConverterAlias(converter, "StyleOptionVersion");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'StyleOptionVersion' enum.

    qRegisterMetaType< ::QStyleOptionProgressBar *>();
    qRegisterMetaType< ::QStyleOptionProgressBar::StyleOptionType >("QStyleOptionProgressBar::StyleOptionType");
    qRegisterMetaType< ::QStyleOptionProgressBar::StyleOptionVersion >("QStyleOptionProgressBar::StyleOptionVersion");

    return pyType;
}
