// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qstyleoptiontoolbox_wrapper.h"

// Argument includes
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStyleOptionToolBox_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QStyleOptionToolBox >()))
        return -1;

    ::QStyleOptionToolBox *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QStyleOptionToolBox", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QStyleOptionToolBox::QStyleOptionToolBox()
    // 1: QStyleOptionToolBox::QStyleOptionToolBox(QStyleOptionToolBox)
    // 2: QStyleOptionToolBox::QStyleOptionToolBox(int)
    if (numArgs == 0) {
        overloadId = 0; // QStyleOptionToolBox()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 2; // QStyleOptionToolBox(int)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolBox_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QStyleOptionToolBox(QStyleOptionToolBox)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolBox_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolBox_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QStyleOptionToolBox()
        {

            // QStyleOptionToolBox()
            cptr = new ::QStyleOptionToolBox();
            break;
        }
        case 1: // QStyleOptionToolBox(const QStyleOptionToolBox &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QStyleOptionToolBox *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QStyleOptionToolBox(QStyleOptionToolBox)
                cptr = new ::QStyleOptionToolBox(*cppArg0);
            }
            break;
        }
        case 2: // QStyleOptionToolBox(int version)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QStyleOptionToolBox(int)
                cptr = new ::QStyleOptionToolBox(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QStyleOptionToolBox >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolBox_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}


static const char *Sbk_QStyleOptionToolBox_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QStyleOptionToolBox_EnumFlagInfo[] = {
    "SelectedPosition:Enum",
    "StyleOptionType:Enum",
    "StyleOptionVersion:Enum",
    "TabPosition:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QStyleOptionToolBox_methods[] = {
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QStyleOptionToolBox_get_text(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionToolBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppSelf->text);
    return pyOut;
}
static int Sbk_QStyleOptionToolBox_set_text(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionToolBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("text");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("text", "QString");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->text;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

static PyObject *Sbk_QStyleOptionToolBox_get_icon(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionToolBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    if (reinterpret_cast<void *>(&(cppSelf->icon)) == reinterpret_cast<void *>(cppSelf)) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::Object::findColocatedChild(reinterpret_cast<SbkObject *>(self), Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QIcon_IDX])));
        if (pyOut != nullptr) {
            Py_IncRef(pyOut);
            return pyOut;
        }
    } else if (Shiboken::BindingManager::instance().hasWrapper(&(cppSelf->icon))) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(&(cppSelf->icon)));
        Py_IncRef(pyOut);
        return pyOut;
    }
    pyOut = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QIcon_IDX]), &(cppSelf->icon), false, true);
    Shiboken::Object::setParent(self, pyOut);
    return pyOut;
}
static int Sbk_QStyleOptionToolBox_set_icon(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionToolBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("icon");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QIcon_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("icon", "QIcon");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->icon;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

static PyObject *Sbk_QStyleOptionToolBox_get_position(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionToolBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::QStyleOptionToolBox::TabPosition cppOut_local = cppSelf->position;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolBox_TabPosition_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QStyleOptionToolBox_set_position(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionToolBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("position");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolBox_TabPosition_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("position", "TabPosition");
        return -1;
    }

    auto cppOut_local = cppSelf->position;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->position = cppOut_local;

    return 0;
}

static PyObject *Sbk_QStyleOptionToolBox_get_selectedPosition(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionToolBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::QStyleOptionToolBox::SelectedPosition cppOut_local = cppSelf->selectedPosition;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolBox_SelectedPosition_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QStyleOptionToolBox_set_selectedPosition(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionToolBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("selectedPosition");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolBox_SelectedPosition_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("selectedPosition", "SelectedPosition");
        return -1;
    }

    auto cppOut_local = cppSelf->selectedPosition;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->selectedPosition = cppOut_local;

    return 0;
}

// Getters and Setters for QStyleOptionToolBox
static PyGetSetDef Sbk_QStyleOptionToolBox_getsetlist[] = {
    {const_cast<char *>("text"), Sbk_QStyleOptionToolBox_get_text, Sbk_QStyleOptionToolBox_set_text, nullptr, nullptr},
    {const_cast<char *>("icon"), Sbk_QStyleOptionToolBox_get_icon, Sbk_QStyleOptionToolBox_set_icon, nullptr, nullptr},
    {const_cast<char *>("position"), Sbk_QStyleOptionToolBox_get_position, Sbk_QStyleOptionToolBox_set_position, nullptr, nullptr},
    {const_cast<char *>("selectedPosition"), Sbk_QStyleOptionToolBox_get_selectedPosition, Sbk_QStyleOptionToolBox_set_selectedPosition, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QStyleOptionToolBox_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QStyleOptionToolBox_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QStyleOptionToolBox_Type = nullptr;
static PyTypeObject *Sbk_QStyleOptionToolBox_TypeF(void)
{
    return _Sbk_QStyleOptionToolBox_Type;
}

static PyType_Slot Sbk_QStyleOptionToolBox_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QStyleOptionToolBox_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QStyleOptionToolBox_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QStyleOptionToolBox_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QStyleOptionToolBox_getsetlist)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QStyleOptionToolBox_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QStyleOptionToolBox_spec = {
    "2:PySide6.QtWidgets.QStyleOptionToolBox",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QStyleOptionToolBox_slots
};

} //extern "C"

static void *Sbk_QStyleOptionToolBox_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (qstyleoption_cast<const QStyleOptionToolBox *>( reinterpret_cast< ::QStyleOption *>(cptr)) != nullptr)
        return cptr;
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QStyleOptionToolBox_StyleOptionType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStyleOptionToolBox::StyleOptionType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStyleOptionToolBox::StyleOptionType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QStyleOptionToolBox_StyleOptionType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolBox_StyleOptionType_IDX])))
        return Enum_PythonToCpp_QStyleOptionToolBox_StyleOptionType;
    return {};
}

static PyObject *QStyleOptionToolBox_StyleOptionType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QStyleOptionToolBox::StyleOptionType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QStyleOptionToolBox::StyleOptionType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolBox_StyleOptionType_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QStyleOptionToolBox_StyleOptionVersion(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStyleOptionToolBox::StyleOptionVersion>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStyleOptionToolBox::StyleOptionVersion *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QStyleOptionToolBox_StyleOptionVersion_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolBox_StyleOptionVersion_IDX])))
        return Enum_PythonToCpp_QStyleOptionToolBox_StyleOptionVersion;
    return {};
}

static PyObject *QStyleOptionToolBox_StyleOptionVersion_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QStyleOptionToolBox::StyleOptionVersion>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QStyleOptionToolBox::StyleOptionVersion *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolBox_StyleOptionVersion_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QStyleOptionToolBox_TabPosition(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStyleOptionToolBox::TabPosition>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStyleOptionToolBox::TabPosition *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QStyleOptionToolBox_TabPosition_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolBox_TabPosition_IDX])))
        return Enum_PythonToCpp_QStyleOptionToolBox_TabPosition;
    return {};
}

static PyObject *QStyleOptionToolBox_TabPosition_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QStyleOptionToolBox::TabPosition>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QStyleOptionToolBox::TabPosition *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolBox_TabPosition_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QStyleOptionToolBox_SelectedPosition(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStyleOptionToolBox::SelectedPosition>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStyleOptionToolBox::SelectedPosition *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QStyleOptionToolBox_SelectedPosition_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolBox_SelectedPosition_IDX])))
        return Enum_PythonToCpp_QStyleOptionToolBox_SelectedPosition;
    return {};
}

static PyObject *QStyleOptionToolBox_SelectedPosition_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QStyleOptionToolBox::SelectedPosition>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QStyleOptionToolBox::SelectedPosition *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolBox_SelectedPosition_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QStyleOptionToolBox_PythonToCpp_QStyleOptionToolBox_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QStyleOptionToolBox_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QStyleOptionToolBox_PythonToCpp_QStyleOptionToolBox_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QStyleOptionToolBox_TypeF()))
        return QStyleOptionToolBox_PythonToCpp_QStyleOptionToolBox_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QStyleOptionToolBox_PTR_CppToPython_QStyleOptionToolBox(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QStyleOptionToolBox_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QStyleOptionToolBox_SignatureStrings[] = {
    "2:PySide6.QtWidgets.QStyleOptionToolBox(self)",
    "1:PySide6.QtWidgets.QStyleOptionToolBox(self,other:PySide6.QtWidgets.QStyleOptionToolBox)",
    "0:PySide6.QtWidgets.QStyleOptionToolBox(self,version:int)",
    nullptr}; // Sentinel
#else
static constexpr size_t QStyleOptionToolBox_SignatureByteSize = 83;
static constexpr uint8_t QStyleOptionToolBox_SignatureBytes[83] = {
    0x78, 0xda, 0x33, 0xb2, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x09, 0xcf,
    0x4c, 0x49, 0x4f, 0x2d, 0x29, 0xd6, 0x0b, 0x0c, 0x2e, 0xa9, 0xcc, 0x49, 0xf5, 0x2f, 0x28, 0xc9,
    0xcc, 0xcf, 0x0b, 0xc9, 0xcf, 0xcf, 0x71, 0xca, 0xaf, 0xd0, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0xe4,
    0x32, 0x24, 0x41, 0xb5, 0x4e, 0x7e, 0x49, 0x46, 0x6a, 0x11, 0x71, 0x1a, 0x34, 0xb9, 0x0c, 0x48,
    0x31, 0xb9, 0x2c, 0xb5, 0xa8, 0x18, 0x28, 0x66, 0x95, 0x99, 0x57, 0xa2, 0xc9, 0x05, 0x00, 0xeb,
    0x4e, 0x47, 0x08
};
#endif

PyTypeObject *init_QStyleOptionToolBox(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolBox_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolBox_IDX].type;

    Shiboken::AutoDecRef Sbk_QStyleOptionToolBox_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]))));

    _Sbk_QStyleOptionToolBox_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QStyleOptionToolBox",
        "QStyleOptionToolBox*",
        &Sbk_QStyleOptionToolBox_spec,
        &Shiboken::callCppDestructor< ::QStyleOptionToolBox >,
        Sbk_QStyleOptionToolBox_Type_bases.object(),
        0);
    auto *pyType = Sbk_QStyleOptionToolBox_TypeF(); // references _Sbk_QStyleOptionToolBox_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QStyleOptionToolBox_SignatureStrings);
#else
    InitSignatureBytes(pyType, QStyleOptionToolBox_SignatureBytes, QStyleOptionToolBox_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QStyleOptionToolBox_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolBox_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QStyleOptionToolBox_PythonToCpp_QStyleOptionToolBox_PTR,
        is_QStyleOptionToolBox_PythonToCpp_QStyleOptionToolBox_PTR_Convertible,
        QStyleOptionToolBox_PTR_CppToPython_QStyleOptionToolBox);

    Shiboken::Conversions::registerConverterName(converter, "QStyleOptionToolBox");
    Shiboken::Conversions::registerConverterName(converter, "QStyleOptionToolBox*");
    Shiboken::Conversions::registerConverterName(converter, "QStyleOptionToolBox&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QStyleOptionToolBox).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QStyleOptionToolBox_TypeF(), &Sbk_QStyleOptionToolBox_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QStyleOptionToolBox_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'StyleOptionType'.
    const char *StyleOptionType_Initializer[] = {
        "Type",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t StyleOptionType_InitializerValues[] = {
        uint8_t(QStyleOptionToolBox::StyleOptionType::Type) //  0x07  7
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStyleOptionToolBox_TypeF(),
        "2:PySide6.QtWidgets.QStyleOptionToolBox.StyleOptionType",
        StyleOptionType_Initializer, StyleOptionType_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolBox_StyleOptionType_IDX].type = EType;
    // Register converter for enum 'QStyleOptionToolBox::StyleOptionType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStyleOptionToolBox_StyleOptionType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QStyleOptionToolBox_StyleOptionType,
            is_Enum_PythonToCpp_QStyleOptionToolBox_StyleOptionType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QStyleOptionToolBox::StyleOptionType");
        Shiboken::Conversions::registerConverterAlias(converter, "StyleOptionType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'StyleOptionType' enum.

    // Initialization of enum 'StyleOptionVersion'.
    const char *StyleOptionVersion_Initializer[] = {
        "Version",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t StyleOptionVersion_InitializerValues[] = {
        uint8_t(QStyleOptionToolBox::StyleOptionVersion::Version) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStyleOptionToolBox_TypeF(),
        "2:PySide6.QtWidgets.QStyleOptionToolBox.StyleOptionVersion",
        StyleOptionVersion_Initializer, StyleOptionVersion_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolBox_StyleOptionVersion_IDX].type = EType;
    // Register converter for enum 'QStyleOptionToolBox::StyleOptionVersion'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStyleOptionToolBox_StyleOptionVersion_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QStyleOptionToolBox_StyleOptionVersion,
            is_Enum_PythonToCpp_QStyleOptionToolBox_StyleOptionVersion_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QStyleOptionToolBox::StyleOptionVersion");
        Shiboken::Conversions::registerConverterAlias(converter, "StyleOptionVersion");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'StyleOptionVersion' enum.

    // Initialization of enum 'TabPosition'.
    const char *TabPosition_Initializer[] = {
        "Beginning",
        "Middle",
        "End",
        "OnlyOneTab",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t TabPosition_InitializerValues[] = {
        uint8_t(QStyleOptionToolBox::TabPosition::Beginning), //  0x00  0
        uint8_t(QStyleOptionToolBox::TabPosition::Middle),    //  0x01  1
        uint8_t(QStyleOptionToolBox::TabPosition::End),       //  0x02  2
        uint8_t(QStyleOptionToolBox::TabPosition::OnlyOneTab) //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStyleOptionToolBox_TypeF(),
        "2:PySide6.QtWidgets.QStyleOptionToolBox.TabPosition",
        TabPosition_Initializer, TabPosition_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolBox_TabPosition_IDX].type = EType;
    // Register converter for enum 'QStyleOptionToolBox::TabPosition'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStyleOptionToolBox_TabPosition_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QStyleOptionToolBox_TabPosition,
            is_Enum_PythonToCpp_QStyleOptionToolBox_TabPosition_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QStyleOptionToolBox::TabPosition");
        Shiboken::Conversions::registerConverterAlias(converter, "TabPosition");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'TabPosition' enum.

    // Initialization of enum 'SelectedPosition'.
    const char *SelectedPosition_Initializer[] = {
        "NotAdjacent",
        "NextIsSelected",
        "PreviousIsSelected",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t SelectedPosition_InitializerValues[] = {
        uint8_t(QStyleOptionToolBox::SelectedPosition::NotAdjacent),       //  0x00  0
        uint8_t(QStyleOptionToolBox::SelectedPosition::NextIsSelected),    //  0x01  1
        uint8_t(QStyleOptionToolBox::SelectedPosition::PreviousIsSelected) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStyleOptionToolBox_TypeF(),
        "2:PySide6.QtWidgets.QStyleOptionToolBox.SelectedPosition",
        SelectedPosition_Initializer, SelectedPosition_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolBox_SelectedPosition_IDX].type = EType;
    // Register converter for enum 'QStyleOptionToolBox::SelectedPosition'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStyleOptionToolBox_SelectedPosition_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QStyleOptionToolBox_SelectedPosition,
            is_Enum_PythonToCpp_QStyleOptionToolBox_SelectedPosition_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QStyleOptionToolBox::SelectedPosition");
        Shiboken::Conversions::registerConverterAlias(converter, "SelectedPosition");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'SelectedPosition' enum.

    qRegisterMetaType< ::QStyleOptionToolBox *>();
    qRegisterMetaType< ::QStyleOptionToolBox::StyleOptionType >("QStyleOptionToolBox::StyleOptionType");
    qRegisterMetaType< ::QStyleOptionToolBox::StyleOptionVersion >("QStyleOptionToolBox::StyleOptionVersion");
    qRegisterMetaType< ::QStyleOptionToolBox::TabPosition >("QStyleOptionToolBox::TabPosition");
    qRegisterMetaType< ::QStyleOptionToolBox::SelectedPosition >("QStyleOptionToolBox::SelectedPosition");

    return pyType;
}
