// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qstyleoptiontoolbutton_wrapper.h"

// Argument includes
#include <QtWidgets/qstyleoption.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStyleOptionToolButton_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QStyleOptionToolButton >()))
        return -1;

    ::QStyleOptionToolButton *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QStyleOptionToolButton", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QStyleOptionToolButton::QStyleOptionToolButton()
    // 1: QStyleOptionToolButton::QStyleOptionToolButton(QStyleOptionToolButton)
    // 2: QStyleOptionToolButton::QStyleOptionToolButton(int)
    if (numArgs == 0) {
        overloadId = 0; // QStyleOptionToolButton()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 2; // QStyleOptionToolButton(int)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolButton_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QStyleOptionToolButton(QStyleOptionToolButton)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolButton_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolButton_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QStyleOptionToolButton()
        {

            // QStyleOptionToolButton()
            cptr = new ::QStyleOptionToolButton();
            break;
        }
        case 1: // QStyleOptionToolButton(const QStyleOptionToolButton &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QStyleOptionToolButton *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QStyleOptionToolButton(QStyleOptionToolButton)
                cptr = new ::QStyleOptionToolButton(*cppArg0);
            }
            break;
        }
        case 2: // QStyleOptionToolButton(int version)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QStyleOptionToolButton(int)
                cptr = new ::QStyleOptionToolButton(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QStyleOptionToolButton >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolButton_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}


static const char *Sbk_QStyleOptionToolButton_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QStyleOptionToolButton_EnumFlagInfo[] = {
    "StyleOptionType:Enum",
    "StyleOptionVersion:Enum",
    "ToolButtonFeature:Flag:ToolButtonFeatures",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QStyleOptionToolButton_methods[] = {
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QStyleOptionToolButton_get_features(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionToolButton *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolButton_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QStyleOptionToolButton_ToolButtonFeature_IDX])))->flagsConverter, &cppSelf->features);
    return pyOut;
}
static int Sbk_QStyleOptionToolButton_set_features(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionToolButton *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolButton_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("features");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QStyleOptionToolButton_ToolButtonFeature_IDX])))->flagsConverter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("features", "ToolButtonFeatures");
        return -1;
    }

    auto cppOut_local = cppSelf->features;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->features = cppOut_local;

    return 0;
}

static PyObject *Sbk_QStyleOptionToolButton_get_icon(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionToolButton *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolButton_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    if (reinterpret_cast<void *>(&(cppSelf->icon)) == reinterpret_cast<void *>(cppSelf)) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::Object::findColocatedChild(reinterpret_cast<SbkObject *>(self), Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QIcon_IDX])));
        if (pyOut != nullptr) {
            Py_IncRef(pyOut);
            return pyOut;
        }
    } else if (Shiboken::BindingManager::instance().hasWrapper(&(cppSelf->icon))) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(&(cppSelf->icon)));
        Py_IncRef(pyOut);
        return pyOut;
    }
    pyOut = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QIcon_IDX]), &(cppSelf->icon), false, true);
    Shiboken::Object::setParent(self, pyOut);
    return pyOut;
}
static int Sbk_QStyleOptionToolButton_set_icon(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionToolButton *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolButton_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("icon");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QIcon_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("icon", "QIcon");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->icon;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

static PyObject *Sbk_QStyleOptionToolButton_get_iconSize(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionToolButton *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolButton_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    if (reinterpret_cast<void *>(&(cppSelf->iconSize)) == reinterpret_cast<void *>(cppSelf)) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::Object::findColocatedChild(reinterpret_cast<SbkObject *>(self), Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX])));
        if (pyOut != nullptr) {
            Py_IncRef(pyOut);
            return pyOut;
        }
    } else if (Shiboken::BindingManager::instance().hasWrapper(&(cppSelf->iconSize))) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(&(cppSelf->iconSize)));
        Py_IncRef(pyOut);
        return pyOut;
    }
    pyOut = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &(cppSelf->iconSize), false, true);
    Shiboken::Object::setParent(self, pyOut);
    return pyOut;
}
static int Sbk_QStyleOptionToolButton_set_iconSize(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionToolButton *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolButton_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("iconSize");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("iconSize", "QSize");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->iconSize;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

static PyObject *Sbk_QStyleOptionToolButton_get_text(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionToolButton *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolButton_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppSelf->text);
    return pyOut;
}
static int Sbk_QStyleOptionToolButton_set_text(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionToolButton *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolButton_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("text");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("text", "QString");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->text;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

static PyObject *Sbk_QStyleOptionToolButton_get_arrowType(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionToolButton *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolButton_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::Qt::ArrowType cppOut_local = cppSelf->arrowType;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ArrowType_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QStyleOptionToolButton_set_arrowType(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionToolButton *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolButton_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("arrowType");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ArrowType_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("arrowType", "ArrowType");
        return -1;
    }

    auto cppOut_local = cppSelf->arrowType;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->arrowType = cppOut_local;

    return 0;
}

static PyObject *Sbk_QStyleOptionToolButton_get_toolButtonStyle(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionToolButton *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolButton_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::Qt::ToolButtonStyle cppOut_local = cppSelf->toolButtonStyle;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ToolButtonStyle_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QStyleOptionToolButton_set_toolButtonStyle(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionToolButton *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolButton_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("toolButtonStyle");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ToolButtonStyle_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("toolButtonStyle", "ToolButtonStyle");
        return -1;
    }

    auto cppOut_local = cppSelf->toolButtonStyle;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->toolButtonStyle = cppOut_local;

    return 0;
}

static PyObject *Sbk_QStyleOptionToolButton_get_pos(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionToolButton *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolButton_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    if (reinterpret_cast<void *>(&(cppSelf->pos)) == reinterpret_cast<void *>(cppSelf)) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::Object::findColocatedChild(reinterpret_cast<SbkObject *>(self), Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX])));
        if (pyOut != nullptr) {
            Py_IncRef(pyOut);
            return pyOut;
        }
    } else if (Shiboken::BindingManager::instance().hasWrapper(&(cppSelf->pos))) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(&(cppSelf->pos)));
        Py_IncRef(pyOut);
        return pyOut;
    }
    pyOut = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), &(cppSelf->pos), false, true);
    Shiboken::Object::setParent(self, pyOut);
    return pyOut;
}
static int Sbk_QStyleOptionToolButton_set_pos(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionToolButton *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolButton_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("pos");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("pos", "QPoint");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->pos;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

static PyObject *Sbk_QStyleOptionToolButton_get_font(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionToolButton *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolButton_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    if (reinterpret_cast<void *>(&(cppSelf->font)) == reinterpret_cast<void *>(cppSelf)) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::Object::findColocatedChild(reinterpret_cast<SbkObject *>(self), Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX])));
        if (pyOut != nullptr) {
            Py_IncRef(pyOut);
            return pyOut;
        }
    } else if (Shiboken::BindingManager::instance().hasWrapper(&(cppSelf->font))) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(&(cppSelf->font)));
        Py_IncRef(pyOut);
        return pyOut;
    }
    pyOut = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), &(cppSelf->font), false, true);
    Shiboken::Object::setParent(self, pyOut);
    return pyOut;
}
static int Sbk_QStyleOptionToolButton_set_font(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionToolButton *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolButton_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("font");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("font", "QFont");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->font;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

// Getters and Setters for QStyleOptionToolButton
static PyGetSetDef Sbk_QStyleOptionToolButton_getsetlist[] = {
    {const_cast<char *>("features"), Sbk_QStyleOptionToolButton_get_features, Sbk_QStyleOptionToolButton_set_features, nullptr, nullptr},
    {const_cast<char *>("icon"), Sbk_QStyleOptionToolButton_get_icon, Sbk_QStyleOptionToolButton_set_icon, nullptr, nullptr},
    {const_cast<char *>("iconSize"), Sbk_QStyleOptionToolButton_get_iconSize, Sbk_QStyleOptionToolButton_set_iconSize, nullptr, nullptr},
    {const_cast<char *>("text"), Sbk_QStyleOptionToolButton_get_text, Sbk_QStyleOptionToolButton_set_text, nullptr, nullptr},
    {const_cast<char *>("arrowType"), Sbk_QStyleOptionToolButton_get_arrowType, Sbk_QStyleOptionToolButton_set_arrowType, nullptr, nullptr},
    {const_cast<char *>("toolButtonStyle"), Sbk_QStyleOptionToolButton_get_toolButtonStyle, Sbk_QStyleOptionToolButton_set_toolButtonStyle, nullptr, nullptr},
    {const_cast<char *>("pos"), Sbk_QStyleOptionToolButton_get_pos, Sbk_QStyleOptionToolButton_set_pos, nullptr, nullptr},
    {const_cast<char *>("font"), Sbk_QStyleOptionToolButton_get_font, Sbk_QStyleOptionToolButton_set_font, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QStyleOptionToolButton_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QStyleOptionToolButton_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QStyleOptionToolButton_Type = nullptr;
static PyTypeObject *Sbk_QStyleOptionToolButton_TypeF(void)
{
    return _Sbk_QStyleOptionToolButton_Type;
}

static PyType_Slot Sbk_QStyleOptionToolButton_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QStyleOptionToolButton_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QStyleOptionToolButton_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QStyleOptionToolButton_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QStyleOptionToolButton_getsetlist)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QStyleOptionToolButton_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QStyleOptionToolButton_spec = {
    "2:PySide6.QtWidgets.QStyleOptionToolButton",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QStyleOptionToolButton_slots
};

} //extern "C"

static void *Sbk_QStyleOptionToolButton_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (qstyleoption_cast<const QStyleOptionToolButton *>( reinterpret_cast< ::QStyleOption *>(cptr)) != nullptr)
        return cptr;
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QStyleOptionToolButton_StyleOptionType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStyleOptionToolButton::StyleOptionType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStyleOptionToolButton::StyleOptionType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QStyleOptionToolButton_StyleOptionType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolButton_StyleOptionType_IDX])))
        return Enum_PythonToCpp_QStyleOptionToolButton_StyleOptionType;
    return {};
}

static PyObject *QStyleOptionToolButton_StyleOptionType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QStyleOptionToolButton::StyleOptionType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QStyleOptionToolButton::StyleOptionType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolButton_StyleOptionType_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QStyleOptionToolButton_StyleOptionVersion(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStyleOptionToolButton::StyleOptionVersion>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStyleOptionToolButton::StyleOptionVersion *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QStyleOptionToolButton_StyleOptionVersion_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolButton_StyleOptionVersion_IDX])))
        return Enum_PythonToCpp_QStyleOptionToolButton_StyleOptionVersion;
    return {};
}

static PyObject *QStyleOptionToolButton_StyleOptionVersion_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QStyleOptionToolButton::StyleOptionVersion>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QStyleOptionToolButton::StyleOptionVersion *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolButton_StyleOptionVersion_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QStyleOptionToolButton_ToolButtonFeature(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStyleOptionToolButton::ToolButtonFeature>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStyleOptionToolButton::ToolButtonFeature *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QStyleOptionToolButton_ToolButtonFeature_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolButton_ToolButtonFeature_IDX])))
        return Enum_PythonToCpp_QStyleOptionToolButton_ToolButtonFeature;
    return {};
}

static PyObject *QStyleOptionToolButton_ToolButtonFeature_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QStyleOptionToolButton::ToolButtonFeature>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QStyleOptionToolButton::ToolButtonFeature *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolButton_ToolButtonFeature_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QStyleOptionToolButton_ToolButtonFeature(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QStyleOptionToolButton::ToolButtonFeature>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QStyleOptionToolButton::ToolButtonFeature> *>(cppOut) = value;

}

static PyObject *QStyleOptionToolButton_ToolButtonFeature_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QStyleOptionToolButton::ToolButtonFeature> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolButton_ToolButtonFeature_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QStyleOptionToolButton_PythonToCpp_QStyleOptionToolButton_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QStyleOptionToolButton_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QStyleOptionToolButton_PythonToCpp_QStyleOptionToolButton_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QStyleOptionToolButton_TypeF()))
        return QStyleOptionToolButton_PythonToCpp_QStyleOptionToolButton_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QStyleOptionToolButton_PTR_CppToPython_QStyleOptionToolButton(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QStyleOptionToolButton_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QStyleOptionToolButton_SignatureStrings[] = {
    "2:PySide6.QtWidgets.QStyleOptionToolButton(self)",
    "1:PySide6.QtWidgets.QStyleOptionToolButton(self,other:PySide6.QtWidgets.QStyleOptionToolButton)",
    "0:PySide6.QtWidgets.QStyleOptionToolButton(self,version:int)",
    nullptr}; // Sentinel
#else
static constexpr size_t QStyleOptionToolButton_SignatureByteSize = 86;
static constexpr uint8_t QStyleOptionToolButton_SignatureBytes[86] = {
    0x78, 0xda, 0x33, 0xb2, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x09, 0xcf,
    0x4c, 0x49, 0x4f, 0x2d, 0x29, 0xd6, 0x0b, 0x0c, 0x2e, 0xa9, 0xcc, 0x49, 0xf5, 0x2f, 0x28, 0xc9,
    0xcc, 0xcf, 0x0b, 0xc9, 0xcf, 0xcf, 0x71, 0x2a, 0x2d, 0x29, 0xc9, 0xcf, 0xd3, 0x28, 0x4e, 0xcd,
    0x49, 0xd3, 0xe4, 0x32, 0x24, 0x4d, 0x83, 0x4e, 0x7e, 0x49, 0x46, 0x6a, 0x11, 0xd1, 0x7a, 0x34,
    0xb9, 0x0c, 0x48, 0x34, 0xbf, 0x2c, 0xb5, 0xa8, 0x18, 0x28, 0x6c, 0x95, 0x99, 0x57, 0xa2, 0xc9,
    0x05, 0x00, 0xb2, 0xf0, 0x4c, 0x54
};
#endif

PyTypeObject *init_QStyleOptionToolButton(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolButton_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolButton_IDX].type;

    Shiboken::AutoDecRef Sbk_QStyleOptionToolButton_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComplex_IDX]))));

    _Sbk_QStyleOptionToolButton_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QStyleOptionToolButton",
        "QStyleOptionToolButton*",
        &Sbk_QStyleOptionToolButton_spec,
        &Shiboken::callCppDestructor< ::QStyleOptionToolButton >,
        Sbk_QStyleOptionToolButton_Type_bases.object(),
        0);
    auto *pyType = Sbk_QStyleOptionToolButton_TypeF(); // references _Sbk_QStyleOptionToolButton_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QStyleOptionToolButton_SignatureStrings);
#else
    InitSignatureBytes(pyType, QStyleOptionToolButton_SignatureBytes, QStyleOptionToolButton_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QStyleOptionToolButton_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolButton_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QStyleOptionToolButton_PythonToCpp_QStyleOptionToolButton_PTR,
        is_QStyleOptionToolButton_PythonToCpp_QStyleOptionToolButton_PTR_Convertible,
        QStyleOptionToolButton_PTR_CppToPython_QStyleOptionToolButton);

    Shiboken::Conversions::registerConverterName(converter, "QStyleOptionToolButton");
    Shiboken::Conversions::registerConverterName(converter, "QStyleOptionToolButton*");
    Shiboken::Conversions::registerConverterName(converter, "QStyleOptionToolButton&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QStyleOptionToolButton).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QStyleOptionToolButton_TypeF(), &Sbk_QStyleOptionToolButton_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QStyleOptionToolButton_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'StyleOptionType'.
    const char *StyleOptionType_Initializer[] = {
        "Type",
        nullptr};
    // "uint32_t" used instead of "unsigned int"
    constexpr uint32_t StyleOptionType_InitializerValues[] = {
        uint32_t(QStyleOptionToolButton::StyleOptionType::Type) //  0x000f0003  983043
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStyleOptionToolButton_TypeF(),
        "2:PySide6.QtWidgets.QStyleOptionToolButton.StyleOptionType",
        StyleOptionType_Initializer, StyleOptionType_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolButton_StyleOptionType_IDX].type = EType;
    // Register converter for enum 'QStyleOptionToolButton::StyleOptionType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStyleOptionToolButton_StyleOptionType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QStyleOptionToolButton_StyleOptionType,
            is_Enum_PythonToCpp_QStyleOptionToolButton_StyleOptionType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QStyleOptionToolButton::StyleOptionType");
        Shiboken::Conversions::registerConverterAlias(converter, "StyleOptionType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'StyleOptionType' enum.

    // Initialization of enum 'StyleOptionVersion'.
    const char *StyleOptionVersion_Initializer[] = {
        "Version",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t StyleOptionVersion_InitializerValues[] = {
        uint8_t(QStyleOptionToolButton::StyleOptionVersion::Version) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStyleOptionToolButton_TypeF(),
        "2:PySide6.QtWidgets.QStyleOptionToolButton.StyleOptionVersion",
        StyleOptionVersion_Initializer, StyleOptionVersion_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolButton_StyleOptionVersion_IDX].type = EType;
    // Register converter for enum 'QStyleOptionToolButton::StyleOptionVersion'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStyleOptionToolButton_StyleOptionVersion_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QStyleOptionToolButton_StyleOptionVersion,
            is_Enum_PythonToCpp_QStyleOptionToolButton_StyleOptionVersion_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QStyleOptionToolButton::StyleOptionVersion");
        Shiboken::Conversions::registerConverterAlias(converter, "StyleOptionVersion");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'StyleOptionVersion' enum.

    // Initialization of enum 'ToolButtonFeature'.
    const char *ToolButtonFeature_Initializer[] = {
        "None_",
        "Arrow",
        "Menu",
        "MenuButtonPopup",
        "PopupDelay",
        "HasMenu",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ToolButtonFeature_InitializerValues[] = {
        uint8_t(QStyleOptionToolButton::ToolButtonFeature::None),            //  0x00  0
        uint8_t(QStyleOptionToolButton::ToolButtonFeature::Arrow),           //  0x01  1
        uint8_t(QStyleOptionToolButton::ToolButtonFeature::Menu),            //  0x04  4
        uint8_t(QStyleOptionToolButton::ToolButtonFeature::MenuButtonPopup), //  0x04  4
        uint8_t(QStyleOptionToolButton::ToolButtonFeature::PopupDelay),      //  0x08  8
        uint8_t(QStyleOptionToolButton::ToolButtonFeature::HasMenu)          //  0x10  16
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStyleOptionToolButton_TypeF(),
        "2:PySide6.QtWidgets.QStyleOptionToolButton.ToolButtonFeature",
        ToolButtonFeature_Initializer, ToolButtonFeature_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolButton_ToolButtonFeature_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QStyleOptionToolButton_ToolButtonFeature_IDX].type =
        EType;
    // Register converter for enum 'QStyleOptionToolButton::ToolButtonFeature'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStyleOptionToolButton_ToolButtonFeature_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QStyleOptionToolButton_ToolButtonFeature,
            is_Enum_PythonToCpp_QStyleOptionToolButton_ToolButtonFeature_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QStyleOptionToolButton::ToolButtonFeature");
        Shiboken::Conversions::registerConverterAlias(converter, "ToolButtonFeature");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QStyleOptionToolButton_ToolButtonFeature_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QStyleOptionToolButton_ToolButtonFeature,
            is_Enum_PythonToCpp_QStyleOptionToolButton_ToolButtonFeature_Convertible);
        // Register converter for flag 'QFlags<QStyleOptionToolButton::ToolButtonFeature>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QStyleOptionToolButton::ToolButtonFeature>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QStyleOptionToolButton::ToolButtonFeatures");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'ToolButtonFeature' enum/flags.

    qRegisterMetaType< ::QStyleOptionToolButton *>();
    qRegisterMetaType< ::QStyleOptionToolButton::StyleOptionType >("QStyleOptionToolButton::StyleOptionType");
    qRegisterMetaType< ::QStyleOptionToolButton::StyleOptionVersion >("QStyleOptionToolButton::StyleOptionVersion");
    qRegisterMetaType< ::QStyleOptionToolButton::ToolButtonFeature >("QStyleOptionToolButton::ToolButtonFeature");

    return pyType;
}
