// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qstylepainter_wrapper.h"

// Argument includes
#include <QList>
#include <QPainter>
#include <QString>
#include <QtGui/qbrush.h>
#include <QtGui/qcolor.h>
#include <QtGui/qfont.h>
#include <QtGui/qfontinfo.h>
#include <QtGui/qfontmetrics.h>
#include <QtGui/qglyphrun.h>
#include <QtGui/qimage.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpainterpath.h>
#include <QtGui/qpalette.h>
#include <QtGui/qpen.h>
#include <QtGui/qpicture.h>
#include <QtGui/qpixmap.h>
#include <QtGui/qpolygon.h>
#include <QtGui/qregion.h>
#include <QtGui/qstatictext.h>
#include <QtGui/qtextoption.h>
#include <QtGui/qtransform.h>
#include <QtWidgets/qstyle.h>
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>
#include <qline.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qrect.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStylePainter_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QStylePainter >()))
        return -1;

    ::QStylePainter *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QStylePainter", 0, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QStylePainter::QStylePainter()
    // 1: QStylePainter::QStylePainter(QPaintDevice*,QWidget*)
    // 2: QStylePainter::QStylePainter(QWidget*)
    if (numArgs == 0) {
        overloadId = 0; // QStylePainter()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QStylePainter(QWidget*)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[1])))) {
        overloadId = 1; // QStylePainter(QPaintDevice*,QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QStylePainter_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWidgetsTypeStructs[SBK_QStylePainter_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QStylePainter()
        {

            // QStylePainter()
            cptr = new ::QStylePainter();
            break;
        }
        case 1: // QStylePainter(QPaintDevice *pd, QWidget *w)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPaintDevice *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QWidget *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QStylePainter(QPaintDevice*,QWidget*)
                cptr = new ::QStylePainter(cppArg0, cppArg1);
            }
            break;
        }
        case 2: // QStylePainter(QWidget *w)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QWidget *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QStylePainter(QWidget*)
                cptr = new ::QStylePainter(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QStylePainter >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QStylePainter_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QStylePainterFunc_begin(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStylePainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStylePainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "begin", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QStylePainter::begin(QPaintDevice*,QWidget*)->bool
    // 1: QStylePainter::begin(QWidget*)->bool
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        overloadId = 1; // begin(QWidget*)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[1])))) {
        overloadId = 0; // begin(QPaintDevice*,QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "begin", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QStylePainter_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // begin(QPaintDevice *pd, QWidget *w)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPaintDevice *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QWidget *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // begin(QPaintDevice*,QWidget*)
                bool cppResult = cppSelf->begin(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // begin(QWidget *w)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QWidget *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // begin(QWidget*)
                bool cppResult = cppSelf->begin(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStylePainterFunc_drawComplexControl(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStylePainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStylePainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "drawComplexControl", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QStylePainter::drawComplexControl(QStyle::ComplexControl,QStyleOptionComplex)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_ComplexControl_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComplex_IDX]), (pyArgs[1])))) {
        overloadId = 0; // drawComplexControl(QStyle::ComplexControl,QStyleOptionComplex)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "drawComplexControl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QStylePainter_IDX]);

    // Call function/method
    {
        ::QStyle::ComplexControl cppArg0{QStyle::CC_SpinBox};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QStyleOptionComplex *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // drawComplexControl(QStyle::ComplexControl,QStyleOptionComplex)
            cppSelf->drawComplexControl(cppArg0, *cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStylePainterFunc_drawControl(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStylePainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStylePainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "drawControl", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QStylePainter::drawControl(QStyle::ControlElement,QStyleOption)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_ControlElement_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), (pyArgs[1])))) {
        overloadId = 0; // drawControl(QStyle::ControlElement,QStyleOption)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "drawControl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QStylePainter_IDX]);

    // Call function/method
    {
        ::QStyle::ControlElement cppArg0{QStyle::CE_PushButton};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QStyleOption *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // drawControl(QStyle::ControlElement,QStyleOption)
            cppSelf->drawControl(cppArg0, *cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStylePainterFunc_drawItemPixmap(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStylePainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStylePainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "drawItemPixmap", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QStylePainter::drawItemPixmap(QRect,int,QPixmap)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), (pyArgs[2])))) {
        overloadId = 0; // drawItemPixmap(QRect,int,QPixmap)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "drawItemPixmap", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QStylePainter_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QRect cppArg0_local;
        ::QRect *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QPixmap cppArg2_local;
        ::QPixmap *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2].isValue())
            pythonToCpp[2](pyArgs[2], &cppArg2_local);
        else
            pythonToCpp[2](pyArgs[2], &cppArg2);


        if (Shiboken::Errors::occurred() == nullptr) {
            // drawItemPixmap(QRect,int,QPixmap)
            cppSelf->drawItemPixmap(*cppArg0, cppArg1, *cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStylePainterFunc_drawItemText(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStylePainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStylePainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[6];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 5, 6));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "drawItemText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QStylePainter_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOOO:drawItemText", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QStylePainter::drawItemText(QRect,int,QPalette,bool,QString,QPalette::ColorRole=)
    if (numArgs >= 5
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPalette_IDX]), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[4])))) {
        if (numArgs == 5) {
            overloadId = 0; // drawItemText(QRect,int,QPalette,bool,QString,QPalette::ColorRole)
        } else if (numArgs >= 6
            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPalette_ColorRole_IDX])))->converter, (pyArgs[5])))) {
            overloadId = 0; // drawItemText(QRect,int,QPalette,bool,QString,QPalette::ColorRole)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "drawItemText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QStylePainter_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_textRole = Shiboken::String::createStaticString("textRole");
            if (PyDict_Contains(kwds, key_textRole) != 0) {
                value = PyDict_GetItem(kwds, key_textRole);
                if (value != nullptr && pyArgs[5] != nullptr ) {
                    errInfo.reset(key_textRole);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "drawItemText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QStylePainter_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[5] = value;
                    if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPalette_ColorRole_IDX])))->converter, (pyArgs[5]))))
                        return Shiboken::returnWrongArguments(args, "drawItemText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QStylePainter_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_textRole);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "drawItemText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QStylePainter_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QRect cppArg0_local;
        ::QRect *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QPalette cppArg2_local;
        ::QPalette *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2].isValue())
            pythonToCpp[2](pyArgs[2], &cppArg2_local);
        else
            pythonToCpp[2](pyArgs[2], &cppArg2);

        bool cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        ::QString cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);
        ::QPalette::ColorRole cppArg5(QPalette::NoRole);
        if (pythonToCpp[5])
            pythonToCpp[5](pyArgs[5], &cppArg5);

        if (Shiboken::Errors::occurred() == nullptr) {
            // drawItemText(QRect,int,QPalette,bool,QString,QPalette::ColorRole)
            cppSelf->drawItemText(*cppArg0, cppArg1, *cppArg2, cppArg3, cppArg4, cppArg5);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStylePainterFunc_drawPrimitive(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStylePainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStylePainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "drawPrimitive", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QStylePainter::drawPrimitive(QStyle::PrimitiveElement,QStyleOption)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_PrimitiveElement_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), (pyArgs[1])))) {
        overloadId = 0; // drawPrimitive(QStyle::PrimitiveElement,QStyleOption)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "drawPrimitive", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QStylePainter_IDX]);

    // Call function/method
    {
        ::QStyle::PrimitiveElement cppArg0{QStyle::PE_Frame};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QStyleOption *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // drawPrimitive(QStyle::PrimitiveElement,QStyleOption)
            cppSelf->drawPrimitive(cppArg0, *cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStylePainterFunc_style(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStylePainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStylePainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // style()const
        QStyle * cppResult = const_cast<const ::QStylePainter *>(cppSelf)->style();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QStylePainter_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QStylePainter_methods[] = {
    {"begin", reinterpret_cast<PyCFunction>(Sbk_QStylePainterFunc_begin), METH_VARARGS, nullptr},
    {"drawComplexControl", reinterpret_cast<PyCFunction>(Sbk_QStylePainterFunc_drawComplexControl), METH_VARARGS, nullptr},
    {"drawControl", reinterpret_cast<PyCFunction>(Sbk_QStylePainterFunc_drawControl), METH_VARARGS, nullptr},
    {"drawItemPixmap", reinterpret_cast<PyCFunction>(Sbk_QStylePainterFunc_drawItemPixmap), METH_VARARGS, nullptr},
    {"drawItemText", reinterpret_cast<PyCFunction>(Sbk_QStylePainterFunc_drawItemText), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"drawPrimitive", reinterpret_cast<PyCFunction>(Sbk_QStylePainterFunc_drawPrimitive), METH_VARARGS, nullptr},
    {"style", reinterpret_cast<PyCFunction>(Sbk_QStylePainterFunc_style), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QStylePainter_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QStylePainter_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QStylePainter_Type = nullptr;
static PyTypeObject *Sbk_QStylePainter_TypeF(void)
{
    return _Sbk_QStylePainter_Type;
}

static PyType_Slot Sbk_QStylePainter_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QStylePainter_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QStylePainter_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QStylePainter_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QStylePainter_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QStylePainter_spec = {
    "2:PySide6.QtWidgets.QStylePainter",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QStylePainter_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QStylePainter_PythonToCpp_QStylePainter_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QStylePainter_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QStylePainter_PythonToCpp_QStylePainter_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QStylePainter_TypeF()))
        return QStylePainter_PythonToCpp_QStylePainter_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QStylePainter_PTR_CppToPython_QStylePainter(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QStylePainter_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QStylePainter_SignatureStrings[] = {
    "2:PySide6.QtWidgets.QStylePainter(self)",
    "1:PySide6.QtWidgets.QStylePainter(self,pd:PySide6.QtGui.QPaintDevice,w:PySide6.QtWidgets.QWidget)",
    "0:PySide6.QtWidgets.QStylePainter(self,w:PySide6.QtWidgets.QWidget)",
    "1:PySide6.QtWidgets.QStylePainter.begin(self,pd:PySide6.QtGui.QPaintDevice,w:PySide6.QtWidgets.QWidget)->bool",
    "0:PySide6.QtWidgets.QStylePainter.begin(self,w:PySide6.QtWidgets.QWidget)->bool",
    "PySide6.QtWidgets.QStylePainter.drawComplexControl(self,cc:PySide6.QtWidgets.QStyle.ComplexControl,opt:PySide6.QtWidgets.QStyleOptionComplex)",
    "PySide6.QtWidgets.QStylePainter.drawControl(self,ce:PySide6.QtWidgets.QStyle.ControlElement,opt:PySide6.QtWidgets.QStyleOption)",
    "PySide6.QtWidgets.QStylePainter.drawItemPixmap(self,r:PySide6.QtCore.QRect,flags:int,pixmap:typing.Union[PySide6.QtGui.QPixmap, PySide6.QtGui.QImage])",
    "PySide6.QtWidgets.QStylePainter.drawItemText(self,r:PySide6.QtCore.QRect,flags:int,pal:typing.Union[PySide6.QtGui.QPalette, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor],enabled:bool,text:QString,textRole:PySide6.QtGui.QPalette.ColorRole=QPalette.NoRole)",
    "PySide6.QtWidgets.QStylePainter.drawPrimitive(self,pe:PySide6.QtWidgets.QStyle.PrimitiveElement,opt:PySide6.QtWidgets.QStyleOption)",
    "PySide6.QtWidgets.QStylePainter.style(self)->PySide6.QtWidgets.QStyle",
    nullptr}; // Sentinel
#else
static constexpr size_t QStylePainter_SignatureByteSize = 324;
static constexpr uint8_t QStylePainter_SignatureBytes[324] = {
    0x78, 0xda, 0xad, 0x94, 0x3f, 0x4f, 0xc3, 0x30, 0x10, 0xc5, 0xf7, 0x7e, 0x0a, 0x46, 0x2a, 0xb9,
    0x16, 0x30, 0x30, 0x44, 0xa2, 0x4b, 0x40, 0x55, 0x17, 0x48, 0x5a, 0x10, 0x03, 0xea, 0xe0, 0x24,
    0xd7, 0xc8, 0xd2, 0xc5, 0x67, 0x39, 0x47, 0xff, 0x7c, 0x7b, 0x12, 0xa7, 0xaa, 0x42, 0xa1, 0xa9,
    0x25, 0xd8, 0x7c, 0xe7, 0xe7, 0xf7, 0x7e, 0xb2, 0xce, 0xbe, 0x8b, 0x92, 0xfd, 0x52, 0x17, 0x70,
    0x2f, 0x53, 0x7e, 0xd7, 0x45, 0x09, 0x5c, 0xcb, 0x74, 0xc9, 0x7b, 0x84, 0x44, 0x69, 0xc3, 0xe0,
    0xae, 0x6b, 0xc0, 0xf5, 0x78, 0x74, 0x1b, 0xa4, 0x13, 0xb6, 0xe8, 0xe9, 0x66, 0x9f, 0x5a, 0xa6,
    0x7e, 0xfb, 0x11, 0x36, 0x3a, 0x07, 0xb1, 0xfd, 0xcd, 0xa4, 0x5b, 0x8c, 0x47, 0x37, 0x61, 0x09,
    0x83, 0x1e, 0x17, 0x29, 0x65, 0x06, 0xa5, 0x36, 0x7f, 0x65, 0x9d, 0x4c, 0x33, 0x22, 0xbc, 0x4c,
    0xdc, 0x4f, 0x0b, 0xf0, 0xbb, 0xe4, 0x56, 0x38, 0xb5, 0x8d, 0xa9, 0xb2, 0x08, 0xbb, 0x98, 0x0c,
    0x3b, 0xc2, 0xce, 0x3a, 0xcf, 0xcf, 0x82, 0xc8, 0xef, 0x7a, 0x41, 0x96, 0xcf, 0x6a, 0x5f, 0x2c,
    0x6b, 0x32, 0x87, 0x03, 0xe3, 0x40, 0x9a, 0x3e, 0x06, 0x0c, 0x61, 0x78, 0xe1, 0x13, 0x42, 0x05,
    0x86, 0x03, 0x30, 0xc2, 0xf2, 0xe7, 0x0c, 0x55, 0xa2, 0x77, 0x95, 0xb2, 0x1d, 0x82, 0xeb, 0xb9,
    0xc6, 0xe4, 0x40, 0xa6, 0x0b, 0xc8, 0x59, 0xac, 0x51, 0x95, 0x75, 0xd4, 0x1c, 0x13, 0xd6, 0x8b,
    0x23, 0xde, 0x5b, 0x6d, 0x4a, 0xf9, 0x66, 0x9a, 0xa4, 0x8f, 0xd3, 0x21, 0xf0, 0x12, 0x71, 0x75,
    0xd2, 0x9e, 0x57, 0xaa, 0x84, 0x55, 0x38, 0xd6, 0x2b, 0xec, 0x38, 0x14, 0x4a, 0xe1, 0x30, 0x91,
    0x42, 0x60, 0x86, 0x3e, 0x52, 0xe7, 0xc3, 0x72, 0x86, 0x94, 0x29, 0x8c, 0x09, 0xc9, 0xfd, 0x20,
    0xf6, 0xdd, 0x95, 0x00, 0xa3, 0x32, 0x84, 0x22, 0x6a, 0x47, 0x4c, 0x70, 0x43, 0x15, 0x35, 0xc0,
    0xae, 0x09, 0xf3, 0xc5, 0x82, 0x10, 0xa2, 0xdf, 0xf3, 0xa4, 0x37, 0x68, 0x05, 0x0f, 0xc7, 0xd6,
    0x33, 0xb5, 0x75, 0xd8, 0x2d, 0x24, 0x4e, 0x57, 0x9a, 0xf5, 0x06, 0x0e, 0xcf, 0x6d, 0x60, 0x3c,
    0x8e, 0xd2, 0xff, 0x1c, 0x90, 0xba, 0x2d, 0xba, 0xef, 0x6b, 0x32, 0x3d, 0x27, 0x1e, 0x7d, 0x01,
    0xb5, 0x82, 0xd1, 0x0a
};
#endif

PyTypeObject *init_QStylePainter(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QStylePainter_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QStylePainter_IDX].type;

    Shiboken::AutoDecRef Sbk_QStylePainter_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]))));

    _Sbk_QStylePainter_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QStylePainter",
        "QStylePainter*",
        &Sbk_QStylePainter_spec,
        &Shiboken::callCppDestructor< ::QStylePainter >,
        Sbk_QStylePainter_Type_bases.object(),
        0);
    auto *pyType = Sbk_QStylePainter_TypeF(); // references _Sbk_QStylePainter_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QStylePainter_SignatureStrings);
#else
    InitSignatureBytes(pyType, QStylePainter_SignatureBytes, QStylePainter_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QStylePainter_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStylePainter_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QStylePainter_PythonToCpp_QStylePainter_PTR,
        is_QStylePainter_PythonToCpp_QStylePainter_PTR_Convertible,
        QStylePainter_PTR_CppToPython_QStylePainter);

    Shiboken::Conversions::registerConverterName(converter, "QStylePainter");
    Shiboken::Conversions::registerConverterName(converter, "QStylePainter*");
    Shiboken::Conversions::registerConverterName(converter, "QStylePainter&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QStylePainter).name());

    qRegisterMetaType< ::QStylePainter *>();

    return pyType;
}
