// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qtablewidgetselectionrange_wrapper.h"

// Argument includes
#include <QtWidgets/qtablewidget.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTableWidgetSelectionRange_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QTableWidgetSelectionRange >()))
        return -1;

    ::QTableWidgetSelectionRange *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTableWidgetSelectionRange_IDX]);

    if (PyArg_UnpackTuple(args, "QTableWidgetSelectionRange", 0, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QTableWidgetSelectionRange::QTableWidgetSelectionRange()
    // 1: QTableWidgetSelectionRange::QTableWidgetSelectionRange(QTableWidgetSelectionRange)
    // 2: QTableWidgetSelectionRange::QTableWidgetSelectionRange(int,int,int,int)
    if (numArgs == 0) {
        overloadId = 0; // QTableWidgetSelectionRange()
    } else if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
        overloadId = 2; // QTableWidgetSelectionRange(int,int,int,int)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTableWidgetSelectionRange_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QTableWidgetSelectionRange(QTableWidgetSelectionRange)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTableWidgetSelectionRange_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWidgetsTypeStructs[SBK_QTableWidgetSelectionRange_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QTableWidgetSelectionRange()
        {

            // QTableWidgetSelectionRange()
            cptr = new ::QTableWidgetSelectionRange();
            break;
        }
        case 1: // QTableWidgetSelectionRange(const QTableWidgetSelectionRange &QTableWidgetSelectionRange)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QTableWidgetSelectionRange cppArg0_local;
            ::QTableWidgetSelectionRange *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QTableWidgetSelectionRange(QTableWidgetSelectionRange)
                cptr = new ::QTableWidgetSelectionRange(*cppArg0);
            }
            break;
        }
        case 2: // QTableWidgetSelectionRange(int top, int left, int bottom, int right)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QTableWidgetSelectionRange(int,int,int,int)
                cptr = new ::QTableWidgetSelectionRange(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QTableWidgetSelectionRange >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTableWidgetSelectionRange_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QTableWidgetSelectionRangeFunc_bottomRow(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTableWidgetSelectionRange *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTableWidgetSelectionRange_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // bottomRow()const
        int cppResult = const_cast<const ::QTableWidgetSelectionRange *>(cppSelf)->bottomRow();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTableWidgetSelectionRangeFunc_columnCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTableWidgetSelectionRange *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTableWidgetSelectionRange_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // columnCount()const
        int cppResult = const_cast<const ::QTableWidgetSelectionRange *>(cppSelf)->columnCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTableWidgetSelectionRangeFunc_leftColumn(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTableWidgetSelectionRange *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTableWidgetSelectionRange_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // leftColumn()const
        int cppResult = const_cast<const ::QTableWidgetSelectionRange *>(cppSelf)->leftColumn();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTableWidgetSelectionRangeFunc_rightColumn(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTableWidgetSelectionRange *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTableWidgetSelectionRange_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rightColumn()const
        int cppResult = const_cast<const ::QTableWidgetSelectionRange *>(cppSelf)->rightColumn();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTableWidgetSelectionRangeFunc_rowCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTableWidgetSelectionRange *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTableWidgetSelectionRange_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rowCount()const
        int cppResult = const_cast<const ::QTableWidgetSelectionRange *>(cppSelf)->rowCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTableWidgetSelectionRangeFunc_topRow(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTableWidgetSelectionRange *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTableWidgetSelectionRange_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // topRow()const
        int cppResult = const_cast<const ::QTableWidgetSelectionRange *>(cppSelf)->topRow();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTableWidgetSelectionRange__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QTableWidgetSelectionRange *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTableWidgetSelectionRange_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTableWidgetSelectionRange_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QTableWidgetSelectionRange_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QTableWidgetSelectionRange_methods[] = {
    {"bottomRow", reinterpret_cast<PyCFunction>(Sbk_QTableWidgetSelectionRangeFunc_bottomRow), METH_NOARGS, nullptr},
    {"columnCount", reinterpret_cast<PyCFunction>(Sbk_QTableWidgetSelectionRangeFunc_columnCount), METH_NOARGS, nullptr},
    {"leftColumn", reinterpret_cast<PyCFunction>(Sbk_QTableWidgetSelectionRangeFunc_leftColumn), METH_NOARGS, nullptr},
    {"rightColumn", reinterpret_cast<PyCFunction>(Sbk_QTableWidgetSelectionRangeFunc_rightColumn), METH_NOARGS, nullptr},
    {"rowCount", reinterpret_cast<PyCFunction>(Sbk_QTableWidgetSelectionRangeFunc_rowCount), METH_NOARGS, nullptr},
    {"topRow", reinterpret_cast<PyCFunction>(Sbk_QTableWidgetSelectionRangeFunc_topRow), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QTableWidgetSelectionRange__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QTableWidgetSelectionRange_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QTableWidgetSelectionRange *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTableWidgetSelectionRange_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTableWidgetSelectionRange_IDX]), (pyArg)))) {
                // operator!=(const QTableWidgetSelectionRange &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QTableWidgetSelectionRange cppArg0_local;
                ::QTableWidgetSelectionRange *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTableWidgetSelectionRange_IDX]), (pyArg)))) {
                // operator==(const QTableWidgetSelectionRange &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QTableWidgetSelectionRange cppArg0_local;
                ::QTableWidgetSelectionRange *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QTableWidgetSelectionRange_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QTableWidgetSelectionRange_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QTableWidgetSelectionRange_Type = nullptr;
static PyTypeObject *Sbk_QTableWidgetSelectionRange_TypeF(void)
{
    return _Sbk_QTableWidgetSelectionRange_Type;
}

static PyType_Slot Sbk_QTableWidgetSelectionRange_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QTableWidgetSelectionRange_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QTableWidgetSelectionRange_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QTableWidgetSelectionRange_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QTableWidgetSelectionRange_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QTableWidgetSelectionRange_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QTableWidgetSelectionRange_spec = {
    "2:PySide6.QtWidgets.QTableWidgetSelectionRange",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QTableWidgetSelectionRange_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QTableWidgetSelectionRange_PythonToCpp_QTableWidgetSelectionRange_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QTableWidgetSelectionRange_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QTableWidgetSelectionRange_PythonToCpp_QTableWidgetSelectionRange_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QTableWidgetSelectionRange_TypeF()))
        return QTableWidgetSelectionRange_PythonToCpp_QTableWidgetSelectionRange_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QTableWidgetSelectionRange_PTR_CppToPython_QTableWidgetSelectionRange(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QTableWidgetSelectionRange_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QTableWidgetSelectionRange_COPY_CppToPython_QTableWidgetSelectionRange(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QTableWidgetSelectionRange *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QTableWidgetSelectionRange_TypeF(), new ::QTableWidgetSelectionRange(*source), true, true);
}

// Python to C++ copy conversion.
static void QTableWidgetSelectionRange_PythonToCpp_QTableWidgetSelectionRange_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QTableWidgetSelectionRange *>(cppOut) = *reinterpret_cast< ::QTableWidgetSelectionRange *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTableWidgetSelectionRange_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QTableWidgetSelectionRange_PythonToCpp_QTableWidgetSelectionRange_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QTableWidgetSelectionRange_TypeF()))
        return QTableWidgetSelectionRange_PythonToCpp_QTableWidgetSelectionRange_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QTableWidgetSelectionRange_SignatureStrings[] = {
    "2:PySide6.QtWidgets.QTableWidgetSelectionRange(self)",
    "1:PySide6.QtWidgets.QTableWidgetSelectionRange(self,QTableWidgetSelectionRange:PySide6.QtWidgets.QTableWidgetSelectionRange)",
    "0:PySide6.QtWidgets.QTableWidgetSelectionRange(self,top:int,left:int,bottom:int,right:int)",
    "PySide6.QtWidgets.QTableWidgetSelectionRange.bottomRow(self)->int",
    "PySide6.QtWidgets.QTableWidgetSelectionRange.columnCount(self)->int",
    "PySide6.QtWidgets.QTableWidgetSelectionRange.leftColumn(self)->int",
    "PySide6.QtWidgets.QTableWidgetSelectionRange.rightColumn(self)->int",
    "PySide6.QtWidgets.QTableWidgetSelectionRange.rowCount(self)->int",
    "PySide6.QtWidgets.QTableWidgetSelectionRange.topRow(self)->int",
    "PySide6.QtWidgets.QTableWidgetSelectionRange.__copy__(self)->typing.Self",
    "PySide6.QtWidgets.QTableWidgetSelectionRange.__ne__(self,rhs:PySide6.QtWidgets.QTableWidgetSelectionRange)->bool",
    "PySide6.QtWidgets.QTableWidgetSelectionRange.__eq__(self,rhs:PySide6.QtWidgets.QTableWidgetSelectionRange)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QTableWidgetSelectionRange_SignatureByteSize = 190;
static constexpr uint8_t QTableWidgetSelectionRange_SignatureBytes[190] = {
    0x78, 0xda, 0xa5, 0xd2, 0xbd, 0x0e, 0x83, 0x20, 0x10, 0x00, 0xe0, 0xdd, 0x27, 0xa9, 0x89, 0x92,
    0xb6, 0x43, 0x07, 0x07, 0x17, 0x5f, 0xa0, 0x6a, 0x93, 0x8e, 0xc4, 0x9f, 0x13, 0x49, 0x90, 0xa3,
    0x7a, 0xc6, 0xf8, 0xf6, 0xb5, 0xd8, 0x8e, 0x1d, 0x90, 0xed, 0xe0, 0xe0, 0xbb, 0xdc, 0xc1, 0x35,
    0xb9, 0xaf, 0xa5, 0x6c, 0xe1, 0xc6, 0x72, 0x7a, 0xca, 0x56, 0x00, 0x4d, 0x2c, 0x7f, 0x54, 0xb5,
    0x82, 0x7d, 0x55, 0x82, 0x82, 0x86, 0x24, 0xea, 0xa2, 0xd2, 0x02, 0x4e, 0x13, 0xa8, 0x2e, 0x0c,
    0x2e, 0xee, 0x97, 0xa2, 0xff, 0x79, 0x27, 0x2c, 0x0c, 0xce, 0x07, 0x8a, 0x13, 0x9a, 0x44, 0x6a,
    0x8a, 0x14, 0x74, 0x64, 0x83, 0x1a, 0x89, 0x70, 0xb0, 0xe1, 0x28, 0x45, 0x6f, 0x37, 0xc3, 0xc0,
    0x05, 0x66, 0x3b, 0x51, 0xe0, 0xb2, 0x0f, 0x25, 0x4e, 0x37, 0xc2, 0x4d, 0x68, 0x50, 0xcd, 0x83,
    0xce, 0x70, 0xd6, 0x74, 0xd8, 0xf8, 0x74, 0x94, 0x59, 0xe7, 0x30, 0x61, 0x07, 0xe0, 0x6b, 0xe0,
    0xe2, 0xd7, 0xc7, 0xf6, 0x42, 0x3e, 0xa3, 0xe4, 0xbc, 0x41, 0xb3, 0x72, 0xfe, 0x03, 0x68, 0x35,
    0x52, 0x0b, 0xb6, 0x9d, 0xea, 0x5c, 0x21, 0x0d, 0x5f, 0x26, 0x1a, 0xfb, 0xc9, 0xed, 0x6f, 0xc6,
    0x69, 0x8d, 0xa8, 0x5c, 0x0b, 0xc2, 0xcb, 0xb7, 0xe0, 0x1b, 0x4d, 0x09, 0x63, 0xad
};
#endif

PyTypeObject *init_QTableWidgetSelectionRange(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QTableWidgetSelectionRange_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QTableWidgetSelectionRange_IDX].type;

    Shiboken::AutoDecRef Sbk_QTableWidgetSelectionRange_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QTableWidgetSelectionRange_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QTableWidgetSelectionRange",
        "QTableWidgetSelectionRange",
        &Sbk_QTableWidgetSelectionRange_spec,
        &Shiboken::callCppDestructor< ::QTableWidgetSelectionRange >,
        Sbk_QTableWidgetSelectionRange_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QTableWidgetSelectionRange_TypeF(); // references _Sbk_QTableWidgetSelectionRange_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QTableWidgetSelectionRange_SignatureStrings);
#else
    InitSignatureBytes(pyType, QTableWidgetSelectionRange_SignatureBytes, QTableWidgetSelectionRange_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QTableWidgetSelectionRange_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QTableWidgetSelectionRange_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QTableWidgetSelectionRange_PythonToCpp_QTableWidgetSelectionRange_PTR,
        is_QTableWidgetSelectionRange_PythonToCpp_QTableWidgetSelectionRange_PTR_Convertible,
        QTableWidgetSelectionRange_PTR_CppToPython_QTableWidgetSelectionRange,
        QTableWidgetSelectionRange_COPY_CppToPython_QTableWidgetSelectionRange);

    Shiboken::Conversions::registerConverterName(converter, "QTableWidgetSelectionRange");
    Shiboken::Conversions::registerConverterName(converter, "QTableWidgetSelectionRange*");
    Shiboken::Conversions::registerConverterName(converter, "QTableWidgetSelectionRange&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QTableWidgetSelectionRange).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QTableWidgetSelectionRange_PythonToCpp_QTableWidgetSelectionRange_COPY,
        is_QTableWidgetSelectionRange_PythonToCpp_QTableWidgetSelectionRange_COPY_Convertible);

    qRegisterMetaType< ::QTableWidgetSelectionRange >("QTableWidgetSelectionRange");

    return pyType;
}
