// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qtilerules_wrapper.h"

// Argument includes
#include <qnamespace.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTileRules_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QTileRules >()))
        return -1;

    ::QTileRules *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTileRules_IDX]);

    if (PyArg_ParseTuple(args, "|OO:QTileRules", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QTileRules::QTileRules(Qt::TileRule,Qt::TileRule)
    // 1: QTileRules::QTileRules(Qt::TileRule=)
    // 2: QTileRules::QTileRules(QTileRules)
    if (numArgs == 0) {
        overloadId = 1; // QTileRules(Qt::TileRule)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_TileRule_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QTileRules(Qt::TileRule)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_TileRule_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // QTileRules(Qt::TileRule,Qt::TileRule)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTileRules_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QTileRules(QTileRules)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTileRules_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWidgetsTypeStructs[SBK_QTileRules_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QTileRules(Qt::TileRule horizontalRule, Qt::TileRule verticalRule)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTileRules_IDX]);
            }
            ::Qt::TileRule cppArg0{Qt::StretchTile};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::Qt::TileRule cppArg1{Qt::StretchTile};
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QTileRules(Qt::TileRule,Qt::TileRule)
                cptr = new ::QTileRules(cppArg0, cppArg1);
            }
            break;
        }
        case 1: // QTileRules(Qt::TileRule rule)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_rule = Shiboken::String::createStaticString("rule");
                if (PyDict_Contains(kwds, key_rule) != 0) {
                    value = PyDict_GetItem(kwds, key_rule);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_rule);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTileRules_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_TileRule_IDX])))->converter, (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTileRules_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_rule);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTileRules_IDX]);
                }
            }
            ::Qt::TileRule cppArg0(Qt::StretchTile);
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QTileRules(Qt::TileRule)
                cptr = new ::QTileRules(cppArg0);
            }
            break;
        }
        case 2: // QTileRules(const QTileRules &QTileRules)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTileRules_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QTileRules cppArg0_local;
            ::QTileRules *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QTileRules(QTileRules)
                cptr = new ::QTileRules(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QTileRules >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTileRules_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QTileRules__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QTileRules *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTileRules_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTileRules_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QTileRules_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QTileRules_methods[] = {
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QTileRules__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QTileRules_get_horizontal(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTileRules *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTileRules_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::Qt::TileRule cppOut_local = cppSelf->horizontal;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_TileRule_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QTileRules_set_horizontal(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QTileRules *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTileRules_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("horizontal");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_TileRule_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("horizontal", "TileRule");
        return -1;
    }

    auto cppOut_local = cppSelf->horizontal;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->horizontal = cppOut_local;

    return 0;
}

static PyObject *Sbk_QTileRules_get_vertical(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTileRules *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTileRules_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::Qt::TileRule cppOut_local = cppSelf->vertical;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_TileRule_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QTileRules_set_vertical(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QTileRules *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTileRules_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("vertical");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_TileRule_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("vertical", "TileRule");
        return -1;
    }

    auto cppOut_local = cppSelf->vertical;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->vertical = cppOut_local;

    return 0;
}

// Getters and Setters for QTileRules
static PyGetSetDef Sbk_QTileRules_getsetlist[] = {
    {const_cast<char *>("horizontal"), Sbk_QTileRules_get_horizontal, Sbk_QTileRules_set_horizontal, nullptr, nullptr},
    {const_cast<char *>("vertical"), Sbk_QTileRules_get_vertical, Sbk_QTileRules_set_vertical, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QTileRules_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QTileRules_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QTileRules_Type = nullptr;
static PyTypeObject *Sbk_QTileRules_TypeF(void)
{
    return _Sbk_QTileRules_Type;
}

static PyType_Slot Sbk_QTileRules_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QTileRules_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QTileRules_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QTileRules_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QTileRules_getsetlist)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QTileRules_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QTileRules_spec = {
    "2:PySide6.QtWidgets.QTileRules",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QTileRules_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QTileRules_PythonToCpp_QTileRules_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QTileRules_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QTileRules_PythonToCpp_QTileRules_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QTileRules_TypeF()))
        return QTileRules_PythonToCpp_QTileRules_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QTileRules_PTR_CppToPython_QTileRules(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QTileRules_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QTileRules_COPY_CppToPython_QTileRules(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QTileRules *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QTileRules_TypeF(), new ::QTileRules(*source), true, true);
}

// Python to C++ copy conversion.
static void QTileRules_PythonToCpp_QTileRules_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QTileRules *>(cppOut) = *reinterpret_cast< ::QTileRules *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTileRules_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QTileRules_PythonToCpp_QTileRules_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QTileRules_TypeF()))
        return QTileRules_PythonToCpp_QTileRules_COPY;
    return {};
}

// Implicit conversions.
static void PySide6_QtCore_Qt_TileRule_PythonToCpp_QTileRules(PyObject *pyIn, void *cppOut)
{
    ::Qt::TileRule cppIn{Qt::StretchTile};
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_TileRule_IDX])))->converter, pyIn, &cppIn);
    *reinterpret_cast<::QTileRules *>(cppOut) = ::QTileRules(cppIn);
}
static PythonToCppFunc is_PySide6_QtCore_Qt_TileRule_PythonToCpp_QTileRules_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_TileRule_IDX]), pyIn))
        return PySide6_QtCore_Qt_TileRule_PythonToCpp_QTileRules;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QTileRules_SignatureStrings[] = {
    "2:PySide6.QtWidgets.QTileRules(self,horizontalRule:PySide6.QtCore.Qt.TileRule,verticalRule:PySide6.QtCore.Qt.TileRule)",
    "1:PySide6.QtWidgets.QTileRules(self,rule:PySide6.QtCore.Qt.TileRule=Qt.StretchTile)",
    "0:PySide6.QtWidgets.QTileRules(self,QTileRules:PySide6.QtWidgets.QTileRules)",
    "PySide6.QtWidgets.QTileRules.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QTileRules_SignatureByteSize = 135;
static constexpr uint8_t QTileRules_SignatureBytes[135] = {
    0x78, 0xda, 0x33, 0xb2, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x09, 0xcf,
    0x4c, 0x49, 0x4f, 0x2d, 0x29, 0xd6, 0x0b, 0x0c, 0xc9, 0xcc, 0x49, 0x0d, 0x2a, 0xcd, 0x49, 0x2d,
    0xd6, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0xc9, 0xc8, 0x2f, 0xca, 0xac, 0xca, 0xcf, 0x2b, 0x49, 0xcc,
    0x01, 0x09, 0x22, 0x69, 0x70, 0xce, 0x2f, 0x4a, 0x05, 0x52, 0x7a, 0x30, 0xf5, 0x3a, 0x65, 0xa9,
    0x45, 0x25, 0x99, 0xc9, 0x04, 0xd5, 0x69, 0x72, 0x19, 0x12, 0x61, 0x6d, 0x11, 0x7e, 0x43, 0x6c,
    0x81, 0xec, 0xe0, 0x92, 0xa2, 0xd4, 0x92, 0xe4, 0x0c, 0x90, 0x90, 0x26, 0x97, 0x01, 0x11, 0x66,
    0x22, 0xf8, 0x78, 0x15, 0x6b, 0x72, 0xe1, 0x93, 0xd5, 0x8b, 0x8f, 0x4f, 0xce, 0x2f, 0xa8, 0x8c,
    0x8f, 0x07, 0x9b, 0xa9, 0xa9, 0x6b, 0x57, 0x52, 0x59, 0x90, 0x99, 0x97, 0xae, 0x17, 0x0c, 0xe4,
    0x71, 0x01, 0x00, 0x18, 0x52, 0x78, 0xf5
};
#endif

PyTypeObject *init_QTileRules(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QTileRules_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QTileRules_IDX].type;

    Shiboken::AutoDecRef Sbk_QTileRules_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QTileRules_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QTileRules",
        "QTileRules",
        &Sbk_QTileRules_spec,
        &Shiboken::callCppDestructor< ::QTileRules >,
        Sbk_QTileRules_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QTileRules_TypeF(); // references _Sbk_QTileRules_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QTileRules_SignatureStrings);
#else
    InitSignatureBytes(pyType, QTileRules_SignatureBytes, QTileRules_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QTileRules_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QTileRules_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QTileRules_PythonToCpp_QTileRules_PTR,
        is_QTileRules_PythonToCpp_QTileRules_PTR_Convertible,
        QTileRules_PTR_CppToPython_QTileRules,
        QTileRules_COPY_CppToPython_QTileRules);

    Shiboken::Conversions::registerConverterName(converter, "QTileRules");
    Shiboken::Conversions::registerConverterName(converter, "QTileRules*");
    Shiboken::Conversions::registerConverterName(converter, "QTileRules&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QTileRules).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QTileRules_PythonToCpp_QTileRules_COPY,
        is_QTileRules_PythonToCpp_QTileRules_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        PySide6_QtCore_Qt_TileRule_PythonToCpp_QTileRules,
        is_PySide6_QtCore_Qt_TileRule_PythonToCpp_QTileRules_Convertible);

    qRegisterMetaType< ::QTileRules >("QTileRules");

    return pyType;
}
