// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qtooltip_wrapper.h"

// Argument includes
#include <QString>
#include <QtGui/qfont.h>
#include <QtGui/qpalette.h>
#include <QtWidgets/qwidget.h>
#include <qpoint.h>
#include <qrect.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QToolTipFunc_font(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // font()
        QFont cppResult = ::QToolTip::font();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QToolTipFunc_hideText(PyObject *self)
{
    SBK_UNUSED(self)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hideText()
        ::QToolTip::hideText();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QToolTipFunc_isVisible(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isVisible()
        bool cppResult = ::QToolTip::isVisible();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QToolTipFunc_palette(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // palette()
        QPalette cppResult = ::QToolTip::palette();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPalette_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QToolTipFunc_setFont(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QToolTip::setFont(QFont)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), (pyArg)))) {
        overloadId = 0; // setFont(QFont)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFont", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QToolTip_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFont cppArg0_local;
        ::QFont *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setFont(QFont)
            ::QToolTip::setFont(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QToolTipFunc_setPalette(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QToolTip::setPalette(QPalette)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPalette_IDX]), (pyArg)))) {
        overloadId = 0; // setPalette(QPalette)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPalette", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QToolTip_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPalette cppArg0_local;
        ::QPalette *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setPalette(QPalette)
            ::QToolTip::setPalette(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QToolTipFunc_showText(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "showText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QToolTip_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOO:showText", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QToolTip::showText(QPoint,QString,QWidget*=,const QRect&=,int=)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // showText(QPoint,QString,QWidget*,QRect,int)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 0; // showText(QPoint,QString,QWidget*,QRect,int)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[3])))) {
                if (numArgs == 4) {
                    overloadId = 0; // showText(QPoint,QString,QWidget*,QRect,int)
                } else if (numArgs >= 5
                    && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))) {
                    overloadId = 0; // showText(QPoint,QString,QWidget*,QRect,int)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "showText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QToolTip_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_w = Shiboken::String::createStaticString("w");
            if (PyDict_Contains(kwds, key_w) != 0) {
                value = PyDict_GetItem(kwds, key_w);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_w);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "showText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QToolTip_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "showText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QToolTip_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_w);
            }
            static PyObject *const key_rect = Shiboken::String::createStaticString("rect");
            if (PyDict_Contains(kwds, key_rect) != 0) {
                value = PyDict_GetItem(kwds, key_rect);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_rect);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "showText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QToolTip_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, "showText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QToolTip_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_rect);
            }
            static PyObject *const key_msecShowTime = Shiboken::String::createStaticString("msecShowTime");
            if (PyDict_Contains(kwds, key_msecShowTime) != 0) {
                value = PyDict_GetItem(kwds, key_msecShowTime);
                if (value != nullptr && pyArgs[4] != nullptr ) {
                    errInfo.reset(key_msecShowTime);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "showText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QToolTip_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[4] = value;
                    if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4]))))
                        return Shiboken::returnWrongArguments(args, "showText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QToolTip_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_msecShowTime);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "showText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QToolTip_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QPoint cppArg0_local;
        ::QPoint *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QWidget *cppArg2 = nullptr;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);
        if (!Shiboken::Object::isValid(pyArgs[3]))
            return {};
        ::QRect cppArg3_local{};
        ::QRect *cppArg3 = &cppArg3_local;
        if (pythonToCpp[3]) {
            if (pythonToCpp[3].isValue())
                pythonToCpp[3](pyArgs[3], &cppArg3_local);
            else
                pythonToCpp[3](pyArgs[3], &cppArg3);
            }
        int cppArg4 = -1;
        if (pythonToCpp[4])
            pythonToCpp[4](pyArgs[4], &cppArg4);

        if (Shiboken::Errors::occurred() == nullptr) {
            // showText(QPoint,QString,QWidget*,QRect,int)
            ::QToolTip::showText(*cppArg0, cppArg1, cppArg2, *cppArg3, cppArg4);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QToolTipFunc_text(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // text()
        QString cppResult = ::QToolTip::text();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QToolTip_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QToolTip_methods[] = {
    {"font", reinterpret_cast<PyCFunction>(Sbk_QToolTipFunc_font), METH_NOARGS|METH_STATIC, nullptr},
    {"hideText", reinterpret_cast<PyCFunction>(Sbk_QToolTipFunc_hideText), METH_NOARGS|METH_STATIC, nullptr},
    {"isVisible", reinterpret_cast<PyCFunction>(Sbk_QToolTipFunc_isVisible), METH_NOARGS|METH_STATIC, nullptr},
    {"palette", reinterpret_cast<PyCFunction>(Sbk_QToolTipFunc_palette), METH_NOARGS|METH_STATIC, nullptr},
    {"setFont", reinterpret_cast<PyCFunction>(Sbk_QToolTipFunc_setFont), METH_O|METH_STATIC, nullptr},
    {"setPalette", reinterpret_cast<PyCFunction>(Sbk_QToolTipFunc_setPalette), METH_O|METH_STATIC, nullptr},
    {"showText", reinterpret_cast<PyCFunction>(Sbk_QToolTipFunc_showText), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"text", reinterpret_cast<PyCFunction>(Sbk_QToolTipFunc_text), METH_NOARGS|METH_STATIC, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QToolTip_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QToolTip_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QToolTip_Type = nullptr;
static PyTypeObject *Sbk_QToolTip_TypeF(void)
{
    return _Sbk_QToolTip_Type;
}

static PyType_Slot Sbk_QToolTip_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QToolTip_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QToolTip_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QToolTip_methods)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QToolTip_spec = {
    "2:PySide6.QtWidgets.QToolTip",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QToolTip_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QToolTip_PythonToCpp_QToolTip_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QToolTip_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QToolTip_PythonToCpp_QToolTip_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QToolTip_TypeF()))
        return QToolTip_PythonToCpp_QToolTip_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QToolTip_PTR_CppToPython_QToolTip(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QToolTip_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QToolTip_SignatureStrings[] = {
    "PySide6.QtWidgets.QToolTip.font()->PySide6.QtGui.QFont",
    "PySide6.QtWidgets.QToolTip.hideText()",
    "PySide6.QtWidgets.QToolTip.isVisible()->bool",
    "PySide6.QtWidgets.QToolTip.palette()->PySide6.QtGui.QPalette",
    "PySide6.QtWidgets.QToolTip.setFont(arg__1:typing.Union[PySide6.QtGui.QFont, QString, QStringList])",
    "PySide6.QtWidgets.QToolTip.setPalette(arg__1:typing.Union[PySide6.QtGui.QPalette, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor])",
    "PySide6.QtWidgets.QToolTip.showText(pos:PySide6.QtCore.QPoint,text:QString,w:PySide6.QtWidgets.QWidget=nullptr,rect:PySide6.QtCore.QRect={},msecShowTime:int=-1)",
    "PySide6.QtWidgets.QToolTip.text()->QString",
    nullptr}; // Sentinel
#else
static constexpr size_t QToolTip_SignatureByteSize = 250;
static constexpr uint8_t QToolTip_SignatureBytes[250] = {
    0x78, 0xda, 0x8d, 0x52, 0x3d, 0x4f, 0xc3, 0x30, 0x10, 0xdd, 0xfb, 0x2b, 0x3a, 0xb6, 0x52, 0x62,
    0xa9, 0x0b, 0x83, 0xa5, 0x74, 0xa9, 0x44, 0x17, 0x06, 0x87, 0x04, 0x18, 0x10, 0xaa, 0x92, 0xf6,
    0x48, 0x4f, 0x72, 0x73, 0x96, 0x7d, 0x55, 0xa9, 0x10, 0xff, 0x9d, 0x4b, 0x1a, 0x0a, 0x82, 0x34,
    0x65, 0xb2, 0xf5, 0x3e, 0xee, 0xbd, 0xb3, 0x6c, 0x8e, 0x19, 0x6e, 0xe0, 0x46, 0xa5, 0xfc, 0x84,
    0x9b, 0x0a, 0x38, 0xa8, 0x34, 0x27, 0xb2, 0x39, 0x3a, 0xf5, 0x4a, 0x35, 0x4f, 0xa6, 0xf1, 0xdc,
    0x9c, 0x25, 0xcb, 0x3d, 0xaa, 0xf4, 0x56, 0xe0, 0x91, 0xb9, 0x6c, 0xdb, 0x0a, 0x91, 0xc3, 0x9b,
    0x58, 0x87, 0x54, 0x18, 0x1e, 0x31, 0x60, 0x69, 0xa1, 0x49, 0x28, 0x05, 0x1c, 0x12, 0xbb, 0xc2,
    0x02, 0x33, 0xf4, 0x94, 0x31, 0x27, 0x66, 0xc8, 0x1c, 0x80, 0x9b, 0xca, 0x93, 0xc2, 0x57, 0xab,
    0xd5, 0x4c, 0xf3, 0xd1, 0x61, 0x5d, 0xa9, 0x87, 0x1a, 0xa9, 0x7e, 0xee, 0x59, 0x2d, 0x1a, 0xa7,
    0x19, 0x7b, 0x91, 0x9c, 0x2f, 0x77, 0x18, 0xf8, 0x65, 0x7a, 0x25, 0xa2, 0x2b, 0xf2, 0x9f, 0x94,
    0x4e, 0x1a, 0x8d, 0xbf, 0xf1, 0x05, 0x79, 0x90, 0x43, 0x2d, 0x2d, 0x95, 0x85, 0x5d, 0x90, 0x25,
    0xff, 0x93, 0x6e, 0x6d, 0x2d, 0x7a, 0xa5, 0xc7, 0x96, 0x0e, 0xed, 0xd3, 0x3b, 0x0a, 0xfa, 0xf7,
    0x74, 0x43, 0x28, 0xdb, 0xb1, 0xd0, 0xfa, 0x6b, 0xc3, 0x83, 0xee, 0x19, 0x76, 0xba, 0x24, 0xf5,
    0xde, 0x5a, 0xc7, 0x3e, 0xf2, 0xb0, 0xe6, 0x3f, 0xb3, 0xee, 0x05, 0x4c, 0xde, 0x3f, 0xa2, 0x5d,
    0x80, 0x75, 0xd6, 0x84, 0xe2, 0x0e, 0xb4, 0x8c, 0x4f, 0xe2, 0xd9, 0x60, 0x41, 0x6e, 0xff, 0x45,
    0x3c, 0xef, 0x0a, 0x8c, 0x3e, 0x01, 0x38, 0x91, 0xe2, 0xb8
};
#endif

PyTypeObject *init_QToolTip(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QToolTip_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QToolTip_IDX].type;

    Shiboken::AutoDecRef Sbk_QToolTip_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QToolTip_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QToolTip",
        "QToolTip*",
        &Sbk_QToolTip_spec,
        &Shiboken::callCppDestructor< ::QToolTip >,
        Sbk_QToolTip_Type_bases.object(),
        0);
    auto *pyType = Sbk_QToolTip_TypeF(); // references _Sbk_QToolTip_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QToolTip_SignatureStrings);
#else
    InitSignatureBytes(pyType, QToolTip_SignatureBytes, QToolTip_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QToolTip_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QToolTip_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QToolTip_PythonToCpp_QToolTip_PTR,
        is_QToolTip_PythonToCpp_QToolTip_PTR_Convertible,
        QToolTip_PTR_CppToPython_QToolTip);

    Shiboken::Conversions::registerConverterName(converter, "QToolTip");
    Shiboken::Conversions::registerConverterName(converter, "QToolTip*");
    Shiboken::Conversions::registerConverterName(converter, "QToolTip&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QToolTip).name());

    qRegisterMetaType< ::QToolTip *>();

    return pyType;
}
