// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QTreeWidgetItemWrapper_H
#define SBK_QTreeWidgetItemWrapper_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtWidgets/qtreewidget.h>

class QTreeWidgetItemWrapper : public QTreeWidgetItem
{
public:
    QTreeWidgetItemWrapper(const QTreeWidgetItemWrapper &) = delete;
    QTreeWidgetItemWrapper& operator=(const QTreeWidgetItemWrapper &) = delete;
    QTreeWidgetItemWrapper(QTreeWidgetItemWrapper &&) = delete;
    QTreeWidgetItemWrapper& operator=(QTreeWidgetItemWrapper &&) = delete;

    QTreeWidgetItemWrapper(::QTreeWidget * treeview, ::QTreeWidgetItem * after, int type = QTreeWidgetItem::ItemType::Type);
    QTreeWidgetItemWrapper(::QTreeWidget * treeview, const ::QStringList & strings, int type = QTreeWidgetItem::ItemType::Type);
    QTreeWidgetItemWrapper(::QTreeWidget * treeview, int type = QTreeWidgetItem::ItemType::Type);
    QTreeWidgetItemWrapper(::QTreeWidgetItem * parent, ::QTreeWidgetItem * after, int type = QTreeWidgetItem::ItemType::Type);
    QTreeWidgetItemWrapper(::QTreeWidgetItem * parent, const ::QStringList & strings, int type = QTreeWidgetItem::ItemType::Type);
    QTreeWidgetItemWrapper(::QTreeWidgetItem * parent, int type = QTreeWidgetItem::ItemType::Type);
    QTreeWidgetItemWrapper(const ::QStringList & strings, int type = QTreeWidgetItem::ItemType::Type);
    QTreeWidgetItemWrapper(const QTreeWidgetItem& self) : QTreeWidgetItem(self)
    {
    }

    QTreeWidgetItemWrapper(int type = QTreeWidgetItem::ItemType::Type);
    ::QTreeWidgetItem * clone() const override;
    ::QVariant data(int column, int role) const override;
    bool operator<(const ::QTreeWidgetItem & other) const override;
    void read(::QDataStream & in) override;
    void setData(int column, int role, const ::QVariant & value) override;
    void write(::QDataStream & out) const override;
    ~QTreeWidgetItemWrapper() override;
    static void pysideInitQtMetaTypes();
    void resetPyMethodCache();
private:
    mutable bool m_PyMethodCache[6] = {false, false, false, false, false, false};
};

#endif // SBK_QTreeWidgetItemWrapper_H

