// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qtreewidgetitemiterator_wrapper.h"

// Argument includes
#include <QtWidgets/qtreewidget.h>
#include <QtWidgets/qtreewidgetitemiterator.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTreeWidgetItemIterator_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QTreeWidgetItemIterator >()))
        return -1;

    ::QTreeWidgetItemIterator *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItemIterator_IDX]);

    if (PyArg_ParseTuple(args, "|OO:QTreeWidgetItemIterator", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QTreeWidgetItemIterator::QTreeWidgetItemIterator(QTreeWidget*,QFlags<QTreeWidgetItemIterator::IteratorFlag>=)
    // 1: QTreeWidgetItemIterator::QTreeWidgetItemIterator(QTreeWidgetItem*,QFlags<QTreeWidgetItemIterator::IteratorFlag>=)
    // 2: QTreeWidgetItemIterator::QTreeWidgetItemIterator(QTreeWidgetItemIterator)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItem_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QTreeWidgetItemIterator(QTreeWidgetItem*,QFlags<QTreeWidgetItemIterator::IteratorFlag>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QTreeWidgetItemIterator_IteratorFlag_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 1; // QTreeWidgetItemIterator(QTreeWidgetItem*,QFlags<QTreeWidgetItemIterator::IteratorFlag>)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // QTreeWidgetItemIterator(QTreeWidget*,QFlags<QTreeWidgetItemIterator::IteratorFlag>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QTreeWidgetItemIterator_IteratorFlag_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 0; // QTreeWidgetItemIterator(QTreeWidget*,QFlags<QTreeWidgetItemIterator::IteratorFlag>)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItemIterator_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QTreeWidgetItemIterator(QTreeWidgetItemIterator)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItemIterator_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItemIterator_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QTreeWidgetItemIterator(QTreeWidget *widget, QFlags<QTreeWidgetItemIterator::IteratorFlag> flags)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_flags = Shiboken::String::createStaticString("flags");
                if (PyDict_Contains(kwds, key_flags) != 0) {
                    value = PyDict_GetItem(kwds, key_flags);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_flags);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItemIterator_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QTreeWidgetItemIterator_IteratorFlag_IDX])))->flagsConverter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItemIterator_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_flags);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItemIterator_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QTreeWidget *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QFlags<QTreeWidgetItemIterator::IteratorFlag> cppArg1(QTreeWidgetItemIterator::IteratorFlag::All);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QTreeWidgetItemIterator(QTreeWidget*,QFlags<QTreeWidgetItemIterator::IteratorFlag>)
                cptr = new ::QTreeWidgetItemIterator(cppArg0, cppArg1);
                // Ownership transferences.
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
        case 1: // QTreeWidgetItemIterator(QTreeWidgetItem *item, QFlags<QTreeWidgetItemIterator::IteratorFlag> flags)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_flags = Shiboken::String::createStaticString("flags");
                if (PyDict_Contains(kwds, key_flags) != 0) {
                    value = PyDict_GetItem(kwds, key_flags);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_flags);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItemIterator_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QTreeWidgetItemIterator_IteratorFlag_IDX])))->flagsConverter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItemIterator_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_flags);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItemIterator_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QTreeWidgetItem *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QFlags<QTreeWidgetItemIterator::IteratorFlag> cppArg1(QTreeWidgetItemIterator::IteratorFlag::All);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QTreeWidgetItemIterator(QTreeWidgetItem*,QFlags<QTreeWidgetItemIterator::IteratorFlag>)
                cptr = new ::QTreeWidgetItemIterator(cppArg0, cppArg1);
            }
            break;
        }
        case 2: // QTreeWidgetItemIterator(const QTreeWidgetItemIterator &it)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItemIterator_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QTreeWidgetItemIterator cppArg0_local = ::QTreeWidgetItemIterator(static_cast<::QTreeWidgetItem*>(nullptr));
            ::QTreeWidgetItemIterator *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QTreeWidgetItemIterator(QTreeWidgetItemIterator)
                cptr = new ::QTreeWidgetItemIterator(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QTreeWidgetItemIterator >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItemIterator_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QTreeWidgetItemIteratorFunc___iter__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidgetItemIterator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItemIterator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // __iter__()
        // Begin code injection
        // TEMPLATE - __iter__ - START
        Py_INCREF(self);
        pyResult = self;
        // TEMPLATE - __iter__ - END
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTreeWidgetItemIteratorFunc___next__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidgetItemIterator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItemIterator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // __next__()
        // Begin code injection
        // ========================================================================
        // START of custom code block [file: ../glue/qtwidgets.cpp (qtreewidgetitemiterator-next)]
        if (**cppSelf) {
            QTreeWidgetItemIterator *cppResult = new QTreeWidgetItemIterator((*cppSelf)++);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItemIterator_IDX]), cppResult);
        }
        // END of custom code block [file: ../glue/qtwidgets.cpp (qtreewidgetitemiterator-next)]
        // ========================================================================
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTreeWidgetItemIteratorFunc_value(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidgetItemIterator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItemIterator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // value()
        // Begin code injection
        // ========================================================================
        // START of custom code block [file: ../glue/qtwidgets.cpp (qtreewidgetitemiterator-value)]
        QTreeWidgetItem *cppResult = cppSelf->operator *();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItem_IDX]), cppResult);
        Shiboken::Object::releaseOwnership(pyResult);
        // END of custom code block [file: ../glue/qtwidgets.cpp (qtreewidgetitemiterator-value)]
        // ========================================================================
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTreeWidgetItemIterator__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QTreeWidgetItemIterator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItemIterator_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItemIterator_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QTreeWidgetItemIterator_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QTreeWidgetItemIterator_EnumFlagInfo[] = {
    "IteratorFlag:Flag:IteratorFlags",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QTreeWidgetItemIterator_methods[] = {
    {"value", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetItemIteratorFunc_value), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetItemIterator__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QTreeWidgetItemIteratorFunc___iadd__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItemIterator_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItemIterator_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidgetItemIterator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItemIterator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTreeWidgetItemIterator::operator+=(int)->QTreeWidgetItemIterator&
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // operator+=(int)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator+=", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItemIterator_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // operator+=(int)
            (*cppSelf) += cppArg0;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_INCREF(self);
    return self;
}

static PyObject *Sbk_QTreeWidgetItemIteratorFunc___isub__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItemIterator_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItemIterator_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidgetItemIterator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItemIterator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTreeWidgetItemIterator::operator-=(int)->QTreeWidgetItemIterator&
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // operator-=(int)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator-=", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItemIterator_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // operator-=(int)
            (*cppSelf) -= cppArg0;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_INCREF(self);
    return self;
}

} // extern "C"

static int Sbk_QTreeWidgetItemIterator_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QTreeWidgetItemIterator_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QTreeWidgetItemIterator_Type = nullptr;
static PyTypeObject *Sbk_QTreeWidgetItemIterator_TypeF(void)
{
    return _Sbk_QTreeWidgetItemIterator_Type;
}

static PyType_Slot Sbk_QTreeWidgetItemIterator_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QTreeWidgetItemIterator_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QTreeWidgetItemIterator_clear)},
    {Py_tp_iter,        reinterpret_cast<void *>(Sbk_QTreeWidgetItemIteratorFunc___iter__)},
    {Py_tp_iternext,    reinterpret_cast<void *>(Sbk_QTreeWidgetItemIteratorFunc___next__)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QTreeWidgetItemIterator_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QTreeWidgetItemIterator_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_inplace_add, reinterpret_cast<void *>(Sbk_QTreeWidgetItemIteratorFunc___iadd__)},
    {Py_nb_inplace_subtract,reinterpret_cast<void *>(Sbk_QTreeWidgetItemIteratorFunc___isub__)},
    {0, nullptr}
};
static PyType_Spec Sbk_QTreeWidgetItemIterator_spec = {
    "2:PySide6.QtWidgets.QTreeWidgetItemIterator",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QTreeWidgetItemIterator_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QTreeWidgetItemIterator_IteratorFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QTreeWidgetItemIterator::IteratorFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QTreeWidgetItemIterator::IteratorFlag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QTreeWidgetItemIterator_IteratorFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItemIterator_IteratorFlag_IDX])))
        return Enum_PythonToCpp_QTreeWidgetItemIterator_IteratorFlag;
    return {};
}

static PyObject *QTreeWidgetItemIterator_IteratorFlag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QTreeWidgetItemIterator::IteratorFlag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QTreeWidgetItemIterator::IteratorFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItemIterator_IteratorFlag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QTreeWidgetItemIterator_IteratorFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QTreeWidgetItemIterator::IteratorFlag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QTreeWidgetItemIterator::IteratorFlag> *>(cppOut) = value;

}

static PyObject *QTreeWidgetItemIterator_IteratorFlag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QTreeWidgetItemIterator::IteratorFlag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItemIterator_IteratorFlag_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QTreeWidgetItemIterator_PythonToCpp_QTreeWidgetItemIterator_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QTreeWidgetItemIterator_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QTreeWidgetItemIterator_PythonToCpp_QTreeWidgetItemIterator_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QTreeWidgetItemIterator_TypeF()))
        return QTreeWidgetItemIterator_PythonToCpp_QTreeWidgetItemIterator_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QTreeWidgetItemIterator_PTR_CppToPython_QTreeWidgetItemIterator(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QTreeWidgetItemIterator_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QTreeWidgetItemIterator_COPY_CppToPython_QTreeWidgetItemIterator(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QTreeWidgetItemIterator *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QTreeWidgetItemIterator_TypeF(), new ::QTreeWidgetItemIterator(*source), true, true);
}

// Python to C++ copy conversion.
static void QTreeWidgetItemIterator_PythonToCpp_QTreeWidgetItemIterator_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QTreeWidgetItemIterator *>(cppOut) = *reinterpret_cast< ::QTreeWidgetItemIterator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItemIterator_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QTreeWidgetItemIterator_PythonToCpp_QTreeWidgetItemIterator_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QTreeWidgetItemIterator_TypeF()))
        return QTreeWidgetItemIterator_PythonToCpp_QTreeWidgetItemIterator_COPY;
    return {};
}

// Implicit conversions.
static void QTreeWidgetPTR_PythonToCpp_QTreeWidgetItemIterator(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QTreeWidgetItemIterator *>(cppOut) = ::QTreeWidgetItemIterator(reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(pyIn))));
}
static PythonToCppFunc is_QTreeWidgetPTR_PythonToCpp_QTreeWidgetItemIterator_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), pyIn))
        return QTreeWidgetPTR_PythonToCpp_QTreeWidgetItemIterator;
    return {};
}

static void QTreeWidgetItemPTR_PythonToCpp_QTreeWidgetItemIterator(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QTreeWidgetItemIterator *>(cppOut) = ::QTreeWidgetItemIterator(reinterpret_cast< ::QTreeWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItem_IDX]), reinterpret_cast<SbkObject *>(pyIn))));
}
static PythonToCppFunc is_QTreeWidgetItemPTR_PythonToCpp_QTreeWidgetItemIterator_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItem_IDX]), pyIn))
        return QTreeWidgetItemPTR_PythonToCpp_QTreeWidgetItemIterator;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QTreeWidgetItemIterator_SignatureStrings[] = {
    "2:PySide6.QtWidgets.QTreeWidgetItemIterator(self,widget:PySide6.QtWidgets.QTreeWidget,flags:PySide6.QtWidgets.QTreeWidgetItemIterator.IteratorFlag=QTreeWidgetItemIterator.IteratorFlag.All)",
    "1:PySide6.QtWidgets.QTreeWidgetItemIterator(self,item:PySide6.QtWidgets.QTreeWidgetItem,flags:PySide6.QtWidgets.QTreeWidgetItemIterator.IteratorFlag=QTreeWidgetItemIterator.IteratorFlag.All)",
    "0:PySide6.QtWidgets.QTreeWidgetItemIterator(self,it:PySide6.QtWidgets.QTreeWidgetItemIterator)",
    "PySide6.QtWidgets.QTreeWidgetItemIterator.__iter__(self)->PyObject",
    "PySide6.QtWidgets.QTreeWidgetItemIterator.__next__(self)->PyObject",
    "PySide6.QtWidgets.QTreeWidgetItemIterator.value(self)->PySide6.QtWidgets.QTreeWidgetItem",
    "PySide6.QtWidgets.QTreeWidgetItemIterator.__copy__(self)->typing.Self",
    "PySide6.QtWidgets.QTreeWidgetItemIterator.__iadd__(self,n:int)->PySide6.QtWidgets.QTreeWidgetItemIterator",
    "PySide6.QtWidgets.QTreeWidgetItemIterator.__isub__(self,n:int)->PySide6.QtWidgets.QTreeWidgetItemIterator",
    nullptr}; // Sentinel
#else
static constexpr size_t QTreeWidgetItemIterator_SignatureByteSize = 186;
static constexpr uint8_t QTreeWidgetItemIterator_SignatureBytes[186] = {
    0x78, 0xda, 0x33, 0xb2, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x09, 0xcf,
    0x4c, 0x49, 0x4f, 0x2d, 0x29, 0xd6, 0x0b, 0x0c, 0x29, 0x4a, 0x4d, 0x85, 0x70, 0x3c, 0x4b, 0x52,
    0x73, 0x81, 0xb8, 0x28, 0xb1, 0x24, 0xbf, 0x48, 0xa3, 0x38, 0x35, 0x27, 0x4d, 0xa7, 0x1c, 0x2c,
    0x8e, 0x5f, 0x97, 0x4e, 0x5a, 0x4e, 0x62, 0x7a, 0x31, 0xf1, 0x26, 0xeb, 0xc1, 0x18, 0x6e, 0x40,
    0x7d, 0xb6, 0xc4, 0x28, 0xd2, 0x73, 0xcc, 0xc9, 0xd1, 0xe4, 0x32, 0x24, 0xd5, 0xf1, 0x99, 0x40,
    0x11, 0xc2, 0x7a, 0xe8, 0xe5, 0x7c, 0x03, 0xd2, 0x9d, 0x4f, 0xbc, 0x0e, 0x4d, 0x2e, 0xe2, 0xdd,
    0x1f, 0x1f, 0x0f, 0x0c, 0x98, 0xa2, 0xf8, 0x78, 0xb0, 0x2d, 0x9a, 0xba, 0x76, 0x01, 0x95, 0xfe,
    0x49, 0x59, 0xa9, 0xc9, 0x25, 0x24, 0x19, 0x91, 0x97, 0x5a, 0x51, 0x42, 0x91, 0x11, 0x65, 0x89,
    0x39, 0xa5, 0xa9, 0x08, 0xfd, 0x04, 0xb4, 0x91, 0xe4, 0xb6, 0xe4, 0xfc, 0x82, 0x4a, 0x84, 0xdb,
    0x4a, 0x2a, 0x0b, 0x32, 0xf3, 0xd2, 0xf5, 0x82, 0x81, 0x3c, 0xd2, 0x02, 0x29, 0x31, 0x25, 0x05,
    0x6a, 0x8a, 0x4e, 0x9e, 0x55, 0x66, 0x5e, 0x09, 0x31, 0xee, 0x84, 0xe9, 0x27, 0xcd, 0xa6, 0xe2,
    0xd2, 0x24, 0xf2, 0x6d, 0x02, 0x00, 0xf8, 0xa9, 0x69, 0xe2
};
#endif

PyTypeObject *init_QTreeWidgetItemIterator(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItemIterator_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItemIterator_IDX].type;

    Shiboken::AutoDecRef Sbk_QTreeWidgetItemIterator_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QTreeWidgetItemIterator_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QTreeWidgetItemIterator",
        "QTreeWidgetItemIterator",
        &Sbk_QTreeWidgetItemIterator_spec,
        &Shiboken::callCppDestructor< ::QTreeWidgetItemIterator >,
        Sbk_QTreeWidgetItemIterator_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QTreeWidgetItemIterator_TypeF(); // references _Sbk_QTreeWidgetItemIterator_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QTreeWidgetItemIterator_SignatureStrings);
#else
    InitSignatureBytes(pyType, QTreeWidgetItemIterator_SignatureBytes, QTreeWidgetItemIterator_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QTreeWidgetItemIterator_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItemIterator_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QTreeWidgetItemIterator_PythonToCpp_QTreeWidgetItemIterator_PTR,
        is_QTreeWidgetItemIterator_PythonToCpp_QTreeWidgetItemIterator_PTR_Convertible,
        QTreeWidgetItemIterator_PTR_CppToPython_QTreeWidgetItemIterator,
        QTreeWidgetItemIterator_COPY_CppToPython_QTreeWidgetItemIterator);

    Shiboken::Conversions::registerConverterName(converter, "QTreeWidgetItemIterator");
    Shiboken::Conversions::registerConverterName(converter, "QTreeWidgetItemIterator*");
    Shiboken::Conversions::registerConverterName(converter, "QTreeWidgetItemIterator&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QTreeWidgetItemIterator).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QTreeWidgetItemIterator_PythonToCpp_QTreeWidgetItemIterator_COPY,
        is_QTreeWidgetItemIterator_PythonToCpp_QTreeWidgetItemIterator_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QTreeWidgetPTR_PythonToCpp_QTreeWidgetItemIterator,
        is_QTreeWidgetPTR_PythonToCpp_QTreeWidgetItemIterator_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QTreeWidgetItemPTR_PythonToCpp_QTreeWidgetItemIterator,
        is_QTreeWidgetItemPTR_PythonToCpp_QTreeWidgetItemIterator_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QTreeWidgetItemIterator_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'IteratorFlag'.
    const char *IteratorFlag_Initializer[] = {
        "All",
        "Hidden",
        "NotHidden",
        "Selected",
        "Unselected",
        "Selectable",
        "NotSelectable",
        "DragEnabled",
        "DragDisabled",
        "DropEnabled",
        "DropDisabled",
        "HasChildren",
        "NoChildren",
        "Checked",
        "NotChecked",
        "Enabled",
        "Disabled",
        "Editable",
        "NotEditable",
        "UserFlag",
        nullptr};
    // "uint32_t" used instead of "unsigned int"
    constexpr uint32_t IteratorFlag_InitializerValues[] = {
        uint32_t(QTreeWidgetItemIterator::IteratorFlag::All),           //  0x00000000  0
        uint32_t(QTreeWidgetItemIterator::IteratorFlag::Hidden),        //  0x00000001  1
        uint32_t(QTreeWidgetItemIterator::IteratorFlag::NotHidden),     //  0x00000002  2
        uint32_t(QTreeWidgetItemIterator::IteratorFlag::Selected),      //  0x00000004  4
        uint32_t(QTreeWidgetItemIterator::IteratorFlag::Unselected),    //  0x00000008  8
        uint32_t(QTreeWidgetItemIterator::IteratorFlag::Selectable),    //  0x00000010  16
        uint32_t(QTreeWidgetItemIterator::IteratorFlag::NotSelectable), //  0x00000020  32
        uint32_t(QTreeWidgetItemIterator::IteratorFlag::DragEnabled),   //  0x00000040  64
        uint32_t(QTreeWidgetItemIterator::IteratorFlag::DragDisabled),  //  0x00000080  128
        uint32_t(QTreeWidgetItemIterator::IteratorFlag::DropEnabled),   //  0x00000100  256
        uint32_t(QTreeWidgetItemIterator::IteratorFlag::DropDisabled),  //  0x00000200  512
        uint32_t(QTreeWidgetItemIterator::IteratorFlag::HasChildren),   //  0x00000400  1024
        uint32_t(QTreeWidgetItemIterator::IteratorFlag::NoChildren),    //  0x00000800  2048
        uint32_t(QTreeWidgetItemIterator::IteratorFlag::Checked),       //  0x00001000  4096
        uint32_t(QTreeWidgetItemIterator::IteratorFlag::NotChecked),    //  0x00002000  8192
        uint32_t(QTreeWidgetItemIterator::IteratorFlag::Enabled),       //  0x00004000  16384
        uint32_t(QTreeWidgetItemIterator::IteratorFlag::Disabled),      //  0x00008000  32768
        uint32_t(QTreeWidgetItemIterator::IteratorFlag::Editable),      //  0x00010000  65536
        uint32_t(QTreeWidgetItemIterator::IteratorFlag::NotEditable),   //  0x00020000  131072
        uint32_t(QTreeWidgetItemIterator::IteratorFlag::UserFlag)       //  0x01000000  16777216
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QTreeWidgetItemIterator_TypeF(),
        "2:PySide6.QtWidgets.QTreeWidgetItemIterator.IteratorFlag",
        IteratorFlag_Initializer, IteratorFlag_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItemIterator_IteratorFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QTreeWidgetItemIterator_IteratorFlag_IDX].type =
        EType;
    // Register converter for enum 'QTreeWidgetItemIterator::IteratorFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QTreeWidgetItemIterator_IteratorFlag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QTreeWidgetItemIterator_IteratorFlag,
            is_Enum_PythonToCpp_QTreeWidgetItemIterator_IteratorFlag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QTreeWidgetItemIterator::IteratorFlag");
        Shiboken::Conversions::registerConverterAlias(converter, "IteratorFlag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QTreeWidgetItemIterator_IteratorFlag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QTreeWidgetItemIterator_IteratorFlag,
            is_Enum_PythonToCpp_QTreeWidgetItemIterator_IteratorFlag_Convertible);
        // Register converter for flag 'QFlags<QTreeWidgetItemIterator::IteratorFlag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QTreeWidgetItemIterator::IteratorFlag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QTreeWidgetItemIterator::IteratorFlags");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'IteratorFlag' enum/flags.

    qRegisterMetaType< ::QTreeWidgetItemIterator::IteratorFlag >("QTreeWidgetItemIterator::IteratorFlag");

    return pyType;
}
