// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qwhatsthis_wrapper.h"

// Argument includes
#include <QString>
#include <QtGui/qaction.h>
#include <QtWidgets/qwidget.h>
#include <qobject.h>
#include <qpoint.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QWhatsThisFunc_createAction(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "createAction", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWhatsThis_IDX]);

    if (PyArg_ParseTuple(args, "|O:createAction", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QWhatsThis::createAction(QObject*=)->QAction*
    if (numArgs == 0) {
        overloadId = 0; // createAction(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // createAction(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "createAction", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWhatsThis_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "createAction", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWhatsThis_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "createAction", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWhatsThis_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "createAction", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWhatsThis_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createAction(QObject*)
            QAction * cppResult = ::QWhatsThis::createAction(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAction_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWhatsThisFunc_enterWhatsThisMode(PyObject *self)
{
    SBK_UNUSED(self)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // enterWhatsThisMode()
        ::QWhatsThis::enterWhatsThisMode();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWhatsThisFunc_hideText(PyObject *self)
{
    SBK_UNUSED(self)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hideText()
        ::QWhatsThis::hideText();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWhatsThisFunc_inWhatsThisMode(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // inWhatsThisMode()
        bool cppResult = ::QWhatsThis::inWhatsThisMode();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWhatsThisFunc_leaveWhatsThisMode(PyObject *self)
{
    SBK_UNUSED(self)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // leaveWhatsThisMode()
        ::QWhatsThis::leaveWhatsThisMode();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWhatsThisFunc_showText(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "showText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWhatsThis_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:showText", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QWhatsThis::showText(QPoint,QString,QWidget*=)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // showText(QPoint,QString,QWidget*)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[2])))) {
            overloadId = 0; // showText(QPoint,QString,QWidget*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "showText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWhatsThis_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_w = Shiboken::String::createStaticString("w");
            if (PyDict_Contains(kwds, key_w) != 0) {
                value = PyDict_GetItem(kwds, key_w);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_w);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "showText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWhatsThis_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "showText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWhatsThis_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_w);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "showText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWhatsThis_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QPoint cppArg0_local;
        ::QPoint *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QWidget *cppArg2 = nullptr;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // showText(QPoint,QString,QWidget*)
            ::QWhatsThis::showText(*cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QWhatsThis_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QWhatsThis_methods[] = {
    {"createAction", reinterpret_cast<PyCFunction>(Sbk_QWhatsThisFunc_createAction), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"enterWhatsThisMode", reinterpret_cast<PyCFunction>(Sbk_QWhatsThisFunc_enterWhatsThisMode), METH_NOARGS|METH_STATIC, nullptr},
    {"hideText", reinterpret_cast<PyCFunction>(Sbk_QWhatsThisFunc_hideText), METH_NOARGS|METH_STATIC, nullptr},
    {"inWhatsThisMode", reinterpret_cast<PyCFunction>(Sbk_QWhatsThisFunc_inWhatsThisMode), METH_NOARGS|METH_STATIC, nullptr},
    {"leaveWhatsThisMode", reinterpret_cast<PyCFunction>(Sbk_QWhatsThisFunc_leaveWhatsThisMode), METH_NOARGS|METH_STATIC, nullptr},
    {"showText", reinterpret_cast<PyCFunction>(Sbk_QWhatsThisFunc_showText), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QWhatsThis_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QWhatsThis_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QWhatsThis_Type = nullptr;
static PyTypeObject *Sbk_QWhatsThis_TypeF(void)
{
    return _Sbk_QWhatsThis_Type;
}

static PyType_Slot Sbk_QWhatsThis_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QWhatsThis_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QWhatsThis_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QWhatsThis_methods)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QWhatsThis_spec = {
    "2:PySide6.QtWidgets.QWhatsThis",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QWhatsThis_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QWhatsThis_PythonToCpp_QWhatsThis_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QWhatsThis_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QWhatsThis_PythonToCpp_QWhatsThis_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QWhatsThis_TypeF()))
        return QWhatsThis_PythonToCpp_QWhatsThis_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QWhatsThis_PTR_CppToPython_QWhatsThis(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QWhatsThis_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QWhatsThis_SignatureStrings[] = {
    "PySide6.QtWidgets.QWhatsThis.createAction(parent:PySide6.QtCore.QObject=nullptr)->PySide6.QtGui.QAction",
    "PySide6.QtWidgets.QWhatsThis.enterWhatsThisMode()",
    "PySide6.QtWidgets.QWhatsThis.hideText()",
    "PySide6.QtWidgets.QWhatsThis.inWhatsThisMode()->bool",
    "PySide6.QtWidgets.QWhatsThis.leaveWhatsThisMode()",
    "PySide6.QtWidgets.QWhatsThis.showText(pos:PySide6.QtCore.QPoint,text:QString,w:PySide6.QtWidgets.QWidget=nullptr)",
    nullptr}; // Sentinel
#else
static constexpr size_t QWhatsThis_SignatureByteSize = 171;
static constexpr uint8_t QWhatsThis_SignatureBytes[171] = {
    0x78, 0xda, 0x95, 0x90, 0x41, 0x0b, 0x82, 0x40, 0x10, 0x85, 0xef, 0xfe, 0x12, 0x03, 0xdd, 0x63,
    0x07, 0x21, 0x21, 0x3a, 0x74, 0x8a, 0x76, 0x51, 0xf0, 0xbc, 0xea, 0xe0, 0x4e, 0x2c, 0x3b, 0xb2,
    0x3b, 0x66, 0xfd, 0xfb, 0xc4, 0xc0, 0xa0, 0xc2, 0xe8, 0x36, 0xc3, 0x7b, 0xdf, 0x9b, 0xc7, 0xc8,
    0x7b, 0x81, 0x2d, 0x6c, 0x85, 0xe2, 0x0a, 0xdb, 0x0e, 0x38, 0x08, 0x55, 0x19, 0xcd, 0xa1, 0x34,
    0x18, 0x44, 0xe3, 0x41, 0x33, 0xec, 0x1b, 0x46, 0x72, 0x71, 0xaf, 0x3d, 0x38, 0xce, 0xe4, 0x02,
    0x1c, 0xc8, 0x83, 0x50, 0xe7, 0xfa, 0x02, 0x0d, 0xef, 0xdc, 0x60, 0x6d, 0xcf, 0x7e, 0x93, 0xe6,
    0x2f, 0xc3, 0x71, 0x40, 0xa1, 0x9e, 0x74, 0x24, 0xd7, 0xee, 0x4c, 0xb9, 0xe0, 0x97, 0xf5, 0x44,
    0x2d, 0xc4, 0x9b, 0x75, 0xc2, 0x4c, 0x52, 0x09, 0x37, 0xfe, 0xe5, 0x43, 0xf7, 0x16, 0x9b, 0xe6,
    0x35, 0x91, 0x5d, 0x87, 0x2c, 0xe8, 0x2b, 0xfc, 0x55, 0x27, 0x18, 0x1a, 0xe7, 0x3a, 0x3d, 0x85,
    0x8f, 0x0f, 0x49, 0x42, 0xc7, 0x09, 0x4f, 0x72, 0xa6, 0x0a, 0xf6, 0xe8, 0xba, 0x64, 0xcc, 0xbe,
    0xc5, 0xcd, 0xc3, 0xf2, 0xc9, 0xe8, 0x01, 0xdb, 0x90, 0x94, 0xeb
};
#endif

PyTypeObject *init_QWhatsThis(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QWhatsThis_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QWhatsThis_IDX].type;

    Shiboken::AutoDecRef Sbk_QWhatsThis_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QWhatsThis_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QWhatsThis",
        "QWhatsThis*",
        &Sbk_QWhatsThis_spec,
        &Shiboken::callCppDestructor< ::QWhatsThis >,
        Sbk_QWhatsThis_Type_bases.object(),
        0);
    auto *pyType = Sbk_QWhatsThis_TypeF(); // references _Sbk_QWhatsThis_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QWhatsThis_SignatureStrings);
#else
    InitSignatureBytes(pyType, QWhatsThis_SignatureBytes, QWhatsThis_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QWhatsThis_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QWhatsThis_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QWhatsThis_PythonToCpp_QWhatsThis_PTR,
        is_QWhatsThis_PythonToCpp_QWhatsThis_PTR_Convertible,
        QWhatsThis_PTR_CppToPython_QWhatsThis);

    Shiboken::Conversions::registerConverterName(converter, "QWhatsThis");
    Shiboken::Conversions::registerConverterName(converter, "QWhatsThis*");
    Shiboken::Conversions::registerConverterName(converter, "QWhatsThis&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QWhatsThis).name());

    qRegisterMetaType< ::QWhatsThis *>();

    return pyType;
}
