// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtxml_python.h"

// main header
#include "qdomcharacterdata_wrapper.h"

// Argument includes
#include <QString>
#include <QtXml/qdom.h>
#include <qtextstream.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDomCharacterData_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QDomCharacterData >()))
        return -1;

    ::QDomCharacterData *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QDomCharacterData", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QDomCharacterData::QDomCharacterData()
    // 1: QDomCharacterData::QDomCharacterData(QDomCharacterData)
    if (numArgs == 0) {
        overloadId = 0; // QDomCharacterData()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomCharacterData_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QDomCharacterData(QDomCharacterData)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomCharacterData_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtXmlTypeStructs[SBK_QDomCharacterData_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QDomCharacterData()
        {

            // QDomCharacterData()
            cptr = new ::QDomCharacterData();
            break;
        }
        case 1: // QDomCharacterData(const QDomCharacterData &characterData)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QDomCharacterData cppArg0_local;
            ::QDomCharacterData *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QDomCharacterData(QDomCharacterData)
                cptr = new ::QDomCharacterData(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QDomCharacterData >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomCharacterData_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QDomCharacterDataFunc_appendData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomCharacterData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomCharacterData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDomCharacterData::appendData(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // appendData(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "appendData", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomCharacterData_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // appendData(QString)
            cppSelf->appendData(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDomCharacterDataFunc_data(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomCharacterData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomCharacterData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // data()const
        QString cppResult = const_cast<const ::QDomCharacterData *>(cppSelf)->data();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomCharacterDataFunc_deleteData(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomCharacterData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomCharacterData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "deleteData", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDomCharacterData::deleteData(ulong,ulong)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), (pyArgs[1])))) {
        overloadId = 0; // deleteData(ulong,ulong)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "deleteData", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomCharacterData_IDX]);

    // Call function/method
    {
        unsigned long cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned long cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // deleteData(ulong,ulong)
            cppSelf->deleteData(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDomCharacterDataFunc_insertData(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomCharacterData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomCharacterData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "insertData", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDomCharacterData::insertData(ulong,QString)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // insertData(ulong,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "insertData", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomCharacterData_IDX]);

    // Call function/method
    {
        unsigned long cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // insertData(ulong,QString)
            cppSelf->insertData(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDomCharacterDataFunc_length(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomCharacterData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomCharacterData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // length()const
        int cppResult = const_cast<const ::QDomCharacterData *>(cppSelf)->length();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomCharacterDataFunc_nodeType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomCharacterData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomCharacterData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // nodeType()const
        QDomNode::NodeType cppResult = const_cast<const ::QDomCharacterData *>(cppSelf)->nodeType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_NodeType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomCharacterDataFunc_replaceData(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomCharacterData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomCharacterData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "replaceData", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDomCharacterData::replaceData(ulong,ulong,QString)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
        overloadId = 0; // replaceData(ulong,ulong,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "replaceData", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomCharacterData_IDX]);

    // Call function/method
    {
        unsigned long cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned long cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QString cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // replaceData(ulong,ulong,QString)
            cppSelf->replaceData(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDomCharacterDataFunc_setData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomCharacterData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomCharacterData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDomCharacterData::setData(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setData(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setData", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomCharacterData_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setData(QString)
            cppSelf->setData(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDomCharacterDataFunc_substringData(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomCharacterData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomCharacterData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "substringData", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDomCharacterData::substringData(ulong,ulong)->QString
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), (pyArgs[1])))) {
        overloadId = 0; // substringData(ulong,ulong)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "substringData", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomCharacterData_IDX]);

    // Call function/method
    {
        unsigned long cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned long cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // substringData(ulong,ulong)
            QString cppResult = cppSelf->substringData(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomCharacterData__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QDomCharacterData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomCharacterData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomCharacterData_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QDomCharacterData_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDomCharacterData_methods[] = {
    {"appendData", reinterpret_cast<PyCFunction>(Sbk_QDomCharacterDataFunc_appendData), METH_O, nullptr},
    {"data", reinterpret_cast<PyCFunction>(Sbk_QDomCharacterDataFunc_data), METH_NOARGS, nullptr},
    {"deleteData", reinterpret_cast<PyCFunction>(Sbk_QDomCharacterDataFunc_deleteData), METH_VARARGS, nullptr},
    {"insertData", reinterpret_cast<PyCFunction>(Sbk_QDomCharacterDataFunc_insertData), METH_VARARGS, nullptr},
    {"length", reinterpret_cast<PyCFunction>(Sbk_QDomCharacterDataFunc_length), METH_NOARGS, nullptr},
    {"nodeType", reinterpret_cast<PyCFunction>(Sbk_QDomCharacterDataFunc_nodeType), METH_NOARGS, nullptr},
    {"replaceData", reinterpret_cast<PyCFunction>(Sbk_QDomCharacterDataFunc_replaceData), METH_VARARGS, nullptr},
    {"setData", reinterpret_cast<PyCFunction>(Sbk_QDomCharacterDataFunc_setData), METH_O, nullptr},
    {"substringData", reinterpret_cast<PyCFunction>(Sbk_QDomCharacterDataFunc_substringData), METH_VARARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QDomCharacterData__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QDomCharacterData___nb_bool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QDomCharacterData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomCharacterData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return !cppSelf->isNull() ? 1 : 0;
}

} // extern "C"

static int Sbk_QDomCharacterData_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDomCharacterData_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDomCharacterData_Type = nullptr;
static PyTypeObject *Sbk_QDomCharacterData_TypeF(void)
{
    return _Sbk_QDomCharacterData_Type;
}

static PyType_Slot Sbk_QDomCharacterData_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDomCharacterData_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDomCharacterData_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDomCharacterData_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDomCharacterData_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_bool,        reinterpret_cast<void *>(Sbk_QDomCharacterData___nb_bool)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDomCharacterData_spec = {
    "2:PySide6.QtXml.QDomCharacterData",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDomCharacterData_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDomCharacterData_PythonToCpp_QDomCharacterData_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDomCharacterData_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDomCharacterData_PythonToCpp_QDomCharacterData_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDomCharacterData_TypeF()))
        return QDomCharacterData_PythonToCpp_QDomCharacterData_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDomCharacterData_PTR_CppToPython_QDomCharacterData(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QDomCharacterData_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QDomCharacterData_COPY_CppToPython_QDomCharacterData(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QDomCharacterData *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QDomCharacterData_TypeF(), new ::QDomCharacterData(*source), true, true);
}

// Python to C++ copy conversion.
static void QDomCharacterData_PythonToCpp_QDomCharacterData_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QDomCharacterData *>(cppOut) = *reinterpret_cast< ::QDomCharacterData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomCharacterData_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QDomCharacterData_PythonToCpp_QDomCharacterData_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QDomCharacterData_TypeF()))
        return QDomCharacterData_PythonToCpp_QDomCharacterData_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QDomCharacterData_SignatureStrings[] = {
    "1:PySide6.QtXml.QDomCharacterData(self)",
    "0:PySide6.QtXml.QDomCharacterData(self,characterData:PySide6.QtXml.QDomCharacterData)",
    "PySide6.QtXml.QDomCharacterData.appendData(self,arg:QString)",
    "PySide6.QtXml.QDomCharacterData.data(self)->QString",
    "PySide6.QtXml.QDomCharacterData.deleteData(self,offset:unsigned long,count:unsigned long)",
    "PySide6.QtXml.QDomCharacterData.insertData(self,offset:unsigned long,arg:QString)",
    "PySide6.QtXml.QDomCharacterData.length(self)->int",
    "PySide6.QtXml.QDomCharacterData.nodeType(self)->PySide6.QtXml.QDomNode.NodeType",
    "PySide6.QtXml.QDomCharacterData.replaceData(self,offset:unsigned long,count:unsigned long,arg:QString)",
    "PySide6.QtXml.QDomCharacterData.setData(self,data:QString)",
    "PySide6.QtXml.QDomCharacterData.substringData(self,offset:unsigned long,count:unsigned long)->QString",
    "PySide6.QtXml.QDomCharacterData.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QDomCharacterData_SignatureByteSize = 212;
static constexpr uint8_t QDomCharacterData_SignatureBytes[212] = {
    0x78, 0xda, 0x9d, 0x92, 0x31, 0x0f, 0x82, 0x30, 0x10, 0x85, 0x77, 0x7e, 0x85, 0xa3, 0x24, 0xda,
    0xe8, 0xe2, 0xc0, 0xe0, 0x22, 0xb3, 0x91, 0xe0, 0xe0, 0x46, 0x6a, 0x7b, 0x94, 0x26, 0xe5, 0xda,
    0xb4, 0xc7, 0xc0, 0xbf, 0x17, 0x8d, 0x88, 0xd1, 0xa1, 0xe2, 0xd8, 0xcb, 0xfb, 0xde, 0xdd, 0xbb,
    0xeb, 0x36, 0x3b, 0xf5, 0xa5, 0x96, 0xb0, 0x63, 0x05, 0x5d, 0x5a, 0xc3, 0x8a, 0xdc, 0xb6, 0x87,
    0x86, 0x7b, 0x2e, 0x08, 0x7c, 0xce, 0x89, 0x2f, 0x03, 0x98, 0x3a, 0x4d, 0x36, 0x3f, 0xe9, 0x56,
    0xe2, 0xbd, 0x14, 0x43, 0xd2, 0x24, 0x22, 0x60, 0xdc, 0x39, 0x40, 0x39, 0xd9, 0x73, 0xaf, 0xb2,
    0xa2, 0x24, 0xaf, 0x51, 0xc5, 0x61, 0xf9, 0x9a, 0x7e, 0xbd, 0x7f, 0x42, 0x71, 0x06, 0x0c, 0x10,
    0x4c, 0x0d, 0x6d, 0x5d, 0x07, 0xa0, 0xac, 0xc3, 0xa0, 0x15, 0x82, 0x5c, 0x18, 0x8b, 0x6a, 0x25,
    0x6c, 0x87, 0x1f, 0xb5, 0xf8, 0x34, 0x1a, 0x03, 0x78, 0x8a, 0x38, 0xcf, 0xca, 0x67, 0x00, 0x15,
    0x35, 0x63, 0x42, 0x8d, 0x14, 0x25, 0xd0, 0x4a, 0x38, 0xf7, 0x0e, 0x46, 0xe6, 0x5b, 0x7f, 0x1c,
    0x14, 0xec, 0xf8, 0x94, 0x45, 0xfd, 0x3c, 0x38, 0xc3, 0xc5, 0x1f, 0xeb, 0x9a, 0x17, 0x74, 0xb0,
    0x9c, 0x5a, 0xdc, 0xaf, 0x3a, 0x03, 0xed, 0xae, 0xe1, 0x21, 0xfd, 0xe3, 0xa4, 0xbf, 0xff, 0x9a,
    0xaa, 0x12, 0xd6, 0xf5, 0x55, 0x35, 0xee, 0x95, 0x7a, 0x37, 0x60, 0xac, 0x1c, 0x5e, 0xc9, 0x0d,
    0xbb, 0x97, 0x38, 0x74
};
#endif

PyTypeObject *init_QDomCharacterData(PyObject *module)
{
    if (SbkPySide6_QtXmlTypeStructs[SBK_QDomCharacterData_IDX].type != nullptr)
        return SbkPySide6_QtXmlTypeStructs[SBK_QDomCharacterData_IDX].type;

    Shiboken::AutoDecRef Sbk_QDomCharacterData_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]))));

    _Sbk_QDomCharacterData_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDomCharacterData",
        "QDomCharacterData",
        &Sbk_QDomCharacterData_spec,
        &Shiboken::callCppDestructor< ::QDomCharacterData >,
        Sbk_QDomCharacterData_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QDomCharacterData_TypeF(); // references _Sbk_QDomCharacterData_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QDomCharacterData_SignatureStrings);
#else
    InitSignatureBytes(pyType, QDomCharacterData_SignatureBytes, QDomCharacterData_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDomCharacterData_PropertyStrings);
    SbkPySide6_QtXmlTypeStructs[SBK_QDomCharacterData_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDomCharacterData_PythonToCpp_QDomCharacterData_PTR,
        is_QDomCharacterData_PythonToCpp_QDomCharacterData_PTR_Convertible,
        QDomCharacterData_PTR_CppToPython_QDomCharacterData,
        QDomCharacterData_COPY_CppToPython_QDomCharacterData);

    Shiboken::Conversions::registerConverterName(converter, "QDomCharacterData");
    Shiboken::Conversions::registerConverterName(converter, "QDomCharacterData*");
    Shiboken::Conversions::registerConverterName(converter, "QDomCharacterData&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDomCharacterData).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QDomCharacterData_PythonToCpp_QDomCharacterData_COPY,
        is_QDomCharacterData_PythonToCpp_QDomCharacterData_COPY_Convertible);

    qRegisterMetaType< ::QDomCharacterData >("QDomCharacterData");

    return pyType;
}
