// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtxml_python.h"

// main header
#include "qdomcomment_wrapper.h"

// Argument includes
#include <QString>
#include <QtXml/qdom.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDomComment_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QDomComment >()))
        return -1;

    ::QDomComment *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QDomComment", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QDomComment::QDomComment()
    // 1: QDomComment::QDomComment(QDomComment)
    if (numArgs == 0) {
        overloadId = 0; // QDomComment()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomComment_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QDomComment(QDomComment)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomComment_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtXmlTypeStructs[SBK_QDomComment_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QDomComment()
        {

            // QDomComment()
            cptr = new ::QDomComment();
            break;
        }
        case 1: // QDomComment(const QDomComment &comment)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QDomComment cppArg0_local;
            ::QDomComment *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QDomComment(QDomComment)
                cptr = new ::QDomComment(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QDomComment >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomComment_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QDomCommentFunc_nodeType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomComment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomComment_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // nodeType()const
        QDomNode::NodeType cppResult = const_cast<const ::QDomComment *>(cppSelf)->nodeType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_NodeType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomComment__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QDomComment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomComment_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomComment_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QDomComment_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDomComment_methods[] = {
    {"nodeType", reinterpret_cast<PyCFunction>(Sbk_QDomCommentFunc_nodeType), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QDomComment__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QDomComment_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDomComment_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDomComment_Type = nullptr;
static PyTypeObject *Sbk_QDomComment_TypeF(void)
{
    return _Sbk_QDomComment_Type;
}

static PyType_Slot Sbk_QDomComment_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDomComment_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDomComment_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDomComment_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDomComment_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDomComment_spec = {
    "2:PySide6.QtXml.QDomComment",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDomComment_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDomComment_PythonToCpp_QDomComment_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDomComment_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDomComment_PythonToCpp_QDomComment_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDomComment_TypeF()))
        return QDomComment_PythonToCpp_QDomComment_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDomComment_PTR_CppToPython_QDomComment(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QDomComment_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QDomComment_COPY_CppToPython_QDomComment(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QDomComment *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QDomComment_TypeF(), new ::QDomComment(*source), true, true);
}

// Python to C++ copy conversion.
static void QDomComment_PythonToCpp_QDomComment_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QDomComment *>(cppOut) = *reinterpret_cast< ::QDomComment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomComment_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QDomComment_PythonToCpp_QDomComment_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QDomComment_TypeF()))
        return QDomComment_PythonToCpp_QDomComment_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QDomComment_SignatureStrings[] = {
    "1:PySide6.QtXml.QDomComment(self)",
    "0:PySide6.QtXml.QDomComment(self,comment:PySide6.QtXml.QDomComment)",
    "PySide6.QtXml.QDomComment.nodeType(self)->PySide6.QtXml.QDomNode.NodeType",
    "PySide6.QtXml.QDomComment.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QDomComment_SignatureByteSize = 101;
static constexpr uint8_t QDomComment_SignatureBytes[101] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x89, 0xc8,
    0xcd, 0xd1, 0x0b, 0x74, 0xc9, 0xcf, 0x75, 0xce, 0xcf, 0xcd, 0x4d, 0xcd, 0x2b, 0xd1, 0x28, 0x4e,
    0xcd, 0x49, 0xd3, 0xe4, 0x32, 0x20, 0xa0, 0x42, 0x27, 0x19, 0xc2, 0xc1, 0xad, 0x4c, 0x93, 0x0b,
    0xa7, 0x94, 0x5e, 0x5e, 0x7e, 0x4a, 0x6a, 0x48, 0x65, 0x41, 0x2a, 0xc4, 0x32, 0x5d, 0x3b, 0x4c,
    0x95, 0x7e, 0x40, 0x15, 0x7a, 0x7e, 0x50, 0x65, 0x78, 0x4c, 0x8a, 0x8f, 0x4f, 0xce, 0x2f, 0xa8,
    0x8c, 0x8f, 0x87, 0x99, 0x54, 0x52, 0x59, 0x90, 0x99, 0x97, 0xae, 0x17, 0x0c, 0xe4, 0x71, 0x01,
    0x00, 0x50, 0x87, 0x50, 0xec
};
#endif

PyTypeObject *init_QDomComment(PyObject *module)
{
    if (SbkPySide6_QtXmlTypeStructs[SBK_QDomComment_IDX].type != nullptr)
        return SbkPySide6_QtXmlTypeStructs[SBK_QDomComment_IDX].type;

    Shiboken::AutoDecRef Sbk_QDomComment_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomCharacterData_IDX]))));

    _Sbk_QDomComment_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDomComment",
        "QDomComment",
        &Sbk_QDomComment_spec,
        &Shiboken::callCppDestructor< ::QDomComment >,
        Sbk_QDomComment_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QDomComment_TypeF(); // references _Sbk_QDomComment_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QDomComment_SignatureStrings);
#else
    InitSignatureBytes(pyType, QDomComment_SignatureBytes, QDomComment_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDomComment_PropertyStrings);
    SbkPySide6_QtXmlTypeStructs[SBK_QDomComment_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDomComment_PythonToCpp_QDomComment_PTR,
        is_QDomComment_PythonToCpp_QDomComment_PTR_Convertible,
        QDomComment_PTR_CppToPython_QDomComment,
        QDomComment_COPY_CppToPython_QDomComment);

    Shiboken::Conversions::registerConverterName(converter, "QDomComment");
    Shiboken::Conversions::registerConverterName(converter, "QDomComment*");
    Shiboken::Conversions::registerConverterName(converter, "QDomComment&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDomComment).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QDomComment_PythonToCpp_QDomComment_COPY,
        is_QDomComment_PythonToCpp_QDomComment_COPY_Convertible);

    qRegisterMetaType< ::QDomComment >("QDomComment");

    return pyType;
}
