// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtxml_python.h"

// main header
#include "qdomdocument_wrapper.h"

// inner classes
#include "qdomdocument_parseresult_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QString>
#include <QtXml/qdom.h>
#include <qbytearray.h>
#include <qiodevice.h>
#include <qtextstream.h>
#include <qxmlstream.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDomDocument_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QDomDocument >()))
        return -1;

    ::QDomDocument *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QDomDocument", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QDomDocument::QDomDocument()
    // 1: QDomDocument::QDomDocument(QDomDocument)
    // 2: QDomDocument::QDomDocument(QDomDocumentType)
    // 3: QDomDocument::QDomDocument(QString)
    if (numArgs == 0) {
        overloadId = 0; // QDomDocument()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 3; // QDomDocument(QString)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocumentType_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QDomDocument(QDomDocumentType)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QDomDocument(QDomDocument)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QDomDocument()
        {

            // QDomDocument()
            cptr = new ::QDomDocument();
            break;
        }
        case 1: // QDomDocument(const QDomDocument &document)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QDomDocument cppArg0_local;
            ::QDomDocument *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QDomDocument(QDomDocument)
                cptr = new ::QDomDocument(*cppArg0);
            }
            break;
        }
        case 2: // QDomDocument(const QDomDocumentType &doctype)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QDomDocumentType cppArg0_local;
            ::QDomDocumentType *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QDomDocument(QDomDocumentType)
                cptr = new ::QDomDocument(*cppArg0);
            }
            break;
        }
        case 3: // QDomDocument(const QString &name)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDomDocument(QString)
                cptr = new ::QDomDocument(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QDomDocument >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QDomDocumentFunc_createAttribute(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDomDocument::createAttribute(QString)->QDomAttr
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // createAttribute(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "createAttribute", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createAttribute(QString)
            QDomAttr cppResult = cppSelf->createAttribute(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomAttr_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomDocumentFunc_createAttributeNS(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "createAttributeNS", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDomDocument::createAttributeNS(QString,QString)->QDomAttr
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // createAttributeNS(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "createAttributeNS", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createAttributeNS(QString,QString)
            QDomAttr cppResult = cppSelf->createAttributeNS(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomAttr_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomDocumentFunc_createCDATASection(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDomDocument::createCDATASection(QString)->QDomCDATASection
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // createCDATASection(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "createCDATASection", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createCDATASection(QString)
            QDomCDATASection cppResult = cppSelf->createCDATASection(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomCDATASection_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomDocumentFunc_createComment(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDomDocument::createComment(QString)->QDomComment
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // createComment(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "createComment", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createComment(QString)
            QDomComment cppResult = cppSelf->createComment(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomComment_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomDocumentFunc_createDocumentFragment(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // createDocumentFragment()
        QDomDocumentFragment cppResult = cppSelf->createDocumentFragment();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocumentFragment_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomDocumentFunc_createElement(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDomDocument::createElement(QString)->QDomElement
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // createElement(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "createElement", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createElement(QString)
            QDomElement cppResult = cppSelf->createElement(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomElement_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomDocumentFunc_createElementNS(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "createElementNS", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDomDocument::createElementNS(QString,QString)->QDomElement
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // createElementNS(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "createElementNS", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createElementNS(QString,QString)
            QDomElement cppResult = cppSelf->createElementNS(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomElement_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomDocumentFunc_createEntityReference(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDomDocument::createEntityReference(QString)->QDomEntityReference
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // createEntityReference(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "createEntityReference", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createEntityReference(QString)
            QDomEntityReference cppResult = cppSelf->createEntityReference(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomEntityReference_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomDocumentFunc_createProcessingInstruction(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "createProcessingInstruction", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDomDocument::createProcessingInstruction(QString,QString)->QDomProcessingInstruction
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // createProcessingInstruction(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "createProcessingInstruction", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createProcessingInstruction(QString,QString)
            QDomProcessingInstruction cppResult = cppSelf->createProcessingInstruction(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomProcessingInstruction_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomDocumentFunc_createTextNode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDomDocument::createTextNode(QString)->QDomText
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // createTextNode(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "createTextNode", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createTextNode(QString)
            QDomText cppResult = cppSelf->createTextNode(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomText_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomDocumentFunc_doctype(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // doctype()const
        QDomDocumentType cppResult = const_cast<const ::QDomDocument *>(cppSelf)->doctype();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocumentType_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomDocumentFunc_documentElement(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // documentElement()const
        QDomElement cppResult = const_cast<const ::QDomDocument *>(cppSelf)->documentElement();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomElement_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomDocumentFunc_elementById(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDomDocument::elementById(QString)->QDomElement
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // elementById(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "elementById", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // elementById(QString)
            QDomElement cppResult = cppSelf->elementById(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomElement_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomDocumentFunc_elementsByTagName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDomDocument::elementsByTagName(QString)const->QDomNodeList
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // elementsByTagName(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "elementsByTagName", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // elementsByTagName(QString)const
            QDomNodeList cppResult = const_cast<const ::QDomDocument *>(cppSelf)->elementsByTagName(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNodeList_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomDocumentFunc_elementsByTagNameNS(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "elementsByTagNameNS", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDomDocument::elementsByTagNameNS(QString,QString)->QDomNodeList
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // elementsByTagNameNS(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "elementsByTagNameNS", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // elementsByTagNameNS(QString,QString)
            QDomNodeList cppResult = cppSelf->elementsByTagNameNS(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNodeList_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomDocumentFunc_implementation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // implementation()const
        QDomImplementation cppResult = const_cast<const ::QDomDocument *>(cppSelf)->implementation();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomImplementation_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomDocumentFunc_importNode(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "importNode", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDomDocument::importNode(QDomNode,bool)->QDomNode
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
        overloadId = 0; // importNode(QDomNode,bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "importNode", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QDomNode cppArg0_local;
        ::QDomNode *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        bool cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // importNode(QDomNode,bool)
            QDomNode cppResult = cppSelf->importNode(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomDocumentFunc_nodeType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // nodeType()const
        QDomNode::NodeType cppResult = const_cast<const ::QDomDocument *>(cppSelf)->nodeType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_NodeType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomDocumentFunc_setContent(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setContent", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOO:setContent", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDomDocument::setContent(QAnyStringView,QFlags<QDomDocument::ParseOption>=)->QDomDocument::ParseResult
    // 1: QDomDocument::setContent(QIODevice*,QString*,int*,int*)->(retval, errorMsg, errorLine, errorColumn)
    // 2: QDomDocument::setContent(QIODevice*,bool,QString*,int*,int*)->(retval, errorMsg, errorLine, errorColumn)
    // 3: QDomDocument::setContent(QIODevice*,QFlags<QDomDocument::ParseOption>=)->QDomDocument::ParseResult
    // 4: QDomDocument::setContent(QXmlStreamReader*,QFlags<QDomDocument::ParseOption>=)->QDomDocument::ParseResult
    // 5: QDomDocument::setContent(QXmlStreamReader*,bool,QString*=,int*=,int*=)->bool
    // 6: QDomDocument::setContent(QByteArray,QString*,int*,int*)->(retval, errorMsg, errorLine, errorColumn)
    // 7: QDomDocument::setContent(QByteArray,bool,QString*,int*,int*)->(retval, errorMsg, errorLine, errorColumn)
    // 8: QDomDocument::setContent(QString,QString*,int*,int*)->(retval, errorMsg, errorLine, errorColumn)
    // 9: QDomDocument::setContent(QString,bool,QString*,int*,int*)->(retval, errorMsg, errorLine, errorColumn)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 4; // setContent(QXmlStreamReader*,QFlags<QDomDocument::ParseOption>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 5; // setContent(QXmlStreamReader*,bool,QString*,int*,int*)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 5; // setContent(QXmlStreamReader*,bool,QString*,int*,int*)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
                    if (numArgs == 4) {
                        overloadId = 5; // setContent(QXmlStreamReader*,bool,QString*,int*,int*)
                    } else if (numArgs >= 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))) {
                        overloadId = 5; // setContent(QXmlStreamReader*,bool,QString*,int*,int*)
                    }
                }
            }
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QFlags_QDomDocument_ParseOption_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 4; // setContent(QXmlStreamReader*,QFlags<QDomDocument::ParseOption>)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 3; // setContent(QIODevice*,QFlags<QDomDocument::ParseOption>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QFlags_QDomDocument_ParseOption_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 3; // setContent(QIODevice*,QFlags<QDomDocument::ParseOption>)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 2; // setContent(QIODevice*,bool,QString*,int*,int*)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 8; // setContent(QString,QString*,int*,int*)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 9; // setContent(QString,bool,QString*,int*,int*)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 6; // setContent(QByteArray,QString*,int*,int*)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 7; // setContent(QByteArray,bool,QString*,int*,int*)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setContent(QAnyStringView,QFlags<QDomDocument::ParseOption>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QFlags_QDomDocument_ParseOption_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 0; // setContent(QAnyStringView,QFlags<QDomDocument::ParseOption>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setContent", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setContent(QAnyStringView data, QFlags<QDomDocument::ParseOption> options)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_options = Shiboken::String::createStaticString("options");
                if (PyDict_Contains(kwds, key_options) != 0) {
                    value = PyDict_GetItem(kwds, key_options);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_options);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "setContent", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QFlags_QDomDocument_ParseOption_IDX])))->flagsConverter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "setContent", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_options);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "setContent", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QFlags<QDomDocument::ParseOption> cppArg1(QDomDocument::ParseOption::Default);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setContent(QAnyStringView,QFlags<QDomDocument::ParseOption>)
                QDomDocument::ParseResult cppResult = cppSelf->setContent(QAnyStringView(cppArg0), cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_ParseResult_IDX]), &cppResult);
            }
            break;
        }
        case 1: // setContent(QIODevice *dev, QString *errorMsg, int *errorLine, int *errorColumn)
        {
            Shiboken::Warnings::warnDeprecated("QDomDocument", "setContent(QIODevice *dev, QString *errorMsg, int *errorLine, int *errorColumn)");
            if (Shiboken::Errors::occurred() != nullptr)
                return {};
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setContent", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QIODevice *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setContent(QIODevice*,QString*,int*,int*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtxml.cpp (qdomdocument-setcontent)]
                QString _errorMsg_;
                int _errorLine_ = 0;
                int _errorColumn_ = 0;
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool _ret_ = cppSelf->setContent(cppArg0, &_errorMsg_, &_errorLine_,
                    &_errorColumn_);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = PyTuple_New(4);
                PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &_ret_));
                PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &_errorMsg_));
                PyTuple_SetItem(pyResult, 2, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &_errorLine_));
                PyTuple_SetItem(pyResult, 3, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &_errorColumn_));
                // END of custom code block [file: ../glue/qtxml.cpp (qdomdocument-setcontent)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 2: // setContent(QIODevice *dev, bool namespaceProcessing, QString *errorMsg, int *errorLine, int *errorColumn)
        {
            Shiboken::Warnings::warnDeprecated("QDomDocument", "setContent(QIODevice *dev, bool namespaceProcessing, QString *errorMsg, int *errorLine, int *errorColumn)");
            if (Shiboken::Errors::occurred() != nullptr)
                return {};
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setContent", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QIODevice *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            bool cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setContent(QIODevice*,bool,QString*,int*,int*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtxml.cpp (qdomdocument-setcontent)]
                QString _errorMsg_;
                int _errorLine_ = 0;
                int _errorColumn_ = 0;
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool _ret_ = cppSelf->setContent(cppArg0, cppArg1, &_errorMsg_, &_errorLine_,
                    &_errorColumn_);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = PyTuple_New(4);
                PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &_ret_));
                PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &_errorMsg_));
                PyTuple_SetItem(pyResult, 2, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &_errorLine_));
                PyTuple_SetItem(pyResult, 3, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &_errorColumn_));
                // END of custom code block [file: ../glue/qtxml.cpp (qdomdocument-setcontent)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 3: // setContent(QIODevice *device, QFlags<QDomDocument::ParseOption> options)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_options = Shiboken::String::createStaticString("options");
                if (PyDict_Contains(kwds, key_options) != 0) {
                    value = PyDict_GetItem(kwds, key_options);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_options);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "setContent", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QFlags_QDomDocument_ParseOption_IDX])))->flagsConverter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "setContent", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_options);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "setContent", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QIODevice *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QFlags<QDomDocument::ParseOption> cppArg1(QDomDocument::ParseOption::Default);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setContent(QIODevice*,QFlags<QDomDocument::ParseOption>)
                QDomDocument::ParseResult cppResult = cppSelf->setContent(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_ParseResult_IDX]), &cppResult);
            }
            break;
        }
        case 4: // setContent(QXmlStreamReader *reader, QFlags<QDomDocument::ParseOption> options)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_options = Shiboken::String::createStaticString("options");
                if (PyDict_Contains(kwds, key_options) != 0) {
                    value = PyDict_GetItem(kwds, key_options);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_options);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "setContent", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QFlags_QDomDocument_ParseOption_IDX])))->flagsConverter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "setContent", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_options);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "setContent", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QXmlStreamReader *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QFlags<QDomDocument::ParseOption> cppArg1(QDomDocument::ParseOption::Default);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setContent(QXmlStreamReader*,QFlags<QDomDocument::ParseOption>)
                QDomDocument::ParseResult cppResult = cppSelf->setContent(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_ParseResult_IDX]), &cppResult);
            }
            break;
        }
        case 5: // setContent(QXmlStreamReader *reader, bool namespaceProcessing, QString *errorMsg, int *errorLine, int *errorColumn)
        {
            Shiboken::Warnings::warnDeprecated("QDomDocument", "setContent(QXmlStreamReader *reader, bool namespaceProcessing, QString *errorMsg, int *errorLine, int *errorColumn)");
            if (Shiboken::Errors::occurred() != nullptr)
                return {};
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_errorMsg = Shiboken::String::createStaticString("errorMsg");
                if (PyDict_Contains(kwds, key_errorMsg) != 0) {
                    value = PyDict_GetItem(kwds, key_errorMsg);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_errorMsg);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "setContent", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "setContent", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_errorMsg);
                }
                static PyObject *const key_errorLine = Shiboken::String::createStaticString("errorLine");
                if (PyDict_Contains(kwds, key_errorLine) != 0) {
                    value = PyDict_GetItem(kwds, key_errorLine);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_errorLine);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "setContent", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "setContent", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_errorLine);
                }
                static PyObject *const key_errorColumn = Shiboken::String::createStaticString("errorColumn");
                if (PyDict_Contains(kwds, key_errorColumn) != 0) {
                    value = PyDict_GetItem(kwds, key_errorColumn);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_errorColumn);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "setContent", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, "setContent", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_errorColumn);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "setContent", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QXmlStreamReader *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            bool cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString *cppArg2 = nullptr;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            int *cppArg3 = nullptr;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            int *cppArg4 = nullptr;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setContent(QXmlStreamReader*,bool,QString*,int*,int*)
                bool cppResult = cppSelf->setContent(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 6: // setContent(const QByteArray &text, QString *errorMsg, int *errorLine, int *errorColumn)
        {
            Shiboken::Warnings::warnDeprecated("QDomDocument", "setContent(const QByteArray &text, QString *errorMsg, int *errorLine, int *errorColumn)");
            if (Shiboken::Errors::occurred() != nullptr)
                return {};
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setContent", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setContent(QByteArray,QString*,int*,int*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtxml.cpp (qdomdocument-setcontent)]
                QString _errorMsg_;
                int _errorLine_ = 0;
                int _errorColumn_ = 0;
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool _ret_ = cppSelf->setContent((*cppArg0), &_errorMsg_, &_errorLine_,
                    &_errorColumn_);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = PyTuple_New(4);
                PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &_ret_));
                PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &_errorMsg_));
                PyTuple_SetItem(pyResult, 2, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &_errorLine_));
                PyTuple_SetItem(pyResult, 3, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &_errorColumn_));
                // END of custom code block [file: ../glue/qtxml.cpp (qdomdocument-setcontent)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 7: // setContent(const QByteArray &text, bool namespaceProcessing, QString *errorMsg, int *errorLine, int *errorColumn)
        {
            Shiboken::Warnings::warnDeprecated("QDomDocument", "setContent(const QByteArray &text, bool namespaceProcessing, QString *errorMsg, int *errorLine, int *errorColumn)");
            if (Shiboken::Errors::occurred() != nullptr)
                return {};
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setContent", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            bool cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setContent(QByteArray,bool,QString*,int*,int*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtxml.cpp (qdomdocument-setcontent)]
                QString _errorMsg_;
                int _errorLine_ = 0;
                int _errorColumn_ = 0;
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool _ret_ = cppSelf->setContent((*cppArg0), cppArg1, &_errorMsg_, &_errorLine_,
                    &_errorColumn_);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = PyTuple_New(4);
                PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &_ret_));
                PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &_errorMsg_));
                PyTuple_SetItem(pyResult, 2, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &_errorLine_));
                PyTuple_SetItem(pyResult, 3, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &_errorColumn_));
                // END of custom code block [file: ../glue/qtxml.cpp (qdomdocument-setcontent)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 8: // setContent(const QString &text, QString *errorMsg, int *errorLine, int *errorColumn)
        {
            Shiboken::Warnings::warnDeprecated("QDomDocument", "setContent(const QString &text, QString *errorMsg, int *errorLine, int *errorColumn)");
            if (Shiboken::Errors::occurred() != nullptr)
                return {};
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setContent", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setContent(QString,QString*,int*,int*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtxml.cpp (qdomdocument-setcontent)]
                QString _errorMsg_;
                int _errorLine_ = 0;
                int _errorColumn_ = 0;
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool _ret_ = cppSelf->setContent(cppArg0, &_errorMsg_, &_errorLine_,
                    &_errorColumn_);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = PyTuple_New(4);
                PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &_ret_));
                PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &_errorMsg_));
                PyTuple_SetItem(pyResult, 2, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &_errorLine_));
                PyTuple_SetItem(pyResult, 3, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &_errorColumn_));
                // END of custom code block [file: ../glue/qtxml.cpp (qdomdocument-setcontent)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 9: // setContent(const QString &text, bool namespaceProcessing, QString *errorMsg, int *errorLine, int *errorColumn)
        {
            Shiboken::Warnings::warnDeprecated("QDomDocument", "setContent(const QString &text, bool namespaceProcessing, QString *errorMsg, int *errorLine, int *errorColumn)");
            if (Shiboken::Errors::occurred() != nullptr)
                return {};
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setContent", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            bool cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setContent(QString,bool,QString*,int*,int*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtxml.cpp (qdomdocument-setcontent)]
                QString _errorMsg_;
                int _errorLine_ = 0;
                int _errorColumn_ = 0;
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool _ret_ = cppSelf->setContent(cppArg0, cppArg1, &_errorMsg_, &_errorLine_,
                    &_errorColumn_);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = PyTuple_New(4);
                PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &_ret_));
                PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &_errorMsg_));
                PyTuple_SetItem(pyResult, 2, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &_errorLine_));
                PyTuple_SetItem(pyResult, 3, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &_errorColumn_));
                // END of custom code block [file: ../glue/qtxml.cpp (qdomdocument-setcontent)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomDocumentFunc_toByteArray(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "toByteArray", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);

    if (PyArg_ParseTuple(args, "|O:toByteArray", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDomDocument::toByteArray(int=)const->QByteArray
    if (numArgs == 0) {
        overloadId = 0; // toByteArray(int)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // toByteArray(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "toByteArray", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_indent = Shiboken::String::createStaticString("indent");
            if (PyDict_Contains(kwds, key_indent) != 0) {
                value = PyDict_GetItem(kwds, key_indent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_indent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "toByteArray", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "toByteArray", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_indent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "toByteArray", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);
            }
        }
        int cppArg0 = 1;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toByteArray(int)const
            QByteArray cppResult = const_cast<const ::QDomDocument *>(cppSelf)->toByteArray(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomDocumentFunc_toString(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "toString", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);

    if (PyArg_ParseTuple(args, "|O:toString", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDomDocument::toString(int=)const->QString
    if (numArgs == 0) {
        overloadId = 0; // toString(int)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // toString(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "toString", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_indent = Shiboken::String::createStaticString("indent");
            if (PyDict_Contains(kwds, key_indent) != 0) {
                value = PyDict_GetItem(kwds, key_indent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_indent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "toString", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "toString", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_indent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "toString", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]);
            }
        }
        int cppArg0 = 1;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toString(int)const
            QString cppResult = const_cast<const ::QDomDocument *>(cppSelf)->toString(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomDocument__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QDomDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QDomDocument_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QDomDocument_EnumFlagInfo[] = {
    "ParseOption:Flag:ParseOptions",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDomDocument_methods[] = {
    {"createAttribute", reinterpret_cast<PyCFunction>(Sbk_QDomDocumentFunc_createAttribute), METH_O, nullptr},
    {"createAttributeNS", reinterpret_cast<PyCFunction>(Sbk_QDomDocumentFunc_createAttributeNS), METH_VARARGS, nullptr},
    {"createCDATASection", reinterpret_cast<PyCFunction>(Sbk_QDomDocumentFunc_createCDATASection), METH_O, nullptr},
    {"createComment", reinterpret_cast<PyCFunction>(Sbk_QDomDocumentFunc_createComment), METH_O, nullptr},
    {"createDocumentFragment", reinterpret_cast<PyCFunction>(Sbk_QDomDocumentFunc_createDocumentFragment), METH_NOARGS, nullptr},
    {"createElement", reinterpret_cast<PyCFunction>(Sbk_QDomDocumentFunc_createElement), METH_O, nullptr},
    {"createElementNS", reinterpret_cast<PyCFunction>(Sbk_QDomDocumentFunc_createElementNS), METH_VARARGS, nullptr},
    {"createEntityReference", reinterpret_cast<PyCFunction>(Sbk_QDomDocumentFunc_createEntityReference), METH_O, nullptr},
    {"createProcessingInstruction", reinterpret_cast<PyCFunction>(Sbk_QDomDocumentFunc_createProcessingInstruction), METH_VARARGS, nullptr},
    {"createTextNode", reinterpret_cast<PyCFunction>(Sbk_QDomDocumentFunc_createTextNode), METH_O, nullptr},
    {"doctype", reinterpret_cast<PyCFunction>(Sbk_QDomDocumentFunc_doctype), METH_NOARGS, nullptr},
    {"documentElement", reinterpret_cast<PyCFunction>(Sbk_QDomDocumentFunc_documentElement), METH_NOARGS, nullptr},
    {"elementById", reinterpret_cast<PyCFunction>(Sbk_QDomDocumentFunc_elementById), METH_O, nullptr},
    {"elementsByTagName", reinterpret_cast<PyCFunction>(Sbk_QDomDocumentFunc_elementsByTagName), METH_O, nullptr},
    {"elementsByTagNameNS", reinterpret_cast<PyCFunction>(Sbk_QDomDocumentFunc_elementsByTagNameNS), METH_VARARGS, nullptr},
    {"implementation", reinterpret_cast<PyCFunction>(Sbk_QDomDocumentFunc_implementation), METH_NOARGS, nullptr},
    {"importNode", reinterpret_cast<PyCFunction>(Sbk_QDomDocumentFunc_importNode), METH_VARARGS, nullptr},
    {"nodeType", reinterpret_cast<PyCFunction>(Sbk_QDomDocumentFunc_nodeType), METH_NOARGS, nullptr},
    {"setContent", reinterpret_cast<PyCFunction>(Sbk_QDomDocumentFunc_setContent), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toByteArray", reinterpret_cast<PyCFunction>(Sbk_QDomDocumentFunc_toByteArray), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toString", reinterpret_cast<PyCFunction>(Sbk_QDomDocumentFunc_toString), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QDomDocument__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QDomDocument___nb_bool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QDomDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return !cppSelf->isNull() ? 1 : 0;
}

} // extern "C"

static int Sbk_QDomDocument_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDomDocument_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDomDocument_Type = nullptr;
static PyTypeObject *Sbk_QDomDocument_TypeF(void)
{
    return _Sbk_QDomDocument_Type;
}

static PyType_Slot Sbk_QDomDocument_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDomDocument_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDomDocument_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDomDocument_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDomDocument_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_bool,        reinterpret_cast<void *>(Sbk_QDomDocument___nb_bool)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDomDocument_spec = {
    "2:PySide6.QtXml.QDomDocument",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDomDocument_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QDomDocument_ParseOption(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QDomDocument::ParseOption>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QDomDocument::ParseOption *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QDomDocument_ParseOption_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_ParseOption_IDX])))
        return Enum_PythonToCpp_QDomDocument_ParseOption;
    return {};
}

static PyObject *QDomDocument_ParseOption_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QDomDocument::ParseOption>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QDomDocument::ParseOption *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_ParseOption_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QDomDocument_ParseOption(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QDomDocument::ParseOption>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QDomDocument::ParseOption> *>(cppOut) = value;

}

static PyObject *QDomDocument_ParseOption_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QDomDocument::ParseOption> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_ParseOption_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDomDocument_PythonToCpp_QDomDocument_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDomDocument_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDomDocument_PythonToCpp_QDomDocument_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDomDocument_TypeF()))
        return QDomDocument_PythonToCpp_QDomDocument_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDomDocument_PTR_CppToPython_QDomDocument(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QDomDocument_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QDomDocument_COPY_CppToPython_QDomDocument(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QDomDocument *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QDomDocument_TypeF(), new ::QDomDocument(*source), true, true);
}

// Python to C++ copy conversion.
static void QDomDocument_PythonToCpp_QDomDocument_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QDomDocument *>(cppOut) = *reinterpret_cast< ::QDomDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QDomDocument_PythonToCpp_QDomDocument_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QDomDocument_TypeF()))
        return QDomDocument_PythonToCpp_QDomDocument_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QDomDocument_SignatureStrings[] = {
    "3:PySide6.QtXml.QDomDocument(self)",
    "2:PySide6.QtXml.QDomDocument(self,document:PySide6.QtXml.QDomDocument)",
    "1:PySide6.QtXml.QDomDocument(self,doctype:PySide6.QtXml.QDomDocumentType)",
    "0:PySide6.QtXml.QDomDocument(self,name:QString)",
    "PySide6.QtXml.QDomDocument.createAttribute(self,name:QString)->PySide6.QtXml.QDomAttr",
    "PySide6.QtXml.QDomDocument.createAttributeNS(self,nsURI:QString,qName:QString)->PySide6.QtXml.QDomAttr",
    "PySide6.QtXml.QDomDocument.createCDATASection(self,data:QString)->PySide6.QtXml.QDomCDATASection",
    "PySide6.QtXml.QDomDocument.createComment(self,data:QString)->PySide6.QtXml.QDomComment",
    "PySide6.QtXml.QDomDocument.createDocumentFragment(self)->PySide6.QtXml.QDomDocumentFragment",
    "PySide6.QtXml.QDomDocument.createElement(self,tagName:QString)->PySide6.QtXml.QDomElement",
    "PySide6.QtXml.QDomDocument.createElementNS(self,nsURI:QString,qName:QString)->PySide6.QtXml.QDomElement",
    "PySide6.QtXml.QDomDocument.createEntityReference(self,name:QString)->PySide6.QtXml.QDomEntityReference",
    "PySide6.QtXml.QDomDocument.createProcessingInstruction(self,target:QString,data:QString)->PySide6.QtXml.QDomProcessingInstruction",
    "PySide6.QtXml.QDomDocument.createTextNode(self,data:QString)->PySide6.QtXml.QDomText",
    "PySide6.QtXml.QDomDocument.doctype(self)->PySide6.QtXml.QDomDocumentType",
    "PySide6.QtXml.QDomDocument.documentElement(self)->PySide6.QtXml.QDomElement",
    "PySide6.QtXml.QDomDocument.elementById(self,elementId:QString)->PySide6.QtXml.QDomElement",
    "PySide6.QtXml.QDomDocument.elementsByTagName(self,tagname:QString)->PySide6.QtXml.QDomNodeList",
    "PySide6.QtXml.QDomDocument.elementsByTagNameNS(self,nsURI:QString,localName:QString)->PySide6.QtXml.QDomNodeList",
    "PySide6.QtXml.QDomDocument.implementation(self)->PySide6.QtXml.QDomImplementation",
    "PySide6.QtXml.QDomDocument.importNode(self,importedNode:PySide6.QtXml.QDomNode,deep:bool)->PySide6.QtXml.QDomNode",
    "PySide6.QtXml.QDomDocument.nodeType(self)->PySide6.QtXml.QDomNode.NodeType",
    "9:PySide6.QtXml.QDomDocument.setContent(self,data:QString,options:PySide6.QtXml.QDomDocument.ParseOption=QDomDocument.ParseOption.Default)->PySide6.QtXml.QDomDocument.ParseResult",
    "8:PySide6.QtXml.QDomDocument.setContent(self,dev:PySide6.QtCore.QIODevice)->Tuple[bool, str, int, int]",
    "7:PySide6.QtXml.QDomDocument.setContent(self,dev:PySide6.QtCore.QIODevice,namespaceProcessing:bool)->Tuple[bool, str, int, int]",
    "6:PySide6.QtXml.QDomDocument.setContent(self,device:PySide6.QtCore.QIODevice,options:PySide6.QtXml.QDomDocument.ParseOption=QDomDocument.ParseOption.Default)->PySide6.QtXml.QDomDocument.ParseResult",
    "5:PySide6.QtXml.QDomDocument.setContent(self,reader:PySide6.QtCore.QXmlStreamReader,options:PySide6.QtXml.QDomDocument.ParseOption=QDomDocument.ParseOption.Default)->PySide6.QtXml.QDomDocument.ParseResult",
    "4:PySide6.QtXml.QDomDocument.setContent(self,reader:PySide6.QtCore.QXmlStreamReader,namespaceProcessing:bool,errorMsg:QString*=nullptr,errorLine:int*=nullptr,errorColumn:int*=nullptr)->bool",
    "3:PySide6.QtXml.QDomDocument.setContent(self,text:typing.Union[PySide6.QtCore.QByteArray, char*])->Tuple[bool, str, int, int]",
    "2:PySide6.QtXml.QDomDocument.setContent(self,text:typing.Union[PySide6.QtCore.QByteArray, char*],namespaceProcessing:bool)->Tuple[bool, str, int, int]",
    "1:PySide6.QtXml.QDomDocument.setContent(self,text:QString)->Tuple[bool, str, int, int]",
    "0:PySide6.QtXml.QDomDocument.setContent(self,text:QString,namespaceProcessing:bool)->Tuple[bool, str, int, int]",
    "PySide6.QtXml.QDomDocument.toByteArray(self,indent:int=1)->PySide6.QtCore.QByteArray",
    "PySide6.QtXml.QDomDocument.toString(self,indent:int=1)->QString",
    "PySide6.QtXml.QDomDocument.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QDomDocument_SignatureByteSize = 643;
static constexpr uint8_t QDomDocument_SignatureBytes[643] = {
    0x78, 0xda, 0xc5, 0x57, 0xdb, 0x6e, 0xda, 0x40, 0x10, 0x7d, 0xf7, 0x57, 0xf0, 0x58, 0x22, 0xd7,
    0x0a, 0x49, 0x9b, 0xb6, 0x96, 0xa8, 0xc4, 0xa5, 0x95, 0x2c, 0xa5, 0x84, 0x8b, 0x23, 0x55, 0x8a,
    0x22, 0xb4, 0xb1, 0x07, 0x6a, 0xc9, 0xde, 0x75, 0x77, 0xc7, 0x51, 0xfd, 0xf7, 0x59, 0x5f, 0x00,
    0x43, 0xcc, 0xae, 0x4d, 0x89, 0xf2, 0x82, 0x58, 0xef, 0x99, 0x73, 0x66, 0x76, 0x8e, 0x67, 0xe1,
    0xda, 0x9e, 0xa6, 0x8b, 0xc0, 0x87, 0x1b, 0x6b, 0x86, 0xbf, 0xa3, 0xd0, 0x9a, 0x8d, 0x59, 0x34,
    0x66, 0x5e, 0x12, 0x01, 0xc5, 0x0f, 0x02, 0xc2, 0x55, 0xd7, 0xb8, 0xd2, 0x41, 0x4c, 0xbf, 0x5c,
    0x29, 0x80, 0x5d, 0xa3, 0xd7, 0x84, 0x06, 0xd3, 0x18, 0x14, 0x38, 0x57, 0x6e, 0x77, 0x8d, 0x4b,
    0x2d, 0x13, 0x25, 0x11, 0xd8, 0xb3, 0x05, 0xf2, 0x80, 0xae, 0xbb, 0xc6, 0x71, 0xb4, 0xe5, 0x71,
    0x20, 0x08, 0x03, 0x94, 0xc8, 0xa7, 0x04, 0xa1, 0x26, 0xfa, 0xe3, 0xf7, 0xd7, 0xe1, 0x19, 0xbe,
    0x05, 0xeb, 0x64, 0x51, 0xf2, 0x8a, 0xfb, 0xb9, 0xb3, 0x21, 0x36, 0xff, 0x4e, 0xce, 0x23, 0x33,
    0x1a, 0x0f, 0xdc, 0xc1, 0x02, 0x3c, 0x0c, 0x18, 0x2d, 0xcf, 0x91, 0x20, 0x51, 0x12, 0x57, 0x43,
    0x1a, 0x08, 0xb0, 0xa8, 0xd2, 0x23, 0x2d, 0x77, 0x81, 0xd6, 0xd3, 0x6e, 0x96, 0x3f, 0x39, 0x59,
    0xef, 0xdc, 0x56, 0x47, 0x79, 0x88, 0xd4, 0x73, 0xff, 0x08, 0x61, 0x97, 0x32, 0x92, 0xb5, 0xf6,
    0xa8, 0xcb, 0x80, 0xc6, 0xcc, 0xa7, 0xb6, 0xb4, 0xb9, 0x0e, 0xc5, 0x00, 0xd3, 0x39, 0xac, 0x80,
    0x03, 0xf5, 0x9a, 0x1a, 0xf3, 0x20, 0x4a, 0x2f, 0x33, 0xe5, 0xcc, 0x03, 0x21, 0x24, 0x9f, 0x43,
    0x05, 0xf2, 0xa4, 0xe2, 0x22, 0x24, 0x7c, 0x0d, 0xb8, 0xad, 0x4d, 0xdb, 0xf8, 0x5a, 0x2a, 0x7d,
    0x06, 0x2e, 0xfc, 0xc3, 0x09, 0xf3, 0xa1, 0xa1, 0xbd, 0x32, 0xb8, 0x8a, 0xb4, 0x9c, 0x21, 0x7a,
    0x33, 0x65, 0xa3, 0x44, 0x43, 0x94, 0x7f, 0xa9, 0x5a, 0xe9, 0xd4, 0x96, 0x42, 0x01, 0x19, 0xa6,
    0x8e, 0x5f, 0x94, 0x59, 0x3e, 0x70, 0xfc, 0xff, 0x35, 0x4b, 0x49, 0x24, 0x86, 0xa9, 0x5b, 0xb8,
    0x7c, 0x6b, 0x79, 0xad, 0x57, 0xb2, 0x43, 0xbf, 0x0d, 0x44, 0x3b, 0xfa, 0x7a, 0xdf, 0x87, 0xcc,
    0x23, 0xe1, 0xe4, 0x1c, 0x82, 0x41, 0x14, 0x17, 0x92, 0x64, 0x6b, 0xc4, 0x5a, 0x2e, 0x67, 0x0f,
    0xa7, 0x61, 0x64, 0xbc, 0xe2, 0xb0, 0x62, 0x0d, 0x7e, 0xf6, 0xc4, 0xae, 0x4f, 0xd2, 0xf4, 0x01,
    0x62, 0xfb, 0x89, 0xb1, 0xf0, 0x68, 0x1d, 0x2a, 0x45, 0x2a, 0xf7, 0x5d, 0xa5, 0x07, 0x33, 0x06,
    0x6b, 0x52, 0xc2, 0x8c, 0x6f, 0x8a, 0xeb, 0xcc, 0x12, 0x80, 0x23, 0x46, 0xb1, 0x76, 0xfe, 0x9a,
    0x2c, 0xce, 0xaa, 0x17, 0xaa, 0xf8, 0x29, 0xe1, 0x02, 0xee, 0x72, 0x5c, 0xff, 0xd8, 0x86, 0x35,
    0x86, 0x15, 0x49, 0x42, 0x54, 0xbe, 0x2f, 0x45, 0xc0, 0x1c, 0x84, 0x04, 0x1a, 0x5f, 0x5b, 0xa5,
    0x0c, 0xcf, 0x15, 0xf8, 0x88, 0x71, 0xb0, 0x66, 0xce, 0xdd, 0x18, 0x9e, 0x03, 0x0f, 0xa4, 0xa4,
    0x9b, 0xc8, 0x56, 0x3e, 0x64, 0xa7, 0x6d, 0x76, 0xe4, 0xdc, 0x30, 0x3b, 0x01, 0xc5, 0xfc, 0xe3,
    0xd1, 0xf8, 0x72, 0x2e, 0x99, 0x7c, 0x72, 0x8a, 0x98, 0x78, 0x95, 0x81, 0xb7, 0x69, 0xb0, 0x42,
    0xff, 0xa6, 0xa5, 0xbe, 0x54, 0x3a, 0x9e, 0xc2, 0xbb, 0x35, 0xeb, 0x73, 0x9b, 0x2a, 0xe4, 0x4c,
    0xf6, 0x81, 0xbf, 0xaa, 0x42, 0xc6, 0x49, 0xcf, 0x01, 0x89, 0xe6, 0xf9, 0xfe, 0xfb, 0x15, 0xf3,
    0xe9, 0x0d, 0x8a, 0x39, 0x66, 0x0e, 0x13, 0x38, 0x67, 0xfc, 0x97, 0x58, 0x6f, 0x5e, 0xb8, 0x8b,
    0x3e, 0x4d, 0xc2, 0x30, 0x96, 0x26, 0xc9, 0x77, 0x6e, 0x03, 0x0a, 0xb6, 0x34, 0xca, 0xc1, 0xe3,
    0x11, 0x0b, 0x93, 0x88, 0xee, 0x6d, 0xc8, 0xfa, 0x32, 0x42, 0xe3, 0xba, 0x4d, 0xf6, 0x28, 0xaf,
    0x3a, 0x5b, 0x5e, 0x66, 0x52, 0xd8, 0xba, 0xa7, 0xf2, 0xb4, 0x1e, 0x0e, 0x0b, 0x19, 0xa6, 0xf2,
    0x57, 0x26, 0xe7, 0x24, 0x35, 0x3b, 0xde, 0x1f, 0xc2, 0x2f, 0x1e, 0xd5, 0x76, 0xbe, 0x7a, 0x63,
    0xf5, 0x13, 0xdf, 0xb2, 0x5e, 0xeb, 0xb4, 0x76, 0xb7, 0x8c, 0x82, 0xf6, 0xf2, 0x54, 0xda, 0x13,
    0xcb, 0x50, 0xa8, 0x21, 0xdb, 0x9e, 0x55, 0x79, 0x09, 0x51, 0x3f, 0xfb, 0xbb, 0x24, 0xe3, 0xfa,
    0xbd, 0x3d, 0xef, 0x1f, 0x9c, 0xac, 0x9a, 0xb4, 0x48, 0xb7, 0x96, 0xb1, 0x2c, 0x45, 0x15, 0xbf,
    0x5c, 0x7a, 0x2c, 0x4e, 0x97, 0xcb, 0xcd, 0x35, 0x55, 0xf6, 0x7a, 0x21, 0x57, 0xc6, 0x0b, 0xd8,
    0xdf, 0x17, 0x4f
};
#endif

PyTypeObject *init_QDomDocument(PyObject *module)
{
    if (SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX].type != nullptr)
        return SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX].type;

    Shiboken::AutoDecRef Sbk_QDomDocument_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]))));

    _Sbk_QDomDocument_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDomDocument",
        "QDomDocument",
        &Sbk_QDomDocument_spec,
        &Shiboken::callCppDestructor< ::QDomDocument >,
        Sbk_QDomDocument_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QDomDocument_TypeF(); // references _Sbk_QDomDocument_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QDomDocument_SignatureStrings);
#else
    InitSignatureBytes(pyType, QDomDocument_SignatureBytes, QDomDocument_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDomDocument_PropertyStrings);
    SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDomDocument_PythonToCpp_QDomDocument_PTR,
        is_QDomDocument_PythonToCpp_QDomDocument_PTR_Convertible,
        QDomDocument_PTR_CppToPython_QDomDocument,
        QDomDocument_COPY_CppToPython_QDomDocument);

    Shiboken::Conversions::registerConverterName(converter, "QDomDocument");
    Shiboken::Conversions::registerConverterName(converter, "QDomDocument*");
    Shiboken::Conversions::registerConverterName(converter, "QDomDocument&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDomDocument).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QDomDocument_PythonToCpp_QDomDocument_COPY,
        is_QDomDocument_PythonToCpp_QDomDocument_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QDomDocument_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'ParseOption'.
    const char *ParseOption_Initializer[] = {
        "Default",
        "UseNamespaceProcessing",
        "PreserveSpacingOnlyNodes",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t ParseOption_InitializerValues[] = {
        int8_t(QDomDocument::ParseOption::Default),                 //  0x00  0
        int8_t(QDomDocument::ParseOption::UseNamespaceProcessing),  //  0x01  1
        int8_t(QDomDocument::ParseOption::PreserveSpacingOnlyNodes) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QDomDocument_TypeF(),
        "2:PySide6.QtXml.QDomDocument.ParseOption",
        ParseOption_Initializer, ParseOption_InitializerValues);
    SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_ParseOption_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtXmlTypeStructs[SBK_QFlags_QDomDocument_ParseOption_IDX].type =
        EType;
    // Register converter for enum 'QDomDocument::ParseOption'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QDomDocument_ParseOption_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QDomDocument_ParseOption,
            is_Enum_PythonToCpp_QDomDocument_ParseOption_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QDomDocument::ParseOption");
        Shiboken::Conversions::registerConverterAlias(converter, "ParseOption");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QDomDocument_ParseOption_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QDomDocument_ParseOption,
            is_Enum_PythonToCpp_QDomDocument_ParseOption_Convertible);
        // Register converter for flag 'QFlags<QDomDocument::ParseOption>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QDomDocument::ParseOption>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QDomDocument::ParseOptions");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'ParseOption' enum/flags.

    qRegisterMetaType< ::QDomDocument >("QDomDocument");
    qRegisterMetaType< ::QDomDocument::ParseOption >("QDomDocument::ParseOption");

    return pyType;
}
