// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtxml_python.h"

// main header
#include "qdomdocumentfragment_wrapper.h"

// Argument includes
#include <QString>
#include <QtXml/qdom.h>
#include <qtextstream.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDomDocumentFragment_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QDomDocumentFragment >()))
        return -1;

    ::QDomDocumentFragment *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QDomDocumentFragment", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QDomDocumentFragment::QDomDocumentFragment()
    // 1: QDomDocumentFragment::QDomDocumentFragment(QDomDocumentFragment)
    if (numArgs == 0) {
        overloadId = 0; // QDomDocumentFragment()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocumentFragment_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QDomDocumentFragment(QDomDocumentFragment)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocumentFragment_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocumentFragment_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QDomDocumentFragment()
        {

            // QDomDocumentFragment()
            cptr = new ::QDomDocumentFragment();
            break;
        }
        case 1: // QDomDocumentFragment(const QDomDocumentFragment &documentFragment)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QDomDocumentFragment cppArg0_local;
            ::QDomDocumentFragment *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QDomDocumentFragment(QDomDocumentFragment)
                cptr = new ::QDomDocumentFragment(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QDomDocumentFragment >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocumentFragment_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QDomDocumentFragmentFunc_nodeType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomDocumentFragment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocumentFragment_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // nodeType()const
        QDomNode::NodeType cppResult = const_cast<const ::QDomDocumentFragment *>(cppSelf)->nodeType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_NodeType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomDocumentFragment__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QDomDocumentFragment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocumentFragment_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocumentFragment_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QDomDocumentFragment_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDomDocumentFragment_methods[] = {
    {"nodeType", reinterpret_cast<PyCFunction>(Sbk_QDomDocumentFragmentFunc_nodeType), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QDomDocumentFragment__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QDomDocumentFragment___nb_bool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QDomDocumentFragment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocumentFragment_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return !cppSelf->isNull() ? 1 : 0;
}

} // extern "C"

static int Sbk_QDomDocumentFragment_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDomDocumentFragment_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDomDocumentFragment_Type = nullptr;
static PyTypeObject *Sbk_QDomDocumentFragment_TypeF(void)
{
    return _Sbk_QDomDocumentFragment_Type;
}

static PyType_Slot Sbk_QDomDocumentFragment_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDomDocumentFragment_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDomDocumentFragment_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDomDocumentFragment_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDomDocumentFragment_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_bool,        reinterpret_cast<void *>(Sbk_QDomDocumentFragment___nb_bool)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDomDocumentFragment_spec = {
    "2:PySide6.QtXml.QDomDocumentFragment",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDomDocumentFragment_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDomDocumentFragment_PythonToCpp_QDomDocumentFragment_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDomDocumentFragment_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDomDocumentFragment_PythonToCpp_QDomDocumentFragment_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDomDocumentFragment_TypeF()))
        return QDomDocumentFragment_PythonToCpp_QDomDocumentFragment_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDomDocumentFragment_PTR_CppToPython_QDomDocumentFragment(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QDomDocumentFragment_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QDomDocumentFragment_COPY_CppToPython_QDomDocumentFragment(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QDomDocumentFragment *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QDomDocumentFragment_TypeF(), new ::QDomDocumentFragment(*source), true, true);
}

// Python to C++ copy conversion.
static void QDomDocumentFragment_PythonToCpp_QDomDocumentFragment_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QDomDocumentFragment *>(cppOut) = *reinterpret_cast< ::QDomDocumentFragment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocumentFragment_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QDomDocumentFragment_PythonToCpp_QDomDocumentFragment_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QDomDocumentFragment_TypeF()))
        return QDomDocumentFragment_PythonToCpp_QDomDocumentFragment_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QDomDocumentFragment_SignatureStrings[] = {
    "1:PySide6.QtXml.QDomDocumentFragment(self)",
    "0:PySide6.QtXml.QDomDocumentFragment(self,documentFragment:PySide6.QtXml.QDomDocumentFragment)",
    "PySide6.QtXml.QDomDocumentFragment.nodeType(self)->PySide6.QtXml.QDomNode.NodeType",
    "PySide6.QtXml.QDomDocumentFragment.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QDomDocumentFragment_SignatureByteSize = 108;
static constexpr uint8_t QDomDocumentFragment_SignatureBytes[108] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x89, 0xc8,
    0xcd, 0xd1, 0x0b, 0x74, 0xc9, 0xcf, 0x75, 0xc9, 0x4f, 0x2e, 0xcd, 0x4d, 0xcd, 0x2b, 0x71, 0x2b,
    0x4a, 0x4c, 0x07, 0xd1, 0x1a, 0xc5, 0xa9, 0x39, 0x69, 0x9a, 0x5c, 0x06, 0xc4, 0x2a, 0xd5, 0x49,
    0x41, 0x13, 0x25, 0x42, 0xa3, 0x26, 0x17, 0x61, 0x35, 0x7a, 0x79, 0xf9, 0x29, 0xa9, 0x21, 0x95,
    0x05, 0xa9, 0x10, 0x07, 0xe9, 0xda, 0x61, 0x6a, 0xf1, 0x03, 0xaa, 0xd0, 0xf3, 0x83, 0x2a, 0x23,
    0xc6, 0xc8, 0xf8, 0xf8, 0xe4, 0xfc, 0x82, 0xca, 0xf8, 0x78, 0x98, 0x91, 0x25, 0x95, 0x05, 0x99,
    0x79, 0xe9, 0x7a, 0xc1, 0x40, 0x1e, 0x17, 0x00, 0x1d, 0xe2, 0x66, 0xac
};
#endif

PyTypeObject *init_QDomDocumentFragment(PyObject *module)
{
    if (SbkPySide6_QtXmlTypeStructs[SBK_QDomDocumentFragment_IDX].type != nullptr)
        return SbkPySide6_QtXmlTypeStructs[SBK_QDomDocumentFragment_IDX].type;

    Shiboken::AutoDecRef Sbk_QDomDocumentFragment_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]))));

    _Sbk_QDomDocumentFragment_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDomDocumentFragment",
        "QDomDocumentFragment",
        &Sbk_QDomDocumentFragment_spec,
        &Shiboken::callCppDestructor< ::QDomDocumentFragment >,
        Sbk_QDomDocumentFragment_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QDomDocumentFragment_TypeF(); // references _Sbk_QDomDocumentFragment_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QDomDocumentFragment_SignatureStrings);
#else
    InitSignatureBytes(pyType, QDomDocumentFragment_SignatureBytes, QDomDocumentFragment_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDomDocumentFragment_PropertyStrings);
    SbkPySide6_QtXmlTypeStructs[SBK_QDomDocumentFragment_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDomDocumentFragment_PythonToCpp_QDomDocumentFragment_PTR,
        is_QDomDocumentFragment_PythonToCpp_QDomDocumentFragment_PTR_Convertible,
        QDomDocumentFragment_PTR_CppToPython_QDomDocumentFragment,
        QDomDocumentFragment_COPY_CppToPython_QDomDocumentFragment);

    Shiboken::Conversions::registerConverterName(converter, "QDomDocumentFragment");
    Shiboken::Conversions::registerConverterName(converter, "QDomDocumentFragment*");
    Shiboken::Conversions::registerConverterName(converter, "QDomDocumentFragment&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDomDocumentFragment).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QDomDocumentFragment_PythonToCpp_QDomDocumentFragment_COPY,
        is_QDomDocumentFragment_PythonToCpp_QDomDocumentFragment_COPY_Convertible);

    qRegisterMetaType< ::QDomDocumentFragment >("QDomDocumentFragment");

    return pyType;
}
