// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtxml_python.h"

// main header
#include "qdomdocumenttype_wrapper.h"

// Argument includes
#include <QString>
#include <QtXml/qdom.h>
#include <qtextstream.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDomDocumentType_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QDomDocumentType >()))
        return -1;

    ::QDomDocumentType *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QDomDocumentType", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QDomDocumentType::QDomDocumentType()
    // 1: QDomDocumentType::QDomDocumentType(QDomDocumentType)
    if (numArgs == 0) {
        overloadId = 0; // QDomDocumentType()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocumentType_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QDomDocumentType(QDomDocumentType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocumentType_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocumentType_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QDomDocumentType()
        {

            // QDomDocumentType()
            cptr = new ::QDomDocumentType();
            break;
        }
        case 1: // QDomDocumentType(const QDomDocumentType &documentType)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QDomDocumentType cppArg0_local;
            ::QDomDocumentType *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QDomDocumentType(QDomDocumentType)
                cptr = new ::QDomDocumentType(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QDomDocumentType >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomDocumentType_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QDomDocumentTypeFunc_entities(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomDocumentType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocumentType_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // entities()const
        QDomNamedNodeMap cppResult = const_cast<const ::QDomDocumentType *>(cppSelf)->entities();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNamedNodeMap_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomDocumentTypeFunc_internalSubset(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomDocumentType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocumentType_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // internalSubset()const
        QString cppResult = const_cast<const ::QDomDocumentType *>(cppSelf)->internalSubset();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomDocumentTypeFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomDocumentType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocumentType_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // name()const
        QString cppResult = const_cast<const ::QDomDocumentType *>(cppSelf)->name();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomDocumentTypeFunc_nodeType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomDocumentType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocumentType_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // nodeType()const
        QDomNode::NodeType cppResult = const_cast<const ::QDomDocumentType *>(cppSelf)->nodeType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_NodeType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomDocumentTypeFunc_notations(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomDocumentType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocumentType_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // notations()const
        QDomNamedNodeMap cppResult = const_cast<const ::QDomDocumentType *>(cppSelf)->notations();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNamedNodeMap_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomDocumentTypeFunc_publicId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomDocumentType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocumentType_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // publicId()const
        QString cppResult = const_cast<const ::QDomDocumentType *>(cppSelf)->publicId();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomDocumentTypeFunc_systemId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomDocumentType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocumentType_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // systemId()const
        QString cppResult = const_cast<const ::QDomDocumentType *>(cppSelf)->systemId();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomDocumentType__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QDomDocumentType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocumentType_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocumentType_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QDomDocumentType_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDomDocumentType_methods[] = {
    {"entities", reinterpret_cast<PyCFunction>(Sbk_QDomDocumentTypeFunc_entities), METH_NOARGS, nullptr},
    {"internalSubset", reinterpret_cast<PyCFunction>(Sbk_QDomDocumentTypeFunc_internalSubset), METH_NOARGS, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_QDomDocumentTypeFunc_name), METH_NOARGS, nullptr},
    {"nodeType", reinterpret_cast<PyCFunction>(Sbk_QDomDocumentTypeFunc_nodeType), METH_NOARGS, nullptr},
    {"notations", reinterpret_cast<PyCFunction>(Sbk_QDomDocumentTypeFunc_notations), METH_NOARGS, nullptr},
    {"publicId", reinterpret_cast<PyCFunction>(Sbk_QDomDocumentTypeFunc_publicId), METH_NOARGS, nullptr},
    {"systemId", reinterpret_cast<PyCFunction>(Sbk_QDomDocumentTypeFunc_systemId), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QDomDocumentType__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QDomDocumentType___nb_bool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QDomDocumentType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocumentType_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return !cppSelf->isNull() ? 1 : 0;
}

} // extern "C"

static int Sbk_QDomDocumentType_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDomDocumentType_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDomDocumentType_Type = nullptr;
static PyTypeObject *Sbk_QDomDocumentType_TypeF(void)
{
    return _Sbk_QDomDocumentType_Type;
}

static PyType_Slot Sbk_QDomDocumentType_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDomDocumentType_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDomDocumentType_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDomDocumentType_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDomDocumentType_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_bool,        reinterpret_cast<void *>(Sbk_QDomDocumentType___nb_bool)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDomDocumentType_spec = {
    "2:PySide6.QtXml.QDomDocumentType",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDomDocumentType_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDomDocumentType_PythonToCpp_QDomDocumentType_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDomDocumentType_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDomDocumentType_PythonToCpp_QDomDocumentType_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDomDocumentType_TypeF()))
        return QDomDocumentType_PythonToCpp_QDomDocumentType_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDomDocumentType_PTR_CppToPython_QDomDocumentType(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QDomDocumentType_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QDomDocumentType_COPY_CppToPython_QDomDocumentType(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QDomDocumentType *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QDomDocumentType_TypeF(), new ::QDomDocumentType(*source), true, true);
}

// Python to C++ copy conversion.
static void QDomDocumentType_PythonToCpp_QDomDocumentType_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QDomDocumentType *>(cppOut) = *reinterpret_cast< ::QDomDocumentType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocumentType_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QDomDocumentType_PythonToCpp_QDomDocumentType_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QDomDocumentType_TypeF()))
        return QDomDocumentType_PythonToCpp_QDomDocumentType_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QDomDocumentType_SignatureStrings[] = {
    "1:PySide6.QtXml.QDomDocumentType(self)",
    "0:PySide6.QtXml.QDomDocumentType(self,documentType:PySide6.QtXml.QDomDocumentType)",
    "PySide6.QtXml.QDomDocumentType.entities(self)->PySide6.QtXml.QDomNamedNodeMap",
    "PySide6.QtXml.QDomDocumentType.internalSubset(self)->QString",
    "PySide6.QtXml.QDomDocumentType.name(self)->QString",
    "PySide6.QtXml.QDomDocumentType.nodeType(self)->PySide6.QtXml.QDomNode.NodeType",
    "PySide6.QtXml.QDomDocumentType.notations(self)->PySide6.QtXml.QDomNamedNodeMap",
    "PySide6.QtXml.QDomDocumentType.publicId(self)->QString",
    "PySide6.QtXml.QDomDocumentType.systemId(self)->QString",
    "PySide6.QtXml.QDomDocumentType.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QDomDocumentType_SignatureByteSize = 178;
static constexpr uint8_t QDomDocumentType_SignatureBytes[178] = {
    0x78, 0xda, 0xad, 0x90, 0x3f, 0x0b, 0xc2, 0x30, 0x10, 0xc5, 0xf7, 0x7e, 0x12, 0x0b, 0x1a, 0x74,
    0x71, 0x70, 0x70, 0xea, 0xe2, 0x60, 0x69, 0x89, 0x83, 0x5b, 0x48, 0x9b, 0x53, 0x0e, 0xf2, 0x8f,
    0xe6, 0x3a, 0xe4, 0xdb, 0x1b, 0xd0, 0xa2, 0xa0, 0x18, 0x0b, 0x4e, 0x21, 0xb9, 0xf7, 0x7b, 0xf7,
    0xf2, 0x36, 0xbb, 0x26, 0x72, 0x54, 0xb0, 0x65, 0x2d, 0x9d, 0x8d, 0x66, 0x6d, 0xe5, 0x4c, 0xe5,
    0xfa, 0xd1, 0x80, 0xa5, 0x53, 0xf4, 0xb0, 0x08, 0xa0, 0x2f, 0x65, 0xb1, 0xfe, 0x45, 0xb6, 0x54,
    0x2f, 0x2f, 0x19, 0xa0, 0x2c, 0xbe, 0xcf, 0x59, 0x3a, 0x91, 0x10, 0xc2, 0x3d, 0xc0, 0x6a, 0xff,
    0x2e, 0xaf, 0xa5, 0x01, 0x55, 0x3b, 0x05, 0x47, 0xe9, 0x73, 0x6e, 0x68, 0x09, 0x06, 0x2b, 0x35,
    0x1f, 0xbb, 0x00, 0x34, 0x79, 0xb6, 0x9c, 0x06, 0xb4, 0xd7, 0x1c, 0x6c, 0xd3, 0xa2, 0xb9, 0x48,
    0x8a, 0xf5, 0xac, 0xef, 0x63, 0xfa, 0xa4, 0x60, 0xf5, 0x43, 0x96, 0xb7, 0x23, 0x49, 0xe8, 0xec,
    0x9f, 0xda, 0xf0, 0x63, 0xa7, 0xb1, 0x3f, 0xa8, 0x99, 0x9f, 0x0a, 0x31, 0x10, 0x98, 0xd9, 0x98,
    0x10, 0xbd, 0xf3, 0x51, 0x88, 0x09, 0xa3, 0xe8, 0x13, 0xc5, 0x78, 0xba, 0x15, 0x37, 0x57, 0xfb,
    0xe5, 0xda
};
#endif

PyTypeObject *init_QDomDocumentType(PyObject *module)
{
    if (SbkPySide6_QtXmlTypeStructs[SBK_QDomDocumentType_IDX].type != nullptr)
        return SbkPySide6_QtXmlTypeStructs[SBK_QDomDocumentType_IDX].type;

    Shiboken::AutoDecRef Sbk_QDomDocumentType_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]))));

    _Sbk_QDomDocumentType_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDomDocumentType",
        "QDomDocumentType",
        &Sbk_QDomDocumentType_spec,
        &Shiboken::callCppDestructor< ::QDomDocumentType >,
        Sbk_QDomDocumentType_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QDomDocumentType_TypeF(); // references _Sbk_QDomDocumentType_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QDomDocumentType_SignatureStrings);
#else
    InitSignatureBytes(pyType, QDomDocumentType_SignatureBytes, QDomDocumentType_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDomDocumentType_PropertyStrings);
    SbkPySide6_QtXmlTypeStructs[SBK_QDomDocumentType_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDomDocumentType_PythonToCpp_QDomDocumentType_PTR,
        is_QDomDocumentType_PythonToCpp_QDomDocumentType_PTR_Convertible,
        QDomDocumentType_PTR_CppToPython_QDomDocumentType,
        QDomDocumentType_COPY_CppToPython_QDomDocumentType);

    Shiboken::Conversions::registerConverterName(converter, "QDomDocumentType");
    Shiboken::Conversions::registerConverterName(converter, "QDomDocumentType*");
    Shiboken::Conversions::registerConverterName(converter, "QDomDocumentType&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDomDocumentType).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QDomDocumentType_PythonToCpp_QDomDocumentType_COPY,
        is_QDomDocumentType_PythonToCpp_QDomDocumentType_COPY_Convertible);

    qRegisterMetaType< ::QDomDocumentType >("QDomDocumentType");

    return pyType;
}
