// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtxml_python.h"

// main header
#include "qdomentity_wrapper.h"

// Argument includes
#include <QString>
#include <QtXml/qdom.h>
#include <qtextstream.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDomEntity_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QDomEntity >()))
        return -1;

    ::QDomEntity *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QDomEntity", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QDomEntity::QDomEntity()
    // 1: QDomEntity::QDomEntity(QDomEntity)
    if (numArgs == 0) {
        overloadId = 0; // QDomEntity()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomEntity_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QDomEntity(QDomEntity)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomEntity_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtXmlTypeStructs[SBK_QDomEntity_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QDomEntity()
        {

            // QDomEntity()
            cptr = new ::QDomEntity();
            break;
        }
        case 1: // QDomEntity(const QDomEntity &entity)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QDomEntity cppArg0_local;
            ::QDomEntity *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QDomEntity(QDomEntity)
                cptr = new ::QDomEntity(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QDomEntity >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomEntity_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QDomEntityFunc_nodeType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomEntity *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomEntity_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // nodeType()const
        QDomNode::NodeType cppResult = const_cast<const ::QDomEntity *>(cppSelf)->nodeType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_NodeType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomEntityFunc_notationName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomEntity *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomEntity_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // notationName()const
        QString cppResult = const_cast<const ::QDomEntity *>(cppSelf)->notationName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomEntityFunc_publicId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomEntity *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomEntity_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // publicId()const
        QString cppResult = const_cast<const ::QDomEntity *>(cppSelf)->publicId();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomEntityFunc_systemId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomEntity *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomEntity_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // systemId()const
        QString cppResult = const_cast<const ::QDomEntity *>(cppSelf)->systemId();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomEntity__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QDomEntity *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomEntity_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomEntity_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QDomEntity_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDomEntity_methods[] = {
    {"nodeType", reinterpret_cast<PyCFunction>(Sbk_QDomEntityFunc_nodeType), METH_NOARGS, nullptr},
    {"notationName", reinterpret_cast<PyCFunction>(Sbk_QDomEntityFunc_notationName), METH_NOARGS, nullptr},
    {"publicId", reinterpret_cast<PyCFunction>(Sbk_QDomEntityFunc_publicId), METH_NOARGS, nullptr},
    {"systemId", reinterpret_cast<PyCFunction>(Sbk_QDomEntityFunc_systemId), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QDomEntity__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QDomEntity___nb_bool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QDomEntity *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomEntity_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return !cppSelf->isNull() ? 1 : 0;
}

} // extern "C"

static int Sbk_QDomEntity_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDomEntity_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDomEntity_Type = nullptr;
static PyTypeObject *Sbk_QDomEntity_TypeF(void)
{
    return _Sbk_QDomEntity_Type;
}

static PyType_Slot Sbk_QDomEntity_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDomEntity_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDomEntity_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDomEntity_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDomEntity_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_bool,        reinterpret_cast<void *>(Sbk_QDomEntity___nb_bool)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDomEntity_spec = {
    "2:PySide6.QtXml.QDomEntity",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDomEntity_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDomEntity_PythonToCpp_QDomEntity_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDomEntity_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDomEntity_PythonToCpp_QDomEntity_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDomEntity_TypeF()))
        return QDomEntity_PythonToCpp_QDomEntity_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDomEntity_PTR_CppToPython_QDomEntity(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QDomEntity_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QDomEntity_COPY_CppToPython_QDomEntity(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QDomEntity *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QDomEntity_TypeF(), new ::QDomEntity(*source), true, true);
}

// Python to C++ copy conversion.
static void QDomEntity_PythonToCpp_QDomEntity_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QDomEntity *>(cppOut) = *reinterpret_cast< ::QDomEntity *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomEntity_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QDomEntity_PythonToCpp_QDomEntity_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QDomEntity_TypeF()))
        return QDomEntity_PythonToCpp_QDomEntity_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QDomEntity_SignatureStrings[] = {
    "1:PySide6.QtXml.QDomEntity(self)",
    "0:PySide6.QtXml.QDomEntity(self,entity:PySide6.QtXml.QDomEntity)",
    "PySide6.QtXml.QDomEntity.nodeType(self)->PySide6.QtXml.QDomNode.NodeType",
    "PySide6.QtXml.QDomEntity.notationName(self)->QString",
    "PySide6.QtXml.QDomEntity.publicId(self)->QString",
    "PySide6.QtXml.QDomEntity.systemId(self)->QString",
    "PySide6.QtXml.QDomEntity.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QDomEntity_SignatureByteSize = 138;
static constexpr uint8_t QDomEntity_SignatureBytes[138] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x89, 0xc8,
    0xcd, 0xd1, 0x0b, 0x74, 0xc9, 0xcf, 0x75, 0xcd, 0x2b, 0xc9, 0x2c, 0xa9, 0xd4, 0x28, 0x4e, 0xcd,
    0x49, 0xd3, 0xe4, 0x32, 0xc0, 0xaf, 0x40, 0x27, 0x15, 0xcc, 0xc6, 0xa9, 0x48, 0x93, 0x0b, 0x97,
    0x8c, 0x5e, 0x5e, 0x7e, 0x4a, 0x6a, 0x48, 0x65, 0x41, 0x2a, 0xc4, 0x22, 0x5d, 0x3b, 0x4c, 0x85,
    0x7e, 0x40, 0x15, 0x7a, 0x7e, 0x50, 0x65, 0xf8, 0x0c, 0x2a, 0x49, 0x2c, 0xc9, 0xcc, 0xcf, 0xf3,
    0x4b, 0xcc, 0x85, 0x1b, 0x16, 0x18, 0x5c, 0x52, 0x94, 0x99, 0x97, 0x8e, 0x5b, 0x53, 0x41, 0x69,
    0x52, 0x4e, 0x66, 0xb2, 0x67, 0x0a, 0xd1, 0x1a, 0x8a, 0x2b, 0x8b, 0x4b, 0x52, 0x73, 0x49, 0xd0,
    0x10, 0x1f, 0x9f, 0x9c, 0x5f, 0x50, 0x19, 0x1f, 0x0f, 0xd3, 0x50, 0x52, 0x59, 0x00, 0x54, 0xaf,
    0x17, 0x0c, 0xe4, 0x71, 0x01, 0x00, 0x27, 0x9a, 0x84, 0xd1
};
#endif

PyTypeObject *init_QDomEntity(PyObject *module)
{
    if (SbkPySide6_QtXmlTypeStructs[SBK_QDomEntity_IDX].type != nullptr)
        return SbkPySide6_QtXmlTypeStructs[SBK_QDomEntity_IDX].type;

    Shiboken::AutoDecRef Sbk_QDomEntity_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]))));

    _Sbk_QDomEntity_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDomEntity",
        "QDomEntity",
        &Sbk_QDomEntity_spec,
        &Shiboken::callCppDestructor< ::QDomEntity >,
        Sbk_QDomEntity_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QDomEntity_TypeF(); // references _Sbk_QDomEntity_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QDomEntity_SignatureStrings);
#else
    InitSignatureBytes(pyType, QDomEntity_SignatureBytes, QDomEntity_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDomEntity_PropertyStrings);
    SbkPySide6_QtXmlTypeStructs[SBK_QDomEntity_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDomEntity_PythonToCpp_QDomEntity_PTR,
        is_QDomEntity_PythonToCpp_QDomEntity_PTR_Convertible,
        QDomEntity_PTR_CppToPython_QDomEntity,
        QDomEntity_COPY_CppToPython_QDomEntity);

    Shiboken::Conversions::registerConverterName(converter, "QDomEntity");
    Shiboken::Conversions::registerConverterName(converter, "QDomEntity*");
    Shiboken::Conversions::registerConverterName(converter, "QDomEntity&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDomEntity).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QDomEntity_PythonToCpp_QDomEntity_COPY,
        is_QDomEntity_PythonToCpp_QDomEntity_COPY_Convertible);

    qRegisterMetaType< ::QDomEntity >("QDomEntity");

    return pyType;
}
