// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtxml_python.h"

// main header
#include "qdomentityreference_wrapper.h"

// Argument includes
#include <QString>
#include <QtXml/qdom.h>
#include <qtextstream.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDomEntityReference_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QDomEntityReference >()))
        return -1;

    ::QDomEntityReference *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QDomEntityReference", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QDomEntityReference::QDomEntityReference()
    // 1: QDomEntityReference::QDomEntityReference(QDomEntityReference)
    if (numArgs == 0) {
        overloadId = 0; // QDomEntityReference()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomEntityReference_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QDomEntityReference(QDomEntityReference)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomEntityReference_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtXmlTypeStructs[SBK_QDomEntityReference_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QDomEntityReference()
        {

            // QDomEntityReference()
            cptr = new ::QDomEntityReference();
            break;
        }
        case 1: // QDomEntityReference(const QDomEntityReference &entityReference)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QDomEntityReference cppArg0_local;
            ::QDomEntityReference *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QDomEntityReference(QDomEntityReference)
                cptr = new ::QDomEntityReference(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QDomEntityReference >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomEntityReference_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QDomEntityReferenceFunc_nodeType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomEntityReference *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomEntityReference_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // nodeType()const
        QDomNode::NodeType cppResult = const_cast<const ::QDomEntityReference *>(cppSelf)->nodeType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_NodeType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomEntityReference__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QDomEntityReference *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomEntityReference_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomEntityReference_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QDomEntityReference_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDomEntityReference_methods[] = {
    {"nodeType", reinterpret_cast<PyCFunction>(Sbk_QDomEntityReferenceFunc_nodeType), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QDomEntityReference__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QDomEntityReference___nb_bool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QDomEntityReference *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomEntityReference_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return !cppSelf->isNull() ? 1 : 0;
}

} // extern "C"

static int Sbk_QDomEntityReference_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDomEntityReference_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDomEntityReference_Type = nullptr;
static PyTypeObject *Sbk_QDomEntityReference_TypeF(void)
{
    return _Sbk_QDomEntityReference_Type;
}

static PyType_Slot Sbk_QDomEntityReference_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDomEntityReference_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDomEntityReference_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDomEntityReference_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDomEntityReference_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_bool,        reinterpret_cast<void *>(Sbk_QDomEntityReference___nb_bool)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDomEntityReference_spec = {
    "2:PySide6.QtXml.QDomEntityReference",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDomEntityReference_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDomEntityReference_PythonToCpp_QDomEntityReference_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDomEntityReference_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDomEntityReference_PythonToCpp_QDomEntityReference_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDomEntityReference_TypeF()))
        return QDomEntityReference_PythonToCpp_QDomEntityReference_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDomEntityReference_PTR_CppToPython_QDomEntityReference(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QDomEntityReference_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QDomEntityReference_COPY_CppToPython_QDomEntityReference(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QDomEntityReference *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QDomEntityReference_TypeF(), new ::QDomEntityReference(*source), true, true);
}

// Python to C++ copy conversion.
static void QDomEntityReference_PythonToCpp_QDomEntityReference_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QDomEntityReference *>(cppOut) = *reinterpret_cast< ::QDomEntityReference *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomEntityReference_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QDomEntityReference_PythonToCpp_QDomEntityReference_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QDomEntityReference_TypeF()))
        return QDomEntityReference_PythonToCpp_QDomEntityReference_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QDomEntityReference_SignatureStrings[] = {
    "1:PySide6.QtXml.QDomEntityReference(self)",
    "0:PySide6.QtXml.QDomEntityReference(self,entityReference:PySide6.QtXml.QDomEntityReference)",
    "PySide6.QtXml.QDomEntityReference.nodeType(self)->PySide6.QtXml.QDomNode.NodeType",
    "PySide6.QtXml.QDomEntityReference.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QDomEntityReference_SignatureByteSize = 108;
static constexpr uint8_t QDomEntityReference_SignatureBytes[108] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x89, 0xc8,
    0xcd, 0xd1, 0x0b, 0x74, 0xc9, 0xcf, 0x75, 0xcd, 0x2b, 0xc9, 0x2c, 0xa9, 0x0c, 0x4a, 0x4d, 0x4b,
    0x2d, 0x4a, 0xcd, 0x4b, 0x4e, 0xd5, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0xe4, 0x32, 0x20, 0x52, 0xa5,
    0x4e, 0x2a, 0xaa, 0x20, 0x61, 0x6d, 0x9a, 0x5c, 0x04, 0x95, 0xe8, 0xe5, 0xe5, 0xa7, 0xa4, 0x86,
    0x54, 0x16, 0x40, 0x1d, 0xa3, 0x6b, 0x87, 0xa9, 0xc3, 0x0f, 0xa8, 0x42, 0xcf, 0x0f, 0xaa, 0x8c,
    0x08, 0x13, 0xe3, 0xe3, 0x93, 0xf3, 0x0b, 0x2a, 0xe3, 0xe3, 0x61, 0x26, 0x96, 0x54, 0x16, 0x64,
    0xe6, 0xa5, 0xeb, 0x05, 0x03, 0x79, 0x5c, 0x00, 0x98, 0xbd, 0x64, 0x42
};
#endif

PyTypeObject *init_QDomEntityReference(PyObject *module)
{
    if (SbkPySide6_QtXmlTypeStructs[SBK_QDomEntityReference_IDX].type != nullptr)
        return SbkPySide6_QtXmlTypeStructs[SBK_QDomEntityReference_IDX].type;

    Shiboken::AutoDecRef Sbk_QDomEntityReference_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]))));

    _Sbk_QDomEntityReference_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDomEntityReference",
        "QDomEntityReference",
        &Sbk_QDomEntityReference_spec,
        &Shiboken::callCppDestructor< ::QDomEntityReference >,
        Sbk_QDomEntityReference_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QDomEntityReference_TypeF(); // references _Sbk_QDomEntityReference_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QDomEntityReference_SignatureStrings);
#else
    InitSignatureBytes(pyType, QDomEntityReference_SignatureBytes, QDomEntityReference_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDomEntityReference_PropertyStrings);
    SbkPySide6_QtXmlTypeStructs[SBK_QDomEntityReference_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDomEntityReference_PythonToCpp_QDomEntityReference_PTR,
        is_QDomEntityReference_PythonToCpp_QDomEntityReference_PTR_Convertible,
        QDomEntityReference_PTR_CppToPython_QDomEntityReference,
        QDomEntityReference_COPY_CppToPython_QDomEntityReference);

    Shiboken::Conversions::registerConverterName(converter, "QDomEntityReference");
    Shiboken::Conversions::registerConverterName(converter, "QDomEntityReference*");
    Shiboken::Conversions::registerConverterName(converter, "QDomEntityReference&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDomEntityReference).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QDomEntityReference_PythonToCpp_QDomEntityReference_COPY,
        is_QDomEntityReference_PythonToCpp_QDomEntityReference_COPY_Convertible);

    qRegisterMetaType< ::QDomEntityReference >("QDomEntityReference");

    return pyType;
}
