// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtxml_python.h"

// main header
#include "qdomimplementation_wrapper.h"

// Argument includes
#include <QString>
#include <QtXml/qdom.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDomImplementation_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QDomImplementation >()))
        return -1;

    ::QDomImplementation *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QDomImplementation", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QDomImplementation::QDomImplementation()
    // 1: QDomImplementation::QDomImplementation(QDomImplementation)
    if (numArgs == 0) {
        overloadId = 0; // QDomImplementation()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomImplementation_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QDomImplementation(QDomImplementation)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomImplementation_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtXmlTypeStructs[SBK_QDomImplementation_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QDomImplementation()
        {

            // QDomImplementation()
            cptr = new ::QDomImplementation();
            break;
        }
        case 1: // QDomImplementation(const QDomImplementation &implementation)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QDomImplementation cppArg0_local;
            ::QDomImplementation *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QDomImplementation(QDomImplementation)
                cptr = new ::QDomImplementation(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QDomImplementation >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomImplementation_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QDomImplementationFunc_createDocument(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomImplementation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomImplementation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "createDocument", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDomImplementation::createDocument(QString,QString,QDomDocumentType)->QDomDocument
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocumentType_IDX]), (pyArgs[2])))) {
        overloadId = 0; // createDocument(QString,QString,QDomDocumentType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "createDocument", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomImplementation_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QDomDocumentType cppArg2_local;
        ::QDomDocumentType *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2].isValue())
            pythonToCpp[2](pyArgs[2], &cppArg2_local);
        else
            pythonToCpp[2](pyArgs[2], &cppArg2);


        if (Shiboken::Errors::occurred() == nullptr) {
            // createDocument(QString,QString,QDomDocumentType)
            QDomDocument cppResult = cppSelf->createDocument(cppArg0, cppArg1, *cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomImplementationFunc_createDocumentType(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomImplementation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomImplementation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "createDocumentType", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDomImplementation::createDocumentType(QString,QString,QString)->QDomDocumentType
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
        overloadId = 0; // createDocumentType(QString,QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "createDocumentType", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomImplementation_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QString cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createDocumentType(QString,QString,QString)
            QDomDocumentType cppResult = cppSelf->createDocumentType(cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocumentType_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomImplementationFunc_hasFeature(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomImplementation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomImplementation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "hasFeature", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDomImplementation::hasFeature(QString,QString)const->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // hasFeature(QString,QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "hasFeature", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomImplementation_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // hasFeature(QString,QString)const
            bool cppResult = const_cast<const ::QDomImplementation *>(cppSelf)->hasFeature(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomImplementationFunc_invalidDataPolicy(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // invalidDataPolicy()
        QDomImplementation::InvalidDataPolicy cppResult = ::QDomImplementation::invalidDataPolicy();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomImplementation_InvalidDataPolicy_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomImplementationFunc_isNull(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomImplementation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomImplementation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isNull()
        bool cppResult = cppSelf->isNull();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomImplementationFunc_setInvalidDataPolicy(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QDomImplementation::setInvalidDataPolicy(QDomImplementation::InvalidDataPolicy)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomImplementation_InvalidDataPolicy_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setInvalidDataPolicy(QDomImplementation::InvalidDataPolicy)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setInvalidDataPolicy", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomImplementation_IDX]);

    // Call function/method
    {
        ::QDomImplementation::InvalidDataPolicy cppArg0{QDomImplementation::AcceptInvalidChars};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setInvalidDataPolicy(QDomImplementation::InvalidDataPolicy)
            ::QDomImplementation::setInvalidDataPolicy(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDomImplementation__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QDomImplementation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomImplementation_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomImplementation_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QDomImplementation_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QDomImplementation_EnumFlagInfo[] = {
    "InvalidDataPolicy:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDomImplementation_methods[] = {
    {"createDocument", reinterpret_cast<PyCFunction>(Sbk_QDomImplementationFunc_createDocument), METH_VARARGS, nullptr},
    {"createDocumentType", reinterpret_cast<PyCFunction>(Sbk_QDomImplementationFunc_createDocumentType), METH_VARARGS, nullptr},
    {"hasFeature", reinterpret_cast<PyCFunction>(Sbk_QDomImplementationFunc_hasFeature), METH_VARARGS, nullptr},
    {"invalidDataPolicy", reinterpret_cast<PyCFunction>(Sbk_QDomImplementationFunc_invalidDataPolicy), METH_NOARGS|METH_STATIC, nullptr},
    {"isNull", reinterpret_cast<PyCFunction>(Sbk_QDomImplementationFunc_isNull), METH_NOARGS, nullptr},
    {"setInvalidDataPolicy", reinterpret_cast<PyCFunction>(Sbk_QDomImplementationFunc_setInvalidDataPolicy), METH_O|METH_STATIC, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QDomImplementation__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QDomImplementation_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QDomImplementation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomImplementation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomImplementation_IDX]), (pyArg)))) {
                // operator!=(const QDomImplementation &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QDomImplementation cppArg0_local;
                ::QDomImplementation *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomImplementation_IDX]), (pyArg)))) {
                // operator==(const QDomImplementation &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QDomImplementation cppArg0_local;
                ::QDomImplementation *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QDomImplementation_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDomImplementation_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDomImplementation_Type = nullptr;
static PyTypeObject *Sbk_QDomImplementation_TypeF(void)
{
    return _Sbk_QDomImplementation_Type;
}

static PyType_Slot Sbk_QDomImplementation_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDomImplementation_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDomImplementation_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QDomImplementation_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDomImplementation_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDomImplementation_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDomImplementation_spec = {
    "2:PySide6.QtXml.QDomImplementation",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDomImplementation_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QDomImplementation_InvalidDataPolicy(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QDomImplementation::InvalidDataPolicy>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QDomImplementation::InvalidDataPolicy *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QDomImplementation_InvalidDataPolicy_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomImplementation_InvalidDataPolicy_IDX])))
        return Enum_PythonToCpp_QDomImplementation_InvalidDataPolicy;
    return {};
}

static PyObject *QDomImplementation_InvalidDataPolicy_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QDomImplementation::InvalidDataPolicy>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QDomImplementation::InvalidDataPolicy *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomImplementation_InvalidDataPolicy_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDomImplementation_PythonToCpp_QDomImplementation_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDomImplementation_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDomImplementation_PythonToCpp_QDomImplementation_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDomImplementation_TypeF()))
        return QDomImplementation_PythonToCpp_QDomImplementation_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDomImplementation_PTR_CppToPython_QDomImplementation(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QDomImplementation_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QDomImplementation_COPY_CppToPython_QDomImplementation(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QDomImplementation *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QDomImplementation_TypeF(), new ::QDomImplementation(*source), true, true);
}

// Python to C++ copy conversion.
static void QDomImplementation_PythonToCpp_QDomImplementation_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QDomImplementation *>(cppOut) = *reinterpret_cast< ::QDomImplementation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomImplementation_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QDomImplementation_PythonToCpp_QDomImplementation_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QDomImplementation_TypeF()))
        return QDomImplementation_PythonToCpp_QDomImplementation_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QDomImplementation_SignatureStrings[] = {
    "1:PySide6.QtXml.QDomImplementation(self)",
    "0:PySide6.QtXml.QDomImplementation(self,implementation:PySide6.QtXml.QDomImplementation)",
    "PySide6.QtXml.QDomImplementation.createDocument(self,nsURI:QString,qName:QString,doctype:PySide6.QtXml.QDomDocumentType)->PySide6.QtXml.QDomDocument",
    "PySide6.QtXml.QDomImplementation.createDocumentType(self,qName:QString,publicId:QString,systemId:QString)->PySide6.QtXml.QDomDocumentType",
    "PySide6.QtXml.QDomImplementation.hasFeature(self,feature:QString,version:QString)->bool",
    "PySide6.QtXml.QDomImplementation.invalidDataPolicy()->PySide6.QtXml.QDomImplementation.InvalidDataPolicy",
    "PySide6.QtXml.QDomImplementation.isNull(self)->bool",
    "PySide6.QtXml.QDomImplementation.setInvalidDataPolicy(policy:PySide6.QtXml.QDomImplementation.InvalidDataPolicy)",
    "PySide6.QtXml.QDomImplementation.__copy__(self)->typing.Self",
    "PySide6.QtXml.QDomImplementation.__ne__(self,other:PySide6.QtXml.QDomImplementation)->bool",
    "PySide6.QtXml.QDomImplementation.__eq__(self,other:PySide6.QtXml.QDomImplementation)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QDomImplementation_SignatureByteSize = 264;
static constexpr uint8_t QDomImplementation_SignatureBytes[264] = {
    0x78, 0xda, 0x9d, 0x93, 0x3f, 0x6f, 0x83, 0x30, 0x10, 0xc5, 0xf7, 0x7c, 0x12, 0x90, 0x28, 0x6a,
    0x96, 0x0e, 0x0c, 0x9d, 0x50, 0x25, 0x96, 0x28, 0x94, 0x56, 0xea, 0x66, 0x39, 0xe6, 0xd2, 0x58,
    0xf2, 0xbf, 0xd8, 0x47, 0x24, 0x7f, 0xfb, 0x9a, 0x92, 0x10, 0x25, 0x4d, 0x6b, 0xa7, 0x13, 0xba,
    0xf3, 0xbd, 0xf7, 0x7e, 0x98, 0x63, 0x59, 0xad, 0x7d, 0xc7, 0x7b, 0x78, 0x2a, 0x5b, 0xfc, 0x90,
    0xa2, 0x6c, 0x6b, 0x2d, 0x1b, 0x69, 0x04, 0x48, 0x50, 0x48, 0x91, 0x6b, 0x95, 0x39, 0x10, 0xdb,
    0x7c, 0xf1, 0x98, 0x36, 0x58, 0xf0, 0x8b, 0x5e, 0x54, 0x94, 0x2f, 0x62, 0x13, 0x25, 0xb3, 0x40,
    0x11, 0x6a, 0xcd, 0x86, 0xb1, 0x37, 0xa5, 0x28, 0xf7, 0xfe, 0xda, 0x54, 0x6d, 0x87, 0x96, 0xab,
    0xcf, 0x62, 0xbf, 0xa2, 0x12, 0xe6, 0xaa, 0xd7, 0x0c, 0xbd, 0x81, 0x1b, 0xd1, 0x27, 0x8f, 0xb7,
    0x70, 0x9c, 0x3f, 0x3c, 0xff, 0x3e, 0x70, 0x2f, 0xd4, 0x68, 0x38, 0x81, 0x5d, 0xa2, 0x98, 0x61,
    0x23, 0x38, 0x6b, 0xfa, 0xb9, 0xe1, 0xbc, 0x43, 0x90, 0xe7, 0xc6, 0x9f, 0x14, 0xa3, 0x6b, 0x9c,
    0x64, 0x47, 0xdd, 0x4b, 0x60, 0x19, 0xec, 0x91, 0x60, 0x3b, 0x15, 0x73, 0xe4, 0x01, 0xac, 0x1b,
    0xbf, 0xc4, 0x39, 0x71, 0xa3, 0xb5, 0x88, 0xfb, 0x72, 0x75, 0xa0, 0x82, 0xf7, 0x35, 0x45, 0xba,
    0xd6, 0xe1, 0x2d, 0x7c, 0x76, 0x13, 0xf6, 0x4a, 0xd5, 0x5c, 0xab, 0x12, 0x82, 0xdc, 0x6a, 0x10,
    0x62, 0x5a, 0xb3, 0x54, 0x38, 0x07, 0xf8, 0x23, 0x29, 0x33, 0xdf, 0x8f, 0xea, 0x7e, 0xc6, 0x84,
    0x25, 0x24, 0x84, 0x69, 0xe3, 0x09, 0x39, 0x61, 0x86, 0x0d, 0x0b, 0x97, 0x59, 0x76, 0xa1, 0x4a,
    0x11, 0x2b, 0x38, 0x4a, 0x0b, 0x8d, 0x3b, 0xb0, 0xf1, 0xdf, 0x22, 0xf5, 0x22, 0x08, 0x81, 0xfd,
    0xff, 0xac, 0xbf, 0x00, 0xe0, 0x6f, 0x76, 0x3d
};
#endif

PyTypeObject *init_QDomImplementation(PyObject *module)
{
    if (SbkPySide6_QtXmlTypeStructs[SBK_QDomImplementation_IDX].type != nullptr)
        return SbkPySide6_QtXmlTypeStructs[SBK_QDomImplementation_IDX].type;

    Shiboken::AutoDecRef Sbk_QDomImplementation_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QDomImplementation_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDomImplementation",
        "QDomImplementation",
        &Sbk_QDomImplementation_spec,
        &Shiboken::callCppDestructor< ::QDomImplementation >,
        Sbk_QDomImplementation_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QDomImplementation_TypeF(); // references _Sbk_QDomImplementation_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QDomImplementation_SignatureStrings);
#else
    InitSignatureBytes(pyType, QDomImplementation_SignatureBytes, QDomImplementation_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDomImplementation_PropertyStrings);
    SbkPySide6_QtXmlTypeStructs[SBK_QDomImplementation_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDomImplementation_PythonToCpp_QDomImplementation_PTR,
        is_QDomImplementation_PythonToCpp_QDomImplementation_PTR_Convertible,
        QDomImplementation_PTR_CppToPython_QDomImplementation,
        QDomImplementation_COPY_CppToPython_QDomImplementation);

    Shiboken::Conversions::registerConverterName(converter, "QDomImplementation");
    Shiboken::Conversions::registerConverterName(converter, "QDomImplementation*");
    Shiboken::Conversions::registerConverterName(converter, "QDomImplementation&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDomImplementation).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QDomImplementation_PythonToCpp_QDomImplementation_COPY,
        is_QDomImplementation_PythonToCpp_QDomImplementation_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QDomImplementation_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'InvalidDataPolicy'.
    const char *InvalidDataPolicy_Initializer[] = {
        "AcceptInvalidChars",
        "DropInvalidChars",
        "ReturnNullNode",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t InvalidDataPolicy_InitializerValues[] = {
        uint8_t(QDomImplementation::InvalidDataPolicy::AcceptInvalidChars), //  0x00  0
        uint8_t(QDomImplementation::InvalidDataPolicy::DropInvalidChars),   //  0x01  1
        uint8_t(QDomImplementation::InvalidDataPolicy::ReturnNullNode)      //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QDomImplementation_TypeF(),
        "2:PySide6.QtXml.QDomImplementation.InvalidDataPolicy",
        InvalidDataPolicy_Initializer, InvalidDataPolicy_InitializerValues);
    SbkPySide6_QtXmlTypeStructs[SBK_QDomImplementation_InvalidDataPolicy_IDX].type = EType;
    // Register converter for enum 'QDomImplementation::InvalidDataPolicy'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QDomImplementation_InvalidDataPolicy_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QDomImplementation_InvalidDataPolicy,
            is_Enum_PythonToCpp_QDomImplementation_InvalidDataPolicy_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QDomImplementation::InvalidDataPolicy");
        Shiboken::Conversions::registerConverterAlias(converter, "InvalidDataPolicy");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'InvalidDataPolicy' enum.

    qRegisterMetaType< ::QDomImplementation >("QDomImplementation");
    qRegisterMetaType< ::QDomImplementation::InvalidDataPolicy >("QDomImplementation::InvalidDataPolicy");

    return pyType;
}
