// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtxml_python.h"

// main header
#include "qdomnamednodemap_wrapper.h"

// Argument includes
#include <QString>
#include <QtXml/qdom.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDomNamedNodeMap_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QDomNamedNodeMap >()))
        return -1;

    ::QDomNamedNodeMap *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QDomNamedNodeMap", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QDomNamedNodeMap::QDomNamedNodeMap()
    // 1: QDomNamedNodeMap::QDomNamedNodeMap(QDomNamedNodeMap)
    if (numArgs == 0) {
        overloadId = 0; // QDomNamedNodeMap()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNamedNodeMap_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QDomNamedNodeMap(QDomNamedNodeMap)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNamedNodeMap_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtXmlTypeStructs[SBK_QDomNamedNodeMap_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QDomNamedNodeMap()
        {

            // QDomNamedNodeMap()
            cptr = new ::QDomNamedNodeMap();
            break;
        }
        case 1: // QDomNamedNodeMap(const QDomNamedNodeMap &namedNodeMap)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QDomNamedNodeMap cppArg0_local;
            ::QDomNamedNodeMap *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QDomNamedNodeMap(QDomNamedNodeMap)
                cptr = new ::QDomNamedNodeMap(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QDomNamedNodeMap >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNamedNodeMap_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QDomNamedNodeMapFunc_contains(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNamedNodeMap *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNamedNodeMap_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDomNamedNodeMap::contains(QString)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // contains(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "contains", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNamedNodeMap_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // contains(QString)const
            bool cppResult = const_cast<const ::QDomNamedNodeMap *>(cppSelf)->contains(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNamedNodeMapFunc_count(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNamedNodeMap *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNamedNodeMap_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // count()const
        int cppResult = const_cast<const ::QDomNamedNodeMap *>(cppSelf)->count();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNamedNodeMapFunc_isEmpty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNamedNodeMap *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNamedNodeMap_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isEmpty()const
        bool cppResult = const_cast<const ::QDomNamedNodeMap *>(cppSelf)->isEmpty();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNamedNodeMapFunc_item(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNamedNodeMap *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNamedNodeMap_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDomNamedNodeMap::item(int)const->QDomNode
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // item(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "item", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNamedNodeMap_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // item(int)const
            QDomNode cppResult = const_cast<const ::QDomNamedNodeMap *>(cppSelf)->item(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNamedNodeMapFunc_length(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNamedNodeMap *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNamedNodeMap_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // length()const
        int cppResult = const_cast<const ::QDomNamedNodeMap *>(cppSelf)->length();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNamedNodeMapFunc_namedItem(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNamedNodeMap *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNamedNodeMap_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDomNamedNodeMap::namedItem(QString)const->QDomNode
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // namedItem(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "namedItem", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNamedNodeMap_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // namedItem(QString)const
            QDomNode cppResult = const_cast<const ::QDomNamedNodeMap *>(cppSelf)->namedItem(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNamedNodeMapFunc_namedItemNS(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNamedNodeMap *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNamedNodeMap_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "namedItemNS", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDomNamedNodeMap::namedItemNS(QString,QString)const->QDomNode
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // namedItemNS(QString,QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "namedItemNS", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNamedNodeMap_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // namedItemNS(QString,QString)const
            QDomNode cppResult = const_cast<const ::QDomNamedNodeMap *>(cppSelf)->namedItemNS(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNamedNodeMapFunc_removeNamedItem(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNamedNodeMap *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNamedNodeMap_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDomNamedNodeMap::removeNamedItem(QString)->QDomNode
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // removeNamedItem(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeNamedItem", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNamedNodeMap_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeNamedItem(QString)
            QDomNode cppResult = cppSelf->removeNamedItem(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNamedNodeMapFunc_removeNamedItemNS(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNamedNodeMap *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNamedNodeMap_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "removeNamedItemNS", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDomNamedNodeMap::removeNamedItemNS(QString,QString)->QDomNode
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // removeNamedItemNS(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "removeNamedItemNS", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNamedNodeMap_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeNamedItemNS(QString,QString)
            QDomNode cppResult = cppSelf->removeNamedItemNS(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNamedNodeMapFunc_setNamedItem(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNamedNodeMap *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNamedNodeMap_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDomNamedNodeMap::setNamedItem(QDomNode)->QDomNode
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), (pyArg)))) {
        overloadId = 0; // setNamedItem(QDomNode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setNamedItem", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNamedNodeMap_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDomNode cppArg0_local;
        ::QDomNode *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setNamedItem(QDomNode)
            QDomNode cppResult = cppSelf->setNamedItem(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNamedNodeMapFunc_setNamedItemNS(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNamedNodeMap *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNamedNodeMap_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDomNamedNodeMap::setNamedItemNS(QDomNode)->QDomNode
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), (pyArg)))) {
        overloadId = 0; // setNamedItemNS(QDomNode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setNamedItemNS", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNamedNodeMap_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDomNode cppArg0_local;
        ::QDomNode *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setNamedItemNS(QDomNode)
            QDomNode cppResult = cppSelf->setNamedItemNS(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNamedNodeMapFunc_size(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNamedNodeMap *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNamedNodeMap_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // size()const
        int cppResult = const_cast<const ::QDomNamedNodeMap *>(cppSelf)->size();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNamedNodeMap__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QDomNamedNodeMap *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNamedNodeMap_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNamedNodeMap_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QDomNamedNodeMap_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDomNamedNodeMap_methods[] = {
    {"contains", reinterpret_cast<PyCFunction>(Sbk_QDomNamedNodeMapFunc_contains), METH_O, nullptr},
    {"count", reinterpret_cast<PyCFunction>(Sbk_QDomNamedNodeMapFunc_count), METH_NOARGS, nullptr},
    {"isEmpty", reinterpret_cast<PyCFunction>(Sbk_QDomNamedNodeMapFunc_isEmpty), METH_NOARGS, nullptr},
    {"item", reinterpret_cast<PyCFunction>(Sbk_QDomNamedNodeMapFunc_item), METH_O, nullptr},
    {"length", reinterpret_cast<PyCFunction>(Sbk_QDomNamedNodeMapFunc_length), METH_NOARGS, nullptr},
    {"namedItem", reinterpret_cast<PyCFunction>(Sbk_QDomNamedNodeMapFunc_namedItem), METH_O, nullptr},
    {"namedItemNS", reinterpret_cast<PyCFunction>(Sbk_QDomNamedNodeMapFunc_namedItemNS), METH_VARARGS, nullptr},
    {"removeNamedItem", reinterpret_cast<PyCFunction>(Sbk_QDomNamedNodeMapFunc_removeNamedItem), METH_O, nullptr},
    {"removeNamedItemNS", reinterpret_cast<PyCFunction>(Sbk_QDomNamedNodeMapFunc_removeNamedItemNS), METH_VARARGS, nullptr},
    {"setNamedItem", reinterpret_cast<PyCFunction>(Sbk_QDomNamedNodeMapFunc_setNamedItem), METH_O, nullptr},
    {"setNamedItemNS", reinterpret_cast<PyCFunction>(Sbk_QDomNamedNodeMapFunc_setNamedItemNS), METH_O, nullptr},
    {"size", reinterpret_cast<PyCFunction>(Sbk_QDomNamedNodeMapFunc_size), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QDomNamedNodeMap__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QDomNamedNodeMap_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QDomNamedNodeMap *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNamedNodeMap_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNamedNodeMap_IDX]), (pyArg)))) {
                // operator!=(const QDomNamedNodeMap &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QDomNamedNodeMap cppArg0_local;
                ::QDomNamedNodeMap *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNamedNodeMap_IDX]), (pyArg)))) {
                // operator==(const QDomNamedNodeMap &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QDomNamedNodeMap cppArg0_local;
                ::QDomNamedNodeMap *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QDomNamedNodeMap_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDomNamedNodeMap_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDomNamedNodeMap_Type = nullptr;
static PyTypeObject *Sbk_QDomNamedNodeMap_TypeF(void)
{
    return _Sbk_QDomNamedNodeMap_Type;
}

static PyType_Slot Sbk_QDomNamedNodeMap_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDomNamedNodeMap_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDomNamedNodeMap_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QDomNamedNodeMap_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDomNamedNodeMap_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDomNamedNodeMap_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDomNamedNodeMap_spec = {
    "2:PySide6.QtXml.QDomNamedNodeMap",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDomNamedNodeMap_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDomNamedNodeMap_PythonToCpp_QDomNamedNodeMap_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDomNamedNodeMap_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDomNamedNodeMap_PythonToCpp_QDomNamedNodeMap_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDomNamedNodeMap_TypeF()))
        return QDomNamedNodeMap_PythonToCpp_QDomNamedNodeMap_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDomNamedNodeMap_PTR_CppToPython_QDomNamedNodeMap(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QDomNamedNodeMap_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QDomNamedNodeMap_COPY_CppToPython_QDomNamedNodeMap(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QDomNamedNodeMap *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QDomNamedNodeMap_TypeF(), new ::QDomNamedNodeMap(*source), true, true);
}

// Python to C++ copy conversion.
static void QDomNamedNodeMap_PythonToCpp_QDomNamedNodeMap_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QDomNamedNodeMap *>(cppOut) = *reinterpret_cast< ::QDomNamedNodeMap *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNamedNodeMap_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QDomNamedNodeMap_PythonToCpp_QDomNamedNodeMap_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QDomNamedNodeMap_TypeF()))
        return QDomNamedNodeMap_PythonToCpp_QDomNamedNodeMap_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QDomNamedNodeMap_SignatureStrings[] = {
    "1:PySide6.QtXml.QDomNamedNodeMap(self)",
    "0:PySide6.QtXml.QDomNamedNodeMap(self,namedNodeMap:PySide6.QtXml.QDomNamedNodeMap)",
    "PySide6.QtXml.QDomNamedNodeMap.contains(self,name:QString)->bool",
    "PySide6.QtXml.QDomNamedNodeMap.count(self)->int",
    "PySide6.QtXml.QDomNamedNodeMap.isEmpty(self)->bool",
    "PySide6.QtXml.QDomNamedNodeMap.item(self,index:int)->PySide6.QtXml.QDomNode",
    "PySide6.QtXml.QDomNamedNodeMap.length(self)->int",
    "PySide6.QtXml.QDomNamedNodeMap.namedItem(self,name:QString)->PySide6.QtXml.QDomNode",
    "PySide6.QtXml.QDomNamedNodeMap.namedItemNS(self,nsURI:QString,localName:QString)->PySide6.QtXml.QDomNode",
    "PySide6.QtXml.QDomNamedNodeMap.removeNamedItem(self,name:QString)->PySide6.QtXml.QDomNode",
    "PySide6.QtXml.QDomNamedNodeMap.removeNamedItemNS(self,nsURI:QString,localName:QString)->PySide6.QtXml.QDomNode",
    "PySide6.QtXml.QDomNamedNodeMap.setNamedItem(self,newNode:PySide6.QtXml.QDomNode)->PySide6.QtXml.QDomNode",
    "PySide6.QtXml.QDomNamedNodeMap.setNamedItemNS(self,newNode:PySide6.QtXml.QDomNode)->PySide6.QtXml.QDomNode",
    "PySide6.QtXml.QDomNamedNodeMap.size(self)->int",
    "PySide6.QtXml.QDomNamedNodeMap.__copy__(self)->typing.Self",
    "PySide6.QtXml.QDomNamedNodeMap.__ne__(self,other:PySide6.QtXml.QDomNamedNodeMap)->bool",
    "PySide6.QtXml.QDomNamedNodeMap.__eq__(self,other:PySide6.QtXml.QDomNamedNodeMap)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QDomNamedNodeMap_SignatureByteSize = 252;
static constexpr uint8_t QDomNamedNodeMap_SignatureBytes[252] = {
    0x78, 0xda, 0xb5, 0x94, 0x31, 0x6f, 0xc2, 0x30, 0x10, 0x85, 0x77, 0x7e, 0x49, 0x23, 0x85, 0xa8,
    0x5d, 0x18, 0x32, 0x30, 0xc1, 0xc0, 0x50, 0x8b, 0x10, 0x55, 0x62, 0xb3, 0xd2, 0xe4, 0x0a, 0x96,
    0xec, 0xbb, 0x34, 0x3e, 0x28, 0xe9, 0xaf, 0xaf, 0x5b, 0x48, 0x40, 0x11, 0xaa, 0x03, 0x22, 0xa3,
    0xed, 0x7b, 0xdf, 0x7b, 0x77, 0xb2, 0xfd, 0x12, 0x2f, 0xeb, 0x54, 0x15, 0x30, 0x89, 0x12, 0x5e,
    0x1b, 0x1d, 0x25, 0x33, 0x32, 0x22, 0x33, 0x50, 0x08, 0x2a, 0xe0, 0x35, 0x2b, 0x9f, 0x2c, 0xe8,
    0x8f, 0x60, 0xf4, 0xdc, 0xa7, 0x2c, 0xc4, 0x8b, 0x1d, 0x8f, 0x20, 0x18, 0xfd, 0x7f, 0x1e, 0xe5,
    0x84, 0x9c, 0x29, 0xb4, 0x67, 0x72, 0x9c, 0xa4, 0x5c, 0x29, 0xdc, 0x04, 0xe3, 0xe9, 0x3b, 0x91,
    0xf6, 0x03, 0x76, 0xc8, 0xc7, 0xf8, 0xe3, 0xa9, 0x42, 0xf6, 0xd5, 0x2b, 0x3b, 0x37, 0x25, 0xd7,
    0x8d, 0xa2, 0x8f, 0x85, 0x62, 0x30, 0xc7, 0x7c, 0x0a, 0x0b, 0x38, 0xc4, 0xce, 0xc5, 0x29, 0xaf,
    0x88, 0x5c, 0xbd, 0x8f, 0xa5, 0x01, 0x37, 0xbc, 0xbd, 0x21, 0xef, 0xdf, 0xb0, 0x17, 0x6d, 0x82,
    0xce, 0x84, 0xee, 0x0b, 0xd1, 0x32, 0x45, 0x7a, 0xa2, 0xda, 0xb7, 0xd5, 0xa2, 0xc1, 0x86, 0x9a,
    0xf2, 0x4c, 0x8b, 0x47, 0x18, 0x55, 0x60, 0x68, 0x0f, 0x62, 0x80, 0x16, 0x3a, 0xe4, 0xa1, 0x1b,
    0xb1, 0xc0, 0xdd, 0x2e, 0xe0, 0xeb, 0xf7, 0x30, 0xbe, 0xce, 0x7b, 0x88, 0x51, 0xdb, 0xd4, 0x40,
    0x56, 0xea, 0x1b, 0x6e, 0xb8, 0x88, 0x52, 0xe6, 0x54, 0xd6, 0x52, 0x36, 0x12, 0xae, 0x4b, 0x37,
    0xd1, 0x28, 0x75, 0x2b, 0xbf, 0x14, 0xe1, 0x24, 0x0c, 0x89, 0xb7, 0x50, 0xf9, 0x7e, 0x8d, 0x7e,
    0xef, 0x52, 0x4a, 0xf8, 0xbc, 0x07, 0xfb, 0x03, 0x5e, 0x92, 0xc8, 0x83
};
#endif

PyTypeObject *init_QDomNamedNodeMap(PyObject *module)
{
    if (SbkPySide6_QtXmlTypeStructs[SBK_QDomNamedNodeMap_IDX].type != nullptr)
        return SbkPySide6_QtXmlTypeStructs[SBK_QDomNamedNodeMap_IDX].type;

    Shiboken::AutoDecRef Sbk_QDomNamedNodeMap_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QDomNamedNodeMap_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDomNamedNodeMap",
        "QDomNamedNodeMap",
        &Sbk_QDomNamedNodeMap_spec,
        &Shiboken::callCppDestructor< ::QDomNamedNodeMap >,
        Sbk_QDomNamedNodeMap_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QDomNamedNodeMap_TypeF(); // references _Sbk_QDomNamedNodeMap_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QDomNamedNodeMap_SignatureStrings);
#else
    InitSignatureBytes(pyType, QDomNamedNodeMap_SignatureBytes, QDomNamedNodeMap_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDomNamedNodeMap_PropertyStrings);
    SbkPySide6_QtXmlTypeStructs[SBK_QDomNamedNodeMap_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDomNamedNodeMap_PythonToCpp_QDomNamedNodeMap_PTR,
        is_QDomNamedNodeMap_PythonToCpp_QDomNamedNodeMap_PTR_Convertible,
        QDomNamedNodeMap_PTR_CppToPython_QDomNamedNodeMap,
        QDomNamedNodeMap_COPY_CppToPython_QDomNamedNodeMap);

    Shiboken::Conversions::registerConverterName(converter, "QDomNamedNodeMap");
    Shiboken::Conversions::registerConverterName(converter, "QDomNamedNodeMap*");
    Shiboken::Conversions::registerConverterName(converter, "QDomNamedNodeMap&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDomNamedNodeMap).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QDomNamedNodeMap_PythonToCpp_QDomNamedNodeMap_COPY,
        is_QDomNamedNodeMap_PythonToCpp_QDomNamedNodeMap_COPY_Convertible);

    qRegisterMetaType< ::QDomNamedNodeMap >("QDomNamedNodeMap");

    return pyType;
}
